@@ -1,22 +1,6 @@
 <?php
 
-/*
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * This software consists of voluntary contributions made by many individuals
- * and is licensed under the MIT license. For more information, see
- * <http://www.doctrine-project.org>.
- */
+declare(strict_types=1);
 
 namespace Doctrine\ORM\Persisters\Entity;
 
@@ -26,24 +10,30 @@ use Doctrine\Common\Util\ClassUtils;
 use Doctrine\DBAL\Connection;
 use Doctrine\DBAL\LockMode;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
-use Doctrine\DBAL\Statement;
+use Doctrine\DBAL\Result;
 use Doctrine\DBAL\Types\Type;
+use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\ORM\Mapping\ClassMetadata;
 use Doctrine\ORM\Mapping\MappingException;
 use Doctrine\ORM\Mapping\QuoteStrategy;
 use Doctrine\ORM\OptimisticLockException;
-use Doctrine\ORM\ORMException;
 use Doctrine\ORM\PersistentCollection;
+use Doctrine\ORM\Persisters\Exception\CantUseInOperatorOnCompositeKeys;
+use Doctrine\ORM\Persisters\Exception\InvalidOrientation;
+use Doctrine\ORM\Persisters\Exception\UnrecognizedField;
 use Doctrine\ORM\Persisters\SqlExpressionVisitor;
 use Doctrine\ORM\Persisters\SqlValueVisitor;
 use Doctrine\ORM\Query;
 use Doctrine\ORM\Query\QueryException;
+use Doctrine\ORM\Repository\Exception\InvalidFindByCall;
 use Doctrine\ORM\UnitOfWork;
 use Doctrine\ORM\Utility\IdentifierFlattener;
 use Doctrine\ORM\Utility\PersisterHelper;
+use LengthException;
 
 use function array_combine;
+use function array_keys;
 use function array_map;
 use function array_merge;
 use function array_search;
@@ -51,12 +41,11 @@ use function array_unique;
 use function array_values;
 use function assert;
 use function count;
-use function get_class;
 use function implode;
 use function is_array;
 use function is_object;
 use function reset;
-use function spl_object_hash;
+use function spl_object_id;
 use function sprintf;
 use function strpos;
 use function strtoupper;
@@ -145,7 +134,7 @@ class BasicEntityPersister implements EntityPersister
     /**
      * Queued inserts.
      *
-     * @psalm-var array<string, object>
+     * @psalm-var array<int, object>
      */
     protected $queuedInserts = [];
 
@@ -246,7 +235,7 @@ class BasicEntityPersister implements EntityPersister
      */
     public function addInsert($entity)
     {
-        $this->queuedInserts[spl_object_hash($entity)] = $entity;
+        $this->queuedInserts[spl_object_id($entity)] = $entity;
     }
 
     /**
@@ -284,10 +273,10 @@ class BasicEntityPersister implements EntityPersister
                 }
             }
 
-            $stmt->execute();
+            $stmt->executeStatement();
 
             if ($isPostInsertId) {
-                $generatedId     = $idGenerator->generate($this->em, $entity);
+                $generatedId     = $idGenerator->generateId($this->em, $entity);
                 $id              = [$this->class->identifier[0] => $generatedId];
                 $postInsertIds[] = [
                     'generatedId' => $generatedId,
@@ -297,12 +286,11 @@ class BasicEntityPersister implements EntityPersister
                 $id = $this->class->getIdentifierValues($entity);
             }
 
-            if ($this->class->isVersioned) {
-                $this->assignDefaultVersionValue($entity, $id);
+            if ($this->class->requiresFetchAfterChange) {
+                $this->assignDefaultVersionAndUpsertableValues($entity, $id);
             }
         }
 
-        $stmt->closeCursor();
         $this->queuedInserts = [];
 
         return $postInsertIds;
@@ -311,59 +299,78 @@ class BasicEntityPersister implements EntityPersister
     /**
      * Retrieves the default version value which was created
      * by the preceding INSERT statement and assigns it back in to the
-     * entities version field.
+     * entities version field if the given entity is versioned.
+     * Also retrieves values of columns marked as 'non insertable' and / or
+     * 'not updatable' and assigns them back to the entities corresponding fields.
      *
      * @param object  $entity
      * @param mixed[] $id
      *
      * @return void
      */
-    protected function assignDefaultVersionValue($entity, array $id)
+    protected function assignDefaultVersionAndUpsertableValues($entity, array $id)
     {
-        $value = $this->fetchVersionValue($this->class, $id);
+        $values = $this->fetchVersionAndNotUpsertableValues($this->class, $id);
 
-        $this->class->setFieldValue($entity, $this->class->versionField, $value);
+        foreach ($values as $field => $value) {
+            $value = Type::getType($this->class->fieldMappings[$field]['type'])->convertToPHPValue($value, $this->platform);
+
+            $this->class->setFieldValue($entity, $field, $value);
+        }
     }
 
     /**
-     * Fetches the current version value of a versioned entity.
+     * Fetches the current version value of a versioned entity and / or the values of fields
+     * marked as 'not insertable' and / or 'not updatable'.
      *
      * @param ClassMetadata $versionedClass
      * @param mixed[]       $id
      *
      * @return mixed
      */
-    protected function fetchVersionValue($versionedClass, array $id)
+    protected function fetchVersionAndNotUpsertableValues($versionedClass, array $id)
     {
-        $versionField = $versionedClass->versionField;
-        $fieldMapping = $versionedClass->fieldMappings[$versionField];
-        $tableName    = $this->quoteStrategy->getTableName($versionedClass, $this->platform);
-        $identifier   = $this->quoteStrategy->getIdentifierColumnNames($versionedClass, $this->platform);
-        $columnName   = $this->quoteStrategy->getColumnName($versionField, $versionedClass, $this->platform);
+        $columnNames = [];
+        foreach ($this->class->fieldMappings as $key => $column) {
+            if (isset($column['generated']) || ($this->class->isVersioned && $key === $versionedClass->versionField)) {
+                $columnNames[$key] = $this->quoteStrategy->getColumnName($key, $versionedClass, $this->platform);
+            }
+        }
+
+        $tableName  = $this->quoteStrategy->getTableName($versionedClass, $this->platform);
+        $identifier = $this->quoteStrategy->getIdentifierColumnNames($versionedClass, $this->platform);
 
         // FIXME: Order with composite keys might not be correct
-        $sql = 'SELECT ' . $columnName
-             . ' FROM ' . $tableName
-             . ' WHERE ' . implode(' = ? AND ', $identifier) . ' = ?';
+        $sql = 'SELECT ' . implode(', ', $columnNames)
+            . ' FROM ' . $tableName
+            . ' WHERE ' . implode(' = ? AND ', $identifier) . ' = ?';
 
         $flatId = $this->identifierFlattener->flattenIdentifier($versionedClass, $id);
 
-        $value = $this->conn->fetchColumn(
+        $values = $this->conn->fetchNumeric(
             $sql,
             array_values($flatId),
-            0,
             $this->extractIdentifierTypes($id, $versionedClass)
         );
 
-        return Type::getType($fieldMapping['type'])->convertToPHPValue($value, $this->platform);
+        if ($values === false) {
+            throw new LengthException('Unexpected empty result for database query.');
+        }
+
+        $values = array_combine(array_keys($columnNames), $values);
+
+        if (! $values) {
+            throw new LengthException('Unexpected number of database columns.');
+        }
+
+        return $values;
     }
 
     /**
      * @param mixed[] $id
      *
      * @return int[]|null[]|string[]
-     *
-     * @psalm-return list<(int|string|null)>
+     * @psalm-return list<int|string|null>
      */
     private function extractIdentifierTypes(array $id, ClassMetadata $versionedClass): array
     {
@@ -399,10 +406,10 @@ class BasicEntityPersister implements EntityPersister
 
         $this->updateTable($entity, $quotedTableName, $data, $isVersioned);
 
-        if ($isVersioned) {
+        if ($this->class->requiresFetchAfterChange) {
             $id = $this->class->getIdentifierValues($entity);
 
-            $this->assignDefaultVersionValue($entity, $id);
+            $this->assignDefaultVersionAndUpsertableValues($entity, $id);
         }
     }
 
@@ -415,13 +422,15 @@ class BasicEntityPersister implements EntityPersister
      * @param mixed[] $updateData      The map of columns to update (column => value).
      * @param bool    $versioned       Whether the UPDATE should be versioned.
      *
-     * @return void
-     *
-     * @throws ORMException
+     * @throws UnrecognizedField
      * @throws OptimisticLockException
      */
-    final protected function updateTable($entity, $quotedTableName, array $updateData, $versioned = false)
-    {
+    final protected function updateTable(
+        $entity,
+        $quotedTableName,
+        array $updateData,
+        $versioned = false
+    ): void {
         $set    = [];
         $types  = [];
         $params = [];
@@ -476,7 +485,7 @@ class BasicEntityPersister implements EntityPersister
             $targetType    = PersisterHelper::getTypeOfField($targetMapping->identifier[0], $targetMapping, $this->em);
 
             if ($targetType === []) {
-                throw ORMException::unrecognizedField($targetMapping->identifier[0]);
+                throw UnrecognizedField::byName($targetMapping->identifier[0]);
             }
 
             $types[] = reset($targetType);
@@ -492,13 +501,13 @@ class BasicEntityPersister implements EntityPersister
             $params[] = $this->class->reflFields[$versionField]->getValue($entity);
 
             switch ($versionFieldType) {
-                case Type::SMALLINT:
-                case Type::INTEGER:
-                case Type::BIGINT:
+                case Types::SMALLINT:
+                case Types::INTEGER:
+                case Types::BIGINT:
                     $set[] = $versionColumn . ' = ' . $versionColumn . ' + 1';
                     break;
 
-                case Type::DATETIME:
+                case Types::DATETIME_MUTABLE:
                     $set[] = $versionColumn . ' = CURRENT_TIMESTAMP';
                     break;
             }
@@ -508,7 +517,7 @@ class BasicEntityPersister implements EntityPersister
              . ' SET ' . implode(', ', $set)
              . ' WHERE ' . implode(' = ? AND ', $where) . ' = ?';
 
-        $result = $this->conn->executeUpdate($sql, $params, $types);
+        $result = $this->conn->executeStatement($sql, $params, $types);
 
         if ($versioned && ! $result) {
             throw OptimisticLockException::lockFailed($entity);
@@ -608,13 +617,13 @@ class BasicEntityPersister implements EntityPersister
      * )
      * </code>
      *
-     * @param object $entity The entity for which to prepare the data.
+     * @param object $entity   The entity for which to prepare the data.
+     * @param bool   $isInsert Whether the data to be prepared refers to an insert statement.
      *
      * @return mixed[][] The prepared data.
-     *
      * @psalm-return array<string, array<array-key, mixed|null>>
      */
-    protected function prepareUpdateData($entity)
+    protected function prepareUpdateData($entity, bool $isInsert = false)
     {
         $versionField = null;
         $result       = [];
@@ -640,6 +649,14 @@ class BasicEntityPersister implements EntityPersister
                 $fieldMapping = $this->class->fieldMappings[$field];
                 $columnName   = $fieldMapping['columnName'];
 
+                if (! $isInsert && isset($fieldMapping['notUpdatable'])) {
+                    continue;
+                }
+
+                if ($isInsert && isset($fieldMapping['notInsertable'])) {
+                    continue;
+                }
+
                 $this->columnTypes[$columnName] = $fieldMapping['type'];
 
                 $result[$this->getOwningTable($field)][$columnName] = $newVal;
@@ -655,7 +672,7 @@ class BasicEntityPersister implements EntityPersister
             }
 
             if ($newVal !== null) {
-                $oid = spl_object_hash($newVal);
+                $oid = spl_object_id($newVal);
 
                 if (isset($this->queuedInserts[$oid]) || $uow->isScheduledForInsert($newVal)) {
                     // The associated entity $newVal is not yet persisted, so we must
@@ -703,12 +720,11 @@ class BasicEntityPersister implements EntityPersister
      * @param object $entity The entity for which to prepare the data.
      *
      * @return mixed[][] The prepared data for the tables to update.
-     *
      * @psalm-return array<string, mixed[]>
      */
     protected function prepareInsertData($entity)
     {
-        return $this->prepareUpdateData($entity);
+        return $this->prepareUpdateData($entity, true);
     }
 
     /**
@@ -772,12 +788,6 @@ class BasicEntityPersister implements EntityPersister
                 $hints['fetched']['r'][$assoc['inversedBy']] = true;
             }
 
-            /* cascade read-only status
-            if ($this->em->getUnitOfWork()->isReadOnly($sourceEntity)) {
-                $hints[Query::HINT_READ_ONLY] = true;
-            }
-            */
-
             $targetEntity = $this->load($identifier, null, $assoc, $hints);
 
             // Complete bidirectional association, if necessary
@@ -839,7 +849,7 @@ class BasicEntityPersister implements EntityPersister
             ? $this->expandCriteriaParameters($criteria)
             : $this->expandParameters($criteria);
 
-        return (int) $this->conn->executeQuery($sql, $params, $types)->fetchColumn();
+        return (int) $this->conn->executeQuery($sql, $params, $types)->fetchOne();
     }
 
     /**
@@ -916,18 +926,17 @@ class BasicEntityPersister implements EntityPersister
 
         $stmt = $this->getManyToManyStatement($assoc, $sourceEntity, $offset, $limit);
 
-        return $this->loadArrayFromStatement($assoc, $stmt);
+        return $this->loadArrayFromResult($assoc, $stmt);
     }
 
     /**
      * Loads an array of entities from a given DBAL statement.
      *
-     * @param mixed[]   $assoc
-     * @param Statement $stmt
+     * @param mixed[] $assoc
      *
      * @return mixed[]
      */
-    private function loadArrayFromStatement($assoc, $stmt)
+    private function loadArrayFromResult(array $assoc, Result $stmt): array
     {
         $rsm   = $this->currentPersisterContext->rsm;
         $hints = [UnitOfWork::HINT_DEFEREAGERLOAD => true];
@@ -943,14 +952,15 @@ class BasicEntityPersister implements EntityPersister
     /**
      * Hydrates a collection from a given DBAL statement.
      *
-     * @param mixed[]              $assoc
-     * @param Statement            $stmt
-     * @param PersistentCollection $coll
+     * @param mixed[] $assoc
      *
      * @return mixed[]
      */
-    private function loadCollectionFromStatement($assoc, $stmt, $coll)
-    {
+    private function loadCollectionFromStatement(
+        array $assoc,
+        Result $stmt,
+        PersistentCollection $coll
+    ): array {
         $rsm   = $this->currentPersisterContext->rsm;
         $hints = [
             UnitOfWork::HINT_DEFEREAGERLOAD => true,
@@ -976,15 +986,16 @@ class BasicEntityPersister implements EntityPersister
     }
 
     /**
-     * @return \Doctrine\DBAL\Driver\Statement
+     * @param object $sourceEntity
+     * @psalm-param array<string, mixed> $assoc
+     *
+     * @return Result
      *
      * @throws MappingException
-     *
-     * @psalm-param array<string, mixed> $assoc
      */
     private function getManyToManyStatement(
         array $assoc,
-        object $sourceEntity,
+        $sourceEntity,
         ?int $offset = null,
         ?int $limit = null
     ) {
@@ -1102,14 +1113,14 @@ class BasicEntityPersister implements EntityPersister
         $from   = ' FROM ' . $tableName . ' ' . $tableAlias;
         $join   = $this->currentPersisterContext->selectJoinSql . $joinSql;
         $where  = ($conditionSql ? ' WHERE ' . $conditionSql : '');
-        $lock   = $this->platform->appendLockHint($from, $lockMode);
+        $lock   = $this->platform->appendLockHint($from, $lockMode ?? LockMode::NONE);
         $query  = $select
             . $lock
             . $join
             . $where
             . $orderBySql;
 
-        return $this->platform->modifyLimitQuery($query, $limit, $offset) . $lockSql;
+        return $this->platform->modifyLimitQuery($query, $limit, $offset ?? 0) . $lockSql;
     }
 
     /**
@@ -1140,9 +1151,11 @@ class BasicEntityPersister implements EntityPersister
     /**
      * Gets the ORDER BY SQL snippet for ordered collections.
      *
-     * @throws ORMException
-     *
      * @psalm-param array<string, string> $orderBy
+     *
+     * @throws InvalidOrientation
+     * @throws InvalidFindByCall
+     * @throws UnrecognizedField
      */
     final protected function getOrderBySQL(array $orderBy, string $baseTableAlias): string
     {
@@ -1152,7 +1165,7 @@ class BasicEntityPersister implements EntityPersister
             $orientation = strtoupper(trim($orientation));
 
             if ($orientation !== 'ASC' && $orientation !== 'DESC') {
-                throw ORMException::invalidOrientation($this->class->name, $fieldName);
+                throw InvalidOrientation::fromClassNameAndField($this->class->name, $fieldName);
             }
 
             if (isset($this->class->fieldMappings[$fieldName])) {
@@ -1168,7 +1181,7 @@ class BasicEntityPersister implements EntityPersister
 
             if (isset($this->class->associationMappings[$fieldName])) {
                 if (! $this->class->associationMappings[$fieldName]['isOwningSide']) {
-                    throw ORMException::invalidFindByInverseAssociation($this->class->name, $fieldName);
+                    throw InvalidFindByCall::fromInverseSideUsage($this->class->name, $fieldName);
                 }
 
                 $tableAlias = isset($this->class->associationMappings[$fieldName]['inherited'])
@@ -1183,7 +1196,7 @@ class BasicEntityPersister implements EntityPersister
                 continue;
             }
 
-            throw ORMException::unrecognizedField($fieldName);
+            throw UnrecognizedField::byName($fieldName);
         }
 
         return ' ORDER BY ' . implode(', ', $orderByList);
@@ -1350,9 +1363,9 @@ class BasicEntityPersister implements EntityPersister
      * Gets the SQL join fragment used when selecting entities from a
      * many-to-many association.
      *
-     * @return string
-     *
      * @psalm-param array<string, mixed> $manyToMany
+     *
+     * @return string
      */
     protected function getSelectManyToManyJoinSQL(array $manyToMany)
     {
@@ -1431,7 +1444,6 @@ class BasicEntityPersister implements EntityPersister
      * columns placed in the INSERT statements used by the persister.
      *
      * @return string[] The list of columns.
-     *
      * @psalm-return list<string>
      */
     protected function getInsertColumnList()
@@ -1460,6 +1472,10 @@ class BasicEntityPersister implements EntityPersister
             }
 
             if (! $this->class->isIdGeneratorIdentity() || $this->class->identifier[0] !== $name) {
+                if (isset($this->class->fieldMappings[$name]['notInsertable'])) {
+                    continue;
+                }
+
                 $columns[]                = $this->quoteStrategy->getColumnName($name, $this->class, $this->platform);
                 $this->columnTypes[$name] = $this->class->fieldMappings[$name]['type'];
             }
@@ -1557,6 +1573,7 @@ class BasicEntityPersister implements EntityPersister
      * Gets the FROM and optionally JOIN conditions to lock the entity managed by this persister.
      *
      * @param int|null $lockMode One of the Doctrine\DBAL\LockMode::* constants.
+     * @psalm-param LockMode::*|null $lockMode
      *
      * @return string
      */
@@ -1566,7 +1583,7 @@ class BasicEntityPersister implements EntityPersister
             'FROM '
             . $this->quoteStrategy->getTableName($this->class, $this->platform) . ' '
             . $this->getSQLTableAlias($this->class->name),
-            $lockMode
+            $lockMode ?? LockMode::NONE
         );
     }
 
@@ -1601,7 +1618,7 @@ class BasicEntityPersister implements EntityPersister
              *  @todo try to support multi-column IN expressions.
              *  Example: (col1, col2) IN (('val1A', 'val2A'), ('val1B', 'val2B'))
              */
-            throw ORMException::cantUseInOperatorOnCompositeKeys();
+            throw CantUseInOperatorOnCompositeKeys::create();
         }
 
         foreach ($columns as $column) {
@@ -1660,17 +1677,18 @@ class BasicEntityPersister implements EntityPersister
     /**
      * Builds the left-hand-side of a where condition statement.
      *
-     * @param string $field
+     * @psalm-param array<string, mixed>|null $assoc
      *
      * @return string[]
-     *
-     * @throws ORMException
-     *
-     * @psalm-param array<string, mixed>|null $assoc
      * @psalm-return list<string>
+     *
+     * @throws InvalidFindByCall
+     * @throws UnrecognizedField
      */
-    private function getSelectConditionStatementColumnSQL($field, $assoc = null)
-    {
+    private function getSelectConditionStatementColumnSQL(
+        string $field,
+        ?array $assoc = null
+    ): array {
         if (isset($this->class->fieldMappings[$field])) {
             $className = $this->class->fieldMappings[$field]['inherited'] ?? $this->class->name;
 
@@ -1698,7 +1716,10 @@ class BasicEntityPersister implements EntityPersister
                 }
             } else {
                 if (! $association['isOwningSide']) {
-                    throw ORMException::invalidFindByInverseAssociation($this->class->name, $field);
+                    throw InvalidFindByCall::fromInverseSideUsage(
+                        $this->class->name,
+                        $field
+                    );
                 }
 
                 $className = $association['inherited'] ?? $this->class->name;
@@ -1719,7 +1740,7 @@ class BasicEntityPersister implements EntityPersister
             return [$field];
         }
 
-        throw ORMException::unrecognizedField($field);
+        throw UnrecognizedField::byName($field);
     }
 
     /**
@@ -1729,10 +1750,11 @@ class BasicEntityPersister implements EntityPersister
      * Subclasses are supposed to override this method if they intend to change
      * or alter the criteria by which entities are selected.
      *
-     * @return string
-     *
+     * @param mixed[]|null $assoc
      * @psalm-param array<string, mixed> $criteria
      * @psalm-param array<string, mixed>|null $assoc
+     *
+     * @return string
      */
     protected function getSelectConditionSQL(array $criteria, $assoc = null)
     {
@@ -1754,7 +1776,7 @@ class BasicEntityPersister implements EntityPersister
 
         $stmt = $this->getOneToManyStatement($assoc, $sourceEntity, $offset, $limit);
 
-        return $this->loadArrayFromStatement($assoc, $stmt);
+        return $this->loadArrayFromResult($assoc, $stmt);
     }
 
     /**
@@ -1770,16 +1792,15 @@ class BasicEntityPersister implements EntityPersister
     /**
      * Builds criteria and execute SQL statement to fetch the one to many entities from.
      *
-     * @param object   $sourceEntity
-     * @param int|null $offset
-     * @param int|null $limit
-     *
-     * @return Statement
-     *
+     * @param object $sourceEntity
      * @psalm-param array<string, mixed> $assoc
      */
-    private function getOneToManyStatement(array $assoc, $sourceEntity, $offset = null, $limit = null)
-    {
+    private function getOneToManyStatement(
+        array $assoc,
+        $sourceEntity,
+        ?int $offset = null,
+        ?int $limit = null
+    ): Result {
         $this->switchPersisterContext($offset, $limit);
 
         $criteria    = [];
@@ -1855,10 +1876,9 @@ class BasicEntityPersister implements EntityPersister
      *                             - class to which the field belongs to
      *
      * @return mixed[][]
-     *
-     * @psalm-return array{0: array, 1: list<mixed>}
+     * @psalm-return array{0: array, 1: list<int|string|null>}
      */
-    private function expandToManyParameters($criteria)
+    private function expandToManyParameters(array $criteria): array
     {
         $params = [];
         $types  = [];
@@ -1878,16 +1898,14 @@ class BasicEntityPersister implements EntityPersister
     /**
      * Infers field types to be used by parameter type casting.
      *
-     * @param string $field
-     * @param mixed  $value
+     * @param mixed $value
      *
      * @return int[]|null[]|string[]
+     * @psalm-return list<int|string|null>
      *
      * @throws QueryException
-     *
-     * @psalm-return list<(int|string|null)>
      */
-    private function getTypes($field, $value, ClassMetadata $class)
+    private function getTypes(string $field, $value, ClassMetadata $class): array
     {
         $types = [];
 
@@ -1936,9 +1954,9 @@ class BasicEntityPersister implements EntityPersister
      *
      * @param mixed $value
      *
-     * @return array{mixed}
+     * @return mixed[]
      */
-    private function getValues($value)
+    private function getValues($value): array
     {
         if (is_array($value)) {
             $newValue = [];
@@ -1950,20 +1968,7 @@ class BasicEntityPersister implements EntityPersister
             return [$newValue];
         }
 
-        if (is_object($value) && $this->em->getMetadataFactory()->hasMetadataFor(ClassUtils::getClass($value))) {
-            $class = $this->em->getClassMetadata(get_class($value));
-            if ($class->isIdentifierComposite) {
-                $newValue = [];
-
-                foreach ($class->getIdentifierValues($value) as $innerValue) {
-                    $newValue = array_merge($newValue, $this->getValues($innerValue));
-                }
-
-                return $newValue;
-            }
-        }
-
-        return [$this->getIndividualValue($value)];
+        return $this->getIndividualValue($value);
     }
 
     /**
@@ -1971,15 +1976,34 @@ class BasicEntityPersister implements EntityPersister
      *
      * @param mixed $value
      *
-     * @return mixed
+     * @return       array<mixed>
+     * @psalm-return list<mixed>
      */
     private function getIndividualValue($value)
     {
-        if (! is_object($value) || ! $this->em->getMetadataFactory()->hasMetadataFor(ClassUtils::getClass($value))) {
-            return $value;
+        if (! is_object($value)) {
+            return [$value];
         }
 
-        return $this->em->getUnitOfWork()->getSingleIdentifierValue($value);
+        $valueClass = ClassUtils::getClass($value);
+
+        if ($this->em->getMetadataFactory()->isTransient($valueClass)) {
+            return [$value];
+        }
+
+        $class = $this->em->getClassMetadata($valueClass);
+
+        if ($class->isIdentifierComposite) {
+            $newValue = [];
+
+            foreach ($class->getIdentifierValues($value) as $innerValue) {
+                $newValue = array_merge($newValue, $this->getValues($innerValue));
+            }
+
+            return $newValue;
+        }
+
+        return [$this->em->getUnitOfWork()->getSingleIdentifierValue($value)];
     }
 
     /**
@@ -2014,15 +2038,16 @@ class BasicEntityPersister implements EntityPersister
             $sql .= ' AND ' . $filterSql;
         }
 
-        return (bool) $this->conn->fetchColumn($sql, $params, 0, $types);
+        return (bool) $this->conn->fetchOne($sql, $params, $types);
     }
 
     /**
      * Generates the appropriate join SQL for the given join column.
      *
-     * @return string LEFT JOIN if one of the columns is nullable, INNER JOIN otherwise.
+     * @param array[] $joinColumns The join columns definition of an association.
+     * @psalm-param array<array<string, mixed>> $joinColumns
      *
-     * @psalm-param array<array<string, mixed>> $joinColumns The join columns definition of an association.
+     * @return string LEFT JOIN if one of the columns is nullable, INNER JOIN otherwise.
      */
     protected function getJoinSQLForJoinColumns($joinColumns)
     {
@@ -2077,6 +2102,8 @@ class BasicEntityPersister implements EntityPersister
      *
      * @param int|null $offset
      * @param int|null $limit
+     *
+     * @return void
      */
     protected function switchPersisterContext($offset, $limit)
     {
@@ -2091,6 +2118,7 @@ class BasicEntityPersister implements EntityPersister
 
     /**
      * @return string[]
+     * @psalm-return list<string>
      */
     protected function getClassIdentifiersTypes(ClassMetadata $class): array
     {
