@@ -1,74 +1,56 @@
 <?php
-/*
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * This software consists of voluntary contributions made by many individuals
- * and is licensed under the MIT license. For more information, see
- * <http://www.doctrine-project.org>.
- */
+
+declare(strict_types=1);
 
 namespace Doctrine\ORM\Query;
 
+use Doctrine\DBAL\Types\Type;
 use Doctrine\ORM\EntityManagerInterface;
+use Doctrine\ORM\Internal\SQLResultCasing;
 use Doctrine\ORM\Mapping\ClassMetadataInfo;
 use Doctrine\ORM\Mapping\MappingException;
 use Doctrine\ORM\Utility\PersisterHelper;
+use InvalidArgumentException;
+
 use function explode;
+use function in_array;
+use function sprintf;
+use function strpos;
+use function strtolower;
 
 /**
  * A ResultSetMappingBuilder uses the EntityManager to automatically populate entity fields.
- *
- * @author Michael Ridgway <mcridgway@gmail.com>
- * @since 2.1
  */
 class ResultSetMappingBuilder extends ResultSetMapping
 {
+    use SQLResultCasing;
+
     /**
      * Picking this rename mode will register entity columns as is,
      * as they are in the database. This can cause clashes when multiple
      * entities are fetched that have columns with the same name.
-     *
-     * @var int
      */
-    const COLUMN_RENAMING_NONE = 1;
+    public const COLUMN_RENAMING_NONE = 1;
 
     /**
      * Picking custom renaming allows the user to define the renaming
      * of specific columns with a rename array that contains column names as
      * keys and result alias as values.
-     *
-     * @var int
      */
-    const COLUMN_RENAMING_CUSTOM = 2;
+    public const COLUMN_RENAMING_CUSTOM = 2;
 
     /**
      * Incremental renaming uses a result set mapping internal counter to add a
      * number to each column result, leading to uniqueness. This only works if
      * you use {@see generateSelectClause()} to generate the SELECT clause for
      * you.
-     *
-     * @var int
      */
-    const COLUMN_RENAMING_INCREMENT = 3;
+    public const COLUMN_RENAMING_INCREMENT = 3;
 
-    /**
-     * @var int
-     */
+    /** @var int */
     private $sqlCounter = 0;
 
-    /**
-     * @var EntityManagerInterface
-     */
+    /** @var EntityManagerInterface */
     private $em;
 
     /**
@@ -79,8 +61,7 @@ class ResultSetMappingBuilder extends ResultSetMapping
     private $defaultRenameMode;
 
     /**
-     * @param EntityManagerInterface $em
-     * @param integer                $defaultRenameMode
+     * @param int $defaultRenameMode
      */
     public function __construct(EntityManagerInterface $em, $defaultRenameMode = self::COLUMN_RENAMING_NONE)
     {
@@ -93,8 +74,9 @@ class ResultSetMappingBuilder extends ResultSetMapping
      *
      * @param string   $class          The class name of the root entity.
      * @param string   $alias          The unique alias to use for the root entity.
-     * @param array    $renamedColumns Columns that have been renamed (tableColumnName => queryColumnName).
+     * @param string[] $renamedColumns Columns that have been renamed (tableColumnName => queryColumnName).
      * @param int|null $renameMode     One of the COLUMN_RENAMING_* constants or array for BC reasons (CUSTOM).
+     * @psalm-param array<string, string> $renamedColumns
      *
      * @return void
      */
@@ -115,8 +97,9 @@ class ResultSetMappingBuilder extends ResultSetMapping
      * @param string   $parentAlias    The alias of the entity result that is the parent of this joined result.
      * @param string   $relation       The association field that connects the parent entity result
      *                                 with the joined entity result.
-     * @param array    $renamedColumns Columns that have been renamed (tableColumnName => queryColumnName).
+     * @param string[] $renamedColumns Columns that have been renamed (tableColumnName => queryColumnName).
      * @param int|null $renameMode     One of the COLUMN_RENAMING_* constants or array for BC reasons (CUSTOM).
+     * @psalm-param array<string, string> $renamedColumns
      *
      * @return void
      */
@@ -132,30 +115,33 @@ class ResultSetMappingBuilder extends ResultSetMapping
     /**
      * Adds all fields of the given class to the result set mapping (columns and meta fields).
      *
-     * @param string $class
-     * @param string $alias
-     * @param array  $columnAliasMap
+     * @param string   $class
+     * @param string   $alias
+     * @param string[] $columnAliasMap
+     * @psalm-param array<string, string> $columnAliasMap
      *
      * @return void
      *
-     * @throws \InvalidArgumentException
+     * @throws InvalidArgumentException
      */
     protected function addAllClassFields($class, $alias, $columnAliasMap = [])
     {
         $classMetadata = $this->em->getClassMetadata($class);
         $platform      = $this->em->getConnection()->getDatabasePlatform();
 
-        if ( ! $this->isInheritanceSupported($classMetadata)) {
-            throw new \InvalidArgumentException('ResultSetMapping builder does not currently support your inheritance scheme.');
+        if (! $this->isInheritanceSupported($classMetadata)) {
+            throw new InvalidArgumentException('ResultSetMapping builder does not currently support your inheritance scheme.');
         }
 
-
         foreach ($classMetadata->getColumnNames() as $columnName) {
             $propertyName = $classMetadata->getFieldName($columnName);
-            $columnAlias  = $platform->getSQLResultCasing($columnAliasMap[$columnName]);
+            $columnAlias  = $this->getSQLResultCasing($platform, $columnAliasMap[$columnName]);
 
             if (isset($this->fieldMappings[$columnAlias])) {
-                throw new \InvalidArgumentException("The column '$columnName' conflicts with another column in the mapper.");
+                throw new InvalidArgumentException(sprintf(
+                    "The column '%s' conflicts with another column in the mapper.",
+                    $columnName
+                ));
             }
 
             $this->addFieldResult($alias, $columnAlias, $propertyName);
@@ -168,11 +154,14 @@ class ResultSetMappingBuilder extends ResultSetMapping
 
                 foreach ($associationMapping['joinColumns'] as $joinColumn) {
                     $columnName  = $joinColumn['name'];
-                    $columnAlias = $platform->getSQLResultCasing($columnAliasMap[$columnName]);
-                    $columnType = PersisterHelper::getTypeOfColumn($joinColumn['referencedColumnName'], $targetClass, $this->em);
+                    $columnAlias = $this->getSQLResultCasing($platform, $columnAliasMap[$columnName]);
+                    $columnType  = PersisterHelper::getTypeOfColumn($joinColumn['referencedColumnName'], $targetClass, $this->em);
 
                     if (isset($this->metaMappings[$columnAlias])) {
-                        throw new \InvalidArgumentException("The column '$columnAlias' conflicts with another column in the mapper.");
+                        throw new InvalidArgumentException(sprintf(
+                            "The column '%s' conflicts with another column in the mapper.",
+                            $columnAlias
+                        ));
                     }
 
                     $this->addMetaResult($alias, $columnAlias, $columnName, $isIdentifier, $columnType);
@@ -181,10 +170,12 @@ class ResultSetMappingBuilder extends ResultSetMapping
         }
     }
 
-    private function isInheritanceSupported(ClassMetadataInfo $classMetadata)
+    private function isInheritanceSupported(ClassMetadataInfo $classMetadata): bool
     {
-        if ($classMetadata->isInheritanceTypeSingleTable()
-            && in_array($classMetadata->name, $classMetadata->discriminatorMap, true)) {
+        if (
+            $classMetadata->isInheritanceTypeSingleTable()
+            && in_array($classMetadata->name, $classMetadata->discriminatorMap, true)
+        ) {
             return true;
         }
 
@@ -194,13 +185,9 @@ class ResultSetMappingBuilder extends ResultSetMapping
     /**
      * Gets column alias for a given column.
      *
-     * @param string $columnName
-     * @param int    $mode
-     * @param array  $customRenameColumns
-     *
-     * @return string
+     * @psalm-param array<string, string>  $customRenameColumns
      */
-    private function getColumnAlias($columnName, $mode, array $customRenameColumns)
+    private function getColumnAlias(string $columnName, int $mode, array $customRenameColumns): string
     {
         switch ($mode) {
             case self::COLUMN_RENAMING_INCREMENT:
@@ -212,6 +199,11 @@ class ResultSetMappingBuilder extends ResultSetMapping
             case self::COLUMN_RENAMING_NONE:
                 return $columnName;
 
+            default:
+                throw new InvalidArgumentException(sprintf(
+                    '%d is not a valid value for $mode',
+                    $mode
+                ));
         }
     }
 
@@ -220,16 +212,18 @@ class ResultSetMappingBuilder extends ResultSetMapping
      *
      * This depends on the renaming mode selected by the user.
      *
-     * @param string $className
-     * @param int    $mode
-     * @param array  $customRenameColumns
+     * @psalm-param class-string $className
+     * @psalm-param self::COLUMN_RENAMING_* $mode
+     * @psalm-param array<string, string> $customRenameColumns
      *
      * @return string[]
-     *
      * @psalm-return array<array-key, string>
      */
-    private function getColumnAliasMap($className, $mode, array $customRenameColumns)
-    {
+    private function getColumnAliasMap(
+        string $className,
+        int $mode,
+        array $customRenameColumns
+    ): array {
         if ($customRenameColumns) { // for BC with 2.2-2.3 API
             $mode = self::COLUMN_RENAMING_CUSTOM;
         }
@@ -244,7 +238,7 @@ class ResultSetMappingBuilder extends ResultSetMapping
         foreach ($class->associationMappings as $associationMapping) {
             if ($associationMapping['isOwningSide'] && $associationMapping['type'] & ClassMetadataInfo::TO_ONE) {
                 foreach ($associationMapping['joinColumns'] as $joinColumn) {
-                    $columnName = $joinColumn['name'];
+                    $columnName               = $joinColumn['name'];
                     $columnAlias[$columnName] = $this->getColumnAlias($columnName, $mode, $customRenameColumns);
                 }
             }
@@ -256,8 +250,7 @@ class ResultSetMappingBuilder extends ResultSetMapping
     /**
      * Adds the mappings of the results of native SQL queries to the result set.
      *
-     * @param ClassMetadataInfo $class
-     * @param array             $queryMapping
+     * @param mixed[] $queryMapping
      *
      * @return ResultSetMappingBuilder
      */
@@ -273,16 +266,15 @@ class ResultSetMappingBuilder extends ResultSetMapping
     /**
      * Adds the class mapping of the results of native SQL queries to the result set.
      *
-     * @param ClassMetadataInfo $class
-     * @param string            $resultClassName
+     * @param string $resultClassName
      *
-     * @return self
+     * @return $this
      */
     public function addNamedNativeQueryResultClassMapping(ClassMetadataInfo $class, $resultClassName)
     {
-        $classMetadata  = $this->em->getClassMetadata($resultClassName);
-        $shortName      = $classMetadata->reflClass->getShortName();
-        $alias          = strtolower($shortName[0]).'0';
+        $classMetadata = $this->em->getClassMetadata($resultClassName);
+        $shortName     = $classMetadata->reflClass->getShortName();
+        $alias         = strtolower($shortName[0]) . '0';
 
         $this->addEntityResult($class->name, $alias);
 
@@ -304,8 +296,8 @@ class ResultSetMappingBuilder extends ResultSetMapping
                 $targetClass = $this->em->getClassMetadata($associationMapping['targetEntity']);
 
                 foreach ($associationMapping['joinColumns'] as $joinColumn) {
-                    $columnName  = $joinColumn['name'];
-                    $columnType  = PersisterHelper::getTypeOfColumn($joinColumn['referencedColumnName'], $targetClass, $this->em);
+                    $columnName = $joinColumn['name'];
+                    $columnType = PersisterHelper::getTypeOfColumn($joinColumn['referencedColumnName'], $targetClass, $this->em);
 
                     $this->addMetaResult($alias, $columnName, $columnName, $classMetadata->isIdentifier($columnName), $columnType);
                 }
@@ -318,30 +310,28 @@ class ResultSetMappingBuilder extends ResultSetMapping
     /**
      * Adds the result set mapping of the results of native SQL queries to the result set.
      *
-     * @param ClassMetadataInfo $class
-     * @param string            $resultSetMappingName
+     * @param string $resultSetMappingName
      *
-     * @return self
+     * @return $this
      */
     public function addNamedNativeQueryResultSetMapping(ClassMetadataInfo $class, $resultSetMappingName)
     {
-        $counter        = 0;
-        $resultMapping  = $class->getSqlResultSetMapping($resultSetMappingName);
-        $rootShortName  = $class->reflClass->getShortName();
-        $rootAlias      = strtolower($rootShortName[0]) . $counter;
-
+        $counter       = 0;
+        $resultMapping = $class->getSqlResultSetMapping($resultSetMappingName);
+        $rootShortName = $class->reflClass->getShortName();
+        $rootAlias     = strtolower($rootShortName[0]) . $counter;
 
         if (isset($resultMapping['entities'])) {
             foreach ($resultMapping['entities'] as $key => $entityMapping) {
-                $classMetadata  = $this->em->getClassMetadata($entityMapping['entityClass']);
+                $classMetadata = $this->em->getClassMetadata($entityMapping['entityClass']);
 
-                if ($class->reflClass->name == $classMetadata->reflClass->name) {
+                if ($class->reflClass->name === $classMetadata->reflClass->name) {
                     $this->addEntityResult($classMetadata->name, $rootAlias);
                     $this->addNamedNativeQueryEntityResultMapping($classMetadata, $entityMapping, $rootAlias);
                 } else {
-                    $shortName      = $classMetadata->reflClass->getShortName();
-                    $joinAlias      = strtolower($shortName[0]) . ++ $counter;
-                    $associations   = $class->getAssociationsByTargetClass($classMetadata->name);
+                    $shortName    = $classMetadata->reflClass->getShortName();
+                    $joinAlias    = strtolower($shortName[0]) . ++$counter;
+                    $associations = $class->getAssociationsByTargetClass($classMetadata->name);
 
                     $this->addNamedNativeQueryEntityResultMapping($classMetadata, $entityMapping, $joinAlias);
 
@@ -349,7 +339,6 @@ class ResultSetMappingBuilder extends ResultSetMapping
                         $this->addJoinedEntityResult($mapping['targetEntity'], $joinAlias, $rootAlias, $relation);
                     }
                 }
-
             }
         }
 
@@ -369,26 +358,25 @@ class ResultSetMappingBuilder extends ResultSetMapping
     /**
      * Adds the entity result mapping of the results of native SQL queries to the result set.
      *
-     * @param ClassMetadataInfo $classMetadata
-     * @param array             $entityMapping
-     * @param string            $alias
+     * @param mixed[] $entityMapping
+     * @param string  $alias
      *
-     * @return self
+     * @return $this
      *
      * @throws MappingException
-     * @throws \InvalidArgumentException
+     * @throws InvalidArgumentException
      */
     public function addNamedNativeQueryEntityResultMapping(ClassMetadataInfo $classMetadata, array $entityMapping, $alias)
     {
         if (isset($entityMapping['discriminatorColumn']) && $entityMapping['discriminatorColumn']) {
             $discriminatorColumn = $entityMapping['discriminatorColumn'];
-            $discriminatorType   = $classMetadata->discriminatorColumn['type'];
+            $discriminatorType   = $classMetadata->getDiscriminatorColumn()['type'];
 
             $this->setDiscriminatorColumn($alias, $discriminatorColumn);
             $this->addMetaResult($alias, $discriminatorColumn, $discriminatorColumn, false, $discriminatorType);
         }
 
-        if (isset($entityMapping['fields']) && !empty($entityMapping['fields'])) {
+        if (isset($entityMapping['fields']) && ! empty($entityMapping['fields'])) {
             foreach ($entityMapping['fields'] as $field) {
                 $fieldName = $field['name'];
                 $relation  = null;
@@ -400,7 +388,7 @@ class ResultSetMappingBuilder extends ResultSetMapping
                 if (isset($classMetadata->associationMappings[$relation])) {
                     if ($relation) {
                         $associationMapping = $classMetadata->associationMappings[$relation];
-                        $joinAlias          = $alias.$relation;
+                        $joinAlias          = $alias . $relation;
                         $parentAlias        = $alias;
 
                         $this->addJoinedEntityResult($associationMapping['targetEntity'], $joinAlias, $parentAlias, $relation);
@@ -409,14 +397,13 @@ class ResultSetMappingBuilder extends ResultSetMapping
                         $this->addFieldResult($alias, $field['column'], $fieldName, $classMetadata->name);
                     }
                 } else {
-                    if ( ! isset($classMetadata->fieldMappings[$fieldName])) {
-                        throw new \InvalidArgumentException("Entity '".$classMetadata->name."' has no field '".$fieldName."'. ");
+                    if (! isset($classMetadata->fieldMappings[$fieldName])) {
+                        throw new InvalidArgumentException("Entity '" . $classMetadata->name . "' has no field '" . $fieldName . "'. ");
                     }
 
                     $this->addFieldResult($alias, $field['column'], $fieldName, $classMetadata->name);
                 }
             }
-
         } else {
             foreach ($classMetadata->getColumnNames() as $columnName) {
                 $propertyName = $classMetadata->getFieldName($columnName);
@@ -434,33 +421,41 @@ class ResultSetMappingBuilder extends ResultSetMapping
      * Works only for all the entity results. The select parts for scalar
      * expressions have to be written manually.
      *
-     * @param array $tableAliases
+     * @param string[] $tableAliases
+     * @psalm-param array<string, string> $tableAliases
      *
      * @return string
      */
     public function generateSelectClause($tableAliases = [])
     {
-        $sql = "";
+        $sql = '';
 
         foreach ($this->columnOwnerMap as $columnName => $dqlAlias) {
             $tableAlias = $tableAliases[$dqlAlias] ?? $dqlAlias;
 
-            if ($sql) {
-                $sql .= ", ";
+            if ($sql !== '') {
+                $sql .= ', ';
             }
 
-            $sql .= $tableAlias . ".";
-
             if (isset($this->fieldMappings[$columnName])) {
-                $class = $this->em->getClassMetadata($this->declaringClasses[$columnName]);
-                $sql  .= $class->fieldMappings[$this->fieldMappings[$columnName]]['columnName'];
-            } else if (isset($this->metaMappings[$columnName])) {
-                $sql .= $this->metaMappings[$columnName];
-            } else if (isset($this->discriminatorColumns[$dqlAlias])) {
-                $sql .= $this->discriminatorColumns[$dqlAlias];
+                $class             = $this->em->getClassMetadata($this->declaringClasses[$columnName]);
+                $fieldName         = $this->fieldMappings[$columnName];
+                $classFieldMapping = $class->fieldMappings[$fieldName];
+                $columnSql         = $tableAlias . '.' . $classFieldMapping['columnName'];
+
+                if (isset($classFieldMapping['requireSQLConversion']) && $classFieldMapping['requireSQLConversion'] === true) {
+                    $type      = Type::getType($classFieldMapping['type']);
+                    $columnSql = $type->convertToPHPValueSQL($columnSql, $this->em->getConnection()->getDatabasePlatform());
+                }
+
+                $sql .= $columnSql;
+            } elseif (isset($this->metaMappings[$columnName])) {
+                $sql .= $tableAlias . '.' . $this->metaMappings[$columnName];
+            } elseif (isset($this->discriminatorColumns[$dqlAlias])) {
+                $sql .= $tableAlias . '.' . $this->discriminatorColumns[$dqlAlias];
             }
 
-            $sql .= " AS " . $columnName;
+            $sql .= ' AS ' . $columnName;
         }
 
         return $sql;
