@@ -5,15 +5,16 @@ declare(strict_types=1);
 namespace Doctrine\Performance;
 
 use Doctrine\Common\EventManager;
-use Doctrine\DBAL\Cache\ArrayStatement;
 use Doctrine\DBAL\Cache\QueryCacheProfile;
 use Doctrine\DBAL\Connection;
-use Doctrine\DBAL\Driver\PDOSqlite\Driver;
+use Doctrine\DBAL\Driver\PDO\SQLite\Driver;
+use Doctrine\DBAL\Result;
 use Doctrine\ORM\Configuration;
 use Doctrine\ORM\EntityManager;
 use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\ORM\Proxy\ProxyFactory;
 use Doctrine\ORM\Tools\SchemaTool;
+use Doctrine\Tests\Mocks\DriverResultMock;
 
 use function array_map;
 use function realpath;
@@ -63,9 +64,9 @@ final class EntityManagerFactory
         $connection = new class ([], new Driver(), null, new EventManager()) extends Connection
         {
             /** {@inheritdoc} */
-            public function executeQuery($query, array $params = [], $types = [], ?QueryCacheProfile $qcp = null)
+            public function executeQuery(string $sql, array $params = [], $types = [], ?QueryCacheProfile $qcp = null): Result
             {
-                return new ArrayStatement([]);
+                return new Result(new DriverResultMock(), $this);
             }
         };
 
