@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Performance\LazyLoading;
 
 use Doctrine\Common\Proxy\AbstractProxyFactory;
@@ -13,28 +15,25 @@ use PhpBench\Benchmark\Metadata\Annotations\BeforeMethods;
  */
 final class ProxyInstantiationTimeBench
 {
-    /**
-     * @var AbstractProxyFactory
-     */
+    /** @var AbstractProxyFactory */
     private $proxyFactory;
 
-    public function init()
+    public function init(): void
     {
         $this->proxyFactory = EntityManagerFactory::getEntityManager([])->getProxyFactory();
     }
 
-    public function benchCmsUserInstantiation()
+    public function benchCmsUserInstantiation(): void
     {
         for ($i = 0; $i < 100000; ++$i) {
             $this->proxyFactory->getProxy(CmsUser::class, ['id' => $i]);
         }
     }
 
-    public function benchCmsEmployeeInstantiation()
+    public function benchCmsEmployeeInstantiation(): void
     {
         for ($i = 0; $i < 100000; ++$i) {
             $this->proxyFactory->getProxy(CmsEmployee::class, ['id' => $i]);
         }
     }
 }
-
