@@ -1,9 +1,10 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Performance\Mock;
 
 use Doctrine\ORM\Persisters\Entity\BasicEntityPersister;
-use Doctrine\ORM\Query;
 
 /**
  * A persister that doesn't actually load given objects
@@ -21,10 +22,10 @@ class NonLoadingPersister extends BasicEntityPersister
         array $criteria,
         $entity = null,
         $assoc = null,
-        array $hints = array(),
+        array $hints = [],
         $lockMode = 0,
         $limit = null,
-        array $orderBy = null
+        ?array $orderBy = null
     ) {
         return $entity;
     }
