@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Mocks;
 
 use Doctrine\ORM\Cache\CacheKey;
@@ -14,7 +16,7 @@ class CacheKeyMock extends CacheKey
     /**
      * @param string $hash The string hash that represend this cache key
      */
-    function __construct($hash)
+    public function __construct(string $hash)
     {
         $this->hash = $hash;
     }
