@@ -60,7 +60,7 @@ class EntityManagerMock extends EntityManager
             $config = new Configuration();
             $config->setProxyDir(__DIR__ . '/../Proxies');
             $config->setProxyNamespace('Doctrine\Tests\Proxies');
-            $config->setMetadataDriverImpl($config->newDefaultAnnotationDriver([], true));
+            $config->setMetadataDriverImpl($config->newDefaultAnnotationDriver([], false));
         }
 
         if ($eventManager === null) {
