@@ -4,7 +4,6 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\Mocks;
 
-use Doctrine\DBAL\Connection;
 use Doctrine\DBAL\Schema\AbstractSchemaManager;
 use Exception;
 
@@ -13,11 +12,6 @@ use Exception;
  */
 class SchemaManagerMock extends AbstractSchemaManager
 {
-    public function __construct(Connection $conn)
-    {
-        parent::__construct($conn);
-    }
-
     /**
      * {@inheritdoc}
      */
