@@ -4,7 +4,14 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\Models\Company;
 
-/** @Entity @Table(name="company_auctions") */
+use Doctrine\ORM\Mapping\Column;
+use Doctrine\ORM\Mapping\Entity;
+use Doctrine\ORM\Mapping\Table;
+
+/**
+ * @Entity
+ * @Table(name="company_auctions")
+ */
 class CompanyAuction extends CompanyEvent
 {
     /**
