@@ -4,6 +4,16 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\Models\Company;
 
+use Doctrine\ORM\Mapping as ORM;
+use Doctrine\ORM\Mapping\PostLoad;
+use Doctrine\ORM\Mapping\PostPersist;
+use Doctrine\ORM\Mapping\PostRemove;
+use Doctrine\ORM\Mapping\PostUpdate;
+use Doctrine\ORM\Mapping\PreFlush;
+use Doctrine\ORM\Mapping\PrePersist;
+use Doctrine\ORM\Mapping\PreRemove;
+use Doctrine\ORM\Mapping\PreUpdate;
+
 use function func_get_args;
 
 class CompanyContractListener
@@ -35,6 +45,7 @@ class CompanyContractListener
     /**
      * @PostPersist
      */
+    #[ORM\PostPersist]
     public function postPersistHandler(CompanyContract $contract): void
     {
         $this->postPersistCalls[] = func_get_args();
@@ -43,6 +54,7 @@ class CompanyContractListener
     /**
      * @PrePersist
      */
+    #[ORM\PrePersist]
     public function prePersistHandler(CompanyContract $contract): void
     {
         $this->prePersistCalls[] = func_get_args();
@@ -51,6 +63,7 @@ class CompanyContractListener
     /**
      * @PostUpdate
      */
+    #[ORM\PostUpdate]
     public function postUpdateHandler(CompanyContract $contract): void
     {
         $this->postUpdateCalls[] = func_get_args();
@@ -59,6 +72,7 @@ class CompanyContractListener
     /**
      * @PreUpdate
      */
+    #[ORM\PreUpdate]
     public function preUpdateHandler(CompanyContract $contract): void
     {
         $this->preUpdateCalls[] = func_get_args();
@@ -67,6 +81,7 @@ class CompanyContractListener
     /**
      * @PostRemove
      */
+    #[ORM\PostRemove]
     public function postRemoveHandler(CompanyContract $contract): void
     {
         $this->postRemoveCalls[] = func_get_args();
@@ -75,6 +90,7 @@ class CompanyContractListener
     /**
      * @PreRemove
      */
+    #[ORM\PreRemove]
     public function preRemoveHandler(CompanyContract $contract): void
     {
         $this->preRemoveCalls[] = func_get_args();
@@ -83,6 +99,7 @@ class CompanyContractListener
     /**
      * @PreFlush
      */
+    #[ORM\PreFlush]
     public function preFlushHandler(CompanyContract $contract): void
     {
         $this->preFlushCalls[] = func_get_args();
@@ -91,6 +108,7 @@ class CompanyContractListener
     /**
      * @PostLoad
      */
+    #[ORM\PostLoad]
     public function postLoadHandler(CompanyContract $contract): void
     {
         $this->postLoadCalls[] = func_get_args();
