@@ -4,15 +4,19 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\Models\Company;
 
+use Doctrine\ORM\Mapping as ORM;
 use Doctrine\ORM\Mapping\ClassMetadataInfo;
+use Doctrine\ORM\Mapping\Column;
+use Doctrine\ORM\Mapping\Entity;
 
 /**
  * @Entity
  */
+#[ORM\Entity]
 class CompanyFixContract extends CompanyContract
 {
     /**
-     * @column(type="integer")
+     * @Column(type="integer")
      * @var int
      */
     private $fixPrice = 0;
