@@ -5,6 +5,8 @@ declare(strict_types=1);
 namespace Doctrine\Tests\Models\Company;
 
 use Doctrine\ORM\Event\LifecycleEventArgs;
+use Doctrine\ORM\Mapping as ORM;
+use Doctrine\ORM\Mapping\PrePersist;
 
 use function func_get_args;
 
@@ -16,6 +18,7 @@ class CompanyFlexUltraContractListener
     /**
      * @PrePersist
      */
+    #[ORM\PrePersist]
     public function prePersistHandler1(CompanyContract $contract, LifecycleEventArgs $args): void
     {
         $this->prePersistCalls[] = func_get_args();
@@ -24,6 +27,7 @@ class CompanyFlexUltraContractListener
     /**
      * @PrePersist
      */
+    #[ORM\PrePersist]
     public function prePersistHandler2(CompanyContract $contract, LifecycleEventArgs $args): void
     {
         $this->prePersistCalls[] = func_get_args();
