@@ -4,6 +4,10 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\Models\CompositeKeyInheritance;
 
+use Doctrine\ORM\Mapping\Column;
+use Doctrine\ORM\Mapping\Entity;
+use Doctrine\ORM\Mapping\Id;
+
 /**
  * @Entity
  */
