@@ -4,6 +4,11 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\Models\CustomType;
 
+use Doctrine\ORM\Mapping\Column;
+use Doctrine\ORM\Mapping\Entity;
+use Doctrine\ORM\Mapping\Id;
+use Doctrine\ORM\Mapping\ManyToOne;
+use Doctrine\ORM\Mapping\Table;
 use Doctrine\Tests\DbalTypes\CustomIdObject;
 
 /**
@@ -13,7 +18,8 @@ use Doctrine\Tests\DbalTypes\CustomIdObject;
 class CustomIdObjectTypeChild
 {
     /**
-     * @Id @Column(type="CustomIdObject")
+     * @Id
+     * @Column(type="CustomIdObject")
      * @var CustomIdObject
      */
     public $id;
