@@ -6,6 +6,11 @@ namespace Doctrine\Tests\Models\CustomType;
 
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\Common\Collections\Collection;
+use Doctrine\ORM\Mapping\Column;
+use Doctrine\ORM\Mapping\Entity;
+use Doctrine\ORM\Mapping\Id;
+use Doctrine\ORM\Mapping\OneToMany;
+use Doctrine\ORM\Mapping\Table;
 use Doctrine\Tests\DbalTypes\CustomIdObject;
 
 /**
@@ -15,7 +20,8 @@ use Doctrine\Tests\DbalTypes\CustomIdObject;
 class CustomIdObjectTypeParent
 {
     /**
-     * @Id @Column(type="CustomIdObject")
+     * @Id
+     * @Column(type="CustomIdObject")
      * @var CustomIdObject
      */
     public $id;
