@@ -4,6 +4,10 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\Models\DDC3579;
 
+use Doctrine\ORM\Mapping\AssociationOverride;
+use Doctrine\ORM\Mapping\AssociationOverrides;
+use Doctrine\ORM\Mapping\Entity;
+
 /**
  * @Entity
  * @AssociationOverrides({
@@ -13,6 +17,8 @@ namespace Doctrine\Tests\Models\DDC3579;
  *      )
  * })
  */
+#[Entity]
+#[AssociationOverrides([new AssociationOverride(name: 'groups', inversedBy: 'admins')])]
 class DDC3579Admin extends DDC3579User
 {
     public static function loadMetadata($metadata): void
