@@ -5,8 +5,17 @@ declare(strict_types=1);
 namespace Doctrine\Tests\Models\DDC3699;
 
 use Doctrine\Common\Collections\Collection;
+use Doctrine\ORM\Mapping\Column;
+use Doctrine\ORM\Mapping\Entity;
+use Doctrine\ORM\Mapping\Id;
+use Doctrine\ORM\Mapping\OneToMany;
+use Doctrine\ORM\Mapping\OneToOne;
+use Doctrine\ORM\Mapping\Table;
 
-/** @Entity @Table(name="ddc3699_child") */
+/**
+ * @Entity
+ * @Table(name="ddc3699_child")
+ */
 class DDC3699Child extends DDC3699Parent
 {
     /**
