@@ -4,6 +4,9 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\Models\DDC3899;
 
+use Doctrine\ORM\Mapping\Column;
+use Doctrine\ORM\Mapping\Entity;
+
 /**
  * @Entity
  */
@@ -11,7 +14,7 @@ class DDC3899FixContract extends DDC3899Contract
 {
     /**
      * @var int
-     * @column(type="integer")
+     * @Column(type="integer")
      */
     public $fixPrice = 0;
 }
