@@ -4,7 +4,11 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\Models\DDC964;
 
+use Doctrine\ORM\Mapping\AttributeOverride;
+use Doctrine\ORM\Mapping\AttributeOverrides;
 use Doctrine\ORM\Mapping\ClassMetadataInfo;
+use Doctrine\ORM\Mapping\Column;
+use Doctrine\ORM\Mapping\Entity;
 
 /**
  * @Entity
@@ -21,11 +25,13 @@ use Doctrine\ORM\Mapping\ClassMetadataInfo;
  *              name     = "guest_name",
  *              nullable = false,
  *              unique   = true,
-                length   = 240
+ *              length   = 240
  *          )
  *      )
  * })
  */
+#[Entity]
+#[AttributeOverrides([new AttributeOverride(name: 'id', column: new Column(name: 'guest_id', type: 'integer', length: 140)), new AttributeOverride(name: 'name', column: new Column(name: 'guest_name', nullable: false, unique: true, length: 240))])]
 class DDC964Guest extends DDC964User
 {
     public static function loadMetadata(ClassMetadataInfo $metadata): void
