@@ -4,6 +4,10 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\Models\Quote;
 
+use Doctrine\ORM\Mapping\Entity;
+use Doctrine\ORM\Mapping\JoinColumn;
+use Doctrine\ORM\Mapping\OneToOne;
+
 /**
  * @Entity
  */
