@@ -4,6 +4,12 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\Models\Taxi;
 
+use Doctrine\ORM\Mapping\Entity;
+use Doctrine\ORM\Mapping\Id;
+use Doctrine\ORM\Mapping\JoinColumn;
+use Doctrine\ORM\Mapping\ManyToOne;
+use Doctrine\ORM\Mapping\Table;
+
 /**
  * Test model that contains only Id-columns
  *
