@@ -1,9 +1,14 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\ValueObjects;
 
 class Person
 {
+    /** @var int */
     private $id;
+
+    /** @var string */
     private $name;
 }
