@@ -18,7 +18,7 @@ class CacheKeyTest extends DoctrineTestCase
         $key1 = new EntityCacheKey('Foo', ['id' => 1]);
         $key2 = new EntityCacheKey('Bar', ['id' => 1]);
 
-        $this->assertNotEquals($key1->hash, $key2->hash);
+        self::assertNotEquals($key1->hash, $key2->hash);
     }
 
     public function testEntityCacheKeyIdentifierType(): void
@@ -26,7 +26,7 @@ class CacheKeyTest extends DoctrineTestCase
         $key1 = new EntityCacheKey('Foo', ['id' => 1]);
         $key2 = new EntityCacheKey('Foo', ['id' => '1']);
 
-        $this->assertEquals($key1->hash, $key2->hash);
+        self::assertEquals($key1->hash, $key2->hash);
     }
 
     public function testEntityCacheKeyIdentifierOrder(): void
@@ -34,7 +34,7 @@ class CacheKeyTest extends DoctrineTestCase
         $key1 = new EntityCacheKey('Foo', ['foo_bar' => 1, 'bar_foo' => 2]);
         $key2 = new EntityCacheKey('Foo', ['bar_foo' => 2, 'foo_bar' => 1]);
 
-        $this->assertEquals($key1->hash, $key2->hash);
+        self::assertEquals($key1->hash, $key2->hash);
     }
 
     public function testCollectionCacheKeyIdentifierType(): void
@@ -42,7 +42,7 @@ class CacheKeyTest extends DoctrineTestCase
         $key1 = new CollectionCacheKey('Foo', 'assoc', ['id' => 1]);
         $key2 = new CollectionCacheKey('Foo', 'assoc', ['id' => '1']);
 
-        $this->assertEquals($key1->hash, $key2->hash);
+        self::assertEquals($key1->hash, $key2->hash);
     }
 
     public function testCollectionCacheKeyIdentifierOrder(): void
@@ -50,7 +50,7 @@ class CacheKeyTest extends DoctrineTestCase
         $key1 = new CollectionCacheKey('Foo', 'assoc', ['foo_bar' => 1, 'bar_foo' => 2]);
         $key2 = new CollectionCacheKey('Foo', 'assoc', ['bar_foo' => 2, 'foo_bar' => 1]);
 
-        $this->assertEquals($key1->hash, $key2->hash);
+        self::assertEquals($key1->hash, $key2->hash);
     }
 
     public function testCollectionCacheKeyIdentifierCollision(): void
@@ -58,7 +58,7 @@ class CacheKeyTest extends DoctrineTestCase
         $key1 = new CollectionCacheKey('Foo', 'assoc', ['id' => 1]);
         $key2 = new CollectionCacheKey('Bar', 'assoc', ['id' => 1]);
 
-        $this->assertNotEquals($key1->hash, $key2->hash);
+        self::assertNotEquals($key1->hash, $key2->hash);
     }
 
     public function testCollectionCacheKeyAssociationCollision(): void
@@ -66,6 +66,6 @@ class CacheKeyTest extends DoctrineTestCase
         $key1 = new CollectionCacheKey('Foo', 'assoc1', ['id' => 1]);
         $key2 = new CollectionCacheKey('Foo', 'assoc2', ['id' => 1]);
 
-        $this->assertNotEquals($key1->hash, $key2->hash);
+        self::assertNotEquals($key1->hash, $key2->hash);
     }
 }
