@@ -4,8 +4,6 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\ORM\Cache;
 
-use Doctrine\Common\Cache\Cache;
-use Doctrine\Common\Cache\CacheProvider;
 use Doctrine\ORM\Cache\CacheFactory;
 use Doctrine\ORM\Cache\DefaultCacheFactory;
 use Doctrine\ORM\Cache\Persister\Collection\CachedCollectionPersister;
@@ -16,10 +14,9 @@ use Doctrine\ORM\Cache\Persister\Entity\CachedEntityPersister;
 use Doctrine\ORM\Cache\Persister\Entity\NonStrictReadWriteCachedEntityPersister;
 use Doctrine\ORM\Cache\Persister\Entity\ReadOnlyCachedEntityPersister;
 use Doctrine\ORM\Cache\Persister\Entity\ReadWriteCachedEntityPersister;
-use Doctrine\ORM\Cache\Region\DefaultMultiGetRegion;
 use Doctrine\ORM\Cache\Region\DefaultRegion;
 use Doctrine\ORM\Cache\RegionsConfiguration;
-use Doctrine\ORM\EntityManager;
+use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\ORM\Mapping\ClassMetadata;
 use Doctrine\ORM\Persisters\Collection\OneToManyPersister;
 use Doctrine\ORM\Persisters\Entity\BasicEntityPersister;
@@ -31,18 +28,18 @@ use Doctrine\Tests\Models\Cache\State;
 use Doctrine\Tests\OrmTestCase;
 use InvalidArgumentException;
 use LogicException;
-
-use function assert;
+use PHPUnit\Framework\MockObject\MockObject;
+use Psr\Cache\CacheItemPoolInterface;
 
 /**
  * @group DDC-2183
  */
 class DefaultCacheFactoryTest extends OrmTestCase
 {
-    /** @var CacheFactory */
+    /** @var CacheFactory&MockObject */
     private $factory;
 
-    /** @var EntityManager */
+    /** @var EntityManagerInterface */
     private $em;
 
     /** @var RegionsConfiguration */
@@ -55,7 +52,7 @@ class DefaultCacheFactoryTest extends OrmTestCase
 
         $this->em            = $this->getTestEntityManager();
         $this->regionsConfig = new RegionsConfiguration();
-        $arguments           = [$this->regionsConfig, $this->getSharedSecondLevelCacheDriverImpl()];
+        $arguments           = [$this->regionsConfig, $this->getSharedSecondLevelCache()];
         $this->factory       = $this->getMockBuilder(DefaultCacheFactory::class)
                                     ->setMethods(['getRegion'])
                                     ->setConstructorArgs($arguments)
@@ -64,7 +61,7 @@ class DefaultCacheFactoryTest extends OrmTestCase
 
     public function testImplementsCacheFactory(): void
     {
-        $this->assertInstanceOf(CacheFactory::class, $this->factory);
+        self::assertInstanceOf(CacheFactory::class, $this->factory);
     }
 
     public function testBuildCachedEntityPersisterReadOnly(): void
@@ -72,19 +69,19 @@ class DefaultCacheFactoryTest extends OrmTestCase
         $em        = $this->em;
         $metadata  = clone $em->getClassMetadata(State::class);
         $persister = new BasicEntityPersister($em, $metadata);
-        $region    = new ConcurrentRegionMock(new DefaultRegion('regionName', $this->getSharedSecondLevelCacheDriverImpl()));
+        $region    = new ConcurrentRegionMock(new DefaultRegion('regionName', $this->getSharedSecondLevelCache()));
 
         $metadata->cache['usage'] = ClassMetadata::CACHE_USAGE_READ_ONLY;
 
-        $this->factory->expects($this->once())
+        $this->factory->expects(self::once())
             ->method('getRegion')
-            ->with($this->equalTo($metadata->cache))
-            ->will($this->returnValue($region));
+            ->with(self::equalTo($metadata->cache))
+            ->will(self::returnValue($region));
 
         $cachedPersister = $this->factory->buildCachedEntityPersister($em, $persister, $metadata);
 
-        $this->assertInstanceOf(CachedEntityPersister::class, $cachedPersister);
-        $this->assertInstanceOf(ReadOnlyCachedEntityPersister::class, $cachedPersister);
+        self::assertInstanceOf(CachedEntityPersister::class, $cachedPersister);
+        self::assertInstanceOf(ReadOnlyCachedEntityPersister::class, $cachedPersister);
     }
 
     public function testBuildCachedEntityPersisterReadWrite(): void
@@ -92,19 +89,19 @@ class DefaultCacheFactoryTest extends OrmTestCase
         $em        = $this->em;
         $metadata  = clone $em->getClassMetadata(State::class);
         $persister = new BasicEntityPersister($em, $metadata);
-        $region    = new ConcurrentRegionMock(new DefaultRegion('regionName', $this->getSharedSecondLevelCacheDriverImpl()));
+        $region    = new ConcurrentRegionMock(new DefaultRegion('regionName', $this->getSharedSecondLevelCache()));
 
         $metadata->cache['usage'] = ClassMetadata::CACHE_USAGE_READ_WRITE;
 
-        $this->factory->expects($this->once())
+        $this->factory->expects(self::once())
             ->method('getRegion')
-            ->with($this->equalTo($metadata->cache))
-            ->will($this->returnValue($region));
+            ->with(self::equalTo($metadata->cache))
+            ->will(self::returnValue($region));
 
         $cachedPersister = $this->factory->buildCachedEntityPersister($em, $persister, $metadata);
 
-        $this->assertInstanceOf(CachedEntityPersister::class, $cachedPersister);
-        $this->assertInstanceOf(ReadWriteCachedEntityPersister::class, $cachedPersister);
+        self::assertInstanceOf(CachedEntityPersister::class, $cachedPersister);
+        self::assertInstanceOf(ReadWriteCachedEntityPersister::class, $cachedPersister);
     }
 
     public function testBuildCachedEntityPersisterNonStrictReadWrite(): void
@@ -112,19 +109,19 @@ class DefaultCacheFactoryTest extends OrmTestCase
         $em        = $this->em;
         $metadata  = clone $em->getClassMetadata(State::class);
         $persister = new BasicEntityPersister($em, $metadata);
-        $region    = new ConcurrentRegionMock(new DefaultRegion('regionName', $this->getSharedSecondLevelCacheDriverImpl()));
+        $region    = new ConcurrentRegionMock(new DefaultRegion('regionName', $this->getSharedSecondLevelCache()));
 
         $metadata->cache['usage'] = ClassMetadata::CACHE_USAGE_NONSTRICT_READ_WRITE;
 
-        $this->factory->expects($this->once())
+        $this->factory->expects(self::once())
             ->method('getRegion')
-            ->with($this->equalTo($metadata->cache))
-            ->will($this->returnValue($region));
+            ->with(self::equalTo($metadata->cache))
+            ->will(self::returnValue($region));
 
         $cachedPersister = $this->factory->buildCachedEntityPersister($em, $persister, $metadata);
 
-        $this->assertInstanceOf(CachedEntityPersister::class, $cachedPersister);
-        $this->assertInstanceOf(NonStrictReadWriteCachedEntityPersister::class, $cachedPersister);
+        self::assertInstanceOf(CachedEntityPersister::class, $cachedPersister);
+        self::assertInstanceOf(NonStrictReadWriteCachedEntityPersister::class, $cachedPersister);
     }
 
     public function testBuildCachedCollectionPersisterReadOnly(): void
@@ -133,19 +130,19 @@ class DefaultCacheFactoryTest extends OrmTestCase
         $metadata  = $em->getClassMetadata(State::class);
         $mapping   = $metadata->associationMappings['cities'];
         $persister = new OneToManyPersister($em);
-        $region    = new ConcurrentRegionMock(new DefaultRegion('regionName', $this->getSharedSecondLevelCacheDriverImpl()));
+        $region    = new ConcurrentRegionMock(new DefaultRegion('regionName', $this->getSharedSecondLevelCache()));
 
         $mapping['cache']['usage'] = ClassMetadata::CACHE_USAGE_READ_ONLY;
 
-        $this->factory->expects($this->once())
+        $this->factory->expects(self::once())
             ->method('getRegion')
-            ->with($this->equalTo($mapping['cache']))
-            ->will($this->returnValue($region));
+            ->with(self::equalTo($mapping['cache']))
+            ->will(self::returnValue($region));
 
         $cachedPersister = $this->factory->buildCachedCollectionPersister($em, $persister, $mapping);
 
-        $this->assertInstanceOf(CachedCollectionPersister::class, $cachedPersister);
-        $this->assertInstanceOf(ReadOnlyCachedCollectionPersister::class, $cachedPersister);
+        self::assertInstanceOf(CachedCollectionPersister::class, $cachedPersister);
+        self::assertInstanceOf(ReadOnlyCachedCollectionPersister::class, $cachedPersister);
     }
 
     public function testBuildCachedCollectionPersisterReadWrite(): void
@@ -154,19 +151,19 @@ class DefaultCacheFactoryTest extends OrmTestCase
         $metadata  = $em->getClassMetadata(State::class);
         $mapping   = $metadata->associationMappings['cities'];
         $persister = new OneToManyPersister($em);
-        $region    = new ConcurrentRegionMock(new DefaultRegion('regionName', $this->getSharedSecondLevelCacheDriverImpl()));
+        $region    = new ConcurrentRegionMock(new DefaultRegion('regionName', $this->getSharedSecondLevelCache()));
 
         $mapping['cache']['usage'] = ClassMetadata::CACHE_USAGE_READ_WRITE;
 
-        $this->factory->expects($this->once())
+        $this->factory->expects(self::once())
             ->method('getRegion')
-            ->with($this->equalTo($mapping['cache']))
-            ->will($this->returnValue($region));
+            ->with(self::equalTo($mapping['cache']))
+            ->will(self::returnValue($region));
 
         $cachedPersister = $this->factory->buildCachedCollectionPersister($em, $persister, $mapping);
 
-        $this->assertInstanceOf(CachedCollectionPersister::class, $cachedPersister);
-        $this->assertInstanceOf(ReadWriteCachedCollectionPersister::class, $cachedPersister);
+        self::assertInstanceOf(CachedCollectionPersister::class, $cachedPersister);
+        self::assertInstanceOf(ReadWriteCachedCollectionPersister::class, $cachedPersister);
     }
 
     public function testBuildCachedCollectionPersisterNonStrictReadWrite(): void
@@ -175,19 +172,19 @@ class DefaultCacheFactoryTest extends OrmTestCase
         $metadata  = $em->getClassMetadata(State::class);
         $mapping   = $metadata->associationMappings['cities'];
         $persister = new OneToManyPersister($em);
-        $region    = new ConcurrentRegionMock(new DefaultRegion('regionName', $this->getSharedSecondLevelCacheDriverImpl()));
+        $region    = new ConcurrentRegionMock(new DefaultRegion('regionName', $this->getSharedSecondLevelCache()));
 
         $mapping['cache']['usage'] = ClassMetadata::CACHE_USAGE_NONSTRICT_READ_WRITE;
 
-        $this->factory->expects($this->once())
+        $this->factory->expects(self::once())
             ->method('getRegion')
-            ->with($this->equalTo($mapping['cache']))
-            ->will($this->returnValue($region));
+            ->with(self::equalTo($mapping['cache']))
+            ->will(self::returnValue($region));
 
         $cachedPersister = $this->factory->buildCachedCollectionPersister($em, $persister, $mapping);
 
-        $this->assertInstanceOf(CachedCollectionPersister::class, $cachedPersister);
-        $this->assertInstanceOf(NonStrictReadWriteCachedCollectionPersister::class, $cachedPersister);
+        self::assertInstanceOf(CachedCollectionPersister::class, $cachedPersister);
+        self::assertInstanceOf(NonStrictReadWriteCachedCollectionPersister::class, $cachedPersister);
     }
 
     public function testInheritedEntityCacheRegion(): void
@@ -197,16 +194,16 @@ class DefaultCacheFactoryTest extends OrmTestCase
         $metadata2  = clone $em->getClassMetadata(AttractionLocationInfo::class);
         $persister1 = new BasicEntityPersister($em, $metadata1);
         $persister2 = new BasicEntityPersister($em, $metadata2);
-        $factory    = new DefaultCacheFactory($this->regionsConfig, $this->getSharedSecondLevelCacheDriverImpl());
+        $factory    = new DefaultCacheFactory($this->regionsConfig, $this->getSharedSecondLevelCache());
 
         $cachedPersister1 = $factory->buildCachedEntityPersister($em, $persister1, $metadata1);
         $cachedPersister2 = $factory->buildCachedEntityPersister($em, $persister2, $metadata2);
 
-        $this->assertInstanceOf(CachedEntityPersister::class, $cachedPersister1);
-        $this->assertInstanceOf(CachedEntityPersister::class, $cachedPersister2);
+        self::assertInstanceOf(CachedEntityPersister::class, $cachedPersister1);
+        self::assertInstanceOf(CachedEntityPersister::class, $cachedPersister2);
 
-        $this->assertNotSame($cachedPersister1, $cachedPersister2);
-        $this->assertSame($cachedPersister1->getCacheRegion(), $cachedPersister2->getCacheRegion());
+        self::assertNotSame($cachedPersister1, $cachedPersister2);
+        self::assertSame($cachedPersister1->getCacheRegion(), $cachedPersister2->getCacheRegion());
     }
 
     public function testCreateNewCacheDriver(): void
@@ -216,16 +213,16 @@ class DefaultCacheFactoryTest extends OrmTestCase
         $metadata2  = clone $em->getClassMetadata(City::class);
         $persister1 = new BasicEntityPersister($em, $metadata1);
         $persister2 = new BasicEntityPersister($em, $metadata2);
-        $factory    = new DefaultCacheFactory($this->regionsConfig, $this->getSharedSecondLevelCacheDriverImpl());
+        $factory    = new DefaultCacheFactory($this->regionsConfig, $this->getSharedSecondLevelCache());
 
         $cachedPersister1 = $factory->buildCachedEntityPersister($em, $persister1, $metadata1);
         $cachedPersister2 = $factory->buildCachedEntityPersister($em, $persister2, $metadata2);
 
-        $this->assertInstanceOf(CachedEntityPersister::class, $cachedPersister1);
-        $this->assertInstanceOf(CachedEntityPersister::class, $cachedPersister2);
+        self::assertInstanceOf(CachedEntityPersister::class, $cachedPersister1);
+        self::assertInstanceOf(CachedEntityPersister::class, $cachedPersister2);
 
-        $this->assertNotSame($cachedPersister1, $cachedPersister2);
-        $this->assertNotSame($cachedPersister1->getCacheRegion(), $cachedPersister2->getCacheRegion());
+        self::assertNotSame($cachedPersister1, $cachedPersister2);
+        self::assertNotSame($cachedPersister1->getCacheRegion(), $cachedPersister2->getCacheRegion());
     }
 
     public function testBuildCachedEntityPersisterNonStrictException(): void
@@ -259,7 +256,7 @@ class DefaultCacheFactoryTest extends OrmTestCase
 
     public function testInvalidFileLockRegionDirectoryException(): void
     {
-        $factory = new DefaultCacheFactory($this->regionsConfig, $this->getSharedSecondLevelCacheDriverImpl());
+        $factory = new DefaultCacheFactory($this->regionsConfig, $this->getSharedSecondLevelCache());
 
         $this->expectException(LogicException::class);
         $this->expectExceptionMessage(
@@ -278,7 +275,7 @@ class DefaultCacheFactoryTest extends OrmTestCase
 
     public function testInvalidFileLockRegionDirectoryExceptionWithEmptyString(): void
     {
-        $factory = new DefaultCacheFactory($this->regionsConfig, $this->getSharedSecondLevelCacheDriverImpl());
+        $factory = new DefaultCacheFactory($this->regionsConfig, $this->getSharedSecondLevelCache());
 
         $factory->setFileLockRegionDirectory('');
 
@@ -297,59 +294,11 @@ class DefaultCacheFactoryTest extends OrmTestCase
         );
     }
 
-    public function testBuildsNewNamespacedCacheInstancePerRegionInstance(): void
-    {
-        $factory = new DefaultCacheFactory($this->regionsConfig, $this->getSharedSecondLevelCacheDriverImpl());
-
-        $fooRegion = $factory->getRegion(
-            [
-                'region' => 'foo',
-                'usage'  => ClassMetadata::CACHE_USAGE_READ_ONLY,
-            ]
-        );
-        $barRegion = $factory->getRegion(
-            [
-                'region' => 'bar',
-                'usage'  => ClassMetadata::CACHE_USAGE_READ_ONLY,
-            ]
-        );
-
-        $this->assertSame('foo', $fooRegion->getCache()->getNamespace());
-        $this->assertSame('bar', $barRegion->getCache()->getNamespace());
-    }
-
-    public function testAppendsNamespacedCacheInstancePerRegionInstanceWhenItsAlreadySet(): void
-    {
-        $cache = clone $this->getSharedSecondLevelCacheDriverImpl();
-        $cache->setNamespace('testing');
-
-        $factory = new DefaultCacheFactory($this->regionsConfig, $cache);
-
-        $fooRegion = $factory->getRegion(
-            [
-                'region' => 'foo',
-                'usage'  => ClassMetadata::CACHE_USAGE_READ_ONLY,
-            ]
-        );
-        $barRegion = $factory->getRegion(
-            [
-                'region' => 'bar',
-                'usage'  => ClassMetadata::CACHE_USAGE_READ_ONLY,
-            ]
-        );
-
-        $this->assertSame('testing:foo', $fooRegion->getCache()->getNamespace());
-        $this->assertSame('testing:bar', $barRegion->getCache()->getNamespace());
-    }
-
     public function testBuildsDefaultCacheRegionFromGenericCacheRegion(): void
     {
-        $cache = $this->createMock(Cache::class);
-        assert($cache instanceof Cache);
+        $factory = new DefaultCacheFactory($this->regionsConfig, $this->createMock(CacheItemPoolInterface::class));
 
-        $factory = new DefaultCacheFactory($this->regionsConfig, $cache);
-
-        $this->assertInstanceOf(
+        self::assertInstanceOf(
             DefaultRegion::class,
             $factory->getRegion(
                 [
@@ -359,22 +308,4 @@ class DefaultCacheFactoryTest extends OrmTestCase
             )
         );
     }
-
-    public function testBuildsMultiGetCacheRegionFromGenericCacheRegion(): void
-    {
-        $cache = $this->getMockForAbstractClass(CacheProvider::class);
-        assert($cache instanceof CacheProvider);
-
-        $factory = new DefaultCacheFactory($this->regionsConfig, $cache);
-
-        $this->assertInstanceOf(
-            DefaultMultiGetRegion::class,
-            $factory->getRegion(
-                [
-                    'region' => 'bar',
-                    'usage'  => ClassMetadata::CACHE_USAGE_READ_ONLY,
-                ]
-            )
-        );
-    }
 }
