@@ -4,18 +4,18 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\ORM\Cache;
 
-use ArrayObject;
 use Doctrine\Common\Collections\Collection;
 use Doctrine\ORM\Cache;
 use Doctrine\ORM\Cache\DefaultQueryCache;
 use Doctrine\ORM\Cache\EntityCacheEntry;
 use Doctrine\ORM\Cache\EntityCacheKey;
+use Doctrine\ORM\Cache\Exception\CacheException;
 use Doctrine\ORM\Cache\QueryCache;
 use Doctrine\ORM\Cache\QueryCacheEntry;
 use Doctrine\ORM\Cache\QueryCacheKey;
-use Doctrine\ORM\EntityManager;
 use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\ORM\Query\ResultSetMappingBuilder;
+use Doctrine\Tests\Mocks\CacheEntryMock;
 use Doctrine\Tests\Mocks\CacheRegionMock;
 use Doctrine\Tests\Mocks\TimestampRegionMock;
 use Doctrine\Tests\Models\Cache\City;
@@ -37,7 +37,7 @@ class DefaultQueryCacheTest extends OrmTestCase
     /** @var DefaultQueryCache */
     private $queryCache;
 
-    /** @var EntityManager */
+    /** @var EntityManagerInterface */
     private $em;
 
     /** @var CacheRegionMock */
@@ -64,20 +64,20 @@ class DefaultQueryCacheTest extends OrmTestCase
 
     public function testImplementQueryCache(): void
     {
-        $this->assertInstanceOf(QueryCache::class, $this->queryCache);
+        self::assertInstanceOf(QueryCache::class, $this->queryCache);
     }
 
     public function testGetRegion(): void
     {
-        $this->assertSame($this->region, $this->queryCache->getRegion());
+        self::assertSame($this->region, $this->queryCache->getRegion());
     }
 
     public function testClearShouldEvictRegion(): void
     {
         $this->queryCache->clear();
 
-        $this->assertArrayHasKey('evictAll', $this->region->calls);
-        $this->assertCount(1, $this->region->calls['evictAll']);
+        self::assertArrayHasKey('evictAll', $this->region->calls);
+        self::assertCount(1, $this->region->calls['evictAll']);
     }
 
     public function testPutBasicQueryResult(): void
@@ -98,21 +98,21 @@ class DefaultQueryCacheTest extends OrmTestCase
             $this->em->getUnitOfWork()->registerManaged($entity, ['id' => $i], ['name' => $name]);
         }
 
-        $this->assertTrue($this->queryCache->put($key, $rsm, $result));
-        $this->assertArrayHasKey('put', $this->region->calls);
-        $this->assertCount(5, $this->region->calls['put']);
+        self::assertTrue($this->queryCache->put($key, $rsm, $result));
+        self::assertArrayHasKey('put', $this->region->calls);
+        self::assertCount(5, $this->region->calls['put']);
 
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][0]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][1]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][2]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][3]['key']);
-        $this->assertInstanceOf(QueryCacheKey::class, $this->region->calls['put'][4]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][0]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][1]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][2]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][3]['key']);
+        self::assertInstanceOf(QueryCacheKey::class, $this->region->calls['put'][4]['key']);
 
-        $this->assertInstanceOf(EntityCacheEntry::class, $this->region->calls['put'][0]['entry']);
-        $this->assertInstanceOf(EntityCacheEntry::class, $this->region->calls['put'][1]['entry']);
-        $this->assertInstanceOf(EntityCacheEntry::class, $this->region->calls['put'][2]['entry']);
-        $this->assertInstanceOf(EntityCacheEntry::class, $this->region->calls['put'][3]['entry']);
-        $this->assertInstanceOf(QueryCacheEntry::class, $this->region->calls['put'][4]['entry']);
+        self::assertInstanceOf(EntityCacheEntry::class, $this->region->calls['put'][0]['entry']);
+        self::assertInstanceOf(EntityCacheEntry::class, $this->region->calls['put'][1]['entry']);
+        self::assertInstanceOf(EntityCacheEntry::class, $this->region->calls['put'][2]['entry']);
+        self::assertInstanceOf(EntityCacheEntry::class, $this->region->calls['put'][3]['entry']);
+        self::assertInstanceOf(QueryCacheEntry::class, $this->region->calls['put'][4]['entry']);
     }
 
     public function testPutToOneAssociationQueryResult(): void
@@ -139,19 +139,19 @@ class DefaultQueryCacheTest extends OrmTestCase
             $uow->registerManaged($city, ['id' => $city->getId()], ['name' => $city->getName(), 'state' => $state]);
         }
 
-        $this->assertTrue($this->queryCache->put($key, $rsm, $result));
-        $this->assertArrayHasKey('put', $this->region->calls);
-        $this->assertCount(9, $this->region->calls['put']);
+        self::assertTrue($this->queryCache->put($key, $rsm, $result));
+        self::assertArrayHasKey('put', $this->region->calls);
+        self::assertCount(9, $this->region->calls['put']);
 
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][0]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][1]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][2]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][3]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][4]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][5]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][6]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][7]['key']);
-        $this->assertInstanceOf(QueryCacheKey::class, $this->region->calls['put'][8]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][0]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][1]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][2]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][3]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][4]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][5]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][6]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][7]['key']);
+        self::assertInstanceOf(QueryCacheKey::class, $this->region->calls['put'][8]['key']);
     }
 
     public function testPutToOneAssociation2LevelsQueryResult(): void
@@ -184,23 +184,23 @@ class DefaultQueryCacheTest extends OrmTestCase
             $uow->registerManaged($city, ['id' => $city->getId()], ['name' => $city->getName(), 'state' => $state]);
         }
 
-        $this->assertTrue($this->queryCache->put($key, $rsm, $result));
-        $this->assertArrayHasKey('put', $this->region->calls);
-        $this->assertCount(13, $this->region->calls['put']);
+        self::assertTrue($this->queryCache->put($key, $rsm, $result));
+        self::assertArrayHasKey('put', $this->region->calls);
+        self::assertCount(13, $this->region->calls['put']);
 
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][0]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][1]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][2]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][3]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][4]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][5]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][6]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][7]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][8]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][9]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][10]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][11]['key']);
-        $this->assertInstanceOf(QueryCacheKey::class, $this->region->calls['put'][12]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][0]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][1]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][2]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][3]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][4]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][5]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][6]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][7]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][8]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][9]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][10]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][11]['key']);
+        self::assertInstanceOf(QueryCacheKey::class, $this->region->calls['put'][12]['key']);
     }
 
     public function testPutToOneAssociationNullQueryResult(): void
@@ -223,15 +223,15 @@ class DefaultQueryCacheTest extends OrmTestCase
             $uow->registerManaged($city, ['id' => $city->getId()], ['name' => $city->getName(), 'state' => null]);
         }
 
-        $this->assertTrue($this->queryCache->put($key, $rsm, $result));
-        $this->assertArrayHasKey('put', $this->region->calls);
-        $this->assertCount(5, $this->region->calls['put']);
+        self::assertTrue($this->queryCache->put($key, $rsm, $result));
+        self::assertArrayHasKey('put', $this->region->calls);
+        self::assertCount(5, $this->region->calls['put']);
 
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][0]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][1]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][2]['key']);
-        $this->assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][3]['key']);
-        $this->assertInstanceOf(QueryCacheKey::class, $this->region->calls['put'][4]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][0]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][1]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][2]['key']);
+        self::assertInstanceOf(EntityCacheKey::class, $this->region->calls['put'][3]['key']);
+        self::assertInstanceOf(QueryCacheKey::class, $this->region->calls['put'][4]['key']);
     }
 
     public function testPutToManyAssociationQueryResult(): void
@@ -264,9 +264,9 @@ class DefaultQueryCacheTest extends OrmTestCase
             $uow->registerManaged($state, ['id' => $state->getId()], ['name' => $state->getName(), 'cities' => $state->getCities()]);
         }
 
-        $this->assertTrue($this->queryCache->put($key, $rsm, $result));
-        $this->assertArrayHasKey('put', $this->region->calls);
-        $this->assertCount(13, $this->region->calls['put']);
+        self::assertTrue($this->queryCache->put($key, $rsm, $result));
+        self::assertArrayHasKey('put', $this->region->calls);
+        self::assertCount(13, $this->region->calls['put']);
     }
 
     public function testGetBasicQueryResult(): void
@@ -299,13 +299,13 @@ class DefaultQueryCacheTest extends OrmTestCase
 
         $result = $this->queryCache->get($key, $rsm);
 
-        $this->assertCount(2, $result);
-        $this->assertInstanceOf(Country::class, $result[0]);
-        $this->assertInstanceOf(Country::class, $result[1]);
-        $this->assertEquals(1, $result[0]->getId());
-        $this->assertEquals(2, $result[1]->getId());
-        $this->assertEquals('Foo', $result[0]->getName());
-        $this->assertEquals('Bar', $result[1]->getName());
+        self::assertCount(2, $result);
+        self::assertInstanceOf(Country::class, $result[0]);
+        self::assertInstanceOf(Country::class, $result[1]);
+        self::assertEquals(1, $result[0]->getId());
+        self::assertEquals(2, $result[1]->getId());
+        self::assertEquals('Foo', $result[0]->getName());
+        self::assertEquals('Bar', $result[1]->getName());
     }
 
     public function testGetWithAssociation(): void
@@ -338,13 +338,13 @@ class DefaultQueryCacheTest extends OrmTestCase
 
         $result = $this->queryCache->get($key, $rsm);
 
-        $this->assertCount(2, $result);
-        $this->assertInstanceOf(Country::class, $result[0]);
-        $this->assertInstanceOf(Country::class, $result[1]);
-        $this->assertEquals(1, $result[0]->getId());
-        $this->assertEquals(2, $result[1]->getId());
-        $this->assertEquals('Foo', $result[0]->getName());
-        $this->assertEquals('Bar', $result[1]->getName());
+        self::assertCount(2, $result);
+        self::assertInstanceOf(Country::class, $result[0]);
+        self::assertInstanceOf(Country::class, $result[1]);
+        self::assertEquals(1, $result[0]->getId());
+        self::assertEquals(2, $result[1]->getId());
+        self::assertEquals('Foo', $result[0]->getName());
+        self::assertEquals('Bar', $result[1]->getName());
     }
 
     public function testGetWithAssociationCacheMiss(): void
@@ -395,9 +395,9 @@ class DefaultQueryCacheTest extends OrmTestCase
 
         $this->region->addReturn('put', false);
 
-        $this->assertFalse($this->queryCache->put($key, $rsm, $result));
-        $this->assertArrayHasKey('put', $this->region->calls);
-        $this->assertCount(1, $this->region->calls['put']);
+        self::assertFalse($this->queryCache->put($key, $rsm, $result));
+        self::assertArrayHasKey('put', $this->region->calls);
+        self::assertCount(1, $this->region->calls['put']);
     }
 
     public function testCancelPutResultIfAssociationEntityPutFails(): void
@@ -425,7 +425,7 @@ class DefaultQueryCacheTest extends OrmTestCase
         $this->region->addReturn('put', true);  // put root entity
         $this->region->addReturn('put', false); // association fails
 
-        $this->assertFalse($this->queryCache->put($key, $rsm, $result));
+        self::assertFalse($this->queryCache->put($key, $rsm, $result));
     }
 
     public function testCancelPutToManyAssociationQueryResult(): void
@@ -459,9 +459,9 @@ class DefaultQueryCacheTest extends OrmTestCase
         $this->region->addReturn('put', true);  // put root entity
         $this->region->addReturn('put', false); // collection association fails
 
-        $this->assertFalse($this->queryCache->put($key, $rsm, $result));
-        $this->assertArrayHasKey('put', $this->region->calls);
-        $this->assertCount(2, $this->region->calls['put']);
+        self::assertFalse($this->queryCache->put($key, $rsm, $result));
+        self::assertArrayHasKey('put', $this->region->calls);
+        self::assertCount(2, $this->region->calls['put']);
     }
 
     public function testIgnoreCacheNonGetMode(): void
@@ -479,7 +479,7 @@ class DefaultQueryCacheTest extends OrmTestCase
 
         $this->region->addReturn('get', $entry);
 
-        $this->assertNull($this->queryCache->get($key, $rsm));
+        self::assertNull($this->queryCache->get($key, $rsm));
     }
 
     public function testIgnoreCacheNonPutMode(): void
@@ -500,7 +500,7 @@ class DefaultQueryCacheTest extends OrmTestCase
             $this->em->getUnitOfWork()->registerManaged($entity, ['id' => $i], ['name' => $name]);
         }
 
-        $this->assertFalse($this->queryCache->put($key, $rsm, $result));
+        self::assertFalse($this->queryCache->put($key, $rsm, $result));
     }
 
     public function testGetShouldIgnoreOldQueryCacheEntryResult(): void
@@ -532,19 +532,17 @@ class DefaultQueryCacheTest extends OrmTestCase
 
         $rsm->addRootEntityFromClassMetadata(Country::class, 'c');
 
-        $this->assertNull($this->queryCache->get($key, $rsm));
+        self::assertNull($this->queryCache->get($key, $rsm));
     }
 
     public function testGetShouldIgnoreNonQueryCacheEntryResult(): void
     {
         $rsm   = new ResultSetMappingBuilder($this->em);
         $key   = new QueryCacheKey('query.key1', 0);
-        $entry = new ArrayObject(
-            [
-                ['identifier' => ['id' => 1]],
-                ['identifier' => ['id' => 2]],
-            ]
-        );
+        $entry = new CacheEntryMock([
+            ['identifier' => ['id' => 1]],
+            ['identifier' => ['id' => 2]],
+        ]);
 
         $data = [
             ['id' => 1, 'name' => 'Foo'],
@@ -563,7 +561,7 @@ class DefaultQueryCacheTest extends OrmTestCase
 
         $rsm->addRootEntityFromClassMetadata(Country::class, 'c');
 
-        $this->assertNull($this->queryCache->get($key, $rsm));
+        self::assertNull($this->queryCache->get($key, $rsm));
     }
 
     public function testGetShouldIgnoreMissingEntityQueryCacheEntry(): void
@@ -582,7 +580,7 @@ class DefaultQueryCacheTest extends OrmTestCase
 
         $rsm->addRootEntityFromClassMetadata(Country::class, 'c');
 
-        $this->assertNull($this->queryCache->get($key, $rsm));
+        self::assertNull($this->queryCache->get($key, $rsm));
     }
 
     public function testGetAssociationValue(): void
@@ -618,20 +616,20 @@ class DefaultQueryCacheTest extends OrmTestCase
         $cities      = $reflection->invoke($this->queryCache, $rsm, 'c', $bavaria);
         $attractions = $reflection->invoke($this->queryCache, $rsm, 'a', $bavaria);
 
-        $this->assertCount(2, $cities);
-        $this->assertCount(2, $attractions);
+        self::assertCount(2, $cities);
+        self::assertCount(2, $attractions);
 
-        $this->assertInstanceOf(Collection::class, $cities);
-        $this->assertInstanceOf(Collection::class, $attractions[0]);
-        $this->assertInstanceOf(Collection::class, $attractions[1]);
+        self::assertInstanceOf(Collection::class, $cities);
+        self::assertInstanceOf(Collection::class, $attractions[0]);
+        self::assertInstanceOf(Collection::class, $attractions[1]);
 
-        $this->assertCount(2, $attractions[0]);
-        $this->assertCount(1, $attractions[1]);
+        self::assertCount(2, $attractions[0]);
+        self::assertCount(1, $attractions[1]);
     }
 
     public function testScalarResultException(): void
     {
-        $this->expectException('Doctrine\ORM\Cache\CacheException');
+        $this->expectException(CacheException::class);
         $this->expectExceptionMessage('Second level cache does not support scalar results.');
         $result = [];
         $key    = new QueryCacheKey('query.key1', 0);
@@ -644,7 +642,7 @@ class DefaultQueryCacheTest extends OrmTestCase
 
     public function testSupportMultipleRootEntitiesException(): void
     {
-        $this->expectException('Doctrine\ORM\Cache\CacheException');
+        $this->expectException(CacheException::class);
         $this->expectExceptionMessage('Second level cache does not support multiple root entities.');
         $result = [];
         $key    = new QueryCacheKey('query.key1', 0);
@@ -658,7 +656,7 @@ class DefaultQueryCacheTest extends OrmTestCase
 
     public function testNotCacheableEntityException(): void
     {
-        $this->expectException('Doctrine\ORM\Cache\CacheException');
+        $this->expectException(CacheException::class);
         $this->expectExceptionMessage('Entity "Doctrine\Tests\Models\Generic\BooleanModel" not configured as part of the second-level cache.');
         $result = [];
         $key    = new QueryCacheKey('query.key1', 0);
@@ -676,7 +674,7 @@ class DefaultQueryCacheTest extends OrmTestCase
             $this->em->getUnitOfWork()->registerManaged($entity, ['id' => $i], ['booleanField' => $boolean]);
         }
 
-        $this->assertFalse($this->queryCache->put($key, $rsm, $result));
+        self::assertFalse($this->queryCache->put($key, $rsm, $result));
     }
 }
 
