@@ -9,24 +9,25 @@ use Doctrine\ORM\Cache\Persister\CachedPersister;
 use Doctrine\ORM\Cache\Persister\Collection\AbstractCollectionPersister;
 use Doctrine\ORM\Cache\Persister\Collection\CachedCollectionPersister;
 use Doctrine\ORM\Cache\Region;
-use Doctrine\ORM\EntityManager;
+use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\ORM\PersistentCollection;
 use Doctrine\ORM\Persisters\Collection\CollectionPersister;
 use Doctrine\Tests\Models\Cache\State;
 use Doctrine\Tests\OrmTestCase;
+use PHPUnit\Framework\MockObject\MockObject;
 
 /**
  * @group DDC-2183
  */
 abstract class AbstractCollectionPersisterTest extends OrmTestCase
 {
-    /** @var Region */
+    /** @var Region&MockObject */
     protected $region;
 
     /** @var CollectionPersister */
     protected $collectionPersister;
 
-    /** @var EntityManager */
+    /** @var EntityManagerInterface */
     protected $em;
 
     /** @var array */
@@ -55,14 +56,11 @@ abstract class AbstractCollectionPersisterTest extends OrmTestCase
         'loadCriteria',
     ];
 
-    /**
-     * @param array $mapping
-     */
-    abstract protected function createPersister(EntityManager $em, CollectionPersister $persister, Region $region, array $mapping): AbstractCollectionPersister;
+    abstract protected function createPersister(EntityManagerInterface $em, CollectionPersister $persister, Region $region, array $mapping): AbstractCollectionPersister;
 
     protected function setUp(): void
     {
-        $this->getSharedSecondLevelCacheDriverImpl()->flushAll();
+        $this->getSharedSecondLevelCache()->clear();
         $this->enableSecondLevelCache();
         parent::setUp();
 
@@ -73,6 +71,9 @@ abstract class AbstractCollectionPersisterTest extends OrmTestCase
                                            ->getMock();
     }
 
+    /**
+     * @return Region&MockObject
+     */
     protected function createRegion(): Region
     {
         return $this->getMockBuilder(Region::class)
@@ -104,9 +105,9 @@ abstract class AbstractCollectionPersisterTest extends OrmTestCase
     {
         $persister = $this->createPersisterDefault();
 
-        $this->assertInstanceOf(CollectionPersister::class, $persister);
-        $this->assertInstanceOf(CachedPersister::class, $persister);
-        $this->assertInstanceOf(CachedCollectionPersister::class, $persister);
+        self::assertInstanceOf(CollectionPersister::class, $persister);
+        self::assertInstanceOf(CachedPersister::class, $persister);
+        self::assertInstanceOf(CachedCollectionPersister::class, $persister);
     }
 
     public function testInvokeDelete(): void
@@ -117,11 +118,11 @@ abstract class AbstractCollectionPersisterTest extends OrmTestCase
 
         $this->em->getUnitOfWork()->registerManaged($entity, ['id' => 1], ['id' => 1, 'name' => 'Foo']);
 
-        $this->collectionPersister->expects($this->once())
+        $this->collectionPersister->expects(self::once())
             ->method('delete')
-            ->with($this->equalTo($collection));
+            ->with(self::equalTo($collection));
 
-        $this->assertNull($persister->delete($collection));
+        self::assertNull($persister->delete($collection));
     }
 
     public function testInvokeUpdate(): void
@@ -134,11 +135,11 @@ abstract class AbstractCollectionPersisterTest extends OrmTestCase
 
         $this->em->getUnitOfWork()->registerManaged($entity, ['id' => 1], ['id' => 1, 'name' => 'Foo']);
 
-        $this->collectionPersister->expects($this->once())
+        $this->collectionPersister->expects(self::once())
             ->method('update')
-            ->with($this->equalTo($collection));
+            ->with(self::equalTo($collection));
 
-        $this->assertNull($persister->update($collection));
+        self::assertNull($persister->update($collection));
     }
 
     public function testInvokeCount(): void
@@ -149,12 +150,12 @@ abstract class AbstractCollectionPersisterTest extends OrmTestCase
 
         $this->em->getUnitOfWork()->registerManaged($entity, ['id' => 1], ['id' => 1, 'name' => 'Foo']);
 
-        $this->collectionPersister->expects($this->once())
+        $this->collectionPersister->expects(self::once())
             ->method('count')
-            ->with($this->equalTo($collection))
-            ->will($this->returnValue(0));
+            ->with(self::equalTo($collection))
+            ->will(self::returnValue(0));
 
-        $this->assertEquals(0, $persister->count($collection));
+        self::assertEquals(0, $persister->count($collection));
     }
 
     public function testInvokeSlice(): void
@@ -166,12 +167,12 @@ abstract class AbstractCollectionPersisterTest extends OrmTestCase
 
         $this->em->getUnitOfWork()->registerManaged($entity, ['id' => 1], ['id' => 1, 'name' => 'Foo']);
 
-        $this->collectionPersister->expects($this->once())
+        $this->collectionPersister->expects(self::once())
             ->method('slice')
-            ->with($this->equalTo($collection), $this->equalTo(1), $this->equalTo(2))
-            ->will($this->returnValue($slice));
+            ->with(self::equalTo($collection), self::equalTo(1), self::equalTo(2))
+            ->will(self::returnValue($slice));
 
-        $this->assertEquals($slice, $persister->slice($collection, 1, 2));
+        self::assertEquals($slice, $persister->slice($collection, 1, 2));
     }
 
     public function testInvokeContains(): void
@@ -183,12 +184,12 @@ abstract class AbstractCollectionPersisterTest extends OrmTestCase
 
         $this->em->getUnitOfWork()->registerManaged($entity, ['id' => 1], ['id' => 1, 'name' => 'Foo']);
 
-        $this->collectionPersister->expects($this->once())
+        $this->collectionPersister->expects(self::once())
             ->method('contains')
-            ->with($this->equalTo($collection), $this->equalTo($element))
-            ->will($this->returnValue(false));
+            ->with(self::equalTo($collection), self::equalTo($element))
+            ->will(self::returnValue(false));
 
-        $this->assertFalse($persister->contains($collection, $element));
+        self::assertFalse($persister->contains($collection, $element));
     }
 
     public function testInvokeContainsKey(): void
@@ -199,12 +200,12 @@ abstract class AbstractCollectionPersisterTest extends OrmTestCase
 
         $this->em->getUnitOfWork()->registerManaged($entity, ['id' => 1], ['id' => 1, 'name' => 'Foo']);
 
-        $this->collectionPersister->expects($this->once())
+        $this->collectionPersister->expects(self::once())
             ->method('containsKey')
-            ->with($this->equalTo($collection), $this->equalTo(0))
-            ->will($this->returnValue(false));
+            ->with(self::equalTo($collection), self::equalTo(0))
+            ->will(self::returnValue(false));
 
-        $this->assertFalse($persister->containsKey($collection, 0));
+        self::assertFalse($persister->containsKey($collection, 0));
     }
 
     public function testInvokeGet(): void
@@ -216,11 +217,11 @@ abstract class AbstractCollectionPersisterTest extends OrmTestCase
 
         $this->em->getUnitOfWork()->registerManaged($entity, ['id' => 1], ['id' => 1, 'name' => 'Foo']);
 
-        $this->collectionPersister->expects($this->once())
+        $this->collectionPersister->expects(self::once())
             ->method('get')
-            ->with($this->equalTo($collection), $this->equalTo(0))
-            ->will($this->returnValue($element));
+            ->with(self::equalTo($collection), self::equalTo(0))
+            ->will(self::returnValue($element));
 
-        $this->assertEquals($element, $persister->get($collection, 0));
+        self::assertEquals($element, $persister->get($collection, 0));
     }
 }
