@@ -7,9 +7,8 @@ namespace Doctrine\Tests\ORM\Decorator;
 use Doctrine\ORM\Decorator\EntityManagerDecorator;
 use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\ORM\Query\ResultSetMapping;
-use Doctrine\Tests\VerifyDeprecations;
+use PHPUnit\Framework\MockObject\MockObject;
 use PHPUnit\Framework\TestCase;
-use PHPUnit_Framework_MockObject_MockObject;
 use ReflectionClass;
 use ReflectionMethod;
 
@@ -18,8 +17,6 @@ use function in_array;
 
 class EntityManagerDecoratorTest extends TestCase
 {
-    use VerifyDeprecations;
-
     public const VOID_METHODS = [
         'persist',
         'remove',
@@ -35,15 +32,9 @@ class EntityManagerDecoratorTest extends TestCase
         'lock',
     ];
 
-    /** @var EntityManagerInterface|PHPUnit_Framework_MockObject_MockObject */
+    /** @var EntityManagerInterface&MockObject */
     private $wrapped;
 
-    /** @before */
-    public function ignoreDeprecationMessagesFromDoctrinePersistence(): void
-    {
-        $this->ignoreDeprecationMessage('The Doctrine\Common\Persistence\ObjectManagerDecorator class is deprecated since doctrine/persistence 1.3 and will be removed in 2.0. Use \Doctrine\Persistence\ObjectManagerDecorator instead.');
-    }
-
     protected function setUp(): void
     {
         $this->wrapped = $this->createMock(EntityManagerInterface::class);
@@ -76,6 +67,16 @@ class EntityManagerDecoratorTest extends TestCase
             return [$method->getName(), ['name', new ResultSetMapping()]];
         }
 
+        if ($method->getName() === 'wrapInTransaction') {
+            return [
+                $method->getName(),
+                [
+                    static function (): void {
+                    },
+                ],
+            ];
+        }
+
         if ($method->getNumberOfRequiredParameters() === 0) {
             return [$method->getName(), []];
         }
@@ -96,9 +97,9 @@ class EntityManagerDecoratorTest extends TestCase
      */
     public function testAllMethodCallsAreDelegatedToTheWrappedInstance($method, array $parameters): void
     {
-        $return = ! in_array($method, self::VOID_METHODS) ? 'INNER VALUE FROM ' . $method : null;
+        $return = ! in_array($method, self::VOID_METHODS, true) ? 'INNER VALUE FROM ' . $method : null;
 
-        $this->wrapped->expects($this->once())
+        $this->wrapped->expects(self::once())
             ->method($method)
             ->with(...$parameters)
             ->willReturn($return);
@@ -106,14 +107,6 @@ class EntityManagerDecoratorTest extends TestCase
         $decorator = new class ($this->wrapped) extends EntityManagerDecorator {
         };
 
-        $this->assertSame($return, $decorator->$method(...$parameters));
-
-        if (in_array($method, ['copy', 'merge', 'detach', 'getHydrator'], true)) {
-            $this->assertHasDeprecationMessages();
-
-            return;
-        }
-
-        $this->assertNotHasDeprecationMessages();
+        self::assertSame($return, $decorator->$method(...$parameters));
     }
 }
