@@ -19,18 +19,12 @@ use Doctrine\Tests\Models\CMS\CmsComment;
 use Doctrine\Tests\Models\CMS\CmsPhonenumber;
 use Doctrine\Tests\Models\CMS\CmsUser;
 use Doctrine\Tests\OrmFunctionalTestCase;
-use Doctrine\Tests\VerifyDeprecations;
 use InvalidArgumentException;
 
-use function count;
 use function get_class;
-use function is_array;
-use function is_numeric;
 
 class BasicFunctionalTest extends OrmFunctionalTestCase
 {
-    use VerifyDeprecations;
-
     protected function setUp(): void
     {
         $this->useModelSet('cms');
@@ -48,45 +42,45 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
 
         $this->_em->flush();
 
-        $this->assertTrue(is_numeric($user->id));
-        $this->assertTrue($this->_em->contains($user));
+        self::assertIsNumeric($user->id);
+        self::assertTrue($this->_em->contains($user));
 
         // Read
         $user2 = $this->_em->find(CmsUser::class, $user->id);
-        $this->assertTrue($user === $user2);
+        self::assertSame($user, $user2);
 
         // Add a phonenumber
         $ph              = new CmsPhonenumber();
         $ph->phonenumber = '12345';
         $user->addPhonenumber($ph);
         $this->_em->flush();
-        $this->assertTrue($this->_em->contains($ph));
-        $this->assertTrue($this->_em->contains($user));
+        self::assertTrue($this->_em->contains($ph));
+        self::assertTrue($this->_em->contains($user));
 
         // Update name
         $user->name = 'guilherme';
         $this->_em->flush();
-        $this->assertEquals('guilherme', $user->name);
+        self::assertEquals('guilherme', $user->name);
 
         // Add another phonenumber
         $ph2              = new CmsPhonenumber();
         $ph2->phonenumber = '6789';
         $user->addPhonenumber($ph2);
         $this->_em->flush();
-        $this->assertTrue($this->_em->contains($ph2));
+        self::assertTrue($this->_em->contains($ph2));
 
         // Delete
         $this->_em->remove($user);
-        $this->assertTrue($this->_em->getUnitOfWork()->isScheduledForDelete($user));
-        $this->assertTrue($this->_em->getUnitOfWork()->isScheduledForDelete($ph));
-        $this->assertTrue($this->_em->getUnitOfWork()->isScheduledForDelete($ph2));
+        self::assertTrue($this->_em->getUnitOfWork()->isScheduledForDelete($user));
+        self::assertTrue($this->_em->getUnitOfWork()->isScheduledForDelete($ph));
+        self::assertTrue($this->_em->getUnitOfWork()->isScheduledForDelete($ph2));
         $this->_em->flush();
-        $this->assertFalse($this->_em->getUnitOfWork()->isScheduledForDelete($user));
-        $this->assertFalse($this->_em->getUnitOfWork()->isScheduledForDelete($ph));
-        $this->assertFalse($this->_em->getUnitOfWork()->isScheduledForDelete($ph2));
-        $this->assertEquals(UnitOfWork::STATE_NEW, $this->_em->getUnitOfWork()->getEntityState($user));
-        $this->assertEquals(UnitOfWork::STATE_NEW, $this->_em->getUnitOfWork()->getEntityState($ph));
-        $this->assertEquals(UnitOfWork::STATE_NEW, $this->_em->getUnitOfWork()->getEntityState($ph2));
+        self::assertFalse($this->_em->getUnitOfWork()->isScheduledForDelete($user));
+        self::assertFalse($this->_em->getUnitOfWork()->isScheduledForDelete($ph));
+        self::assertFalse($this->_em->getUnitOfWork()->isScheduledForDelete($ph2));
+        self::assertEquals(UnitOfWork::STATE_NEW, $this->_em->getUnitOfWork()->getEntityState($user));
+        self::assertEquals(UnitOfWork::STATE_NEW, $this->_em->getUnitOfWork()->getEntityState($ph));
+        self::assertEquals(UnitOfWork::STATE_NEW, $this->_em->getUnitOfWork()->getEntityState($ph2));
     }
 
     public function testOneToManyAssociationModification(): void
@@ -113,8 +107,8 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
 
         $this->_em->flush();
 
-        $this->assertEquals(1, count($user->phonenumbers));
-        $this->assertNull($ph1->user);
+        self::assertCount(1, $user->phonenumbers);
+        self::assertNull($ph1->user);
     }
 
     public function testBasicOneToOne(): void
@@ -140,8 +134,8 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $userId = $this->_em->getConnection()->executeQuery(
             'SELECT user_id FROM cms_addresses WHERE id=?',
             [$address->id]
-        )->fetchColumn();
-        $this->assertTrue(is_numeric($userId));
+        )->fetchOne();
+        self::assertIsNumeric($userId);
 
         $this->_em->clear();
 
@@ -150,8 +144,8 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
                 ->getSingleResult();
 
         // Address has been eager-loaded because it cant be lazy
-        $this->assertInstanceOf(CmsAddress::class, $user2->address);
-        $this->assertNotInstanceOf(Proxy::class, $user2->address);
+        self::assertInstanceOf(CmsAddress::class, $user2->address);
+        self::assertNotInstanceOf(Proxy::class, $user2->address);
     }
 
     /**
@@ -164,15 +158,15 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $user->username = 'gblanco';
         $user->status   = 'developer';
 
-        $this->assertEquals(UnitOfWork::STATE_NEW, $this->_em->getUnitOfWork()->getEntityState($user), 'State should be UnitOfWork::STATE_NEW');
+        self::assertEquals(UnitOfWork::STATE_NEW, $this->_em->getUnitOfWork()->getEntityState($user), 'State should be UnitOfWork::STATE_NEW');
 
         $this->_em->persist($user);
 
-        $this->assertEquals(UnitOfWork::STATE_MANAGED, $this->_em->getUnitOfWork()->getEntityState($user), 'State should be UnitOfWork::STATE_MANAGED');
+        self::assertEquals(UnitOfWork::STATE_MANAGED, $this->_em->getUnitOfWork()->getEntityState($user), 'State should be UnitOfWork::STATE_MANAGED');
 
         $this->_em->remove($user);
 
-        $this->assertEquals(UnitOfWork::STATE_NEW, $this->_em->getUnitOfWork()->getEntityState($user), 'State should be UnitOfWork::STATE_NEW');
+        self::assertEquals(UnitOfWork::STATE_NEW, $this->_em->getUnitOfWork()->getEntityState($user), 'State should be UnitOfWork::STATE_NEW');
 
         $this->_em->persist($user);
         $this->_em->flush();
@@ -180,12 +174,12 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
 
         $this->_em->remove($user);
 
-        $this->assertEquals(UnitOfWork::STATE_REMOVED, $this->_em->getUnitOfWork()->getEntityState($user), 'State should be UnitOfWork::STATE_REMOVED');
+        self::assertEquals(UnitOfWork::STATE_REMOVED, $this->_em->getUnitOfWork()->getEntityState($user), 'State should be UnitOfWork::STATE_REMOVED');
         $this->_em->flush();
 
-        $this->assertEquals(UnitOfWork::STATE_NEW, $this->_em->getUnitOfWork()->getEntityState($user), 'State should be UnitOfWork::STATE_NEW');
+        self::assertEquals(UnitOfWork::STATE_NEW, $this->_em->getUnitOfWork()->getEntityState($user), 'State should be UnitOfWork::STATE_NEW');
 
-        $this->assertNull($this->_em->find(CmsUser::class, $id));
+        self::assertNull($this->_em->find(CmsUser::class, $id));
     }
 
     public function testOneToManyOrphanRemoval(): void
@@ -206,18 +200,18 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $this->_em->flush();
 
         $user->getPhonenumbers()->remove(0);
-        $this->assertEquals(2, count($user->getPhonenumbers()));
+        self::assertCount(2, $user->getPhonenumbers());
 
         $this->_em->flush();
 
         // Check that there are just 2 phonenumbers left
-        $count = $this->_em->getConnection()->fetchColumn('SELECT COUNT(*) FROM cms_phonenumbers');
-        $this->assertEquals(2, $count); // only 2 remaining
+        $count = $this->_em->getConnection()->fetchOne('SELECT COUNT(*) FROM cms_phonenumbers');
+        self::assertEquals(2, $count); // only 2 remaining
 
         // check that clear() removes the others via orphan removal
         $user->getPhonenumbers()->clear();
         $this->_em->flush();
-        $this->assertEquals(0, $this->_em->getConnection()->fetchColumn('select count(*) from cms_phonenumbers'));
+        self::assertEquals(0, $this->_em->getConnection()->fetchOne('select count(*) from cms_phonenumbers'));
     }
 
     public function testBasicQuery(): void
@@ -233,10 +227,10 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
 
         $users = $query->getResult();
 
-        $this->assertEquals(1, count($users));
-        $this->assertEquals('Guilherme', $users[0]->name);
-        $this->assertEquals('gblanco', $users[0]->username);
-        $this->assertEquals('developer', $users[0]->status);
+        self::assertCount(1, $users);
+        self::assertEquals('Guilherme', $users[0]->name);
+        self::assertEquals('gblanco', $users[0]->username);
+        self::assertEquals('developer', $users[0]->status);
         //$this->assertNull($users[0]->phonenumbers);
         //$this->assertNull($users[0]->articles);
 
@@ -246,19 +240,48 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
 
         $usersArray = $query->getArrayResult();
 
-        $this->assertTrue(is_array($usersArray));
-        $this->assertEquals(1, count($usersArray));
-        $this->assertEquals('Guilherme', $usersArray[0]['name']);
-        $this->assertEquals('gblanco', $usersArray[0]['username']);
-        $this->assertEquals('developer', $usersArray[0]['status']);
+        self::assertIsArray($usersArray);
+        self::assertCount(1, $usersArray);
+        self::assertEquals('Guilherme', $usersArray[0]['name']);
+        self::assertEquals('gblanco', $usersArray[0]['username']);
+        self::assertEquals('developer', $usersArray[0]['status']);
 
         $usersScalar = $query->getScalarResult();
 
-        $this->assertTrue(is_array($usersScalar));
-        $this->assertEquals(1, count($usersScalar));
-        $this->assertEquals('Guilherme', $usersScalar[0]['u_name']);
-        $this->assertEquals('gblanco', $usersScalar[0]['u_username']);
-        $this->assertEquals('developer', $usersScalar[0]['u_status']);
+        self::assertIsArray($usersScalar);
+        self::assertCount(1, $usersScalar);
+        self::assertEquals('Guilherme', $usersScalar[0]['u_name']);
+        self::assertEquals('gblanco', $usersScalar[0]['u_username']);
+        self::assertEquals('developer', $usersScalar[0]['u_status']);
+    }
+
+    public function testSingleColumnQuery(): void
+    {
+        $gregoire           = new CmsUser();
+        $gregoire->name     = 'Gregoire';
+        $gregoire->username = 'greg0ire';
+        $gregoire->status   = 'developer';
+        $this->_em->persist($gregoire);
+
+        $bhushan           = new CmsUser();
+        $bhushan->name     = 'Bhushan';
+        $bhushan->username = 'bhushan';
+        $bhushan->status   = 'developer';
+        $this->_em->persist($bhushan);
+
+        $this->_em->flush();
+
+        $query = $this->_em->createQuery('select u.username from Doctrine\Tests\Models\CMS\CmsUser u order by u.username DESC');
+
+        $users = $query->getSingleColumnResult();
+
+        $expected = [
+            'greg0ire',
+            'bhushan',
+        ];
+
+        self::assertCount(2, $users);
+        self::assertSame($expected, $users);
     }
 
     public function testBasicOneToManyInnerJoin(): void
@@ -274,7 +297,7 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
 
         $users = $query->getResult();
 
-        $this->assertEquals(0, count($users));
+        self::assertCount(0, $users);
     }
 
     public function testBasicOneToManyLeftJoin(): void
@@ -290,13 +313,13 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
 
         $users = $query->getResult();
 
-        $this->assertEquals(1, count($users));
-        $this->assertEquals('Guilherme', $users[0]->name);
-        $this->assertEquals('gblanco', $users[0]->username);
-        $this->assertEquals('developer', $users[0]->status);
-        $this->assertInstanceOf(PersistentCollection::class, $users[0]->phonenumbers);
-        $this->assertTrue($users[0]->phonenumbers->isInitialized());
-        $this->assertEquals(0, $users[0]->phonenumbers->count());
+        self::assertCount(1, $users);
+        self::assertEquals('Guilherme', $users[0]->name);
+        self::assertEquals('gblanco', $users[0]->username);
+        self::assertEquals('developer', $users[0]->status);
+        self::assertInstanceOf(PersistentCollection::class, $users[0]->phonenumbers);
+        self::assertTrue($users[0]->phonenumbers->isInitialized());
+        self::assertEquals(0, $users[0]->phonenumbers->count());
     }
 
     public function testBasicRefresh(): void
@@ -311,9 +334,9 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
 
         $user->status = 'mascot';
 
-        $this->assertEquals('mascot', $user->status);
+        self::assertEquals('mascot', $user->status);
         $this->_em->refresh($user);
-        $this->assertEquals('developer', $user->status);
+        self::assertEquals('developer', $user->status);
     }
 
     /**
@@ -342,10 +365,10 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
 
         $user->addPhonenumber($ph2);
 
-        $this->assertEquals(2, count($user->phonenumbers));
+        self::assertCount(2, $user->phonenumbers);
         $this->_em->refresh($user);
 
-        $this->assertEquals(1, count($user->phonenumbers));
+        self::assertCount(1, $user->phonenumbers);
     }
 
     /**
@@ -374,14 +397,14 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
 
         $user->addPhonenumber($ph2);
 
-        $this->assertEquals(2, count($user->phonenumbers));
+        self::assertCount(2, $user->phonenumbers);
         $dql  = 'SELECT u FROM Doctrine\Tests\Models\CMS\CmsUser u WHERE u.id = ?1';
         $user = $this->_em->createQuery($dql)
                           ->setParameter(1, $user->id)
                           ->setHint(Query::HINT_REFRESH, true)
                           ->getSingleResult();
 
-        $this->assertEquals(1, count($user->phonenumbers));
+        self::assertCount(1, $user->phonenumbers);
     }
 
     /**
@@ -417,7 +440,7 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
                           ->setParameter(1, $userId)
                           ->getSingleResult();
 
-        $this->assertEquals(1, count($user->phonenumbers));
+        self::assertCount(1, $user->phonenumbers);
     }
 
     public function testAddToCollectionDoesNotInitialize(): void
@@ -437,19 +460,19 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $this->_em->flush();
         $this->_em->clear();
 
-        $this->assertEquals(3, $user->getPhonenumbers()->count());
+        self::assertEquals(3, $user->getPhonenumbers()->count());
 
         $query = $this->_em->createQuery("select u from Doctrine\Tests\Models\CMS\CmsUser u where u.username='gblanco'");
 
         $gblanco = $query->getSingleResult();
 
-        $this->assertFalse($gblanco->getPhonenumbers()->isInitialized());
+        self::assertFalse($gblanco->getPhonenumbers()->isInitialized());
 
         $newPhone              = new CmsPhonenumber();
         $newPhone->phonenumber = 555;
         $gblanco->addPhonenumber($newPhone);
 
-        $this->assertFalse($gblanco->getPhonenumbers()->isInitialized());
+        self::assertFalse($gblanco->getPhonenumbers()->isInitialized());
         $this->_em->persist($gblanco);
 
         $this->_em->flush();
@@ -457,7 +480,7 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
 
         $query    = $this->_em->createQuery("select u, p from Doctrine\Tests\Models\CMS\CmsUser u join u.phonenumbers p where u.username='gblanco'");
         $gblanco2 = $query->getSingleResult();
-        $this->assertEquals(4, $gblanco2->getPhonenumbers()->count());
+        self::assertEquals(4, $gblanco2->getPhonenumbers()->count());
     }
 
     public function testInitializeCollectionWithNewObjectsRetainsNewObjects(): void
@@ -477,28 +500,28 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $this->_em->flush();
         $this->_em->clear();
 
-        $this->assertEquals(3, $user->getPhonenumbers()->count());
+        self::assertEquals(3, $user->getPhonenumbers()->count());
 
         $query = $this->_em->createQuery("select u from Doctrine\Tests\Models\CMS\CmsUser u where u.username='gblanco'");
 
         $gblanco = $query->getSingleResult();
 
-        $this->assertFalse($gblanco->getPhonenumbers()->isInitialized());
+        self::assertFalse($gblanco->getPhonenumbers()->isInitialized());
 
         $newPhone              = new CmsPhonenumber();
         $newPhone->phonenumber = 555;
         $gblanco->addPhonenumber($newPhone);
 
-        $this->assertFalse($gblanco->getPhonenumbers()->isInitialized());
-        $this->assertEquals(4, $gblanco->getPhonenumbers()->count());
-        $this->assertTrue($gblanco->getPhonenumbers()->isInitialized());
+        self::assertFalse($gblanco->getPhonenumbers()->isInitialized());
+        self::assertEquals(4, $gblanco->getPhonenumbers()->count());
+        self::assertTrue($gblanco->getPhonenumbers()->isInitialized());
 
         $this->_em->flush();
         $this->_em->clear();
 
         $query    = $this->_em->createQuery("select u, p from Doctrine\Tests\Models\CMS\CmsUser u join u.phonenumbers p where u.username='gblanco'");
         $gblanco2 = $query->getSingleResult();
-        $this->assertEquals(4, $gblanco2->getPhonenumbers()->count());
+        self::assertEquals(4, $gblanco2->getPhonenumbers()->count());
     }
 
     public function testSetSetAssociationWithGetReference(): void
@@ -518,8 +541,8 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $this->_em->flush();
         $this->_em->clear(CmsAddress::class);
 
-        $this->assertFalse($this->_em->contains($address));
-        $this->assertTrue($this->_em->contains($user));
+        self::assertFalse($this->_em->contains($address));
+        self::assertTrue($this->_em->contains($user));
 
         // Assume we only got the identifier of the address and now want to attach
         // that address to the user without actually loading it, using getReference().
@@ -534,9 +557,9 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $query   = $this->_em->createQuery("select u, a from Doctrine\Tests\Models\CMS\CmsUser u join u.address a where u.username='gblanco'");
         $gblanco = $query->getSingleResult();
 
-        $this->assertInstanceOf(CmsUser::class, $gblanco);
-        $this->assertInstanceOf(CmsAddress::class, $gblanco->getAddress());
-        $this->assertEquals('Berlin', $gblanco->getAddress()->getCity());
+        self::assertInstanceOf(CmsUser::class, $gblanco);
+        self::assertInstanceOf(CmsAddress::class, $gblanco->getAddress());
+        self::assertEquals('Berlin', $gblanco->getAddress()->getCity());
     }
 
     public function testOneToManyCascadeRemove(): void
@@ -564,12 +587,12 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
 
         $this->_em->clear();
 
-        $this->assertEquals(0, $this->_em->createQuery(
+        self::assertEquals(0, $this->_em->createQuery(
             'select count(p.phonenumber) from Doctrine\Tests\Models\CMS\CmsPhonenumber p'
         )
                 ->getSingleScalarResult());
 
-        $this->assertEquals(0, $this->_em->createQuery(
+        self::assertEquals(0, $this->_em->createQuery(
             'select count(u.id) from Doctrine\Tests\Models\CMS\CmsUser u'
         )
                 ->getSingleScalarResult());
@@ -597,10 +620,10 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
 
         // test find() with leading backslash at the same time
         $articleNew = $this->_em->find('\Doctrine\Tests\Models\CMS\CmsArticle', $articleId);
-        $this->assertTrue($this->_em->contains($articleNew));
-        $this->assertEquals('Lorem ipsum dolor sunt.', $articleNew->text);
+        self::assertTrue($this->_em->contains($articleNew));
+        self::assertEquals('Lorem ipsum dolor sunt.', $articleNew->text);
 
-        $this->assertNotSame($article, $articleNew);
+        self::assertNotSame($article, $articleNew);
 
         $articleNew->text = 'Lorem ipsum dolor sunt. And stuff!';
 
@@ -608,8 +631,8 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $this->_em->clear();
 
         $articleNew = $this->_em->find(CmsArticle::class, $articleId);
-        $this->assertEquals('Lorem ipsum dolor sunt. And stuff!', $articleNew->text);
-        $this->assertTrue($this->_em->contains($articleNew));
+        self::assertEquals('Lorem ipsum dolor sunt. And stuff!', $articleNew->text);
+        self::assertTrue($this->_em->contains($articleNew));
     }
 
     public function testFlushDoesNotIssueUnnecessaryUpdates(): void
@@ -643,15 +666,15 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $query = $this->_em->createQuery('select u,a,ad from Doctrine\Tests\Models\CMS\CmsUser u join u.articles a join u.address ad');
         $user2 = $query->getSingleResult();
 
-        $this->assertEquals(1, count($user2->articles));
-        $this->assertInstanceOf(CmsAddress::class, $user2->address);
+        self::assertCount(1, $user2->articles);
+        self::assertInstanceOf(CmsAddress::class, $user2->address);
 
         $oldLogger  = $this->_em->getConnection()->getConfiguration()->getSQLLogger();
         $debugStack = new DebugStack();
         $this->_em->getConnection()->getConfiguration()->setSQLLogger($debugStack);
 
         $this->_em->flush();
-        $this->assertEquals(0, count($debugStack->queries));
+        self::assertCount(0, $debugStack->queries);
 
         $this->_em->getConnection()->getConfiguration()->setSQLLogger($oldLogger);
     }
@@ -674,7 +697,7 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $this->_em->flush();
         $this->_em->clear();
 
-        $this->assertEquals(0, $this->_em->getConnection()->fetchColumn('select count(*) from cms_users'));
+        self::assertEquals(0, $this->_em->getConnection()->fetchOne('select count(*) from cms_users'));
 
         //$this->_em->getConnection()->getConfiguration()->setSQLLogger(null);
     }
@@ -705,12 +728,12 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
                 ->setParameter('user', $userRef)
                 ->getSingleResult();
 
-        $this->assertInstanceOf(Proxy::class, $address2->getUser());
-        $this->assertTrue($userRef === $address2->getUser());
-        $this->assertFalse($userRef->__isInitialized__);
-        $this->assertEquals('Germany', $address2->country);
-        $this->assertEquals('Berlin', $address2->city);
-        $this->assertEquals('12345', $address2->zip);
+        self::assertInstanceOf(Proxy::class, $address2->getUser());
+        self::assertTrue($userRef === $address2->getUser());
+        self::assertFalse($userRef->__isInitialized__);
+        self::assertEquals('Germany', $address2->country);
+        self::assertEquals('Berlin', $address2->city);
+        self::assertEquals('12345', $address2->zip);
     }
 
     public function testOneToOneNullUpdate(): void
@@ -731,12 +754,12 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $this->_em->persist($user);
         $this->_em->flush();
 
-        $this->assertEquals(1, $this->_em->getConnection()->fetchColumn('select 1 from cms_addresses where user_id = ' . $user->id));
+        self::assertEquals(1, $this->_em->getConnection()->fetchOne('select 1 from cms_addresses where user_id = ' . $user->id));
 
         $address->user = null;
         $this->_em->flush();
 
-        $this->assertNotEquals(1, $this->_em->getConnection()->fetchColumn('select 1 from cms_addresses where user_id = ' . $user->id));
+        self::assertNotEquals(1, $this->_em->getConnection()->fetchOne('select 1 from cms_addresses where user_id = ' . $user->id));
     }
 
     /**
@@ -843,14 +866,14 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
 
         $this->_em->flush();
 
-        $this->assertEquals(0, $this->_em->getConnection()->fetchColumn('select count(*) from cms_addresses'));
+        self::assertEquals(0, $this->_em->getConnection()->fetchOne('select count(*) from cms_addresses'));
 
         // check orphan removal through replacement
         $user->address = $address;
         $address->user = $user;
 
         $this->_em->flush();
-        $this->assertEquals(1, $this->_em->getConnection()->fetchColumn('select count(*) from cms_addresses'));
+        self::assertEquals(1, $this->_em->getConnection()->fetchOne('select count(*) from cms_addresses'));
 
         // remove $address to free up unique key id
         $this->_em->remove($address);
@@ -865,7 +888,7 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $user->address       = $newAddress;
 
         $this->_em->flush();
-        $this->assertEquals(1, $this->_em->getConnection()->fetchColumn('select count(*) from cms_addresses'));
+        self::assertEquals(1, $this->_em->getConnection()->fetchOne('select count(*) from cms_addresses'));
     }
 
     public function testGetPartialReferenceToUpdateObjectWithoutLoadingIt(): void
@@ -880,15 +903,15 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $this->_em->clear();
 
         $user = $this->_em->getPartialReference(CmsUser::class, $userId);
-        $this->assertTrue($this->_em->contains($user));
-        $this->assertNull($user->getName());
-        $this->assertEquals($userId, $user->id);
+        self::assertTrue($this->_em->contains($user));
+        self::assertNull($user->getName());
+        self::assertEquals($userId, $user->id);
 
         $user->name = 'Stephan';
         $this->_em->flush();
         $this->_em->clear();
 
-        $this->assertEquals('Benjamin E.', $this->_em->find(get_class($user), $userId)->name);
+        self::assertEquals('Benjamin E.', $this->_em->find(get_class($user), $userId)->name);
     }
 
     public function testMergePersistsNewEntities(): void
@@ -899,20 +922,19 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $user->status   = 'active';
 
         $managedUser = $this->_em->merge($user);
-        $this->assertEquals('beberlei', $managedUser->username);
-        $this->assertEquals('Benjamin E.', $managedUser->name);
-        $this->assertEquals('active', $managedUser->status);
+        self::assertEquals('beberlei', $managedUser->username);
+        self::assertEquals('Benjamin E.', $managedUser->name);
+        self::assertEquals('active', $managedUser->status);
 
-        $this->assertTrue($user !== $managedUser);
-        $this->assertTrue($this->_em->contains($managedUser));
+        self::assertTrue($user !== $managedUser);
+        self::assertTrue($this->_em->contains($managedUser));
 
         $this->_em->flush();
         $userId = $managedUser->id;
         $this->_em->clear();
 
         $user2 = $this->_em->find(get_class($managedUser), $userId);
-        $this->assertInstanceOf(CmsUser::class, $user2);
-        $this->assertHasDeprecationMessages();
+        self::assertInstanceOf(CmsUser::class, $user2);
     }
 
     public function testMergeNonPersistedProperties(): void
@@ -925,22 +947,21 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $user->nonPersistedPropertyObject = new CmsPhonenumber();
 
         $managedUser = $this->_em->merge($user);
-        $this->assertEquals('test', $managedUser->nonPersistedProperty);
-        $this->assertSame($user->nonPersistedProperty, $managedUser->nonPersistedProperty);
-        $this->assertSame($user->nonPersistedPropertyObject, $managedUser->nonPersistedPropertyObject);
+        self::assertEquals('test', $managedUser->nonPersistedProperty);
+        self::assertSame($user->nonPersistedProperty, $managedUser->nonPersistedProperty);
+        self::assertSame($user->nonPersistedPropertyObject, $managedUser->nonPersistedPropertyObject);
 
-        $this->assertTrue($user !== $managedUser);
-        $this->assertTrue($this->_em->contains($managedUser));
+        self::assertTrue($user !== $managedUser);
+        self::assertTrue($this->_em->contains($managedUser));
 
         $this->_em->flush();
         $userId = $managedUser->id;
         $this->_em->clear();
 
         $user2 = $this->_em->find(get_class($managedUser), $userId);
-        $this->assertNull($user2->nonPersistedProperty);
-        $this->assertNull($user2->nonPersistedPropertyObject);
-        $this->assertEquals('active', $user2->status);
-        $this->assertHasDeprecationMessages();
+        self::assertNull($user2->nonPersistedProperty);
+        self::assertNull($user2->nonPersistedPropertyObject);
+        self::assertEquals('active', $user2->status);
     }
 
     public function testMergeThrowsExceptionIfEntityWithGeneratedIdentifierDoesNotExist(): void
@@ -953,7 +974,6 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
 
         $this->expectException(EntityNotFoundException::class);
         $this->_em->merge($user);
-        $this->assertHasDeprecationMessages();
     }
 
     /**
@@ -982,8 +1002,7 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $this->_em->flush();
         $this->_em->clear();
 
-        $this->assertNull($this->_em->find(get_class($ph), $ph->phonenumber)->getUser());
-        $this->assertHasDeprecationMessages();
+        self::assertNull($this->_em->find(get_class($ph), $ph->phonenumber)->getUser());
     }
 
     /**
@@ -1012,9 +1031,9 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
                              ->setParameter(1, $article->id)
                              ->setFetchMode(CmsArticle::class, 'user', ClassMetadata::FETCH_EAGER)
                              ->getSingleResult();
-        $this->assertInstanceOf(Proxy::class, $article->user, 'It IS a proxy, ...');
-        $this->assertTrue($article->user->__isInitialized__, '...but its initialized!');
-        $this->assertEquals($qc + 2, $this->getCurrentQueryCount());
+        self::assertInstanceOf(Proxy::class, $article->user, 'It IS a proxy, ...');
+        self::assertTrue($article->user->__isInitialized__, '...but its initialized!');
+        self::assertEquals($qc + 2, $this->getCurrentQueryCount());
     }
 
     /**
@@ -1056,14 +1075,14 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
 
         $this->_em->clear(CmsUser::class);
 
-        $this->assertEquals(UnitOfWork::STATE_DETACHED, $unitOfWork->getEntityState($user));
-        $this->assertEquals(UnitOfWork::STATE_DETACHED, $unitOfWork->getEntityState($article1));
-        $this->assertEquals(UnitOfWork::STATE_DETACHED, $unitOfWork->getEntityState($article2));
-        $this->assertEquals(UnitOfWork::STATE_MANAGED, $unitOfWork->getEntityState($address));
+        self::assertEquals(UnitOfWork::STATE_DETACHED, $unitOfWork->getEntityState($user));
+        self::assertEquals(UnitOfWork::STATE_DETACHED, $unitOfWork->getEntityState($article1));
+        self::assertEquals(UnitOfWork::STATE_DETACHED, $unitOfWork->getEntityState($article2));
+        self::assertEquals(UnitOfWork::STATE_MANAGED, $unitOfWork->getEntityState($address));
 
         $this->_em->clear();
 
-        $this->assertEquals(UnitOfWork::STATE_DETACHED, $unitOfWork->getEntityState($address));
+        self::assertEquals(UnitOfWork::STATE_DETACHED, $unitOfWork->getEntityState($address));
     }
 
     public function testFlushManyExplicitEntities(): void
@@ -1091,11 +1110,10 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $this->_em->flush([$userA, $userB]);
         $this->_em->refresh($userC);
 
-        $this->assertTrue($userA->id > 0, 'user a has an id');
-        $this->assertTrue($userB->id > 0, 'user b has an id');
-        $this->assertTrue($userC->id > 0, 'user c has an id');
-        $this->assertEquals('UserC', $userC->name, 'name has not changed because we did not flush it');
-        $this->assertHasDeprecationMessages();
+        self::assertTrue($userA->id > 0, 'user a has an id');
+        self::assertTrue($userB->id > 0, 'user b has an id');
+        self::assertTrue($userC->id > 0, 'user c has an id');
+        self::assertEquals('UserC', $userC->name, 'name has not changed because we did not flush it');
     }
 
     /**
@@ -1116,8 +1134,7 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $this->_em->clear();
 
         $user = $this->_em->find(get_class($user), $user->id);
-        $this->assertEquals('administrator', $user->status);
-        $this->assertHasDeprecationMessages();
+        self::assertEquals('administrator', $user->status);
     }
 
     /**
@@ -1159,9 +1176,8 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $this->_em->persist($otherUser);
         $this->_em->flush($user);
 
-        $this->assertTrue($this->_em->contains($otherUser), 'Other user is contained in EntityManager');
-        $this->assertTrue($otherUser->id > 0, 'other user has an id');
-        $this->assertHasDeprecationMessages();
+        self::assertTrue($this->_em->contains($otherUser), 'Other user is contained in EntityManager');
+        self::assertTrue($otherUser->id > 0, 'other user has an id');
     }
 
     /**
@@ -1187,9 +1203,8 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
 
         $this->_em->flush($user);
 
-        $this->assertTrue($this->_em->contains($address), 'Other user is contained in EntityManager');
-        $this->assertTrue($address->id > 0, 'other user has an id');
-        $this->assertHasDeprecationMessages();
+        self::assertTrue($this->_em->contains($address), 'Other user is contained in EntityManager');
+        self::assertTrue($address->id > 0, 'other user has an id');
     }
 
     /**
@@ -1238,8 +1253,7 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $this->_em->flush($user);
         $this->_em->clear();
 
-        $this->assertNull($this->_em->find(get_class($user), $userId));
-        $this->assertHasDeprecationMessages();
+        self::assertNull($this->_em->find(get_class($user), $userId));
     }
 
     /**
@@ -1266,9 +1280,8 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $this->_em->persist($otherUser);
         $this->_em->flush($user);
 
-        $this->assertTrue($this->_em->contains($otherUser), 'Other user is contained in EntityManager');
-        $this->assertTrue($otherUser->id > 0, 'other user has an id');
-        $this->assertHasDeprecationMessages();
+        self::assertTrue($this->_em->contains($otherUser), 'Other user is contained in EntityManager');
+        self::assertTrue($otherUser->id > 0, 'other user has an id');
     }
 
     /**
@@ -1297,8 +1310,7 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         $this->_em->clear();
 
         $user2 = $this->_em->find(get_class($user2), $user2->id);
-        $this->assertEquals('developer', $user2->status);
-        $this->assertHasDeprecationMessages();
+        self::assertEquals('developer', $user2->status);
     }
 
     /**
