@@ -18,9 +18,8 @@ use Doctrine\Tests\Models\Company\CompanyPerson;
 use Doctrine\Tests\Models\Company\CompanyRaffle;
 use Doctrine\Tests\OrmFunctionalTestCase;
 
-use function count;
 use function get_class;
-use function is_numeric;
+use function get_debug_type;
 use function sprintf;
 
 /**
@@ -58,14 +57,14 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
 
         $entities = $query->getResult();
 
-        $this->assertCount(2, $entities);
-        $this->assertInstanceOf(CompanyPerson::class, $entities[0]);
-        $this->assertInstanceOf(CompanyEmployee::class, $entities[1]);
-        $this->assertTrue(is_numeric($entities[0]->getId()));
-        $this->assertTrue(is_numeric($entities[1]->getId()));
-        $this->assertEquals('Roman S. Borschel', $entities[0]->getName());
-        $this->assertEquals('Guilherme Blanco', $entities[1]->getName());
-        $this->assertEquals(100000, $entities[1]->getSalary());
+        self::assertCount(2, $entities);
+        self::assertInstanceOf(CompanyPerson::class, $entities[0]);
+        self::assertInstanceOf(CompanyEmployee::class, $entities[1]);
+        self::assertIsNumeric($entities[0]->getId());
+        self::assertIsNumeric($entities[1]->getId());
+        self::assertEquals('Roman S. Borschel', $entities[0]->getName());
+        self::assertEquals('Guilherme Blanco', $entities[1]->getName());
+        self::assertEquals(100000, $entities[1]->getSalary());
 
         $this->_em->clear();
 
@@ -79,7 +78,7 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
 
         self::assertCount(1, $entities);
         self::assertInstanceOf(CompanyEmployee::class, $entities[0]);
-        $this->assertTrue(is_numeric($entities[0]->getId()));
+        self::assertIsNumeric($entities[0]->getId());
         self::assertEquals('Guilherme Blanco', $entities[0]->getName());
         self::assertEquals(100000, $entities[0]->getSalary());
 
@@ -90,8 +89,8 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
         $this->_em->clear();
 
         $guilherme = $this->_em->getRepository(get_class($employee))->findOneBy(['name' => 'Guilherme Blanco']);
-        $this->assertInstanceOf(CompanyEmployee::class, $guilherme);
-        $this->assertEquals('Guilherme Blanco', $guilherme->getName());
+        self::assertInstanceOf(CompanyEmployee::class, $guilherme);
+        self::assertEquals('Guilherme Blanco', $guilherme->getName());
 
         $this->_em->clear();
 
@@ -101,11 +100,11 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
         $query->setParameter(3, 100000);
         $query->getSQL();
         $numUpdated = $query->execute();
-        $this->assertEquals(1, $numUpdated);
+        self::assertEquals(1, $numUpdated);
 
         $query      = $this->_em->createQuery('delete from ' . CompanyPerson::class . ' p');
         $numDeleted = $query->execute();
-        $this->assertEquals(2, $numDeleted);
+        self::assertEquals(2, $numDeleted);
     }
 
     public function testMultiLevelUpdateAndFind(): void
@@ -128,11 +127,11 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
 
         $manager = $this->_em->find(CompanyManager::class, $manager->getId());
 
-        $this->assertInstanceOf(CompanyManager::class, $manager);
-        $this->assertEquals('Roman B.', $manager->getName());
-        $this->assertEquals(119000, $manager->getSalary());
-        $this->assertEquals('CEO', $manager->getTitle());
-        $this->assertTrue(is_numeric($manager->getId()));
+        self::assertInstanceOf(CompanyManager::class, $manager);
+        self::assertEquals('Roman B.', $manager->getName());
+        self::assertEquals(119000, $manager->getSalary());
+        self::assertEquals('CEO', $manager->getTitle());
+        self::assertIsNumeric($manager->getId());
     }
 
     public function testFindOnBaseClass(): void
@@ -149,11 +148,11 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
 
         $person = $this->_em->find(CompanyPerson::class, $manager->getId());
 
-        $this->assertInstanceOf(CompanyManager::class, $person);
-        $this->assertEquals('Roman S. Borschel', $person->getName());
-        $this->assertEquals(100000, $person->getSalary());
-        $this->assertEquals('CTO', $person->getTitle());
-        $this->assertTrue(is_numeric($person->getId()));
+        self::assertInstanceOf(CompanyManager::class, $person);
+        self::assertEquals('Roman S. Borschel', $person->getName());
+        self::assertEquals(100000, $person->getSalary());
+        self::assertEquals('CTO', $person->getTitle());
+        self::assertIsNumeric($person->getId());
     }
 
     public function testSelfReferencingOneToOne(): void
@@ -168,8 +167,8 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
         $wife->setName('Mary Smith');
         $wife->setSpouse($manager);
 
-        $this->assertSame($manager, $wife->getSpouse());
-        $this->assertSame($wife, $manager->getSpouse());
+        self::assertSame($manager, $wife->getSpouse());
+        self::assertSame($wife, $manager->getSpouse());
 
         $this->_em->persist($manager);
         $this->_em->persist($wife);
@@ -179,12 +178,12 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
         $query = $this->_em->createQuery('select p, s from ' . CompanyPerson::class . ' p join p.spouse s where p.name=\'Mary Smith\'');
 
         $result = $query->getResult();
-        $this->assertCount(1, $result);
-        $this->assertInstanceOf(CompanyPerson::class, $result[0]);
-        $this->assertEquals('Mary Smith', $result[0]->getName());
-        $this->assertInstanceOf(CompanyEmployee::class, $result[0]->getSpouse());
-        $this->assertEquals('John Smith', $result[0]->getSpouse()->getName());
-        $this->assertSame($result[0], $result[0]->getSpouse()->getSpouse());
+        self::assertCount(1, $result);
+        self::assertInstanceOf(CompanyPerson::class, $result[0]);
+        self::assertEquals('Mary Smith', $result[0]->getName());
+        self::assertInstanceOf(CompanyEmployee::class, $result[0]->getSpouse());
+        self::assertEquals('John Smith', $result[0]->getSpouse()->getName());
+        self::assertSame($result[0], $result[0]->getSpouse()->getSpouse());
 
         $this->_em->clear();
 
@@ -201,8 +200,8 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
 
         $person1->addFriend($person2);
 
-        $this->assertCount(1, $person1->getFriends());
-        $this->assertCount(1, $person2->getFriends());
+        self::assertCount(1, $person1->getFriends());
+        self::assertCount(1, $person2->getFriends());
 
         $this->_em->persist($person1);
         $this->_em->persist($person2);
@@ -215,12 +214,12 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
         $query->setParameter(1, 'Roman');
 
         $result = $query->getResult();
-        $this->assertCount(1, $result);
-        $this->assertCount(1, $result[0]->getFriends());
-        $this->assertEquals('Roman', $result[0]->getName());
+        self::assertCount(1, $result);
+        self::assertCount(1, $result[0]->getFriends());
+        self::assertEquals('Roman', $result[0]->getName());
 
         $friends = $result[0]->getFriends();
-        $this->assertEquals('Jonathan', $friends[0]->getName());
+        self::assertEquals('Jonathan', $friends[0]->getName());
     }
 
     public function testLazyLoading1(): void
@@ -244,21 +243,21 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
 
         $result = $q->getResult();
 
-        $this->assertCount(1, $result);
-        $this->assertInstanceOf(CompanyOrganization::class, $result[0]);
-        $this->assertNull($result[0]->getMainEvent());
+        self::assertCount(1, $result);
+        self::assertInstanceOf(CompanyOrganization::class, $result[0]);
+        self::assertNull($result[0]->getMainEvent());
 
         $events = $result[0]->getEvents();
 
-        $this->assertInstanceOf(PersistentCollection::class, $events);
-        $this->assertFalse($events->isInitialized());
+        self::assertInstanceOf(PersistentCollection::class, $events);
+        self::assertFalse($events->isInitialized());
 
-        $this->assertCount(2, $events);
+        self::assertCount(2, $events);
         if ($events[0] instanceof CompanyAuction) {
-            $this->assertInstanceOf(CompanyRaffle::class, $events[1]);
+            self::assertInstanceOf(CompanyRaffle::class, $events[1]);
         } else {
-            $this->assertInstanceOf(CompanyRaffle::class, $events[0]);
-            $this->assertInstanceOf(CompanyAuction::class, $events[1]);
+            self::assertInstanceOf(CompanyRaffle::class, $events[0]);
+            self::assertInstanceOf(CompanyAuction::class, $events[1]);
         }
 
         $this->_em->clear();
@@ -281,8 +280,8 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
         $q->setParameter(1, $event1->getId());
 
         $result = $q->getResult();
-        $this->assertCount(1, $result);
-        $this->assertInstanceOf(CompanyAuction::class, $result[0], sprintf('Is of class %s', get_class($result[0])));
+        self::assertCount(1, $result);
+        self::assertInstanceOf(CompanyAuction::class, $result[0], sprintf('Is of class %s', get_debug_type($result[0])));
 
         $this->_em->clear();
 
@@ -295,13 +294,13 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
 
         $result = $q->getResult();
 
-        $this->assertCount(1, $result);
-        $this->assertInstanceOf(CompanyOrganization::class, $result[0]);
+        self::assertCount(1, $result);
+        self::assertInstanceOf(CompanyOrganization::class, $result[0]);
 
         $mainEvent = $result[0]->getMainEvent();
         // mainEvent should have been loaded because it can't be lazy
-        $this->assertInstanceOf(CompanyAuction::class, $mainEvent);
-        $this->assertNotInstanceOf(Proxy::class, $mainEvent);
+        self::assertInstanceOf(CompanyAuction::class, $mainEvent);
+        self::assertNotInstanceOf(Proxy::class, $mainEvent);
 
         $this->_em->clear();
 
@@ -319,7 +318,7 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
         $query  = $this->_em->createQuery('SELECT count(p.id) FROM ' . CompanyEmployee::class . ' p WHERE p.salary = 1');
         $result = $query->getResult();
 
-        $this->assertGreaterThan(0, count($result));
+        self::assertGreaterThan(0, $result);
 
         $this->_em->clear();
 
@@ -365,7 +364,7 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
         $this->_em->remove($employee1);
         $this->_em->flush();
 
-        $this->assertNull($this->_em->find(get_class($employee1), $employee1Id));
+        self::assertNull($this->_em->find(get_class($employee1), $employee1Id));
     }
 
     /**
@@ -393,8 +392,8 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
                                 ->setParameter(1, $person->getId())
                                 ->getSingleResult();
 
-        $this->assertEquals($manager->getId(), $dqlManager->getId());
-        $this->assertEquals($person->getId(), $dqlManager->getSpouse()->getId());
+        self::assertEquals($manager->getId(), $dqlManager->getId());
+        self::assertEquals($person->getId(), $dqlManager->getSpouse()->getId());
     }
 
     /**
@@ -421,12 +420,12 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
         $repos    = $this->_em->getRepository(CompanyManager::class);
         $pmanager = $repos->findOneBy(['spouse' => $person->getId()]);
 
-        $this->assertEquals($manager->getId(), $pmanager->getId());
+        self::assertEquals($manager->getId(), $pmanager->getId());
 
         $repos    = $this->_em->getRepository(CompanyPerson::class);
         $pmanager = $repos->findOneBy(['spouse' => $person->getId()]);
 
-        $this->assertEquals($manager->getId(), $pmanager->getId());
+        self::assertEquals($manager->getId(), $pmanager->getId());
     }
 
     /**
@@ -445,13 +444,13 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
         $this->_em->clear();
 
         $ref = $this->_em->getReference(CompanyPerson::class, $manager->getId());
-        $this->assertNotInstanceOf(Proxy::class, $ref, 'Cannot Request a proxy from a class that has subclasses.');
-        $this->assertInstanceOf(CompanyPerson::class, $ref);
-        $this->assertInstanceOf(CompanyEmployee::class, $ref, 'Direct fetch of the reference has to load the child class Employee directly.');
+        self::assertNotInstanceOf(Proxy::class, $ref, 'Cannot Request a proxy from a class that has subclasses.');
+        self::assertInstanceOf(CompanyPerson::class, $ref);
+        self::assertInstanceOf(CompanyEmployee::class, $ref, 'Direct fetch of the reference has to load the child class Employee directly.');
         $this->_em->clear();
 
         $ref = $this->_em->getReference(CompanyManager::class, $manager->getId());
-        $this->assertInstanceOf(Proxy::class, $ref, 'A proxy can be generated only if no subclasses exists for the requested reference.');
+        self::assertInstanceOf(Proxy::class, $ref, 'A proxy can be generated only if no subclasses exists for the requested reference.');
     }
 
     /**
@@ -477,7 +476,7 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
 
         $manager = $this->_em->find(CompanyManager::class, $manager->getId());
 
-        $this->assertCount(1, $manager->getFriends());
+        self::assertCount(1, $manager->getFriends());
     }
 
     /**
@@ -491,12 +490,12 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
         $manager->setTitle('Awesome!');
         $manager->setDepartment('IT');
 
-        $this->assertFalse($this->_em->getUnitOfWork()->getEntityPersister(get_class($manager))->exists($manager));
+        self::assertFalse($this->_em->getUnitOfWork()->getEntityPersister(get_class($manager))->exists($manager));
 
         $this->_em->persist($manager);
         $this->_em->flush();
 
-        $this->assertTrue($this->_em->getUnitOfWork()->getEntityPersister(get_class($manager))->exists($manager));
+        self::assertTrue($this->_em->getUnitOfWork()->getEntityPersister(get_class($manager))->exists($manager));
     }
 
     /**
@@ -517,12 +516,12 @@ class ClassTableInheritanceTest extends OrmFunctionalTestCase
         $users      = $repository->matching(new Criteria(
             Criteria::expr()->eq('department', 'IT')
         ));
-        $this->assertCount(1, $users);
+        self::assertCount(1, $users);
 
         $repository = $this->_em->getRepository(CompanyManager::class);
         $users      = $repository->matching(new Criteria(
             Criteria::expr()->eq('department', 'IT')
         ));
-        $this->assertCount(1, $users);
+        self::assertCount(1, $users);
     }
 }
