@@ -4,7 +4,8 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\ORM\Functional;
 
-use Doctrine\ORM\ORMException;
+use Doctrine\ORM\Exception\MissingIdentifierField;
+use Doctrine\ORM\Exception\UnrecognizedIdentifierFields;
 use Doctrine\ORM\Query\QueryException;
 use Doctrine\Tests\IterableTester;
 use Doctrine\Tests\Models\Navigation\NavCountry;
@@ -14,8 +15,6 @@ use Doctrine\Tests\Models\Navigation\NavTour;
 use Doctrine\Tests\Models\Navigation\NavUser;
 use Doctrine\Tests\OrmFunctionalTestCase;
 
-use function count;
-
 class CompositePrimaryKeyTest extends OrmFunctionalTestCase
 {
     protected function setUp(): void
@@ -54,10 +53,10 @@ class CompositePrimaryKeyTest extends OrmFunctionalTestCase
 
         $poi = $this->_em->find(NavPointOfInterest::class, ['lat' => 100, 'long' => 200]);
 
-        $this->assertInstanceOf(NavPointOfInterest::class, $poi);
-        $this->assertEquals(100, $poi->getLat());
-        $this->assertEquals(200, $poi->getLong());
-        $this->assertEquals('Brandenburger Tor', $poi->getName());
+        self::assertInstanceOf(NavPointOfInterest::class, $poi);
+        self::assertEquals(100, $poi->getLat());
+        self::assertEquals(200, $poi->getLong());
+        self::assertEquals('Brandenburger Tor', $poi->getName());
     }
 
     /**
@@ -95,9 +94,9 @@ class CompositePrimaryKeyTest extends OrmFunctionalTestCase
         $query  = $this->_em->createQuery($dql);
         $result = $query->getResult();
 
-        $this->assertCount(1, $result);
-        $this->assertEquals(200, $result[0]['long']);
-        $this->assertEquals(100, $result[0]['lat']);
+        self::assertCount(1, $result);
+        self::assertEquals(200, $result[0]['long']);
+        self::assertEquals(100, $result[0]['lat']);
 
         $this->_em->clear();
 
@@ -111,7 +110,7 @@ class CompositePrimaryKeyTest extends OrmFunctionalTestCase
 
         $tour = $this->_em->find(NavTour::class, $tour->getId());
 
-        $this->assertEquals(1, count($tour->getPointOfInterests()));
+        self::assertCount(1, $tour->getPointOfInterests());
     }
 
     public function testCompositeDqlEagerFetching(): void
@@ -130,13 +129,13 @@ class CompositePrimaryKeyTest extends OrmFunctionalTestCase
 
         $pois = $tours[0]->getPointOfInterests();
 
-        $this->assertEquals(1, count($pois));
-        $this->assertEquals('Brandenburger Tor', $pois[0]->getName());
+        self::assertCount(1, $pois);
+        self::assertEquals('Brandenburger Tor', $pois[0]->getName());
     }
 
     public function testCompositeCollectionMemberExpression(): void
     {
-        $this->markTestSkipped('How to test this?');
+        self::markTestSkipped('How to test this?');
 
         $this->putGermanysBrandenburderTor();
         $this->putTripAroundEurope();
@@ -146,7 +145,7 @@ class CompositePrimaryKeyTest extends OrmFunctionalTestCase
         $tours = $this->_em->createQuery($dql)
                            ->getResult();
 
-        $this->assertEquals(1, count($tours));
+        self::assertCount(1, $tours);
 
         $this->_em->clear();
 
@@ -155,7 +154,7 @@ class CompositePrimaryKeyTest extends OrmFunctionalTestCase
 
     public function testSpecifyUnknownIdentifierPrimaryKeyFails(): void
     {
-        $this->expectException(ORMException::class);
+        $this->expectException(MissingIdentifierField::class);
         $this->expectExceptionMessage('The identifier long is missing for a query of Doctrine\Tests\Models\Navigation\NavPointOfInterest');
 
         $poi = $this->_em->find(NavPointOfInterest::class, ['key1' => 100]);
@@ -163,8 +162,8 @@ class CompositePrimaryKeyTest extends OrmFunctionalTestCase
 
     public function testUnrecognizedIdentifierFieldsOnGetReference(): void
     {
-        $this->expectException(ORMException::class);
-        $this->expectExceptionMessage("Unrecognized identifier fields: 'key1'");
+        $this->expectException(UnrecognizedIdentifierFields::class);
+        $this->expectExceptionMessage('Unrecognized identifier fields: "key1"');
 
         $poi = $this->_em->getReference(NavPointOfInterest::class, ['lat' => 10, 'long' => 20, 'key1' => 100]);
     }
@@ -188,6 +187,6 @@ class CompositePrimaryKeyTest extends OrmFunctionalTestCase
         $this->_em->clear();
 
         $poi = $this->_em->find(NavPointOfInterest::class, ['lat' => 100, 'long' => 200]);
-        $this->assertEquals(0, count($poi->getVisitors()));
+        self::assertCount(0, $poi->getVisitors());
     }
 }
