@@ -15,7 +15,6 @@ use Doctrine\Tests\OrmFunctionalTestCase;
 
 use function array_shift;
 use function assert;
-use function count;
 
 /**
  * Description of ExtraLazyCollectionTest
@@ -67,9 +66,13 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
         $class->associationMappings['phonenumbers']['fetch']   = ClassMetadataInfo::FETCH_EXTRA_LAZY;
         $class->associationMappings['phonenumbers']['indexBy'] = 'phonenumber';
 
-        unset($class->associationMappings['phonenumbers']['cache']);
-        unset($class->associationMappings['articles']['cache']);
-        unset($class->associationMappings['users']['cache']);
+        foreach (['phonenumbers', 'articles', 'users'] as $field) {
+            if (isset($class->associationMappings[$field]['cache'])) {
+                $this->previousCacheConfig[$field] = $class->associationMappings[$field]['cache'];
+            }
+
+            unset($class->associationMappings[$field]['cache']);
+        }
 
         $class                                          = $this->_em->getClassMetadata(CmsGroup::class);
         $class->associationMappings['users']['fetch']   = ClassMetadataInfo::FETCH_EXTRA_LAZY;
@@ -87,6 +90,13 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
         $class->associationMappings['articles']['fetch']     = ClassMetadataInfo::FETCH_LAZY;
         $class->associationMappings['phonenumbers']['fetch'] = ClassMetadataInfo::FETCH_LAZY;
 
+        foreach (['phonenumbers', 'articles', 'users'] as $field) {
+            if (isset($this->previousCacheConfig[$field])) {
+                $class->associationMappings[$field]['cache'] = $this->previousCacheConfig[$field];
+                unset($this->previousCacheConfig[$field]);
+            }
+        }
+
         unset($class->associationMappings['groups']['indexBy']);
         unset($class->associationMappings['articles']['indexBy']);
         unset($class->associationMappings['phonenumbers']['indexBy']);
@@ -106,14 +116,14 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
         $user       = $this->_em->find(CmsUser::class, $this->userId);
         $queryCount = $this->getCurrentQueryCount();
 
-        $this->assertFalse($user->groups->isInitialized());
-        $this->assertEquals(3, count($user->groups));
-        $this->assertFalse($user->groups->isInitialized());
+        self::assertFalse($user->groups->isInitialized());
+        self::assertCount(3, $user->groups);
+        self::assertFalse($user->groups->isInitialized());
 
         foreach ($user->groups as $group) {
         }
 
-        $this->assertEquals($queryCount + 2, $this->getCurrentQueryCount(), 'Expecting two queries to be fired for count, then iteration.');
+        self::assertEquals($queryCount + 2, $this->getCurrentQueryCount(), 'Expecting two queries to be fired for count, then iteration.');
     }
 
     /**
@@ -129,9 +139,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
         $user->addGroup($newGroup);
         $this->_em->persist($newGroup);
 
-        $this->assertFalse($user->groups->isInitialized());
-        $this->assertEquals(4, count($user->groups));
-        $this->assertFalse($user->groups->isInitialized());
+        self::assertFalse($user->groups->isInitialized());
+        self::assertCount(4, $user->groups);
+        self::assertFalse($user->groups->isInitialized());
     }
 
     /**
@@ -146,9 +156,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
         foreach ($user->groups as $group) {
         }
 
-        $this->assertTrue($user->groups->isInitialized());
-        $this->assertEquals(3, count($user->groups));
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount(), 'Should only execute one query to initialize collection, no extra query for count() more.');
+        self::assertTrue($user->groups->isInitialized());
+        self::assertCount(3, $user->groups);
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount(), 'Should only execute one query to initialize collection, no extra query for count() more.');
     }
 
     /**
@@ -157,10 +167,10 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
     public function testCountInverseCollection(): void
     {
         $group = $this->_em->find(CmsGroup::class, $this->groupId);
-        $this->assertFalse($group->users->isInitialized(), 'Pre-Condition');
+        self::assertFalse($group->users->isInitialized(), 'Pre-Condition');
 
-        $this->assertEquals(4, count($group->users));
-        $this->assertFalse($group->users->isInitialized(), 'Extra Lazy collection should not be initialized by counting the collection.');
+        self::assertCount(4, $group->users);
+        self::assertFalse($group->users->isInitialized(), 'Extra Lazy collection should not be initialized by counting the collection.');
     }
 
     /**
@@ -169,9 +179,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
     public function testCountOneToMany(): void
     {
         $user = $this->_em->find(CmsUser::class, $this->userId);
-        $this->assertFalse($user->groups->isInitialized(), 'Pre-Condition');
+        self::assertFalse($user->groups->isInitialized(), 'Pre-Condition');
 
-        $this->assertEquals(2, count($user->articles));
+        self::assertCount(2, $user->articles);
     }
 
     /**
@@ -181,8 +191,8 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
     {
         $otherClass = $this->_em->find(DDC2504OtherClass::class, $this->ddc2504OtherClassId);
 
-        $this->assertFalse($otherClass->childClasses->isInitialized(), 'Pre-Condition');
-        $this->assertEquals(2, count($otherClass->childClasses));
+        self::assertFalse($otherClass->childClasses->isInitialized(), 'Pre-Condition');
+        self::assertCount(2, $otherClass->childClasses);
     }
 
     /**
@@ -191,10 +201,10 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
     public function testFullSlice(): void
     {
         $user = $this->_em->find(CmsUser::class, $this->userId);
-        $this->assertFalse($user->groups->isInitialized(), 'Pre-Condition: Collection is not initialized.');
+        self::assertFalse($user->groups->isInitialized(), 'Pre-Condition: Collection is not initialized.');
 
         $someGroups = $user->groups->slice(null);
-        $this->assertEquals(3, count($someGroups));
+        self::assertCount(3, $someGroups);
     }
 
     /**
@@ -204,29 +214,29 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
     public function testSlice(): void
     {
         $user = $this->_em->find(CmsUser::class, $this->userId);
-        $this->assertFalse($user->groups->isInitialized(), 'Pre-Condition: Collection is not initialized.');
+        self::assertFalse($user->groups->isInitialized(), 'Pre-Condition: Collection is not initialized.');
 
         $queryCount = $this->getCurrentQueryCount();
 
         $someGroups = $user->groups->slice(0, 2);
 
-        $this->assertContainsOnly(CmsGroup::class, $someGroups);
-        $this->assertEquals(2, count($someGroups));
-        $this->assertFalse($user->groups->isInitialized(), "Slice should not initialize the collection if it wasn't before!");
+        self::assertContainsOnly(CmsGroup::class, $someGroups);
+        self::assertCount(2, $someGroups);
+        self::assertFalse($user->groups->isInitialized(), "Slice should not initialize the collection if it wasn't before!");
 
         $otherGroup = $user->groups->slice(2, 1);
 
-        $this->assertContainsOnly(CmsGroup::class, $otherGroup);
-        $this->assertEquals(1, count($otherGroup));
-        $this->assertFalse($user->groups->isInitialized());
+        self::assertContainsOnly(CmsGroup::class, $otherGroup);
+        self::assertCount(1, $otherGroup);
+        self::assertFalse($user->groups->isInitialized());
 
         foreach ($user->groups as $group) {
         }
 
-        $this->assertTrue($user->groups->isInitialized());
-        $this->assertEquals(3, count($user->groups));
+        self::assertTrue($user->groups->isInitialized());
+        self::assertCount(3, $user->groups);
 
-        $this->assertEquals($queryCount + 3, $this->getCurrentQueryCount());
+        self::assertEquals($queryCount + 3, $this->getCurrentQueryCount());
     }
 
     /**
@@ -243,11 +253,11 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
 
         $someGroups = $user->groups->slice(0, 2);
 
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount());
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount());
 
-        $this->assertEquals(2, count($someGroups));
-        $this->assertTrue($user->groups->contains(array_shift($someGroups)));
-        $this->assertTrue($user->groups->contains(array_shift($someGroups)));
+        self::assertCount(2, $someGroups);
+        self::assertTrue($user->groups->contains(array_shift($someGroups)));
+        self::assertTrue($user->groups->contains(array_shift($someGroups)));
     }
 
     /**
@@ -256,19 +266,19 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
     public function testSliceInverseCollection(): void
     {
         $group = $this->_em->find(CmsGroup::class, $this->groupId);
-        $this->assertFalse($group->users->isInitialized(), 'Pre-Condition');
+        self::assertFalse($group->users->isInitialized(), 'Pre-Condition');
         $queryCount = $this->getCurrentQueryCount();
 
         $someUsers  = $group->users->slice(0, 2);
         $otherUsers = $group->users->slice(2, 2);
 
-        $this->assertContainsOnly(CmsUser::class, $someUsers);
-        $this->assertContainsOnly(CmsUser::class, $otherUsers);
-        $this->assertEquals(2, count($someUsers));
-        $this->assertEquals(2, count($otherUsers));
+        self::assertContainsOnly(CmsUser::class, $someUsers);
+        self::assertContainsOnly(CmsUser::class, $otherUsers);
+        self::assertCount(2, $someUsers);
+        self::assertCount(2, $otherUsers);
 
         // +2 queries executed by slice
-        $this->assertEquals($queryCount + 2, $this->getCurrentQueryCount(), 'Slicing two parts should only execute two additional queries.');
+        self::assertEquals($queryCount + 2, $this->getCurrentQueryCount(), 'Slicing two parts should only execute two additional queries.');
     }
 
     /**
@@ -277,14 +287,14 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
     public function testSliceOneToMany(): void
     {
         $user = $this->_em->find(CmsUser::class, $this->userId);
-        $this->assertFalse($user->articles->isInitialized(), 'Pre-Condition: Collection is not initialized.');
+        self::assertFalse($user->articles->isInitialized(), 'Pre-Condition: Collection is not initialized.');
 
         $queryCount = $this->getCurrentQueryCount();
 
         $someArticle  = $user->articles->slice(0, 1);
         $otherArticle = $user->articles->slice(1, 1);
 
-        $this->assertEquals($queryCount + 2, $this->getCurrentQueryCount());
+        self::assertEquals($queryCount + 2, $this->getCurrentQueryCount());
     }
 
     /**
@@ -293,15 +303,15 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
     public function testContainsOneToMany(): void
     {
         $user = $this->_em->find(CmsUser::class, $this->userId);
-        $this->assertFalse($user->articles->isInitialized(), 'Pre-Condition: Collection is not initialized.');
+        self::assertFalse($user->articles->isInitialized(), 'Pre-Condition: Collection is not initialized.');
 
         // Test One to Many existence retrieved from DB
         $article    = $this->_em->find(CmsArticle::class, $this->articleId);
         $queryCount = $this->getCurrentQueryCount();
 
-        $this->assertTrue($user->articles->contains($article));
-        $this->assertFalse($user->articles->isInitialized(), 'Post-Condition: Collection is not initialized.');
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount());
+        self::assertTrue($user->articles->contains($article));
+        self::assertFalse($user->articles->isInitialized(), 'Post-Condition: Collection is not initialized.');
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount());
 
         // Test One to Many existence with state new
         $article        = new CmsArticle();
@@ -309,17 +319,17 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
         $article->text  = 'blub';
 
         $queryCount = $this->getCurrentQueryCount();
-        $this->assertFalse($user->articles->contains($article));
-        $this->assertEquals($queryCount, $this->getCurrentQueryCount(), 'Checking for contains of new entity should cause no query to be executed.');
+        self::assertFalse($user->articles->contains($article));
+        self::assertEquals($queryCount, $this->getCurrentQueryCount(), 'Checking for contains of new entity should cause no query to be executed.');
 
         // Test One to Many existence with state clear
         $this->_em->persist($article);
         $this->_em->flush();
 
         $queryCount = $this->getCurrentQueryCount();
-        $this->assertFalse($user->articles->contains($article));
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount(), 'Checking for contains of persisted entity should cause one query to be executed.');
-        $this->assertFalse($user->articles->isInitialized(), 'Post-Condition: Collection is not initialized.');
+        self::assertFalse($user->articles->contains($article));
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount(), 'Checking for contains of persisted entity should cause one query to be executed.');
+        self::assertFalse($user->articles->isInitialized(), 'Post-Condition: Collection is not initialized.');
 
         // Test One to Many existence with state managed
         $article        = new CmsArticle();
@@ -330,9 +340,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
 
         $queryCount = $this->getCurrentQueryCount();
 
-        $this->assertFalse($user->articles->contains($article));
-        $this->assertEquals($queryCount, $this->getCurrentQueryCount(), 'Checking for contains of managed entity (but not persisted) should cause no query to be executed.');
-        $this->assertFalse($user->articles->isInitialized(), 'Post-Condition: Collection is not initialized.');
+        self::assertFalse($user->articles->contains($article));
+        self::assertEquals($queryCount, $this->getCurrentQueryCount(), 'Checking for contains of managed entity (but not persisted) should cause no query to be executed.');
+        self::assertFalse($user->articles->isInitialized(), 'Post-Condition: Collection is not initialized.');
     }
 
     /**
@@ -342,7 +352,7 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
     {
         $otherClass = $this->_em->find(DDC2504OtherClass::class, $this->ddc2504OtherClassId);
 
-        $this->assertFalse($otherClass->childClasses->isInitialized(), 'Collection is not initialized.');
+        self::assertFalse($otherClass->childClasses->isInitialized(), 'Collection is not initialized.');
     }
 
     /**
@@ -356,9 +366,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
         $childClass = $this->_em->find(DDC2504ChildClass::class, $this->ddc2504ChildClassId);
         $queryCount = $this->getCurrentQueryCount();
 
-        $this->assertTrue($otherClass->childClasses->contains($childClass));
-        $this->assertFalse($otherClass->childClasses->isInitialized(), 'Collection is not initialized.');
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount(), 'Search operation was performed via SQL');
+        self::assertTrue($otherClass->childClasses->contains($childClass));
+        self::assertFalse($otherClass->childClasses->isInitialized(), 'Collection is not initialized.');
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount(), 'Search operation was performed via SQL');
     }
 
     /**
@@ -369,8 +379,8 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
         $otherClass = $this->_em->find(DDC2504OtherClass::class, $this->ddc2504OtherClassId);
         $queryCount = $this->getCurrentQueryCount();
 
-        $this->assertFalse($otherClass->childClasses->contains(new DDC2504ChildClass()));
-        $this->assertEquals(
+        self::assertFalse($otherClass->childClasses->contains(new DDC2504ChildClass()));
+        self::assertEquals(
             $queryCount,
             $this->getCurrentQueryCount(),
             'Checking for contains of new entity should cause no query to be executed.'
@@ -390,9 +400,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
         $this->_em->flush();
 
         $queryCount = $this->getCurrentQueryCount();
-        $this->assertFalse($otherClass->childClasses->contains($childClass));
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount(), 'Checking for contains of persisted entity should cause one query to be executed.');
-        $this->assertFalse($otherClass->childClasses->isInitialized(), 'Post-Condition: Collection is not initialized.');
+        self::assertFalse($otherClass->childClasses->contains($childClass));
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount(), 'Checking for contains of persisted entity should cause one query to be executed.');
+        self::assertFalse($otherClass->childClasses->isInitialized(), 'Post-Condition: Collection is not initialized.');
     }
 
     /**
@@ -407,9 +417,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
 
         $queryCount = $this->getCurrentQueryCount();
 
-        $this->assertFalse($otherClass->childClasses->contains($childClass));
-        $this->assertEquals($queryCount, $this->getCurrentQueryCount(), 'Checking for contains of managed entity (but not persisted) should cause no query to be executed.');
-        $this->assertFalse($otherClass->childClasses->isInitialized(), 'Post-Condition: Collection is not initialized.');
+        self::assertFalse($otherClass->childClasses->contains($childClass));
+        self::assertEquals($queryCount, $this->getCurrentQueryCount(), 'Checking for contains of managed entity (but not persisted) should cause no query to be executed.');
+        self::assertFalse($otherClass->childClasses->isInitialized(), 'Post-Condition: Collection is not initialized.');
     }
 
     /**
@@ -419,9 +429,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
     {
         $otherClass = $this->_em->find(DDC2504OtherClass::class, $this->ddc2504OtherClassId);
 
-        $this->assertEquals(2, count($otherClass->childClasses));
+        self::assertCount(2, $otherClass->childClasses);
 
-        $this->assertFalse($otherClass->childClasses->isInitialized());
+        self::assertFalse($otherClass->childClasses->isInitialized());
     }
 
     /**
@@ -430,15 +440,15 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
     public function testContainsManyToMany(): void
     {
         $user = $this->_em->find(CmsUser::class, $this->userId);
-        $this->assertFalse($user->groups->isInitialized(), 'Pre-Condition: Collection is not initialized.');
+        self::assertFalse($user->groups->isInitialized(), 'Pre-Condition: Collection is not initialized.');
 
         // Test Many to Many existence retrieved from DB
         $group      = $this->_em->find(CmsGroup::class, $this->groupId);
         $queryCount = $this->getCurrentQueryCount();
 
-        $this->assertTrue($user->groups->contains($group));
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount(), 'Checking for contains of managed entity should cause one query to be executed.');
-        $this->assertFalse($user->groups->isInitialized(), 'Post-Condition: Collection is not initialized.');
+        self::assertTrue($user->groups->contains($group));
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount(), 'Checking for contains of managed entity should cause one query to be executed.');
+        self::assertFalse($user->groups->isInitialized(), 'Post-Condition: Collection is not initialized.');
 
         // Test Many to Many existence with state new
         $group       = new CmsGroup();
@@ -446,9 +456,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
 
         $queryCount = $this->getCurrentQueryCount();
 
-        $this->assertFalse($user->groups->contains($group));
-        $this->assertEquals($queryCount, $this->getCurrentQueryCount(), 'Checking for contains of new entity should cause no query to be executed.');
-        $this->assertFalse($user->groups->isInitialized(), 'Post-Condition: Collection is not initialized.');
+        self::assertFalse($user->groups->contains($group));
+        self::assertEquals($queryCount, $this->getCurrentQueryCount(), 'Checking for contains of new entity should cause no query to be executed.');
+        self::assertFalse($user->groups->isInitialized(), 'Post-Condition: Collection is not initialized.');
 
         // Test Many to Many existence with state clear
         $this->_em->persist($group);
@@ -456,9 +466,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
 
         $queryCount = $this->getCurrentQueryCount();
 
-        $this->assertFalse($user->groups->contains($group));
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount(), 'Checking for contains of persisted entity should cause one query to be executed.');
-        $this->assertFalse($user->groups->isInitialized(), 'Post-Condition: Collection is not initialized.');
+        self::assertFalse($user->groups->contains($group));
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount(), 'Checking for contains of persisted entity should cause one query to be executed.');
+        self::assertFalse($user->groups->isInitialized(), 'Post-Condition: Collection is not initialized.');
 
         // Test Many to Many existence with state managed
         $group       = new CmsGroup();
@@ -468,9 +478,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
 
         $queryCount = $this->getCurrentQueryCount();
 
-        $this->assertFalse($user->groups->contains($group));
-        $this->assertEquals($queryCount, $this->getCurrentQueryCount(), 'Checking for contains of managed entity (but not persisted) should cause no query to be executed.');
-        $this->assertFalse($user->groups->isInitialized(), 'Post-Condition: Collection is not initialized.');
+        self::assertFalse($user->groups->contains($group));
+        self::assertEquals($queryCount, $this->getCurrentQueryCount(), 'Checking for contains of managed entity (but not persisted) should cause no query to be executed.');
+        self::assertFalse($user->groups->isInitialized(), 'Post-Condition: Collection is not initialized.');
     }
 
     /**
@@ -479,22 +489,22 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
     public function testContainsManyToManyInverse(): void
     {
         $group = $this->_em->find(CmsGroup::class, $this->groupId);
-        $this->assertFalse($group->users->isInitialized(), 'Pre-Condition: Collection is not initialized.');
+        self::assertFalse($group->users->isInitialized(), 'Pre-Condition: Collection is not initialized.');
 
         $user = $this->_em->find(CmsUser::class, $this->userId);
 
         $queryCount = $this->getCurrentQueryCount();
-        $this->assertTrue($group->users->contains($user));
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount(), 'Checking for contains of managed entity should cause one query to be executed.');
-        $this->assertFalse($user->groups->isInitialized(), 'Post-Condition: Collection is not initialized.');
+        self::assertTrue($group->users->contains($user));
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount(), 'Checking for contains of managed entity should cause one query to be executed.');
+        self::assertFalse($user->groups->isInitialized(), 'Post-Condition: Collection is not initialized.');
 
         $newUser       = new CmsUser();
         $newUser->name = 'A New group!';
 
         $queryCount = $this->getCurrentQueryCount();
-        $this->assertFalse($group->users->contains($newUser));
-        $this->assertEquals($queryCount, $this->getCurrentQueryCount(), 'Checking for contains of new entity should cause no query to be executed.');
-        $this->assertFalse($user->groups->isInitialized(), 'Post-Condition: Collection is not initialized.');
+        self::assertFalse($group->users->contains($newUser));
+        self::assertEquals($queryCount, $this->getCurrentQueryCount(), 'Checking for contains of new entity should cause no query to be executed.');
+        self::assertFalse($user->groups->isInitialized(), 'Post-Condition: Collection is not initialized.');
     }
 
     /**
@@ -510,13 +520,13 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
         $user->addGroup($newGroup);
         $this->_em->persist($newGroup);
 
-        $this->assertFalse($user->groups->isInitialized());
-        $this->assertEquals(4, count($user->groups));
-        $this->assertFalse($user->groups->isInitialized());
+        self::assertFalse($user->groups->isInitialized());
+        self::assertCount(4, $user->groups);
+        self::assertFalse($user->groups->isInitialized());
 
         $this->_em->flush();
 
-        $this->assertEquals(4, count($user->groups));
+        self::assertCount(4, $user->groups);
     }
 
     /**
@@ -537,8 +547,8 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
         $qc     = $this->getCurrentQueryCount();
         $groups = $user->groups->slice(0, 10);
 
-        $this->assertEquals(4, count($groups));
-        $this->assertEquals($qc + 1, $this->getCurrentQueryCount());
+        self::assertCount(4, $groups);
+        self::assertEquals($qc + 1, $this->getCurrentQueryCount());
     }
 
     /**
@@ -553,12 +563,12 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
         $queryCount  = $this->getCurrentQueryCount();
         $phonenumber = $user->phonenumbers->get($this->phonenumber);
 
-        $this->assertFalse($user->phonenumbers->isInitialized());
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount());
-        $this->assertSame($phonenumber, $this->_em->find(CmsPhonenumber::class, $this->phonenumber));
+        self::assertFalse($user->phonenumbers->isInitialized());
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount());
+        self::assertSame($phonenumber, $this->_em->find(CmsPhonenumber::class, $this->phonenumber));
 
         $article = $user->phonenumbers->get($this->phonenumber);
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount(), 'Getting the same entity should not cause an extra query to be executed');
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount(), 'Getting the same entity should not cause an extra query to be executed');
     }
 
     /**
@@ -573,9 +583,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
 
         $article = $user->articles->get($this->topic);
 
-        $this->assertFalse($user->articles->isInitialized());
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount());
-        $this->assertSame($article, $this->_em->find(CmsArticle::class, $this->articleId));
+        self::assertFalse($user->articles->isInitialized());
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount());
+        self::assertSame($article, $this->_em->find(CmsArticle::class, $this->articleId));
     }
 
     /**
@@ -590,9 +600,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
 
         $user = $group->users->get($this->username);
 
-        $this->assertFalse($group->users->isInitialized());
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount());
-        $this->assertSame($user, $this->_em->find(CmsUser::class, $this->userId));
+        self::assertFalse($group->users->isInitialized());
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount());
+        self::assertSame($user, $this->_em->find(CmsUser::class, $this->userId));
     }
 
     /**
@@ -607,9 +617,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
 
         $group = $user->groups->get($this->groupname);
 
-        $this->assertFalse($user->groups->isInitialized());
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount());
-        $this->assertSame($group, $this->_em->find(CmsGroup::class, $this->groupId));
+        self::assertFalse($user->groups->isInitialized());
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount());
+        self::assertSame($group, $this->_em->find(CmsGroup::class, $this->groupId));
     }
 
     /**
@@ -618,8 +628,8 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
     public function testGetNonExistentIndexBy(): void
     {
         $user = $this->_em->find(CmsUser::class, $this->userId);
-        $this->assertNull($user->articles->get(-1));
-        $this->assertNull($user->groups->get(-1));
+        self::assertNull($user->articles->get(-1));
+        self::assertNull($user->groups->get(-1));
     }
 
     public function testContainsKeyIndexByOneToMany(): void
@@ -631,9 +641,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
 
         $contains = $user->articles->containsKey($this->topic);
 
-        $this->assertTrue($contains);
-        $this->assertFalse($user->articles->isInitialized());
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount());
+        self::assertTrue($contains);
+        self::assertFalse($user->articles->isInitialized());
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount());
     }
 
     public function testContainsKeyIndexByOneToManyJoinedInheritance(): void
@@ -647,9 +657,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
 
         $contains = $otherClass->childClasses->containsKey($this->ddc2504ChildClassId);
 
-        $this->assertTrue($contains);
-        $this->assertFalse($otherClass->childClasses->isInitialized());
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount());
+        self::assertTrue($contains);
+        self::assertFalse($otherClass->childClasses->isInitialized());
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount());
     }
 
     public function testContainsKeyIndexByManyToMany(): void
@@ -662,9 +672,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
 
         $contains = $user->groups->containsKey($group->name);
 
-        $this->assertTrue($contains, 'The item is not into collection');
-        $this->assertFalse($user->groups->isInitialized(), 'The collection must not be initialized');
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount());
+        self::assertTrue($contains, 'The item is not into collection');
+        self::assertFalse($user->groups->isInitialized(), 'The collection must not be initialized');
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount());
     }
 
     public function testContainsKeyIndexByManyToManyNonOwning(): void
@@ -676,9 +686,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
 
         $contains = $group->users->containsKey($user->username);
 
-        $this->assertTrue($contains, 'The item is not into collection');
-        $this->assertFalse($group->users->isInitialized(), 'The collection must not be initialized');
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount());
+        self::assertTrue($contains, 'The item is not into collection');
+        self::assertFalse($group->users->isInitialized(), 'The collection must not be initialized');
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount());
     }
 
     public function testContainsKeyIndexByWithPkManyToMany(): void
@@ -692,9 +702,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
 
         $contains = $user->groups->containsKey($this->groupId);
 
-        $this->assertTrue($contains, 'The item is not into collection');
-        $this->assertFalse($user->groups->isInitialized(), 'The collection must not be initialized');
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount());
+        self::assertTrue($contains, 'The item is not into collection');
+        self::assertFalse($user->groups->isInitialized(), 'The collection must not be initialized');
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount());
     }
 
     public function testContainsKeyIndexByWithPkManyToManyNonOwning(): void
@@ -708,9 +718,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
 
         $contains = $group->users->containsKey($this->userId2);
 
-        $this->assertTrue($contains, 'The item is not into collection');
-        $this->assertFalse($group->users->isInitialized(), 'The collection must not be initialized');
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount());
+        self::assertTrue($contains, 'The item is not into collection');
+        self::assertFalse($group->users->isInitialized(), 'The collection must not be initialized');
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount());
     }
 
     public function testContainsKeyNonExistentIndexByOneToMany(): void
@@ -721,9 +731,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
 
         $contains = $user->articles->containsKey('NonExistentTopic');
 
-        $this->assertFalse($contains);
-        $this->assertFalse($user->articles->isInitialized());
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount());
+        self::assertFalse($contains);
+        self::assertFalse($user->articles->isInitialized());
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount());
     }
 
     public function testContainsKeyNonExistentIndexByManyToMany(): void
@@ -734,9 +744,9 @@ class ExtraLazyCollectionTest extends OrmFunctionalTestCase
 
         $contains = $user->groups->containsKey('NonExistentTopic');
 
-        $this->assertFalse($contains);
-        $this->assertFalse($user->groups->isInitialized());
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount());
+        self::assertFalse($contains);
+        self::assertFalse($user->groups->isInitialized());
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount());
     }
 
     private function loadFixture(): void
