@@ -5,14 +5,13 @@ declare(strict_types=1);
 namespace Doctrine\Tests\ORM\Functional\Locking;
 
 use Closure;
-use Doctrine\Common\Cache\ArrayCache;
 use Doctrine\DBAL\Connection;
-use Doctrine\DBAL\Logging\EchoSQLLogger;
 use Doctrine\ORM\Configuration;
 use Doctrine\ORM\EntityManager;
 use Doctrine\ORM\EntityManagerInterface;
 use GearmanWorker;
 use InvalidArgumentException;
+use Symfony\Component\Cache\Adapter\ArrayAdapter;
 
 use function assert;
 use function is_array;
@@ -119,13 +118,11 @@ class LockAgentWorker
         $config->setProxyNamespace('MyProject\Proxies');
         $config->setAutoGenerateProxyClasses(true);
 
-        $annotDriver = $config->newDefaultAnnotationDriver([__DIR__ . '/../../../Models/'], true);
+        $annotDriver = $config->newDefaultAnnotationDriver([__DIR__ . '/../../../Models/'], false);
         $config->setMetadataDriverImpl($annotDriver);
+        $config->setMetadataCache(new ArrayAdapter());
 
-        $cache = new ArrayCache();
-        $config->setMetadataCacheImpl($cache);
-        $config->setQueryCacheImpl($cache);
-        $config->setSQLLogger(new EchoSQLLogger());
+        $config->setQueryCache(new ArrayAdapter());
 
         return EntityManager::create($conn, $config);
     }
