@@ -7,8 +7,6 @@ namespace Doctrine\Tests\ORM\Functional;
 use Doctrine\ORM\Mapping\ClassMetadata;
 use Doctrine\Tests\Models\ECommerce\ECommerceProduct;
 
-use function count;
-
 /**
  * Tests a self referential many-to-many association mapping (from a model to the same model, without inheritance).
  * For simplicity the relation duplicates entries in the association table
@@ -110,20 +108,20 @@ class ManyToManySelfReferentialAssociationTest extends AbstractManyToManyAssocia
     public function assertLoadingOfOwningSide(array $products): void
     {
         [$firstProduct, $secondProduct] = $products;
-        $this->assertEquals(2, count($firstProduct->getRelated()));
-        $this->assertEquals(2, count($secondProduct->getRelated()));
+        self::assertCount(2, $firstProduct->getRelated());
+        self::assertCount(2, $secondProduct->getRelated());
 
         $categories      = $firstProduct->getRelated();
         $firstRelatedBy  = $categories[0]->getRelated();
         $secondRelatedBy = $categories[1]->getRelated();
 
-        $this->assertEquals(2, count($firstRelatedBy));
-        $this->assertEquals(2, count($secondRelatedBy));
+        self::assertCount(2, $firstRelatedBy);
+        self::assertCount(2, $secondRelatedBy);
 
-        $this->assertInstanceOf(ECommerceProduct::class, $firstRelatedBy[0]);
-        $this->assertInstanceOf(ECommerceProduct::class, $firstRelatedBy[1]);
-        $this->assertInstanceOf(ECommerceProduct::class, $secondRelatedBy[0]);
-        $this->assertInstanceOf(ECommerceProduct::class, $secondRelatedBy[1]);
+        self::assertInstanceOf(ECommerceProduct::class, $firstRelatedBy[0]);
+        self::assertInstanceOf(ECommerceProduct::class, $firstRelatedBy[1]);
+        self::assertInstanceOf(ECommerceProduct::class, $secondRelatedBy[0]);
+        self::assertInstanceOf(ECommerceProduct::class, $secondRelatedBy[1]);
 
         $this->assertCollectionEquals($firstRelatedBy, $secondRelatedBy);
     }
