@@ -4,8 +4,8 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\ORM\Functional;
 
-use Doctrine\DBAL\Driver\Connection;
-use Doctrine\ORM\EntityManager;
+use Doctrine\DBAL\Connection;
+use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\ORM\Mapping\Driver\XmlDriver;
 use Doctrine\Persistence\Mapping\Driver\MappingDriver;
 use Doctrine\Tests\Models\OrnementalOrphanRemoval\Person;
@@ -74,20 +74,20 @@ class ManyToOneOrphanRemovalTest extends OrmFunctionalTestCase
         );
         $result = $query->getResult();
 
-        $this->assertEquals(0, count($result), 'Person should be removed by EntityManager');
+        self::assertEquals(0, count($result), 'Person should be removed by EntityManager');
 
         $query  = $this->_em->createQuery(
             'SELECT p FROM Doctrine\Tests\Models\OrnementalOrphanRemoval\PhoneNumber p'
         );
         $result = $query->getResult();
 
-        $this->assertEquals(2, count($result), 'Orphan removal should not kick in');
+        self::assertEquals(2, count($result), 'Orphan removal should not kick in');
     }
 
     protected function getEntityManager(
         ?Connection $connection = null,
         ?MappingDriver $mappingDriver = null
-    ): EntityManager {
+    ): EntityManagerInterface {
         return parent::getEntityManager($connection, new XmlDriver(
             __DIR__ . DIRECTORY_SEPARATOR . 'xml'
         ));
