@@ -7,14 +7,11 @@ namespace Doctrine\Tests\ORM\Functional;
 use Doctrine\Tests\Models\MixedToOneIdentity\CompositeToOneKeyState;
 use Doctrine\Tests\Models\MixedToOneIdentity\Country;
 use Doctrine\Tests\OrmFunctionalTestCase;
-use Doctrine\Tests\VerifyDeprecations;
 
 use function assert;
 
 class MergeCompositeToOneKeyTest extends OrmFunctionalTestCase
 {
-    use VerifyDeprecations;
-
     protected function setUp(): void
     {
         parent::setUp();
@@ -43,10 +40,9 @@ class MergeCompositeToOneKeyTest extends OrmFunctionalTestCase
         $merged = $this->_em->merge($state);
         assert($merged instanceof CompositeToOneKeyState);
 
-        $this->assertInstanceOf(CompositeToOneKeyState::class, $state);
-        $this->assertNotSame($state, $merged);
-        $this->assertInstanceOf(Country::class, $merged->country);
-        $this->assertNotSame($country, $merged->country);
-        $this->assertHasDeprecationMessages();
+        self::assertInstanceOf(CompositeToOneKeyState::class, $state);
+        self::assertNotSame($state, $merged);
+        self::assertInstanceOf(Country::class, $merged->country);
+        self::assertNotSame($country, $merged->country);
     }
 }
