@@ -7,15 +7,12 @@ namespace Doctrine\Tests\ORM\Functional;
 use Doctrine\Tests\Models\VersionedManyToOne\Article;
 use Doctrine\Tests\Models\VersionedManyToOne\Category;
 use Doctrine\Tests\OrmFunctionalTestCase;
-use Doctrine\Tests\VerifyDeprecations;
 
 /**
  * @group MergeVersionedOneToMany
  */
 class MergeVersionedManyToOneTest extends OrmFunctionalTestCase
 {
-    use VerifyDeprecations;
-
     protected function setUp(): void
     {
         $this->useModelSet('versioned_many_to_one');
@@ -44,7 +41,6 @@ class MergeVersionedManyToOneTest extends OrmFunctionalTestCase
         $articleMerged->name = 'Article Merged';
 
         $this->_em->flush();
-        $this->assertEquals(2, $articleMerged->version);
-        $this->assertHasDeprecationMessages();
+        self::assertEquals(2, $articleMerged->version);
     }
 }
