@@ -5,11 +5,16 @@ declare(strict_types=1);
 namespace Doctrine\Tests\ORM\Functional;
 
 use Doctrine\Common\Collections\ArrayCollection;
+use Doctrine\DBAL\Platforms\AbstractPlatform;
+use Doctrine\DBAL\Types\Type as DBALType;
+use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
 use Doctrine\ORM\Internal\Hydration\HydrationException;
+use Doctrine\ORM\Internal\SQLResultCasing;
 use Doctrine\ORM\PersistentCollection;
 use Doctrine\ORM\Query\Parameter;
 use Doctrine\ORM\Query\ResultSetMapping;
 use Doctrine\ORM\Query\ResultSetMappingBuilder;
+use Doctrine\Tests\DbalTypes\UpperCaseStringType;
 use Doctrine\Tests\Models\CMS\CmsAddress;
 use Doctrine\Tests\Models\CMS\CmsEmail;
 use Doctrine\Tests\Models\CMS\CmsPhonenumber;
@@ -19,20 +24,17 @@ use Doctrine\Tests\Models\Company\CompanyEmployee;
 use Doctrine\Tests\Models\Company\CompanyFixContract;
 use Doctrine\Tests\Models\Company\CompanyFlexContract;
 use Doctrine\Tests\Models\Company\CompanyPerson;
+use Doctrine\Tests\Models\CustomType\CustomTypeUpperCase;
 use Doctrine\Tests\Models\DDC3899\DDC3899FixContract;
 use Doctrine\Tests\Models\DDC3899\DDC3899User;
 use Doctrine\Tests\OrmFunctionalTestCase;
 use InvalidArgumentException;
 
-use function count;
-use function is_array;
-use function is_numeric;
-
-/**
- * NativeQueryTest
- */
 class NativeQueryTest extends OrmFunctionalTestCase
 {
+    use SQLResultCasing;
+    use VerifyDeprecations;
+
     /** @var AbstractPlatform */
     private $platform = null;
 
@@ -58,17 +60,17 @@ class NativeQueryTest extends OrmFunctionalTestCase
 
         $rsm = new ResultSetMapping();
         $rsm->addEntityResult(CmsUser::class, 'u');
-        $rsm->addFieldResult('u', $this->platform->getSQLResultCasing('id'), 'id');
-        $rsm->addFieldResult('u', $this->platform->getSQLResultCasing('name'), 'name');
+        $rsm->addFieldResult('u', $this->getSQLResultCasing($this->platform, 'id'), 'id');
+        $rsm->addFieldResult('u', $this->getSQLResultCasing($this->platform, 'name'), 'name');
 
         $query = $this->_em->createNativeQuery('SELECT id, name FROM cms_users WHERE username = ?', $rsm);
         $query->setParameter(1, 'romanb');
 
         $users = $query->getResult();
 
-        $this->assertEquals(1, count($users));
-        $this->assertInstanceOf(CmsUser::class, $users[0]);
-        $this->assertEquals('Roman', $users[0]->name);
+        self::assertCount(1, $users);
+        self::assertInstanceOf(CmsUser::class, $users[0]);
+        self::assertEquals('Roman', $users[0]->name);
     }
 
     public function testBasicNativeQueryWithMetaResult(): void
@@ -92,24 +94,24 @@ class NativeQueryTest extends OrmFunctionalTestCase
 
         $rsm = new ResultSetMapping();
         $rsm->addEntityResult(CmsAddress::class, 'a');
-        $rsm->addFieldResult('a', $this->platform->getSQLResultCasing('id'), 'id');
-        $rsm->addFieldResult('a', $this->platform->getSQLResultCasing('country'), 'country');
-        $rsm->addFieldResult('a', $this->platform->getSQLResultCasing('zip'), 'zip');
-        $rsm->addFieldResult('a', $this->platform->getSQLResultCasing('city'), 'city');
-        $rsm->addMetaResult('a', $this->platform->getSQLResultCasing('user_id'), 'user_id', false, 'integer');
+        $rsm->addFieldResult('a', $this->getSQLResultCasing($this->platform, 'id'), 'id');
+        $rsm->addFieldResult('a', $this->getSQLResultCasing($this->platform, 'country'), 'country');
+        $rsm->addFieldResult('a', $this->getSQLResultCasing($this->platform, 'zip'), 'zip');
+        $rsm->addFieldResult('a', $this->getSQLResultCasing($this->platform, 'city'), 'city');
+        $rsm->addMetaResult('a', $this->getSQLResultCasing($this->platform, 'user_id'), 'user_id', false, 'integer');
 
         $query = $this->_em->createNativeQuery('SELECT a.id, a.country, a.zip, a.city, a.user_id FROM cms_addresses a WHERE a.id = ?', $rsm);
         $query->setParameter(1, $addr->id);
 
         $addresses = $query->getResult();
 
-        $this->assertEquals(1, count($addresses));
-        $this->assertTrue($addresses[0] instanceof CmsAddress);
-        $this->assertEquals($addr->country, $addresses[0]->country);
-        $this->assertEquals($addr->zip, $addresses[0]->zip);
-        $this->assertEquals($addr->city, $addresses[0]->city);
-        $this->assertEquals($addr->street, $addresses[0]->street);
-        $this->assertTrue($addresses[0]->user instanceof CmsUser);
+        self::assertCount(1, $addresses);
+        self::assertInstanceOf(CmsAddress::class, $addresses[0]);
+        self::assertEquals($addr->country, $addresses[0]->country);
+        self::assertEquals($addr->zip, $addresses[0]->zip);
+        self::assertEquals($addr->city, $addresses[0]->city);
+        self::assertEquals($addr->street, $addresses[0]->street);
+        self::assertInstanceOf(CmsUser::class, $addresses[0]->user);
     }
 
     public function testJoinedOneToManyNativeQuery(): void
@@ -131,25 +133,25 @@ class NativeQueryTest extends OrmFunctionalTestCase
 
         $rsm = new ResultSetMapping();
         $rsm->addEntityResult(CmsUser::class, 'u');
-        $rsm->addFieldResult('u', $this->platform->getSQLResultCasing('id'), 'id');
-        $rsm->addFieldResult('u', $this->platform->getSQLResultCasing('name'), 'name');
-        $rsm->addFieldResult('u', $this->platform->getSQLResultCasing('status'), 'status');
+        $rsm->addFieldResult('u', $this->getSQLResultCasing($this->platform, 'id'), 'id');
+        $rsm->addFieldResult('u', $this->getSQLResultCasing($this->platform, 'name'), 'name');
+        $rsm->addFieldResult('u', $this->getSQLResultCasing($this->platform, 'status'), 'status');
         $rsm->addJoinedEntityResult(CmsPhonenumber::class, 'p', 'u', 'phonenumbers');
-        $rsm->addFieldResult('p', $this->platform->getSQLResultCasing('phonenumber'), 'phonenumber');
+        $rsm->addFieldResult('p', $this->getSQLResultCasing($this->platform, 'phonenumber'), 'phonenumber');
 
         $query = $this->_em->createNativeQuery('SELECT id, name, status, phonenumber FROM cms_users INNER JOIN cms_phonenumbers ON id = user_id WHERE username = ?', $rsm);
         $query->setParameter(1, 'romanb');
 
         $users = $query->getResult();
-        $this->assertEquals(1, count($users));
-        $this->assertInstanceOf(CmsUser::class, $users[0]);
-        $this->assertEquals('Roman', $users[0]->name);
-        $this->assertInstanceOf(PersistentCollection::class, $users[0]->getPhonenumbers());
-        $this->assertTrue($users[0]->getPhonenumbers()->isInitialized());
-        $this->assertEquals(1, count($users[0]->getPhonenumbers()));
+        self::assertCount(1, $users);
+        self::assertInstanceOf(CmsUser::class, $users[0]);
+        self::assertEquals('Roman', $users[0]->name);
+        self::assertInstanceOf(PersistentCollection::class, $users[0]->getPhonenumbers());
+        self::assertTrue($users[0]->getPhonenumbers()->isInitialized());
+        self::assertCount(1, $users[0]->getPhonenumbers());
         $phones = $users[0]->getPhonenumbers();
-        $this->assertEquals(424242, $phones[0]->phonenumber);
-        $this->assertTrue($phones[0]->getUser() === $users[0]);
+        self::assertEquals(424242, $phones[0]->phonenumber);
+        self::assertSame($phones[0]->getUser(), $users[0]);
     }
 
     public function testJoinedOneToOneNativeQuery(): void
@@ -173,30 +175,30 @@ class NativeQueryTest extends OrmFunctionalTestCase
 
         $rsm = new ResultSetMapping();
         $rsm->addEntityResult(CmsUser::class, 'u');
-        $rsm->addFieldResult('u', $this->platform->getSQLResultCasing('id'), 'id');
-        $rsm->addFieldResult('u', $this->platform->getSQLResultCasing('name'), 'name');
-        $rsm->addFieldResult('u', $this->platform->getSQLResultCasing('status'), 'status');
+        $rsm->addFieldResult('u', $this->getSQLResultCasing($this->platform, 'id'), 'id');
+        $rsm->addFieldResult('u', $this->getSQLResultCasing($this->platform, 'name'), 'name');
+        $rsm->addFieldResult('u', $this->getSQLResultCasing($this->platform, 'status'), 'status');
         $rsm->addJoinedEntityResult(CmsAddress::class, 'a', 'u', 'address');
-        $rsm->addFieldResult('a', $this->platform->getSQLResultCasing('a_id'), 'id');
-        $rsm->addFieldResult('a', $this->platform->getSQLResultCasing('country'), 'country');
-        $rsm->addFieldResult('a', $this->platform->getSQLResultCasing('zip'), 'zip');
-        $rsm->addFieldResult('a', $this->platform->getSQLResultCasing('city'), 'city');
+        $rsm->addFieldResult('a', $this->getSQLResultCasing($this->platform, 'a_id'), 'id');
+        $rsm->addFieldResult('a', $this->getSQLResultCasing($this->platform, 'country'), 'country');
+        $rsm->addFieldResult('a', $this->getSQLResultCasing($this->platform, 'zip'), 'zip');
+        $rsm->addFieldResult('a', $this->getSQLResultCasing($this->platform, 'city'), 'city');
 
         $query = $this->_em->createNativeQuery('SELECT u.id, u.name, u.status, a.id AS a_id, a.country, a.zip, a.city FROM cms_users u INNER JOIN cms_addresses a ON u.id = a.user_id WHERE u.username = ?', $rsm);
         $query->setParameter(1, 'romanb');
 
         $users = $query->getResult();
 
-        $this->assertEquals(1, count($users));
-        $this->assertInstanceOf(CmsUser::class, $users[0]);
-        $this->assertEquals('Roman', $users[0]->name);
-        $this->assertInstanceOf(PersistentCollection::class, $users[0]->getPhonenumbers());
-        $this->assertFalse($users[0]->getPhonenumbers()->isInitialized());
-        $this->assertInstanceOf(CmsAddress::class, $users[0]->getAddress());
-        $this->assertTrue($users[0]->getAddress()->getUser() === $users[0]);
-        $this->assertEquals('germany', $users[0]->getAddress()->getCountry());
-        $this->assertEquals(10827, $users[0]->getAddress()->getZipCode());
-        $this->assertEquals('Berlin', $users[0]->getAddress()->getCity());
+        self::assertCount(1, $users);
+        self::assertInstanceOf(CmsUser::class, $users[0]);
+        self::assertEquals('Roman', $users[0]->name);
+        self::assertInstanceOf(PersistentCollection::class, $users[0]->getPhonenumbers());
+        self::assertFalse($users[0]->getPhonenumbers()->isInitialized());
+        self::assertInstanceOf(CmsAddress::class, $users[0]->getAddress());
+        self::assertEquals($users[0]->getAddress()->getUser(), $users[0]);
+        self::assertEquals('germany', $users[0]->getAddress()->getCountry());
+        self::assertEquals(10827, $users[0]->getAddress()->getZipCode());
+        self::assertEquals('Berlin', $users[0]->getAddress()->getCity());
     }
 
     public function testFluentInterface(): void
@@ -217,7 +219,7 @@ class NativeQueryTest extends OrmFunctionalTestCase
           ->setResultCacheDriver(null)
           ->setResultCacheLifetime(3500);
 
-        $this->assertSame($q, $q2);
+        self::assertSame($q, $q2);
     }
 
     public function testJoinedOneToManyNativeQueryWithRSMBuilder(): void
@@ -244,15 +246,15 @@ class NativeQueryTest extends OrmFunctionalTestCase
         $query->setParameter(1, 'romanb');
 
         $users = $query->getResult();
-        $this->assertEquals(1, count($users));
-        $this->assertInstanceOf(CmsUser::class, $users[0]);
-        $this->assertEquals('Roman', $users[0]->name);
-        $this->assertInstanceOf(PersistentCollection::class, $users[0]->getPhonenumbers());
-        $this->assertTrue($users[0]->getPhonenumbers()->isInitialized());
-        $this->assertEquals(1, count($users[0]->getPhonenumbers()));
+        self::assertCount(1, $users);
+        self::assertInstanceOf(CmsUser::class, $users[0]);
+        self::assertEquals('Roman', $users[0]->name);
+        self::assertInstanceOf(PersistentCollection::class, $users[0]->getPhonenumbers());
+        self::assertTrue($users[0]->getPhonenumbers()->isInitialized());
+        self::assertCount(1, $users[0]->getPhonenumbers());
         $phones = $users[0]->getPhonenumbers();
-        $this->assertEquals(424242, $phones[0]->phonenumber);
-        $this->assertTrue($phones[0]->getUser() === $users[0]);
+        self::assertEquals(424242, $phones[0]->phonenumber);
+        self::assertSame($phones[0]->getUser(), $users[0]);
 
         $this->_em->clear();
 
@@ -262,8 +264,8 @@ class NativeQueryTest extends OrmFunctionalTestCase
         $query->setParameter(1, $phone->phonenumber);
         $phone = $query->getSingleResult();
 
-        $this->assertNotNull($phone->getUser());
-        $this->assertEquals($user->name, $phone->getUser()->getName());
+        self::assertNotNull($phone->getUser());
+        self::assertEquals($user->name, $phone->getUser()->getName());
     }
 
     public function testJoinedOneToOneNativeQueryWithRSMBuilder(): void
@@ -294,16 +296,16 @@ class NativeQueryTest extends OrmFunctionalTestCase
 
         $users = $query->getResult();
 
-        $this->assertEquals(1, count($users));
-        $this->assertInstanceOf(CmsUser::class, $users[0]);
-        $this->assertEquals('Roman', $users[0]->name);
-        $this->assertInstanceOf(PersistentCollection::class, $users[0]->getPhonenumbers());
-        $this->assertFalse($users[0]->getPhonenumbers()->isInitialized());
-        $this->assertInstanceOf(CmsAddress::class, $users[0]->getAddress());
-        $this->assertTrue($users[0]->getAddress()->getUser() === $users[0]);
-        $this->assertEquals('germany', $users[0]->getAddress()->getCountry());
-        $this->assertEquals(10827, $users[0]->getAddress()->getZipCode());
-        $this->assertEquals('Berlin', $users[0]->getAddress()->getCity());
+        self::assertCount(1, $users);
+        self::assertInstanceOf(CmsUser::class, $users[0]);
+        self::assertEquals('Roman', $users[0]->name);
+        self::assertInstanceOf(PersistentCollection::class, $users[0]->getPhonenumbers());
+        self::assertFalse($users[0]->getPhonenumbers()->isInitialized());
+        self::assertInstanceOf(CmsAddress::class, $users[0]->getAddress());
+        self::assertEquals($users[0]->getAddress()->getUser(), $users[0]);
+        self::assertEquals('germany', $users[0]->getAddress()->getCountry());
+        self::assertEquals(10827, $users[0]->getAddress()->getZipCode());
+        self::assertEquals('Berlin', $users[0]->getAddress()->getCity());
 
         $this->_em->clear();
 
@@ -313,8 +315,8 @@ class NativeQueryTest extends OrmFunctionalTestCase
         $query->setParameter(1, $addr->getId());
         $address = $query->getSingleResult();
 
-        $this->assertNotNull($address->getUser());
-        $this->assertEquals($user->name, $address->getUser()->getName());
+        self::assertNotNull($address->getUser());
+        self::assertEquals($user->name, $address->getUser()->getName());
     }
 
     /**
@@ -393,11 +395,11 @@ class NativeQueryTest extends OrmFunctionalTestCase
         $query      = $repository->createNativeNamedQuery('find-all');
         $result     = $query->getResult();
 
-        $this->assertCount(1, $result);
-        $this->assertInstanceOf(CmsAddress::class, $result[0]);
-        $this->assertEquals($addr->id, $result[0]->id);
-        $this->assertEquals($addr->city, $result[0]->city);
-        $this->assertEquals($addr->country, $result[0]->country);
+        self::assertCount(1, $result);
+        self::assertInstanceOf(CmsAddress::class, $result[0]);
+        self::assertEquals($addr->id, $result[0]->id);
+        self::assertEquals($addr->city, $result[0]->city);
+        self::assertEquals($addr->country, $result[0]->country);
     }
 
     /**
@@ -405,6 +407,8 @@ class NativeQueryTest extends OrmFunctionalTestCase
      */
     public function testBasicNativeNamedQueryWithResultClass(): void
     {
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/orm/issues/8592');
+
         $user           = new CmsUser();
         $user->name     = 'Fabio B. Silva';
         $user->username = 'FabioBatSilva';
@@ -427,12 +431,12 @@ class NativeQueryTest extends OrmFunctionalTestCase
                             ->setParameter(1, 'FabioBatSilva')
                             ->getResult();
 
-        $this->assertEquals(1, count($result));
-        $this->assertInstanceOf(CmsUser::class, $result[0]);
-        $this->assertNull($result[0]->name);
-        $this->assertNull($result[0]->email);
-        $this->assertEquals($user->id, $result[0]->id);
-        $this->assertEquals('FabioBatSilva', $result[0]->username);
+        self::assertCount(1, $result);
+        self::assertInstanceOf(CmsUser::class, $result[0]);
+        self::assertNull($result[0]->name);
+        self::assertNull($result[0]->email);
+        self::assertEquals($user->id, $result[0]->id);
+        self::assertEquals('FabioBatSilva', $result[0]->username);
 
         $this->_em->clear();
 
@@ -440,13 +444,13 @@ class NativeQueryTest extends OrmFunctionalTestCase
                             ->setParameter(1, 'FabioBatSilva')
                             ->getResult();
 
-        $this->assertEquals(1, count($result));
-        $this->assertInstanceOf(CmsUser::class, $result[0]);
-        $this->assertEquals($user->id, $result[0]->id);
-        $this->assertEquals('Fabio B. Silva', $result[0]->name);
-        $this->assertEquals('FabioBatSilva', $result[0]->username);
-        $this->assertEquals('dev', $result[0]->status);
-        $this->assertInstanceOf(CmsEmail::class, $result[0]->email);
+        self::assertCount(1, $result);
+        self::assertInstanceOf(CmsUser::class, $result[0]);
+        self::assertEquals($user->id, $result[0]->id);
+        self::assertEquals('Fabio B. Silva', $result[0]->name);
+        self::assertEquals('FabioBatSilva', $result[0]->username);
+        self::assertEquals('dev', $result[0]->status);
+        self::assertInstanceOf(CmsEmail::class, $result[0]->email);
     }
 
     /**
@@ -475,16 +479,16 @@ class NativeQueryTest extends OrmFunctionalTestCase
                             ->setParameter(1, 'FabioBatSilva')
                             ->getResult();
 
-        $this->assertEquals(1, count($result));
-        $this->assertInstanceOf(CmsUser::class, $result[0]);
-        $this->assertEquals('Fabio B. Silva', $result[0]->name);
-        $this->assertInstanceOf(PersistentCollection::class, $result[0]->getPhonenumbers());
-        $this->assertFalse($result[0]->getPhonenumbers()->isInitialized());
-        $this->assertInstanceOf(CmsAddress::class, $result[0]->getAddress());
-        $this->assertTrue($result[0]->getAddress()->getUser() === $result[0]);
-        $this->assertEquals('Brazil', $result[0]->getAddress()->getCountry());
-        $this->assertEquals(10827, $result[0]->getAddress()->getZipCode());
-        $this->assertEquals('São Paulo', $result[0]->getAddress()->getCity());
+        self::assertCount(1, $result);
+        self::assertInstanceOf(CmsUser::class, $result[0]);
+        self::assertEquals('Fabio B. Silva', $result[0]->name);
+        self::assertInstanceOf(PersistentCollection::class, $result[0]->getPhonenumbers());
+        self::assertFalse($result[0]->getPhonenumbers()->isInitialized());
+        self::assertInstanceOf(CmsAddress::class, $result[0]->getAddress());
+        self::assertEquals($result[0]->getAddress()->getUser(), $result[0]);
+        self::assertEquals('Brazil', $result[0]->getAddress()->getCountry());
+        self::assertEquals(10827, $result[0]->getAddress()->getZipCode());
+        self::assertEquals('São Paulo', $result[0]->getAddress()->getCity());
     }
 
     /**
@@ -512,15 +516,15 @@ class NativeQueryTest extends OrmFunctionalTestCase
         $result = $repository->createNativeNamedQuery('fetchJoinedPhonenumber')
                         ->setParameter(1, 'FabioBatSilva')->getResult();
 
-        $this->assertEquals(1, count($result));
-        $this->assertInstanceOf(CmsUser::class, $result[0]);
-        $this->assertEquals('Fabio B. Silva', $result[0]->name);
-        $this->assertInstanceOf(PersistentCollection::class, $result[0]->getPhonenumbers());
-        $this->assertTrue($result[0]->getPhonenumbers()->isInitialized());
-        $this->assertEquals(1, count($result[0]->getPhonenumbers()));
+        self::assertCount(1, $result);
+        self::assertInstanceOf(CmsUser::class, $result[0]);
+        self::assertEquals('Fabio B. Silva', $result[0]->name);
+        self::assertInstanceOf(PersistentCollection::class, $result[0]->getPhonenumbers());
+        self::assertTrue($result[0]->getPhonenumbers()->isInitialized());
+        self::assertCount(1, $result[0]->getPhonenumbers());
         $phones = $result[0]->getPhonenumbers();
-        $this->assertEquals(424242, $phones[0]->phonenumber);
-        $this->assertTrue($phones[0]->getUser() === $result[0]);
+        self::assertEquals(424242, $phones[0]->phonenumber);
+        self::assertSame($phones[0]->getUser(), $result[0]);
     }
 
     /**
@@ -560,19 +564,19 @@ class NativeQueryTest extends OrmFunctionalTestCase
         $result = $repository->createNativeNamedQuery('fetchUserPhonenumberCount')
                         ->setParameter(1, ['test', 'FabioBatSilva'])->getResult();
 
-        $this->assertEquals(2, count($result));
-        $this->assertTrue(is_array($result[0]));
-        $this->assertTrue(is_array($result[1]));
+        self::assertCount(2, $result);
+        self::assertIsArray($result[0]);
+        self::assertIsArray($result[1]);
 
         // first user => 2 phonenumbers
-        $this->assertInstanceOf(CmsUser::class, $result[0][0]);
-        $this->assertEquals('Fabio B. Silva', $result[0][0]->name);
-        $this->assertEquals(2, $result[0]['numphones']);
+        self::assertInstanceOf(CmsUser::class, $result[0][0]);
+        self::assertEquals('Fabio B. Silva', $result[0][0]->name);
+        self::assertEquals(2, $result[0]['numphones']);
 
         // second user => 1 phonenumbers
-        $this->assertInstanceOf(CmsUser::class, $result[1][0]);
-        $this->assertEquals('test tester', $result[1][0]->name);
-        $this->assertEquals(1, $result[1]['numphones']);
+        self::assertInstanceOf(CmsUser::class, $result[1][0]);
+        self::assertEquals('test tester', $result[1][0]->name);
+        self::assertEquals(1, $result[1]['numphones']);
     }
 
     /**
@@ -599,26 +603,26 @@ class NativeQueryTest extends OrmFunctionalTestCase
         $result = $repository->createNativeNamedQuery('fetchAllWithSqlResultSetMapping')
                         ->getResult();
 
-        $this->assertEquals(2, count($result));
-        $this->assertInstanceOf(CompanyPerson::class, $result[0]);
-        $this->assertInstanceOf(CompanyEmployee::class, $result[1]);
-        $this->assertTrue(is_numeric($result[0]->getId()));
-        $this->assertTrue(is_numeric($result[1]->getId()));
-        $this->assertEquals('Fabio B. Silva', $result[0]->getName());
-        $this->assertEquals('Fabio Silva', $result[1]->getName());
+        self::assertCount(2, $result);
+        self::assertInstanceOf(CompanyPerson::class, $result[0]);
+        self::assertInstanceOf(CompanyEmployee::class, $result[1]);
+        self::assertIsNumeric($result[0]->getId());
+        self::assertIsNumeric($result[1]->getId());
+        self::assertEquals('Fabio B. Silva', $result[0]->getName());
+        self::assertEquals('Fabio Silva', $result[1]->getName());
 
         $this->_em->clear();
 
         $result = $repository->createNativeNamedQuery('fetchAllWithResultClass')
                         ->getResult();
 
-        $this->assertEquals(2, count($result));
-        $this->assertInstanceOf(CompanyPerson::class, $result[0]);
-        $this->assertInstanceOf(CompanyEmployee::class, $result[1]);
-        $this->assertTrue(is_numeric($result[0]->getId()));
-        $this->assertTrue(is_numeric($result[1]->getId()));
-        $this->assertEquals('Fabio B. Silva', $result[0]->getName());
-        $this->assertEquals('Fabio Silva', $result[1]->getName());
+        self::assertCount(2, $result);
+        self::assertInstanceOf(CompanyPerson::class, $result[0]);
+        self::assertInstanceOf(CompanyEmployee::class, $result[1]);
+        self::assertIsNumeric($result[0]->getId());
+        self::assertIsNumeric($result[1]->getId());
+        self::assertEquals('Fabio B. Silva', $result[0]->getName());
+        self::assertEquals('Fabio Silva', $result[1]->getName());
     }
 
     /**
@@ -653,17 +657,16 @@ class NativeQueryTest extends OrmFunctionalTestCase
         $query      = $repository->createNativeNamedQuery('fetchMultipleJoinsEntityResults');
         $result     = $query->getResult();
 
-        $this->assertEquals(1, count($result));
-        $this->assertTrue(is_array($result[0]));
+        self::assertCount(1, $result);
+        self::assertIsArray($result[0]);
+        self::assertInstanceOf(CmsUser::class, $result[0][0]);
+        self::assertEquals('Fabio B. Silva', $result[0][0]->name);
+        self::assertInstanceOf(CmsAddress::class, $result[0][0]->getAddress());
+        self::assertEquals($result[0][0]->getAddress()->getUser(), $result[0][0]);
+        self::assertEquals('Brazil', $result[0][0]->getAddress()->getCountry());
+        self::assertEquals(10827, $result[0][0]->getAddress()->getZipCode());
 
-        $this->assertInstanceOf(CmsUser::class, $result[0][0]);
-        $this->assertEquals('Fabio B. Silva', $result[0][0]->name);
-        $this->assertInstanceOf(CmsAddress::class, $result[0][0]->getAddress());
-        $this->assertTrue($result[0][0]->getAddress()->getUser() === $result[0][0]);
-        $this->assertEquals('Brazil', $result[0][0]->getAddress()->getCountry());
-        $this->assertEquals(10827, $result[0][0]->getAddress()->getZipCode());
-
-        $this->assertEquals(1, $result[0]['numphones']);
+        self::assertEquals(1, $result[0]['numphones']);
     }
 
     /**
@@ -681,38 +684,38 @@ class NativeQueryTest extends OrmFunctionalTestCase
         $flexMappings     = $flexMetadata->getSqlResultSetMappings();
 
         // contract queries
-        $this->assertEquals('all-contracts', $contractQueries['all-contracts']['name']);
-        $this->assertEquals(CompanyContract::class, $contractQueries['all-contracts']['resultClass']);
+        self::assertEquals('all-contracts', $contractQueries['all-contracts']['name']);
+        self::assertEquals(CompanyContract::class, $contractQueries['all-contracts']['resultClass']);
 
-        $this->assertEquals('all', $contractQueries['all']['name']);
-        $this->assertEquals(CompanyContract::class, $contractQueries['all']['resultClass']);
+        self::assertEquals('all', $contractQueries['all']['name']);
+        self::assertEquals(CompanyContract::class, $contractQueries['all']['resultClass']);
 
         // flex contract queries
-        $this->assertEquals('all-contracts', $flexQueries['all-contracts']['name']);
-        $this->assertEquals(CompanyFlexContract::class, $flexQueries['all-contracts']['resultClass']);
+        self::assertEquals('all-contracts', $flexQueries['all-contracts']['name']);
+        self::assertEquals(CompanyFlexContract::class, $flexQueries['all-contracts']['resultClass']);
 
-        $this->assertEquals('all-flex', $flexQueries['all-flex']['name']);
-        $this->assertEquals(CompanyFlexContract::class, $flexQueries['all-flex']['resultClass']);
+        self::assertEquals('all-flex', $flexQueries['all-flex']['name']);
+        self::assertEquals(CompanyFlexContract::class, $flexQueries['all-flex']['resultClass']);
 
-        $this->assertEquals('all', $flexQueries['all']['name']);
-        $this->assertEquals(CompanyFlexContract::class, $flexQueries['all']['resultClass']);
+        self::assertEquals('all', $flexQueries['all']['name']);
+        self::assertEquals(CompanyFlexContract::class, $flexQueries['all']['resultClass']);
 
         // contract result mapping
-        $this->assertEquals('mapping-all-contracts', $contractMappings['mapping-all-contracts']['name']);
-        $this->assertEquals(CompanyContract::class, $contractMappings['mapping-all-contracts']['entities'][0]['entityClass']);
+        self::assertEquals('mapping-all-contracts', $contractMappings['mapping-all-contracts']['name']);
+        self::assertEquals(CompanyContract::class, $contractMappings['mapping-all-contracts']['entities'][0]['entityClass']);
 
-        $this->assertEquals('mapping-all', $contractMappings['mapping-all']['name']);
-        $this->assertEquals(CompanyContract::class, $contractMappings['mapping-all-contracts']['entities'][0]['entityClass']);
+        self::assertEquals('mapping-all', $contractMappings['mapping-all']['name']);
+        self::assertEquals(CompanyContract::class, $contractMappings['mapping-all-contracts']['entities'][0]['entityClass']);
 
         // flex contract result mapping
-        $this->assertEquals('mapping-all-contracts', $flexMappings['mapping-all-contracts']['name']);
-        $this->assertEquals(CompanyFlexContract::class, $flexMappings['mapping-all-contracts']['entities'][0]['entityClass']);
+        self::assertEquals('mapping-all-contracts', $flexMappings['mapping-all-contracts']['name']);
+        self::assertEquals(CompanyFlexContract::class, $flexMappings['mapping-all-contracts']['entities'][0]['entityClass']);
 
-        $this->assertEquals('mapping-all', $flexMappings['mapping-all']['name']);
-        $this->assertEquals(CompanyFlexContract::class, $flexMappings['mapping-all']['entities'][0]['entityClass']);
+        self::assertEquals('mapping-all', $flexMappings['mapping-all']['name']);
+        self::assertEquals(CompanyFlexContract::class, $flexMappings['mapping-all']['entities'][0]['entityClass']);
 
-        $this->assertEquals('mapping-all-flex', $flexMappings['mapping-all-flex']['name']);
-        $this->assertEquals(CompanyFlexContract::class, $flexMappings['mapping-all-flex']['entities'][0]['entityClass']);
+        self::assertEquals('mapping-all-flex', $flexMappings['mapping-all-flex']['name']);
+        self::assertEquals(CompanyFlexContract::class, $flexMappings['mapping-all-flex']['entities'][0]['entityClass']);
     }
 
     /**
@@ -789,11 +792,45 @@ class NativeQueryTest extends OrmFunctionalTestCase
         $rsm = new ResultSetMappingBuilder($this->_em, ResultSetMappingBuilder::COLUMN_RENAMING_INCREMENT);
         $rsm->addEntityResult(DDC3899User::class, 'u');
         $rsm->addJoinedEntityResult(DDC3899FixContract::class, 'c', 'u', 'contracts');
-        $rsm->addFieldResult('u', $this->platform->getSQLResultCasing('id'), 'id');
-        $rsm->setDiscriminatorColumn('c', $this->platform->getSQLResultCasing('discr'));
+        $rsm->addFieldResult('u', $this->getSQLResultCasing($this->platform, 'id'), 'id');
+        $rsm->setDiscriminatorColumn('c', $this->getSQLResultCasing($this->platform, 'discr'));
 
         $selectClause = $rsm->generateSelectClause(['u' => 'u1', 'c' => 'c1']);
 
         $this->assertSQLEquals('u1.id as id, c1.discr as discr', $selectClause);
     }
+
+    public function testGenerateSelectClauseWithCustomTypeUsingEntityFromClassMetadata(): void
+    {
+        if (DBALType::hasType('upper_case_string')) {
+            DBALType::overrideType('upper_case_string', UpperCaseStringType::class);
+        } else {
+            DBALType::addType('upper_case_string', UpperCaseStringType::class);
+        }
+
+        $rsm = new ResultSetMappingBuilder($this->_em, ResultSetMappingBuilder::COLUMN_RENAMING_INCREMENT);
+
+        $rsm->addRootEntityFromClassMetadata(CustomTypeUpperCase::class, 'ct');
+
+        $selectClause = $rsm->generateSelectClause(['ct' => 'ct1']);
+
+        $this->assertSQLEquals('ct1.id as id0, lower(ct1.lowercasestring) as lowercasestring1, lower(ct1.named_lower_case_string) as named_lower_case_string2', $selectClause);
+    }
+
+    public function testGenerateSelectClauseWithCustomTypeUsingAddFieldResult(): void
+    {
+        if (DBALType::hasType('upper_case_string')) {
+            DBALType::overrideType('upper_case_string', UpperCaseStringType::class);
+        } else {
+            DBALType::addType('upper_case_string', UpperCaseStringType::class);
+        }
+
+        $rsm = new ResultSetMappingBuilder($this->_em, ResultSetMappingBuilder::COLUMN_RENAMING_INCREMENT);
+        $rsm->addEntityResult(CustomTypeUpperCase::class, 'ct');
+        $rsm->addFieldResult('ct', $this->getSQLResultCasing($this->platform, 'lowercasestring'), 'lowerCaseString');
+
+        $selectClause = $rsm->generateSelectClause(['ct' => 'ct1']);
+
+        $this->assertSQLEquals('lower(ct1.lowercasestring) as lowercasestring', $selectClause);
+    }
 }
