@@ -11,8 +11,6 @@ use Doctrine\Tests\Models\Routing\RoutingRoute;
 use Doctrine\Tests\OrmFunctionalTestCase;
 use Exception;
 
-use function count;
-
 /**
  * Tests a bidirectional one-to-one association mapping (without inheritance).
  */
@@ -58,9 +56,9 @@ class OneToManyUnidirectionalAssociationTest extends OrmFunctionalTestCase
             'JOIN r.legs l JOIN l.fromLocation f JOIN l.toLocation t'
         )->getSingleResult();
 
-        $this->assertEquals(1, count($routes->legs));
-        $this->assertEquals('Berlin', $routes->legs[0]->fromLocation->name);
-        $this->assertEquals('Bonn', $routes->legs[0]->toLocation->name);
+        self::assertCount(1, $routes->legs);
+        self::assertEquals('Berlin', $routes->legs[0]->fromLocation->name);
+        self::assertEquals('Bonn', $routes->legs[0]->toLocation->name);
     }
 
     public function testLegsAreUniqueToRoutes(): void
@@ -88,6 +86,6 @@ class OneToManyUnidirectionalAssociationTest extends OrmFunctionalTestCase
             $exceptionThrown = true;
         }
 
-        $this->assertTrue($exceptionThrown, 'The underlying database driver throws an exception.');
+        self::assertTrue($exceptionThrown, 'The underlying database driver throws an exception.');
     }
 }
