@@ -59,7 +59,7 @@ class PaginationTest extends OrmFunctionalTestCase
 
         $paginator = new Paginator($query);
         $paginator->setUseOutputWalkers($useOutputWalkers);
-        $this->assertCount(9, $paginator);
+        self::assertCount(9, $paginator);
     }
 
     /**
@@ -72,7 +72,7 @@ class PaginationTest extends OrmFunctionalTestCase
 
         $paginator = new Paginator($query);
         $paginator->setUseOutputWalkers($useOutputWalkers);
-        $this->assertCount(9, $paginator);
+        self::assertCount(9, $paginator);
     }
 
     public function testCountComplexWithOutputWalker(): void
@@ -82,7 +82,7 @@ class PaginationTest extends OrmFunctionalTestCase
 
         $paginator = new Paginator($query);
         $paginator->setUseOutputWalkers(true);
-        $this->assertCount(3, $paginator);
+        self::assertCount(3, $paginator);
     }
 
     public function testCountComplexWithoutOutputWalker(): void
@@ -96,7 +96,7 @@ class PaginationTest extends OrmFunctionalTestCase
         $this->expectException(RuntimeException::class);
         $this->expectExceptionMessage('Cannot count query that uses a HAVING clause. Use the output walkers for pagination');
 
-        $this->assertCount(3, $paginator);
+        self::assertCount(3, $paginator);
     }
 
     /**
@@ -109,7 +109,7 @@ class PaginationTest extends OrmFunctionalTestCase
 
         $paginator = new Paginator($query);
         $paginator->setUseOutputWalkers($useOutputWalkers);
-        $this->assertCount(9, $paginator);
+        self::assertCount(9, $paginator);
     }
 
     /**
@@ -122,19 +122,19 @@ class PaginationTest extends OrmFunctionalTestCase
 
         $paginator = new Paginator($query, $fetchJoinCollection);
         $paginator->setUseOutputWalkers($useOutputWalkers);
-        $this->assertCount(9, $paginator->getIterator());
+        self::assertCount(9, $paginator->getIterator());
 
         // Test with limit
         $query->setMaxResults(3);
         $paginator = new Paginator($query, $fetchJoinCollection);
         $paginator->setUseOutputWalkers($useOutputWalkers);
-        $this->assertCount(3, $paginator->getIterator());
+        self::assertCount(3, $paginator->getIterator());
 
         // Test with limit and offset
         $query->setMaxResults(3)->setFirstResult(4);
         $paginator = new Paginator($query, $fetchJoinCollection);
         $paginator->setUseOutputWalkers($useOutputWalkers);
-        $this->assertCount(3, $paginator->getIterator());
+        self::assertCount(3, $paginator->getIterator());
     }
 
     private function iterateWithOrderAsc($useOutputWalkers, $fetchJoinCollection, $baseDql, $checkField): void
@@ -146,9 +146,9 @@ class PaginationTest extends OrmFunctionalTestCase
         $paginator = new Paginator($query, $fetchJoinCollection);
         $paginator->setUseOutputWalkers($useOutputWalkers);
         $iter = $paginator->getIterator();
-        $this->assertCount(9, $iter);
+        self::assertCount(9, $iter);
         $result = iterator_to_array($iter);
-        $this->assertEquals($checkField . '0', $result[0]->$checkField);
+        self::assertEquals($checkField . '0', $result[0]->$checkField);
     }
 
     private function iterateWithOrderAscWithLimit($useOutputWalkers, $fetchJoinCollection, $baseDql, $checkField): void
@@ -162,9 +162,9 @@ class PaginationTest extends OrmFunctionalTestCase
         $paginator = new Paginator($query, $fetchJoinCollection);
         $paginator->setUseOutputWalkers($useOutputWalkers);
         $iter = $paginator->getIterator();
-        $this->assertCount(3, $iter);
+        self::assertCount(3, $iter);
         $result = iterator_to_array($iter);
-        $this->assertEquals($checkField . '0', $result[0]->$checkField);
+        self::assertEquals($checkField . '0', $result[0]->$checkField);
     }
 
     private function iterateWithOrderAscWithLimitAndOffset($useOutputWalkers, $fetchJoinCollection, $baseDql, $checkField): void
@@ -178,9 +178,9 @@ class PaginationTest extends OrmFunctionalTestCase
         $paginator = new Paginator($query, $fetchJoinCollection);
         $paginator->setUseOutputWalkers($useOutputWalkers);
         $iter = $paginator->getIterator();
-        $this->assertCount(3, $iter);
+        self::assertCount(3, $iter);
         $result = iterator_to_array($iter);
-        $this->assertEquals($checkField . '3', $result[0]->$checkField);
+        self::assertEquals($checkField . '3', $result[0]->$checkField);
     }
 
     private function iterateWithOrderDesc($useOutputWalkers, $fetchJoinCollection, $baseDql, $checkField): void
@@ -191,9 +191,9 @@ class PaginationTest extends OrmFunctionalTestCase
         $paginator = new Paginator($query, $fetchJoinCollection);
         $paginator->setUseOutputWalkers($useOutputWalkers);
         $iter = $paginator->getIterator();
-        $this->assertCount(9, $iter);
+        self::assertCount(9, $iter);
         $result = iterator_to_array($iter);
-        $this->assertEquals($checkField . '8', $result[0]->$checkField);
+        self::assertEquals($checkField . '8', $result[0]->$checkField);
     }
 
     private function iterateWithOrderDescWithLimit($useOutputWalkers, $fetchJoinCollection, $baseDql, $checkField): void
@@ -206,9 +206,9 @@ class PaginationTest extends OrmFunctionalTestCase
         $paginator = new Paginator($query, $fetchJoinCollection);
         $paginator->setUseOutputWalkers($useOutputWalkers);
         $iter = $paginator->getIterator();
-        $this->assertCount(3, $iter);
+        self::assertCount(3, $iter);
         $result = iterator_to_array($iter);
-        $this->assertEquals($checkField . '8', $result[0]->$checkField);
+        self::assertEquals($checkField . '8', $result[0]->$checkField);
     }
 
     private function iterateWithOrderDescWithLimitAndOffset($useOutputWalkers, $fetchJoinCollection, $baseDql, $checkField): void
@@ -221,9 +221,9 @@ class PaginationTest extends OrmFunctionalTestCase
         $paginator = new Paginator($query, $fetchJoinCollection);
         $paginator->setUseOutputWalkers($useOutputWalkers);
         $iter = $paginator->getIterator();
-        $this->assertCount(3, $iter);
+        self::assertCount(3, $iter);
         $result = iterator_to_array($iter);
-        $this->assertEquals($checkField . '5', $result[0]->$checkField);
+        self::assertEquals($checkField . '5', $result[0]->$checkField);
     }
 
     /**
@@ -302,7 +302,7 @@ class PaginationTest extends OrmFunctionalTestCase
 
         $paginator = new Paginator($query, true);
         $paginator->setUseOutputWalkers($useOutputWalkers);
-        $this->assertCount(9, $paginator->getIterator());
+        self::assertCount(9, $paginator->getIterator());
     }
 
     /**
@@ -478,7 +478,7 @@ class PaginationTest extends OrmFunctionalTestCase
 
         $paginator = new Paginator($query);
         $paginator->setUseOutputWalkers(true);
-        $this->assertCount(3, $paginator->getIterator());
+        self::assertCount(3, $paginator->getIterator());
     }
 
     public function testJoinedClassTableInheritance(): void
@@ -487,7 +487,7 @@ class PaginationTest extends OrmFunctionalTestCase
         $query = $this->_em->createQuery($dql);
 
         $paginator = new Paginator($query);
-        $this->assertCount(1, $paginator->getIterator());
+        self::assertCount(1, $paginator->getIterator());
     }
 
     /**
@@ -588,7 +588,7 @@ class PaginationTest extends OrmFunctionalTestCase
 
         $paginator = new Paginator($query, true);
         $paginator->setUseOutputWalkers(true);
-        $this->assertCount(9, $paginator);
+        self::assertCount(9, $paginator);
     }
 
     public function testIterateWithCountSubqueryInWhereClause(): void
@@ -600,9 +600,9 @@ class PaginationTest extends OrmFunctionalTestCase
         $paginator->setUseOutputWalkers(true);
 
         $users = iterator_to_array($paginator->getIterator());
-        $this->assertCount(9, $users);
+        self::assertCount(9, $users);
         foreach ($users as $i => $user) {
-            $this->assertEquals('username' . (8 - $i), $user->username);
+            self::assertEquals('username' . (8 - $i), $user->username);
         }
     }
 
@@ -634,7 +634,7 @@ class PaginationTest extends OrmFunctionalTestCase
         $paginator = new Paginator($query);
         $paginator->getIterator();
 
-        $this->assertCount(9, $paginator->getIterator());
+        self::assertCount(9, $paginator->getIterator());
     }
 
     public function testCloneQuery(): void
@@ -645,7 +645,7 @@ class PaginationTest extends OrmFunctionalTestCase
         $paginator = new Paginator($query);
         $paginator->getIterator();
 
-        $this->assertTrue($query->getParameters()->isEmpty());
+        self::assertTrue($query->getParameters()->isEmpty());
     }
 
     public function testQueryWalkerIsKept(): void
@@ -656,8 +656,8 @@ class PaginationTest extends OrmFunctionalTestCase
 
         $paginator = new Paginator($query, true);
         $paginator->setUseOutputWalkers(false);
-        $this->assertCount(1, $paginator->getIterator());
-        $this->assertEquals(1, $paginator->count());
+        self::assertCount(1, $paginator->getIterator());
+        self::assertEquals(1, $paginator->count());
     }
 
     /**
@@ -698,8 +698,8 @@ class PaginationTest extends OrmFunctionalTestCase
 
         $getCountQuery->setAccessible(true);
 
-        $this->assertCount(2, $getCountQuery->invoke($paginator)->getParameters());
-        $this->assertCount(9, $paginator);
+        self::assertCount(2, $getCountQuery->invoke($paginator)->getParameters());
+        self::assertCount(9, $paginator);
 
         $query->setHint(Query::HINT_CUSTOM_OUTPUT_WALKER, Query\SqlWalker::class);
 
@@ -707,8 +707,8 @@ class PaginationTest extends OrmFunctionalTestCase
 
         // if select part of query is replaced with count(...) paginator should remove
         // parameters from query object not used in new query.
-        $this->assertCount(1, $getCountQuery->invoke($paginator)->getParameters());
-        $this->assertCount(9, $paginator);
+        self::assertCount(1, $getCountQuery->invoke($paginator)->getParameters());
+        self::assertCount(9, $paginator);
     }
 
     /**
@@ -732,7 +732,7 @@ SQL
         $paginator = new Paginator($query, $fetchJoinCollection);
         $paginator->setUseOutputWalkers($useOutputWalker);
 
-        $this->assertCount(9, $paginator->getIterator());
+        self::assertCount(9, $paginator->getIterator());
     }
 
     public function populate(): void
