@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\ORM\Functional;
 
 use DateTimeImmutable;
@@ -8,7 +10,6 @@ use Doctrine\ORM\AbstractQuery;
 use Doctrine\Tests\Models\Company\CompanyManager;
 use Doctrine\Tests\OrmFunctionalTestCase;
 
-use function count;
 use function round;
 use function sprintf;
 
@@ -30,7 +31,7 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         $salarySum = $this->_em->createQuery('SELECT SUM(m.salary) AS salary FROM Doctrine\Tests\Models\Company\CompanyManager m')
                                ->getSingleResult();
 
-        $this->assertEquals(1500000, $salarySum['salary']);
+        self::assertEquals(1500000, $salarySum['salary']);
     }
 
     public function testAggregateAvg(): void
@@ -38,7 +39,7 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         $salaryAvg = $this->_em->createQuery('SELECT AVG(m.salary) AS salary FROM Doctrine\Tests\Models\Company\CompanyManager m')
                                ->getSingleResult();
 
-        $this->assertEquals(375000, round($salaryAvg['salary'], 0));
+        self::assertEquals(375000, round((float) $salaryAvg['salary'], 0));
     }
 
     public function testAggregateMin(): void
@@ -46,7 +47,7 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         $salary = $this->_em->createQuery('SELECT MIN(m.salary) AS salary FROM Doctrine\Tests\Models\Company\CompanyManager m')
                                ->getSingleResult();
 
-        $this->assertEquals(100000, $salary['salary']);
+        self::assertEquals(100000, $salary['salary']);
     }
 
     public function testAggregateMax(): void
@@ -54,7 +55,7 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         $salary = $this->_em->createQuery('SELECT MAX(m.salary) AS salary FROM Doctrine\Tests\Models\Company\CompanyManager m')
                                ->getSingleResult();
 
-        $this->assertEquals(800000, $salary['salary']);
+        self::assertEquals(800000, $salary['salary']);
     }
 
     public function testAggregateCount(): void
@@ -62,7 +63,7 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         $managerCount = $this->_em->createQuery('SELECT COUNT(m.id) AS managers FROM Doctrine\Tests\Models\Company\CompanyManager m')
                                ->getSingleResult();
 
-        $this->assertEquals(4, $managerCount['managers']);
+        self::assertEquals(4, $managerCount['managers']);
     }
 
     public function testFunctionAbs(): void
@@ -70,11 +71,11 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         $result = $this->_em->createQuery('SELECT m, ABS(m.salary * -1) AS abs FROM Doctrine\Tests\Models\Company\CompanyManager m ORDER BY m.salary ASC')
                          ->getResult();
 
-        $this->assertEquals(4, count($result));
-        $this->assertEquals(100000, $result[0]['abs']);
-        $this->assertEquals(200000, $result[1]['abs']);
-        $this->assertEquals(400000, $result[2]['abs']);
-        $this->assertEquals(800000, $result[3]['abs']);
+        self::assertCount(4, $result);
+        self::assertEquals(100000, $result[0]['abs']);
+        self::assertEquals(200000, $result[1]['abs']);
+        self::assertEquals(400000, $result[2]['abs']);
+        self::assertEquals(800000, $result[3]['abs']);
     }
 
     public function testFunctionConcat(): void
@@ -82,11 +83,11 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         $arg = $this->_em->createQuery('SELECT m, CONCAT(m.name, m.department) AS namedep FROM Doctrine\Tests\Models\Company\CompanyManager m ORDER BY m.salary ASC')
                          ->getArrayResult();
 
-        $this->assertEquals(4, count($arg));
-        $this->assertEquals('Roman B.IT', $arg[0]['namedep']);
-        $this->assertEquals('Benjamin E.HR', $arg[1]['namedep']);
-        $this->assertEquals('Guilherme B.Complaint Department', $arg[2]['namedep']);
-        $this->assertEquals('Jonathan W.Administration', $arg[3]['namedep']);
+        self::assertCount(4, $arg);
+        self::assertEquals('Roman B.IT', $arg[0]['namedep']);
+        self::assertEquals('Benjamin E.HR', $arg[1]['namedep']);
+        self::assertEquals('Guilherme B.Complaint Department', $arg[2]['namedep']);
+        self::assertEquals('Jonathan W.Administration', $arg[3]['namedep']);
     }
 
     public function testFunctionLength(): void
@@ -94,11 +95,11 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         $result = $this->_em->createQuery('SELECT m, LENGTH(CONCAT(m.name, m.department)) AS namedeplength FROM Doctrine\Tests\Models\Company\CompanyManager m ORDER BY m.salary ASC')
                          ->getArrayResult();
 
-        $this->assertEquals(4, count($result));
-        $this->assertEquals(10, $result[0]['namedeplength']);
-        $this->assertEquals(13, $result[1]['namedeplength']);
-        $this->assertEquals(32, $result[2]['namedeplength']);
-        $this->assertEquals(25, $result[3]['namedeplength']);
+        self::assertCount(4, $result);
+        self::assertEquals(10, $result[0]['namedeplength']);
+        self::assertEquals(13, $result[1]['namedeplength']);
+        self::assertEquals(32, $result[2]['namedeplength']);
+        self::assertEquals(25, $result[3]['namedeplength']);
     }
 
     public function testFunctionLocate(): void
@@ -109,15 +110,15 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         $result = $this->_em->createQuery($dql)
                          ->getArrayResult();
 
-        $this->assertEquals(4, count($result));
-        $this->assertEquals(0, $result[0]['loc']);
-        $this->assertEquals(2, $result[1]['loc']);
-        $this->assertEquals(6, $result[2]['loc']);
-        $this->assertEquals(0, $result[3]['loc']);
-        $this->assertEquals(0, $result[0]['loc2']);
-        $this->assertEquals(10, $result[1]['loc2']);
-        $this->assertEquals(9, $result[2]['loc2']);
-        $this->assertEquals(0, $result[3]['loc2']);
+        self::assertCount(4, $result);
+        self::assertEquals(0, $result[0]['loc']);
+        self::assertEquals(2, $result[1]['loc']);
+        self::assertEquals(6, $result[2]['loc']);
+        self::assertEquals(0, $result[3]['loc']);
+        self::assertEquals(0, $result[0]['loc2']);
+        self::assertEquals(10, $result[1]['loc2']);
+        self::assertEquals(9, $result[2]['loc2']);
+        self::assertEquals(0, $result[3]['loc2']);
     }
 
     public function testFunctionLower(): void
@@ -125,11 +126,11 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         $result = $this->_em->createQuery('SELECT m, LOWER(m.name) AS lowername FROM Doctrine\Tests\Models\Company\CompanyManager m ORDER BY m.salary ASC')
                          ->getArrayResult();
 
-        $this->assertEquals(4, count($result));
-        $this->assertEquals('roman b.', $result[0]['lowername']);
-        $this->assertEquals('benjamin e.', $result[1]['lowername']);
-        $this->assertEquals('guilherme b.', $result[2]['lowername']);
-        $this->assertEquals('jonathan w.', $result[3]['lowername']);
+        self::assertCount(4, $result);
+        self::assertEquals('roman b.', $result[0]['lowername']);
+        self::assertEquals('benjamin e.', $result[1]['lowername']);
+        self::assertEquals('guilherme b.', $result[2]['lowername']);
+        self::assertEquals('jonathan w.', $result[3]['lowername']);
     }
 
     public function testFunctionMod(): void
@@ -137,11 +138,11 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         $result = $this->_em->createQuery('SELECT m, MOD(m.salary, 3500) AS amod FROM Doctrine\Tests\Models\Company\CompanyManager m ORDER BY m.salary ASC')
                          ->getArrayResult();
 
-        $this->assertEquals(4, count($result));
-        $this->assertEquals(2000, $result[0]['amod']);
-        $this->assertEquals(500, $result[1]['amod']);
-        $this->assertEquals(1000, $result[2]['amod']);
-        $this->assertEquals(2000, $result[3]['amod']);
+        self::assertCount(4, $result);
+        self::assertEquals(2000, $result[0]['amod']);
+        self::assertEquals(500, $result[1]['amod']);
+        self::assertEquals(1000, $result[2]['amod']);
+        self::assertEquals(2000, $result[3]['amod']);
     }
 
     public function testFunctionSqrt(): void
@@ -149,11 +150,11 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         $result = $this->_em->createQuery('SELECT m, SQRT(m.salary) AS sqrtsalary FROM Doctrine\Tests\Models\Company\CompanyManager m ORDER BY m.salary ASC')
                          ->getArrayResult();
 
-        $this->assertEquals(4, count($result));
-        $this->assertEquals(316, round($result[0]['sqrtsalary']));
-        $this->assertEquals(447, round($result[1]['sqrtsalary']));
-        $this->assertEquals(632, round($result[2]['sqrtsalary']));
-        $this->assertEquals(894, round($result[3]['sqrtsalary']));
+        self::assertCount(4, $result);
+        self::assertEquals(316, round((float) $result[0]['sqrtsalary']));
+        self::assertEquals(447, round((float) $result[1]['sqrtsalary']));
+        self::assertEquals(632, round((float) $result[2]['sqrtsalary']));
+        self::assertEquals(894, round((float) $result[3]['sqrtsalary']));
     }
 
     public function testFunctionUpper(): void
@@ -161,11 +162,11 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         $result = $this->_em->createQuery('SELECT m, UPPER(m.name) AS uppername FROM Doctrine\Tests\Models\Company\CompanyManager m ORDER BY m.salary ASC')
                          ->getArrayResult();
 
-        $this->assertEquals(4, count($result));
-        $this->assertEquals('ROMAN B.', $result[0]['uppername']);
-        $this->assertEquals('BENJAMIN E.', $result[1]['uppername']);
-        $this->assertEquals('GUILHERME B.', $result[2]['uppername']);
-        $this->assertEquals('JONATHAN W.', $result[3]['uppername']);
+        self::assertCount(4, $result);
+        self::assertEquals('ROMAN B.', $result[0]['uppername']);
+        self::assertEquals('BENJAMIN E.', $result[1]['uppername']);
+        self::assertEquals('GUILHERME B.', $result[2]['uppername']);
+        self::assertEquals('JONATHAN W.', $result[3]['uppername']);
     }
 
     public function testFunctionSubstring(): void
@@ -176,16 +177,16 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         $result = $this->_em->createQuery($dql)
                          ->getArrayResult();
 
-        $this->assertEquals(4, count($result));
-        $this->assertEquals('Ben', $result[0]['str1']);
-        $this->assertEquals('Gui', $result[1]['str1']);
-        $this->assertEquals('Jon', $result[2]['str1']);
-        $this->assertEquals('Rom', $result[3]['str1']);
+        self::assertCount(4, $result);
+        self::assertEquals('Ben', $result[0]['str1']);
+        self::assertEquals('Gui', $result[1]['str1']);
+        self::assertEquals('Jon', $result[2]['str1']);
+        self::assertEquals('Rom', $result[3]['str1']);
 
-        $this->assertEquals('amin E.', $result[0]['str2']);
-        $this->assertEquals('herme B.', $result[1]['str2']);
-        $this->assertEquals('than W.', $result[2]['str2']);
-        $this->assertEquals('n B.', $result[3]['str2']);
+        self::assertEquals('amin E.', $result[0]['str2']);
+        self::assertEquals('herme B.', $result[1]['str2']);
+        self::assertEquals('than W.', $result[2]['str2']);
+        self::assertEquals('n B.', $result[3]['str2']);
     }
 
     public function testFunctionTrim(): void
@@ -196,19 +197,19 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
 
         $result = $this->_em->createQuery($dql)->getArrayResult();
 
-        $this->assertEquals(4, count($result));
-        $this->assertEquals('Roman B', $result[0]['str1']);
-        $this->assertEquals('Benjamin E', $result[1]['str1']);
-        $this->assertEquals('Guilherme B', $result[2]['str1']);
-        $this->assertEquals('Jonathan W', $result[3]['str1']);
-        $this->assertEquals('Roman B.', $result[0]['str2']);
-        $this->assertEquals('Benjamin E.', $result[1]['str2']);
-        $this->assertEquals('Guilherme B.', $result[2]['str2']);
-        $this->assertEquals('Jonathan W.', $result[3]['str2']);
-        $this->assertEquals('Roman B.', $result[0]['str3']);
-        $this->assertEquals('Benjamin E.', $result[1]['str3']);
-        $this->assertEquals('Guilherme B.', $result[2]['str3']);
-        $this->assertEquals('Jonathan W.', $result[3]['str3']);
+        self::assertCount(4, $result);
+        self::assertEquals('Roman B', $result[0]['str1']);
+        self::assertEquals('Benjamin E', $result[1]['str1']);
+        self::assertEquals('Guilherme B', $result[2]['str1']);
+        self::assertEquals('Jonathan W', $result[3]['str1']);
+        self::assertEquals('Roman B.', $result[0]['str2']);
+        self::assertEquals('Benjamin E.', $result[1]['str2']);
+        self::assertEquals('Guilherme B.', $result[2]['str2']);
+        self::assertEquals('Jonathan W.', $result[3]['str2']);
+        self::assertEquals('Roman B.', $result[0]['str3']);
+        self::assertEquals('Benjamin E.', $result[1]['str3']);
+        self::assertEquals('Guilherme B.', $result[2]['str3']);
+        self::assertEquals('Jonathan W.', $result[3]['str3']);
     }
 
     public function testOperatorAdd(): void
@@ -216,11 +217,11 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         $result = $this->_em->createQuery('SELECT m, m.salary+2500 AS add FROM Doctrine\Tests\Models\Company\CompanyManager m ORDER BY m.salary ASC')
                 ->getResult();
 
-        $this->assertEquals(4, count($result));
-        $this->assertEquals(102500, $result[0]['add']);
-        $this->assertEquals(202500, $result[1]['add']);
-        $this->assertEquals(402500, $result[2]['add']);
-        $this->assertEquals(802500, $result[3]['add']);
+        self::assertCount(4, $result);
+        self::assertEquals(102500, $result[0]['add']);
+        self::assertEquals(202500, $result[1]['add']);
+        self::assertEquals(402500, $result[2]['add']);
+        self::assertEquals(802500, $result[3]['add']);
     }
 
     public function testOperatorSub(): void
@@ -228,11 +229,11 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         $result = $this->_em->createQuery('SELECT m, m.salary-2500 AS sub FROM Doctrine\Tests\Models\Company\CompanyManager m ORDER BY m.salary ASC')
                 ->getResult();
 
-        $this->assertEquals(4, count($result));
-        $this->assertEquals(97500, $result[0]['sub']);
-        $this->assertEquals(197500, $result[1]['sub']);
-        $this->assertEquals(397500, $result[2]['sub']);
-        $this->assertEquals(797500, $result[3]['sub']);
+        self::assertCount(4, $result);
+        self::assertEquals(97500, $result[0]['sub']);
+        self::assertEquals(197500, $result[1]['sub']);
+        self::assertEquals(397500, $result[2]['sub']);
+        self::assertEquals(797500, $result[3]['sub']);
     }
 
     public function testOperatorMultiply(): void
@@ -240,11 +241,11 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         $result = $this->_em->createQuery('SELECT m, m.salary*2 AS op FROM Doctrine\Tests\Models\Company\CompanyManager m ORDER BY m.salary ASC')
                 ->getResult();
 
-        $this->assertEquals(4, count($result));
-        $this->assertEquals(200000, $result[0]['op']);
-        $this->assertEquals(400000, $result[1]['op']);
-        $this->assertEquals(800000, $result[2]['op']);
-        $this->assertEquals(1600000, $result[3]['op']);
+        self::assertCount(4, $result);
+        self::assertEquals(200000, $result[0]['op']);
+        self::assertEquals(400000, $result[1]['op']);
+        self::assertEquals(800000, $result[2]['op']);
+        self::assertEquals(1600000, $result[3]['op']);
     }
 
     /**
@@ -255,11 +256,11 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         $result = $this->_em->createQuery('SELECT m, (m.salary/0.5) AS op FROM Doctrine\Tests\Models\Company\CompanyManager m ORDER BY m.salary ASC')
                 ->getResult();
 
-        $this->assertEquals(4, count($result));
-        $this->assertEquals(200000, $result[0]['op']);
-        $this->assertEquals(400000, $result[1]['op']);
-        $this->assertEquals(800000, $result[2]['op']);
-        $this->assertEquals(1600000, $result[3]['op']);
+        self::assertCount(4, $result);
+        self::assertEquals(200000, $result[0]['op']);
+        self::assertEquals(400000, $result[1]['op']);
+        self::assertEquals(800000, $result[2]['op']);
+        self::assertEquals(1600000, $result[3]['op']);
     }
 
     public function testConcatFunction(): void
@@ -267,11 +268,11 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         $arg = $this->_em->createQuery('SELECT CONCAT(m.name, m.department) AS namedep FROM Doctrine\Tests\Models\Company\CompanyManager m order by namedep desc')
                 ->getArrayResult();
 
-        $this->assertEquals(4, count($arg));
-        $this->assertEquals('Roman B.IT', $arg[0]['namedep']);
-        $this->assertEquals('Jonathan W.Administration', $arg[1]['namedep']);
-        $this->assertEquals('Guilherme B.Complaint Department', $arg[2]['namedep']);
-        $this->assertEquals('Benjamin E.HR', $arg[3]['namedep']);
+        self::assertCount(4, $arg);
+        self::assertEquals('Roman B.IT', $arg[0]['namedep']);
+        self::assertEquals('Jonathan W.Administration', $arg[1]['namedep']);
+        self::assertEquals('Guilherme B.Complaint Department', $arg[2]['namedep']);
+        self::assertEquals('Benjamin E.HR', $arg[3]['namedep']);
     }
 
     /**
@@ -282,12 +283,12 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         $query = $this->_em->createQuery("SELECT DATE_DIFF(CURRENT_TIMESTAMP(), DATE_ADD(CURRENT_TIMESTAMP(), 10, 'day')) AS diff FROM Doctrine\Tests\Models\Company\CompanyManager m");
         $arg   = $query->getArrayResult();
 
-        $this->assertEqualsWithDelta(-10, $arg[0]['diff'], 1, 'Should be roughly -10 (or -9)');
+        self::assertEqualsWithDelta(-10, $arg[0]['diff'], 1, 'Should be roughly -10 (or -9)');
 
         $query = $this->_em->createQuery("SELECT DATE_DIFF(DATE_ADD(CURRENT_TIMESTAMP(), 10, 'day'), CURRENT_TIMESTAMP()) AS diff FROM Doctrine\Tests\Models\Company\CompanyManager m");
         $arg   = $query->getArrayResult();
 
-        $this->assertEqualsWithDelta(10, $arg[0]['diff'], 1, 'Should be roughly 10 (or 9)');
+        self::assertEqualsWithDelta(10, $arg[0]['diff'], 1, 'Should be roughly 10 (or 9)');
     }
 
     /**
@@ -311,8 +312,18 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
         self::assertArrayHasKey('now', $result);
         self::assertArrayHasKey('add', $result);
 
+        $now       = new DateTimeImmutable($result['now']);
+        $inOneUnit = $now->modify(sprintf('+%d %s', $amount, $unit));
+        if (
+            $unit === 'month'
+            && $inOneUnit->format('m') === $now->modify('+2 month')->format('m')
+            && ! $this->_em->getConnection()->getDatabasePlatform() instanceof SqlitePlatform
+        ) {
+            $inOneUnit = new DateTimeImmutable('last day of next month');
+        }
+
         self::assertEqualsWithDelta(
-            (new DateTimeImmutable($result['now']))->modify(sprintf('+%d %s', $amount, $unit)),
+            $inOneUnit,
             new DateTimeImmutable($result['add']),
             $delta
         );
@@ -384,15 +395,15 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
                     'm.id ';
         $result = $this->_em->createQuery($dql)->getArrayResult();
 
-        $this->assertEquals(4 | 2, $result[0]['bit_or']);
-        $this->assertEquals(4 | 2, $result[1]['bit_or']);
-        $this->assertEquals(4 | 2, $result[2]['bit_or']);
-        $this->assertEquals(4 | 2, $result[3]['bit_or']);
+        self::assertEquals(4 | 2, $result[0]['bit_or']);
+        self::assertEquals(4 | 2, $result[1]['bit_or']);
+        self::assertEquals(4 | 2, $result[2]['bit_or']);
+        self::assertEquals(4 | 2, $result[3]['bit_or']);
 
-        $this->assertEquals($result[0][0]['salary'] / 100000 | 2, $result[0]['salary_bit_or']);
-        $this->assertEquals($result[1][0]['salary'] / 100000 | 2, $result[1]['salary_bit_or']);
-        $this->assertEquals($result[2][0]['salary'] / 100000 | 2, $result[2]['salary_bit_or']);
-        $this->assertEquals($result[3][0]['salary'] / 100000 | 2, $result[3]['salary_bit_or']);
+        self::assertEquals($result[0][0]['salary'] / 100000 | 2, $result[0]['salary_bit_or']);
+        self::assertEquals($result[1][0]['salary'] / 100000 | 2, $result[1]['salary_bit_or']);
+        self::assertEquals($result[2][0]['salary'] / 100000 | 2, $result[2]['salary_bit_or']);
+        self::assertEquals($result[3][0]['salary'] / 100000 | 2, $result[3]['salary_bit_or']);
     }
 
     /**
@@ -408,15 +419,48 @@ class QueryDqlFunctionTest extends OrmFunctionalTestCase
                     'm.id ';
         $result = $this->_em->createQuery($dql)->getArrayResult();
 
-        $this->assertEquals(4 & 2, $result[0]['bit_and']);
-        $this->assertEquals(4 & 2, $result[1]['bit_and']);
-        $this->assertEquals(4 & 2, $result[2]['bit_and']);
-        $this->assertEquals(4 & 2, $result[3]['bit_and']);
+        self::assertEquals(4 & 2, $result[0]['bit_and']);
+        self::assertEquals(4 & 2, $result[1]['bit_and']);
+        self::assertEquals(4 & 2, $result[2]['bit_and']);
+        self::assertEquals(4 & 2, $result[3]['bit_and']);
 
-        $this->assertEquals($result[0][0]['salary'] / 100000 & 2, $result[0]['salary_bit_and']);
-        $this->assertEquals($result[1][0]['salary'] / 100000 & 2, $result[1]['salary_bit_and']);
-        $this->assertEquals($result[2][0]['salary'] / 100000 & 2, $result[2]['salary_bit_and']);
-        $this->assertEquals($result[3][0]['salary'] / 100000 & 2, $result[3]['salary_bit_and']);
+        self::assertEquals($result[0][0]['salary'] / 100000 & 2, $result[0]['salary_bit_and']);
+        self::assertEquals($result[1][0]['salary'] / 100000 & 2, $result[1]['salary_bit_and']);
+        self::assertEquals($result[2][0]['salary'] / 100000 & 2, $result[2]['salary_bit_and']);
+        self::assertEquals($result[3][0]['salary'] / 100000 & 2, $result[3]['salary_bit_and']);
+    }
+
+    public function testInArithmeticExpression1(): void
+    {
+        $dql = <<<'SQL'
+            SELECT m, m.name AS m_name
+            FROM Doctrine\Tests\Models\Company\CompanyManager m
+            WHERE m.salary IN (800000 / 8, 100000 * 2)
+SQL;
+
+        $result = $this->_em->createQuery($dql)->getArrayResult();
+
+        self::assertCount(2, $result);
+        self::assertEquals('Roman B.', $result[0]['m_name']);
+        self::assertEquals('Benjamin E.', $result[1]['m_name']);
+    }
+
+    public function testInArithmeticExpression2(): void
+    {
+        $this->_em->getConfiguration()->addCustomStringFunction('FOO', static function ($funcName) {
+            return new NoOp($funcName); // See Doctrine/Tests/ORM/Functional/CustomFunctionsTest
+        });
+
+        $dql = <<<'SQL'
+            SELECT m, m.name AS m_name
+            FROM Doctrine\Tests\Models\Company\CompanyManager m
+            WHERE m.department IN (FOO('Administration'))
+SQL;
+
+        $result = $this->_em->createQuery($dql)->getArrayResult();
+
+        self::assertCount(1, $result);
+        self::assertEquals('Jonathan W.', $result[0]['m_name']);
     }
 
     protected function generateFixture(): void
