@@ -22,7 +22,7 @@ class SecondLevelCacheCriteriaTest extends SecondLevelCacheAbstractTest
         $this->evictRegions();
         $this->_em->clear();
 
-        $this->assertFalse($this->cache->containsEntity(Country::class, $this->countries[0]->getId()));
+        self::assertFalse($this->cache->containsEntity(Country::class, $this->countries[0]->getId()));
 
         $repository = $this->_em->getRepository(Country::class);
         $queryCount = $this->getCurrentQueryCount();
@@ -34,11 +34,11 @@ class SecondLevelCacheCriteriaTest extends SecondLevelCacheAbstractTest
         // Because matching returns lazy collection, we force initialization
         $result1->toArray();
 
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount());
-        $this->assertEquals($this->countries[0]->getId(), $result1[0]->getId());
-        $this->assertEquals($this->countries[0]->getName(), $result1[0]->getName());
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount());
+        self::assertEquals($this->countries[0]->getId(), $result1[0]->getId());
+        self::assertEquals($this->countries[0]->getName(), $result1[0]->getName());
 
-        $this->assertTrue($this->cache->containsEntity(Country::class, $this->countries[0]->getId()));
+        self::assertTrue($this->cache->containsEntity(Country::class, $this->countries[0]->getId()));
 
         $this->_em->clear();
 
@@ -46,13 +46,13 @@ class SecondLevelCacheCriteriaTest extends SecondLevelCacheAbstractTest
             Criteria::expr()->eq('name', $name)
         ));
 
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount());
-        $this->assertCount(1, $result2);
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount());
+        self::assertCount(1, $result2);
 
-        $this->assertInstanceOf(Country::class, $result2[0]);
+        self::assertInstanceOf(Country::class, $result2[0]);
 
-        $this->assertEquals($result1[0]->getId(), $result2[0]->getId());
-        $this->assertEquals($result1[0]->getName(), $result2[0]->getName());
+        self::assertEquals($result1[0]->getId(), $result2[0]->getId());
+        self::assertEquals($result1[0]->getName(), $result2[0]->getName());
     }
 
     public function testRepositoryMatching(): void
@@ -62,7 +62,7 @@ class SecondLevelCacheCriteriaTest extends SecondLevelCacheAbstractTest
         $this->loadFixturesCountries();
         $this->_em->clear();
 
-        $this->assertTrue($this->cache->containsEntity(Country::class, $this->countries[0]->getId()));
+        self::assertTrue($this->cache->containsEntity(Country::class, $this->countries[0]->getId()));
 
         $repository = $this->_em->getRepository(Country::class);
         $queryCount = $this->getCurrentQueryCount();
@@ -73,10 +73,10 @@ class SecondLevelCacheCriteriaTest extends SecondLevelCacheAbstractTest
         // Because matching returns lazy collection, we force initialization
         $result1->toArray();
 
-        $this->assertCount(1, $result1);
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount());
-        $this->assertEquals($this->countries[0]->getId(), $result1[0]->getId());
-        $this->assertEquals($this->countries[0]->getName(), $result1[0]->getName());
+        self::assertCount(1, $result1);
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount());
+        self::assertEquals($this->countries[0]->getId(), $result1[0]->getId());
+        self::assertEquals($this->countries[0]->getName(), $result1[0]->getName());
 
         $this->_em->clear();
 
@@ -87,13 +87,13 @@ class SecondLevelCacheCriteriaTest extends SecondLevelCacheAbstractTest
         // Because matching returns lazy collection, we force initialization
         $result2->toArray();
 
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount());
-        $this->assertCount(1, $result2);
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount());
+        self::assertCount(1, $result2);
 
-        $this->assertInstanceOf(Country::class, $result2[0]);
+        self::assertInstanceOf(Country::class, $result2[0]);
 
-        $this->assertEquals($this->countries[0]->getId(), $result2[0]->getId());
-        $this->assertEquals($this->countries[0]->getName(), $result2[0]->getName());
+        self::assertEquals($this->countries[0]->getId(), $result2[0]->getId());
+        self::assertEquals($this->countries[0]->getName(), $result2[0]->getName());
 
         $result3 = $repository->matching(new Criteria(
             Criteria::expr()->eq('name', $this->countries[1]->getName())
@@ -102,25 +102,25 @@ class SecondLevelCacheCriteriaTest extends SecondLevelCacheAbstractTest
         // Because matching returns lazy collection, we force initialization
         $result3->toArray();
 
-        $this->assertEquals($queryCount + 2, $this->getCurrentQueryCount());
-        $this->assertCount(1, $result3);
+        self::assertEquals($queryCount + 2, $this->getCurrentQueryCount());
+        self::assertCount(1, $result3);
 
-        $this->assertInstanceOf(Country::class, $result3[0]);
+        self::assertInstanceOf(Country::class, $result3[0]);
 
-        $this->assertEquals($this->countries[1]->getId(), $result3[0]->getId());
-        $this->assertEquals($this->countries[1]->getName(), $result3[0]->getName());
+        self::assertEquals($this->countries[1]->getId(), $result3[0]->getId());
+        self::assertEquals($this->countries[1]->getName(), $result3[0]->getName());
 
         $result4 = $repository->matching(new Criteria(
             Criteria::expr()->eq('name', $this->countries[1]->getName())
         ));
 
-        $this->assertEquals($queryCount + 2, $this->getCurrentQueryCount());
-        $this->assertCount(1, $result4);
+        self::assertEquals($queryCount + 2, $this->getCurrentQueryCount());
+        self::assertCount(1, $result4);
 
-        $this->assertInstanceOf(Country::class, $result4[0]);
+        self::assertInstanceOf(Country::class, $result4[0]);
 
-        $this->assertEquals($this->countries[1]->getId(), $result4[0]->getId());
-        $this->assertEquals($this->countries[1]->getName(), $result4[0]->getName());
+        self::assertEquals($this->countries[1]->getId(), $result4[0]->getId());
+        self::assertEquals($this->countries[1]->getName(), $result4[0]->getName());
     }
 
     public function testCollectionMatching(): void
@@ -139,9 +139,9 @@ class SecondLevelCacheCriteriaTest extends SecondLevelCacheAbstractTest
             Criteria::expr()->eq('name', $itemName)
         ));
 
-        $this->assertEquals($queryCount + 1, $this->getCurrentQueryCount());
-        $this->assertInstanceOf(Collection::class, $matching);
-        $this->assertCount(1, $matching);
+        self::assertEquals($queryCount + 1, $this->getCurrentQueryCount());
+        self::assertInstanceOf(Collection::class, $matching);
+        self::assertCount(1, $matching);
 
         $this->_em->clear();
 
@@ -152,8 +152,8 @@ class SecondLevelCacheCriteriaTest extends SecondLevelCacheAbstractTest
             Criteria::expr()->eq('name', $itemName)
         ));
 
-        $this->assertEquals($queryCount, $this->getCurrentQueryCount());
-        $this->assertInstanceOf(Collection::class, $matching);
-        $this->assertCount(1, $matching);
+        self::assertEquals($queryCount, $this->getCurrentQueryCount());
+        self::assertInstanceOf(Collection::class, $matching);
+        self::assertCount(1, $matching);
     }
 }
