@@ -6,7 +6,7 @@ namespace Doctrine\Tests\ORM\Functional;
 
 use Doctrine\Common\Collections\Criteria;
 use Doctrine\ORM\Mapping\ClassMetadata;
-use Doctrine\ORM\Persisters\PersisterException;
+use Doctrine\ORM\Persisters\MatchingAssociationFieldRequiresObject;
 use Doctrine\ORM\Proxy\Proxy;
 use Doctrine\Tests\Models\Company\CompanyContract;
 use Doctrine\Tests\Models\Company\CompanyEmployee;
@@ -16,7 +16,6 @@ use Doctrine\Tests\Models\Company\CompanyFlexUltraContract;
 use Doctrine\Tests\OrmFunctionalTestCase;
 
 use function array_map;
-use function count;
 use function get_class;
 use function sort;
 
@@ -130,9 +129,9 @@ class SingleTableInheritanceTest extends OrmFunctionalTestCase
 
         $contract = $this->_em->find(CompanyFixContract::class, $fixContract->getId());
 
-        $this->assertInstanceOf(CompanyFixContract::class, $contract);
-        $this->assertEquals(1000, $contract->getFixPrice());
-        $this->assertEquals($this->salesPerson->getId(), $contract->getSalesPerson()->getId());
+        self::assertInstanceOf(CompanyFixContract::class, $contract);
+        self::assertEquals(1000, $contract->getFixPrice());
+        self::assertEquals($this->salesPerson->getId(), $contract->getSalesPerson()->getId());
     }
 
     public function testPersistDeepChildOfBaseClass(): void
@@ -151,10 +150,10 @@ class SingleTableInheritanceTest extends OrmFunctionalTestCase
 
         $contract = $this->_em->find(CompanyFlexUltraContract::class, $ultraContract->getId());
 
-        $this->assertInstanceOf(CompanyFlexUltraContract::class, $contract);
-        $this->assertEquals(7000, $contract->getMaxPrice());
-        $this->assertEquals(100, $contract->getHoursWorked());
-        $this->assertEquals(50, $contract->getPricePerHour());
+        self::assertInstanceOf(CompanyFlexUltraContract::class, $contract);
+        self::assertEquals(7000, $contract->getMaxPrice());
+        self::assertEquals(100, $contract->getHoursWorked());
+        self::assertEquals(50, $contract->getPricePerHour());
     }
 
     public function testChildClassLifecycleUpdate(): void
@@ -168,7 +167,7 @@ class SingleTableInheritanceTest extends OrmFunctionalTestCase
         $this->_em->clear();
 
         $newFix = $this->_em->find(CompanyContract::class, $this->fix->getId());
-        $this->assertEquals(2500, $newFix->getFixPrice());
+        self::assertEquals(2500, $newFix->getFixPrice());
     }
 
     public function testChildClassLifecycleRemove(): void
@@ -179,7 +178,7 @@ class SingleTableInheritanceTest extends OrmFunctionalTestCase
         $this->_em->remove($fix);
         $this->_em->flush();
 
-        $this->assertNull($this->_em->find(CompanyContract::class, $this->fix->getId()));
+        self::assertNull($this->_em->find(CompanyContract::class, $this->fix->getId()));
     }
 
     public function testFindAllForAbstractBaseClass(): void
@@ -187,17 +186,17 @@ class SingleTableInheritanceTest extends OrmFunctionalTestCase
         $this->loadFullFixture();
         $contracts = $this->_em->getRepository(CompanyContract::class)->findAll();
 
-        $this->assertEquals(3, count($contracts));
-        $this->assertContainsOnly(CompanyContract::class, $contracts);
+        self::assertCount(3, $contracts);
+        self::assertContainsOnly(CompanyContract::class, $contracts);
     }
 
     public function testFindAllForChildClass(): void
     {
         $this->loadFullFixture();
 
-        $this->assertEquals(1, count($this->_em->getRepository(CompanyFixContract::class)->findAll()));
-        $this->assertEquals(2, count($this->_em->getRepository(CompanyFlexContract::class)->findAll()));
-        $this->assertEquals(1, count($this->_em->getRepository(CompanyFlexUltraContract::class)->findAll()));
+        self::assertCount(1, $this->_em->getRepository(CompanyFixContract::class)->findAll());
+        self::assertCount(2, $this->_em->getRepository(CompanyFlexContract::class)->findAll());
+        self::assertCount(1, $this->_em->getRepository(CompanyFlexUltraContract::class)->findAll());
     }
 
     public function testFindForAbstractBaseClass(): void
@@ -206,8 +205,8 @@ class SingleTableInheritanceTest extends OrmFunctionalTestCase
 
         $contract = $this->_em->find(CompanyContract::class, $this->fix->getId());
 
-        $this->assertInstanceOf(CompanyFixContract::class, $contract);
-        $this->assertEquals(1000, $contract->getFixPrice());
+        self::assertInstanceOf(CompanyFixContract::class, $contract);
+        self::assertEquals(1000, $contract->getFixPrice());
     }
 
     public function testQueryForAbstractBaseClass(): void
@@ -216,17 +215,17 @@ class SingleTableInheritanceTest extends OrmFunctionalTestCase
 
         $contracts = $this->_em->createQuery('SELECT c FROM Doctrine\Tests\Models\Company\CompanyContract c')->getResult();
 
-        $this->assertEquals(3, count($contracts));
-        $this->assertContainsOnly(CompanyContract::class, $contracts);
+        self::assertCount(3, $contracts);
+        self::assertContainsOnly(CompanyContract::class, $contracts);
     }
 
     public function testQueryForChildClass(): void
     {
         $this->loadFullFixture();
 
-        $this->assertEquals(1, count($this->_em->createQuery('SELECT c FROM Doctrine\Tests\Models\Company\CompanyFixContract c')->getResult()));
-        $this->assertEquals(2, count($this->_em->createQuery('SELECT c FROM Doctrine\Tests\Models\Company\CompanyFlexContract c')->getResult()));
-        $this->assertEquals(1, count($this->_em->createQuery('SELECT c FROM Doctrine\Tests\Models\Company\CompanyFlexUltraContract c')->getResult()));
+        self::assertCount(1, $this->_em->createQuery('SELECT c FROM Doctrine\Tests\Models\Company\CompanyFixContract c')->getResult());
+        self::assertCount(2, $this->_em->createQuery('SELECT c FROM Doctrine\Tests\Models\Company\CompanyFlexContract c')->getResult());
+        self::assertCount(1, $this->_em->createQuery('SELECT c FROM Doctrine\Tests\Models\Company\CompanyFlexUltraContract c')->getResult());
     }
 
     public function testQueryBaseClassWithJoin(): void
@@ -234,8 +233,8 @@ class SingleTableInheritanceTest extends OrmFunctionalTestCase
         $this->loadFullFixture();
 
         $contracts = $this->_em->createQuery('SELECT c, p FROM Doctrine\Tests\Models\Company\CompanyContract c JOIN c.salesPerson p')->getResult();
-        $this->assertEquals(3, count($contracts));
-        $this->assertContainsOnly(CompanyContract::class, $contracts);
+        self::assertCount(3, $contracts);
+        self::assertContainsOnly(CompanyContract::class, $contracts);
     }
 
     public function testQueryScalarWithDiscriminatorValue(): void
@@ -250,7 +249,7 @@ class SingleTableInheritanceTest extends OrmFunctionalTestCase
 
         sort($discrValues);
 
-        $this->assertEquals(['fix', 'flexible', 'flexultra'], $discrValues);
+        self::assertEquals(['fix', 'flexible', 'flexultra'], $discrValues);
     }
 
     public function testQueryChildClassWithCondition(): void
@@ -260,8 +259,8 @@ class SingleTableInheritanceTest extends OrmFunctionalTestCase
         $dql      = 'SELECT c FROM Doctrine\Tests\Models\Company\CompanyFixContract c WHERE c.fixPrice = ?1';
         $contract = $this->_em->createQuery($dql)->setParameter(1, 1000)->getSingleResult();
 
-        $this->assertInstanceOf(CompanyFixContract::class, $contract);
-        $this->assertEquals(1000, $contract->getFixPrice());
+        self::assertInstanceOf(CompanyFixContract::class, $contract);
+        self::assertEquals(1000, $contract->getFixPrice());
     }
 
     /**
@@ -274,13 +273,13 @@ class SingleTableInheritanceTest extends OrmFunctionalTestCase
         $dql      = 'UPDATE Doctrine\Tests\Models\Company\CompanyFlexContract c SET c.hoursWorked = c.hoursWorked * 2 WHERE c.hoursWorked = 150';
         $affected = $this->_em->createQuery($dql)->execute();
 
-        $this->assertEquals(1, $affected);
+        self::assertEquals(1, $affected);
 
         $flexContract  = $this->_em->find(CompanyContract::class, $this->flex->getId());
         $ultraContract = $this->_em->find(CompanyContract::class, $this->ultra->getId());
 
-        $this->assertEquals(300, $ultraContract->getHoursWorked());
-        $this->assertEquals(100, $flexContract->getHoursWorked());
+        self::assertEquals(300, $ultraContract->getHoursWorked());
+        self::assertEquals(100, $flexContract->getHoursWorked());
     }
 
     public function testUpdateBaseClassWithCondition(): void
@@ -290,12 +289,12 @@ class SingleTableInheritanceTest extends OrmFunctionalTestCase
         $dql      = 'UPDATE Doctrine\Tests\Models\Company\CompanyContract c SET c.completed = true WHERE c.completed = false';
         $affected = $this->_em->createQuery($dql)->execute();
 
-        $this->assertEquals(1, $affected);
+        self::assertEquals(1, $affected);
 
         $dql      = 'UPDATE Doctrine\Tests\Models\Company\CompanyContract c SET c.completed = false';
         $affected = $this->_em->createQuery($dql)->execute();
 
-        $this->assertEquals(3, $affected);
+        self::assertEquals(3, $affected);
     }
 
     public function testDeleteByChildClassCondition(): void
@@ -305,7 +304,7 @@ class SingleTableInheritanceTest extends OrmFunctionalTestCase
         $dql      = 'DELETE Doctrine\Tests\Models\Company\CompanyFlexContract c';
         $affected = $this->_em->createQuery($dql)->execute();
 
-        $this->assertEquals(2, $affected);
+        self::assertEquals(2, $affected);
     }
 
     public function testDeleteByBaseClassCondition(): void
@@ -315,12 +314,12 @@ class SingleTableInheritanceTest extends OrmFunctionalTestCase
         $dql      = 'DELETE Doctrine\Tests\Models\Company\CompanyContract c WHERE c.completed = true';
         $affected = $this->_em->createQuery($dql)->execute();
 
-        $this->assertEquals(2, $affected);
+        self::assertEquals(2, $affected);
 
         $contracts = $this->_em->createQuery('SELECT c FROM Doctrine\Tests\Models\Company\CompanyContract c')->getResult();
-        $this->assertEquals(1, count($contracts));
+        self::assertCount(1, $contracts);
 
-        $this->assertFalse($contracts[0]->isCompleted(), 'Only non completed contracts should be left.');
+        self::assertFalse($contracts[0]->isCompleted(), 'Only non completed contracts should be left.');
     }
 
     /**
@@ -334,7 +333,7 @@ class SingleTableInheritanceTest extends OrmFunctionalTestCase
         $this->_em->remove($this->_em->find(get_class($this->fix), $this->fix->getId()));
         $this->_em->flush();
 
-        $this->assertNull($this->_em->find(get_class($this->fix), $this->fix->getId()), 'Contract should not be present in the database anymore.');
+        self::assertNull($this->_em->find(get_class($this->fix), $this->fix->getId()), 'Contract should not be present in the database anymore.');
     }
 
     /**
@@ -346,19 +345,19 @@ class SingleTableInheritanceTest extends OrmFunctionalTestCase
 
         $repos     = $this->_em->getRepository(CompanyContract::class);
         $contracts = $repos->findBy(['salesPerson' => $this->salesPerson->getId()]);
-        $this->assertEquals(3, count($contracts), 'There should be 3 entities related to ' . $this->salesPerson->getId() . " for 'Doctrine\Tests\Models\Company\CompanyContract'");
+        self::assertCount(3, $contracts, 'There should be 3 entities related to ' . $this->salesPerson->getId() . " for 'Doctrine\Tests\Models\Company\CompanyContract'");
 
         $repos     = $this->_em->getRepository(CompanyFixContract::class);
         $contracts = $repos->findBy(['salesPerson' => $this->salesPerson->getId()]);
-        $this->assertEquals(1, count($contracts), 'There should be 1 entities related to ' . $this->salesPerson->getId() . " for 'Doctrine\Tests\Models\Company\CompanyFixContract'");
+        self::assertCount(1, $contracts, 'There should be 1 entities related to ' . $this->salesPerson->getId() . " for 'Doctrine\Tests\Models\Company\CompanyFixContract'");
 
         $repos     = $this->_em->getRepository(CompanyFlexContract::class);
         $contracts = $repos->findBy(['salesPerson' => $this->salesPerson->getId()]);
-        $this->assertEquals(2, count($contracts), 'There should be 2 entities related to ' . $this->salesPerson->getId() . " for 'Doctrine\Tests\Models\Company\CompanyFlexContract'");
+        self::assertCount(2, $contracts, 'There should be 2 entities related to ' . $this->salesPerson->getId() . " for 'Doctrine\Tests\Models\Company\CompanyFlexContract'");
 
         $repos     = $this->_em->getRepository(CompanyFlexUltraContract::class);
         $contracts = $repos->findBy(['salesPerson' => $this->salesPerson->getId()]);
-        $this->assertEquals(1, count($contracts), 'There should be 1 entities related to ' . $this->salesPerson->getId() . " for 'Doctrine\Tests\Models\Company\CompanyFlexUltraContract'");
+        self::assertCount(1, $contracts, 'There should be 1 entities related to ' . $this->salesPerson->getId() . " for 'Doctrine\Tests\Models\Company\CompanyFlexUltraContract'");
     }
 
     /**
@@ -372,13 +371,13 @@ class SingleTableInheritanceTest extends OrmFunctionalTestCase
         $contracts  = $repository->matching(new Criteria(
             Criteria::expr()->eq('salesPerson', $this->salesPerson)
         ));
-        $this->assertEquals(3, count($contracts));
+        self::assertCount(3, $contracts);
 
         $repository = $this->_em->getRepository(CompanyFixContract::class);
         $contracts  = $repository->matching(new Criteria(
             Criteria::expr()->eq('salesPerson', $this->salesPerson)
         ));
-        $this->assertEquals(1, count($contracts));
+        self::assertCount(1, $contracts);
     }
 
     /**
@@ -390,7 +389,7 @@ class SingleTableInheritanceTest extends OrmFunctionalTestCase
 
         $repository = $this->_em->getRepository(CompanyContract::class);
 
-        $this->expectException(PersisterException::class);
+        $this->expectException(MatchingAssociationFieldRequiresObject::class);
         $this->expectExceptionMessage('annot match on Doctrine\Tests\Models\Company\CompanyContract::salesPerson with a non-object value.');
 
         $contracts = $repository->matching(new Criteria(
@@ -409,13 +408,13 @@ class SingleTableInheritanceTest extends OrmFunctionalTestCase
         $this->loadFullFixture();
 
         $ref = $this->_em->getReference(CompanyContract::class, $this->fix->getId());
-        $this->assertNotInstanceOf(Proxy::class, $ref, 'Cannot Request a proxy from a class that has subclasses.');
-        $this->assertInstanceOf(CompanyContract::class, $ref);
-        $this->assertInstanceOf(CompanyFixContract::class, $ref, 'Direct fetch of the reference has to load the child class Employee directly.');
+        self::assertNotInstanceOf(Proxy::class, $ref, 'Cannot Request a proxy from a class that has subclasses.');
+        self::assertInstanceOf(CompanyContract::class, $ref);
+        self::assertInstanceOf(CompanyFixContract::class, $ref, 'Direct fetch of the reference has to load the child class Employee directly.');
         $this->_em->clear();
 
         $ref = $this->_em->getReference(CompanyFixContract::class, $this->fix->getId());
-        $this->assertInstanceOf(Proxy::class, $ref, 'A proxy can be generated only if no subclasses exists for the requested reference.');
+        self::assertInstanceOf(Proxy::class, $ref, 'A proxy can be generated only if no subclasses exists for the requested reference.');
     }
 
     /**
@@ -431,6 +430,6 @@ class SingleTableInheritanceTest extends OrmFunctionalTestCase
                               ->setParameter(1, $this->fix->getId())
                               ->getSingleResult();
 
-        $this->assertNotInstanceOf(Proxy::class, $contract->getSalesPerson());
+        self::assertNotInstanceOf(Proxy::class, $contract->getSalesPerson());
     }
 }
