@@ -33,6 +33,6 @@ class DDC1043Test extends OrmFunctionalTestCase
         $this->_em->clear();
 
         $user = $this->_em->find(CmsUser::class, $user->id);
-        $this->assertSame('44', $user->status);
+        self::assertSame('44', $user->status);
     }
 }
