@@ -7,8 +7,6 @@ namespace Doctrine\Tests\ORM\Functional\Ticket;
 use Doctrine\Tests\Models\CMS\CmsArticle;
 use Doctrine\Tests\OrmFunctionalTestCase;
 
-use function count;
-
 /**
  * @group DDC-1129
  */
@@ -29,22 +27,22 @@ class DDC1129Test extends OrmFunctionalTestCase
         $this->_em->persist($article);
         $this->_em->flush();
 
-        $this->assertEquals(1, $article->version);
+        self::assertEquals(1, $article->version);
 
         $class = $this->_em->getClassMetadata(CmsArticle::class);
         $uow   = $this->_em->getUnitOfWork();
 
         $uow->computeChangeSet($class, $article);
         $changeSet = $uow->getEntityChangeSet($article);
-        $this->assertEquals(0, count($changeSet), 'No changesets should be computed.');
+        self::assertCount(0, $changeSet, 'No changesets should be computed.');
 
         $article->text = 'This is John Galt speaking.';
         $this->_em->flush();
 
-        $this->assertEquals(2, $article->version);
+        self::assertEquals(2, $article->version);
 
         $uow->computeChangeSet($class, $article);
         $changeSet = $uow->getEntityChangeSet($article);
-        $this->assertEquals(0, count($changeSet), 'No changesets should be computed.');
+        self::assertCount(0, $changeSet, 'No changesets should be computed.');
     }
 }
