@@ -7,7 +7,6 @@ namespace Doctrine\Tests\ORM\Functional\Ticket;
 use Doctrine\Tests\Models\CMS\CmsGroup;
 use Doctrine\Tests\Models\CMS\CmsUser;
 use Doctrine\Tests\OrmFunctionalTestCase;
-use Doctrine\Tests\VerifyDeprecations;
 
 use function count;
 
@@ -16,8 +15,6 @@ use function count;
  */
 class DDC1276Test extends OrmFunctionalTestCase
 {
-    use VerifyDeprecations;
-
     protected function setUp(): void
     {
         $this->useModelSet('cms');
@@ -45,13 +42,12 @@ class DDC1276Test extends OrmFunctionalTestCase
         $user   = $this->_em->find(CmsUser::class, $user->id);
         $cloned = clone $user;
 
-        $this->assertSame($user->groups, $cloned->groups);
-        $this->assertEquals(2, count($user->groups));
+        self::assertSame($user->groups, $cloned->groups);
+        self::assertEquals(2, count($user->groups));
         $this->_em->merge($cloned);
 
-        $this->assertEquals(2, count($user->groups));
+        self::assertEquals(2, count($user->groups));
 
         $this->_em->flush();
-        $this->assertHasDeprecationMessages();
     }
 }
