@@ -1,44 +1,47 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\ORM\Functional\Ticket;
 
 use Doctrine\Tests\Models\CMS\CmsAddress;
-use Doctrine\Tests\Models\CMS\CmsUser;
 use Doctrine\Tests\Models\CMS\CmsPhonenumber;
+use Doctrine\Tests\Models\CMS\CmsUser;
+use Doctrine\Tests\OrmFunctionalTestCase;
 
 /**
  * @group DDC-1306
  */
-class DDC1306Test extends \Doctrine\Tests\OrmFunctionalTestCase
+class DDC1306Test extends OrmFunctionalTestCase
 {
-    public function setUp()
+    protected function setUp(): void
     {
         $this->useModelSet('cms');
 
         parent::setUp();
     }
 
-    public function testIssue()
+    public function testIssue(): void
     {
-        $phone = new CmsPhonenumber();
-        $phone->phonenumber = "1234";
+        $phone              = new CmsPhonenumber();
+        $phone->phonenumber = '1234';
 
         // puts user and phone into commit order calculator
         $this->_em->persist($phone);
         $this->_em->flush();
 
-        $address = new CmsAddress();
-        $address->city = "bonn";
-        $address->country = "Germany";
-        $address->street = "somestreet!";
-        $address->zip = 12345;
+        $address          = new CmsAddress();
+        $address->city    = 'bonn';
+        $address->country = 'Germany';
+        $address->street  = 'somestreet!';
+        $address->zip     = 12345;
 
         $this->_em->persist($address);
 
-        $user = new CmsUser();
-        $user->username = "beberlei";
-        $user->name = "benjamin";
-        $user->status = "active";
+        $user           = new CmsUser();
+        $user->username = 'beberlei';
+        $user->name     = 'benjamin';
+        $user->status   = 'active';
         $user->setAddress($address);
 
         // puts user and address into commit order calculator, but does not calculate user dependencies new
