@@ -7,7 +7,6 @@ namespace Doctrine\Tests\ORM\Functional\Ticket;
 use Doctrine\ORM\Proxy\Proxy;
 use Doctrine\Tests\Models\CMS\CmsGroup;
 use Doctrine\Tests\OrmFunctionalTestCase;
-use Doctrine\Tests\VerifyDeprecations;
 
 use function get_class;
 use function serialize;
@@ -15,20 +14,12 @@ use function unserialize;
 
 class DDC1734Test extends OrmFunctionalTestCase
 {
-    use VerifyDeprecations;
-
     protected function setUp(): void
     {
         $this->useModelSet('cms');
         parent::setUp();
     }
 
-    /** @after */
-    public function ensureTestGeneratedDeprecationMessages(): void
-    {
-        $this->assertHasDeprecationMessages();
-    }
-
     /**
      * This test is DDC-1734 minus the serialization, i.e. it works
      *
@@ -45,15 +36,15 @@ class DDC1734Test extends OrmFunctionalTestCase
 
         $proxy = $this->getProxy($group);
 
-        $this->assertInstanceOf(Proxy::class, $proxy);
-        $this->assertFalse($proxy->__isInitialized());
+        self::assertInstanceOf(Proxy::class, $proxy);
+        self::assertFalse($proxy->__isInitialized());
 
         $this->_em->detach($proxy);
         $this->_em->clear();
 
         $proxy = $this->_em->merge($proxy);
 
-        $this->assertEquals('Foo', $proxy->getName(), 'The entity is broken');
+        self::assertEquals('Foo', $proxy->getName(), 'The entity is broken');
     }
 
     /**
@@ -75,18 +66,21 @@ class DDC1734Test extends OrmFunctionalTestCase
 
         $proxy = $this->getProxy($group);
 
-        $this->assertInstanceOf(Proxy::class, $proxy);
-        $this->assertFalse($proxy->__isInitialized());
+        self::assertInstanceOf(Proxy::class, $proxy);
+        self::assertFalse($proxy->__isInitialized());
 
         $this->_em->detach($proxy);
         $serializedProxy = serialize($proxy);
         $this->_em->clear();
 
         $unserializedProxy = $this->_em->merge(unserialize($serializedProxy));
-        $this->assertEquals('Foo', $unserializedProxy->getName(), 'The entity is broken');
+        self::assertEquals('Foo', $unserializedProxy->getName(), 'The entity is broken');
     }
 
-    private function getProxy(object $object): \Doctrine\Common\Proxy\Proxy
+    /**
+     * @param object $object
+     */
+    private function getProxy($object): \Doctrine\Common\Proxy\Proxy
     {
         $metadataFactory = $this->_em->getMetadataFactory();
         $className       = get_class($object);
