@@ -55,8 +55,9 @@ class DDC1884Test extends OrmFunctionalTestCase
     }
 
     /**
-     * @psalm-var class-string<Car> $class
      * @psalm-return array{Car, Car, Car, Car}
+     *
+     * @psalm-var class-string<Car> $class
      */
     private function createCars(string $class): array
     {
@@ -85,8 +86,9 @@ class DDC1884Test extends OrmFunctionalTestCase
     }
 
     /**
-     * @psalm-var class-string<Driver> $class
      * @psalm-return array{Driver, Driver}
+     *
+     * @psalm-var class-string<Driver> $class
      */
     private function createDrivers(string $class): array
     {
@@ -119,9 +121,9 @@ class DDC1884Test extends OrmFunctionalTestCase
             ->getQuery()
             ->getArrayResult();
 
-        $this->assertCount(1, $result);
-        $this->assertArrayHasKey('freeDriverRides', $result[0]);
-        $this->assertCount(3, $result[0]['freeDriverRides']);
+        self::assertCount(1, $result);
+        self::assertArrayHasKey('freeDriverRides', $result[0]);
+        self::assertCount(3, $result[0]['freeDriverRides']);
     }
 
     /**
@@ -140,9 +142,9 @@ class DDC1884Test extends OrmFunctionalTestCase
             ->setParameter(1, 'John Doe')
             ->getQuery()->getArrayResult();
 
-        $this->assertCount(1, $result);
-        $this->assertArrayHasKey('driverRides', $result[0]);
-        $this->assertCount(3, $result[0]['driverRides']);
+        self::assertCount(1, $result);
+        self::assertArrayHasKey('driverRides', $result[0]);
+        self::assertCount(3, $result[0]['driverRides']);
     }
 
     /**
@@ -160,8 +162,8 @@ class DDC1884Test extends OrmFunctionalTestCase
             ->setParameter(1, 'John Doe')
             ->getQuery()->getArrayResult();
 
-        $this->assertCount(3, $result);
-        $this->assertArrayHasKey('driver', $result[0]);
-        $this->assertArrayHasKey('car', $result[0]);
+        self::assertCount(3, $result);
+        self::assertArrayHasKey('driver', $result[0]);
+        self::assertArrayHasKey('car', $result[0]);
     }
 }
