@@ -49,17 +49,17 @@ class DDC1885Test extends OrmFunctionalTestCase
         // Retrieve
         $user = $this->_em->find(User::class, $u1Id);
 
-        $this->assertInstanceOf(User::class, $user);
-        $this->assertEquals('FabioBatSilva', $user->name);
-        $this->assertEquals($u1Id, $user->id);
+        self::assertInstanceOf(User::class, $user);
+        self::assertEquals('FabioBatSilva', $user->name);
+        self::assertEquals($u1Id, $user->id);
 
-        $this->assertCount(2, $user->groups);
+        self::assertCount(2, $user->groups);
 
         $g1 = $user->getGroups()->get(0);
         $g2 = $user->getGroups()->get(1);
 
-        $this->assertInstanceOf(Group::class, $g1);
-        $this->assertInstanceOf(Group::class, $g2);
+        self::assertInstanceOf(Group::class, $g1);
+        self::assertInstanceOf(Group::class, $g2);
 
         $g1->name = 'Bar 11';
         $g2->name = 'Foo 22';
@@ -71,9 +71,9 @@ class DDC1885Test extends OrmFunctionalTestCase
 
         $user = $this->_em->find(User::class, $u1Id);
 
-        $this->assertInstanceOf(User::class, $user);
-        $this->assertEquals('FabioBatSilva', $user->name);
-        $this->assertEquals($u1Id, $user->id);
+        self::assertInstanceOf(User::class, $user);
+        self::assertEquals('FabioBatSilva', $user->name);
+        self::assertEquals($u1Id, $user->id);
 
         // Delete
         $this->_em->remove($user);
@@ -81,9 +81,9 @@ class DDC1885Test extends OrmFunctionalTestCase
         $this->_em->flush();
         $this->_em->clear();
 
-        $this->assertNull($this->_em->find(User::class, $u1Id));
-        $this->assertNull($this->_em->find(Group::class, $g1Id));
-        $this->assertNull($this->_em->find(Group::class, $g2Id));
+        self::assertNull($this->_em->find(User::class, $u1Id));
+        self::assertNull($this->_em->find(Group::class, $g1Id));
+        self::assertNull($this->_em->find(Group::class, $g2Id));
     }
 
     public function testRemoveItem(): void
@@ -92,13 +92,13 @@ class DDC1885Test extends OrmFunctionalTestCase
         $u1Id = $user->id;
         $user = $this->_em->find(User::class, $u1Id);
 
-        $this->assertInstanceOf(User::class, $user);
-        $this->assertEquals('FabioBatSilva', $user->name);
-        $this->assertEquals($u1Id, $user->id);
+        self::assertInstanceOf(User::class, $user);
+        self::assertEquals('FabioBatSilva', $user->name);
+        self::assertEquals($u1Id, $user->id);
 
-        $this->assertCount(2, $user->groups);
-        $this->assertInstanceOf(Group::class, $user->getGroups()->get(0));
-        $this->assertInstanceOf(Group::class, $user->getGroups()->get(1));
+        self::assertCount(2, $user->groups);
+        self::assertInstanceOf(Group::class, $user->getGroups()->get(0));
+        self::assertInstanceOf(Group::class, $user->getGroups()->get(1));
 
         $user->getGroups()->remove(0);
 
@@ -109,11 +109,11 @@ class DDC1885Test extends OrmFunctionalTestCase
 
         $user = $this->_em->find(User::class, $u1Id);
 
-        $this->assertInstanceOf(User::class, $user);
-        $this->assertEquals('FabioBatSilva', $user->name);
-        $this->assertEquals($u1Id, $user->id);
+        self::assertInstanceOf(User::class, $user);
+        self::assertEquals('FabioBatSilva', $user->name);
+        self::assertEquals($u1Id, $user->id);
 
-        $this->assertCount(1, $user->getGroups());
+        self::assertCount(1, $user->getGroups());
     }
 
     public function testClearAll(): void
@@ -122,13 +122,13 @@ class DDC1885Test extends OrmFunctionalTestCase
         $u1Id = $user->id;
         $user = $this->_em->find(User::class, $u1Id);
 
-        $this->assertInstanceOf(User::class, $user);
-        $this->assertEquals('FabioBatSilva', $user->name);
-        $this->assertEquals($u1Id, $user->id);
+        self::assertInstanceOf(User::class, $user);
+        self::assertEquals('FabioBatSilva', $user->name);
+        self::assertEquals($u1Id, $user->id);
 
-        $this->assertCount(2, $user->groups);
-        $this->assertInstanceOf(Group::class, $user->getGroups()->get(0));
-        $this->assertInstanceOf(Group::class, $user->getGroups()->get(1));
+        self::assertCount(2, $user->groups);
+        self::assertInstanceOf(Group::class, $user->getGroups()->get(0));
+        self::assertInstanceOf(Group::class, $user->getGroups()->get(1));
 
         $user->getGroups()->clear();
 
@@ -139,11 +139,11 @@ class DDC1885Test extends OrmFunctionalTestCase
 
         $user = $this->_em->find(User::class, $u1Id);
 
-        $this->assertInstanceOf(User::class, $user);
-        $this->assertEquals('FabioBatSilva', $user->name);
-        $this->assertEquals($u1Id, $user->id);
+        self::assertInstanceOf(User::class, $user);
+        self::assertEquals('FabioBatSilva', $user->name);
+        self::assertEquals($u1Id, $user->id);
 
-        $this->assertCount(0, $user->getGroups());
+        self::assertCount(0, $user->getGroups());
     }
 
     public function testCountExtraLazy(): void
@@ -152,12 +152,12 @@ class DDC1885Test extends OrmFunctionalTestCase
         $u1Id = $user->id;
         $user = $this->_em->find(User::class, $u1Id);
 
-        $this->assertInstanceOf(User::class, $user);
-        $this->assertEquals('FabioBatSilva', $user->name);
-        $this->assertEquals($u1Id, $user->id);
+        self::assertInstanceOf(User::class, $user);
+        self::assertEquals('FabioBatSilva', $user->name);
+        self::assertEquals($u1Id, $user->id);
 
-        $this->assertCount(2, $user->groups);
-        $this->assertInstanceOf(Group::class, $user->getGroups()->get(0));
-        $this->assertInstanceOf(Group::class, $user->getGroups()->get(1));
+        self::assertCount(2, $user->groups);
+        self::assertInstanceOf(Group::class, $user->getGroups()->get(0));
+        self::assertInstanceOf(Group::class, $user->getGroups()->get(1));
     }
 }
