@@ -4,6 +4,11 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\ORM\Functional\Ticket;
 
+use Doctrine\ORM\Mapping\Column;
+use Doctrine\ORM\Mapping\Embeddable;
+use Doctrine\ORM\Mapping\Embedded;
+use Doctrine\ORM\Mapping\Entity;
+use Doctrine\ORM\Mapping\Id;
 use Doctrine\Tests\OrmFunctionalTestCase;
 
 use function assert;
@@ -20,9 +25,9 @@ class DDC3582Test extends OrmFunctionalTestCase
         $entity = $this->_em->find(DDC3582Entity::class, 'foo');
         assert($entity instanceof DDC3582Entity);
 
-        $this->assertInstanceOf(DDC3582Embeddable1::class, $entity->embeddable1);
-        $this->assertInstanceOf(DDC3582Embeddable2::class, $entity->embeddable1->embeddable2);
-        $this->assertInstanceOf(DDC3582Embeddable3::class, $entity->embeddable1->embeddable2->embeddable3);
+        self::assertInstanceOf(DDC3582Embeddable1::class, $entity->embeddable1);
+        self::assertInstanceOf(DDC3582Embeddable2::class, $entity->embeddable1->embeddable2);
+        self::assertInstanceOf(DDC3582Embeddable3::class, $entity->embeddable1->embeddable2->embeddable3);
     }
 }
 
