@@ -44,7 +44,7 @@ class DDC3597Test extends OrmFunctionalTestCase
 
         //request entity
         $imageEntity = $this->_em->find(DDC3597Image::class, $imageEntity->getId());
-        $this->assertInstanceOf(DDC3597Image::class, $imageEntity);
+        self::assertInstanceOf(DDC3597Image::class, $imageEntity);
 
         //cleanup
         $this->_em->remove($imageEntity);
@@ -53,6 +53,6 @@ class DDC3597Test extends OrmFunctionalTestCase
 
         //check delete
         $imageEntity = $this->_em->find(DDC3597Image::class, $imageEntity->getId());
-        $this->assertNull($imageEntity);
+        self::assertNull($imageEntity);
     }
 }
