@@ -7,12 +7,9 @@ namespace Doctrine\Tests\ORM\Functional\Ticket;
 use Doctrine\Tests\Models\CMS\CmsArticle;
 use Doctrine\Tests\Models\CMS\CmsUser;
 use Doctrine\Tests\OrmFunctionalTestCase;
-use Doctrine\Tests\VerifyDeprecations;
 
 class DDC518Test extends OrmFunctionalTestCase
 {
-    use VerifyDeprecations;
-
     protected function setUp(): void
     {
         $this->useModelSet('cms');
@@ -39,7 +36,6 @@ class DDC518Test extends OrmFunctionalTestCase
         $this->_em->persist($user);
         $managedArticle = $this->_em->merge($article);
 
-        $this->assertSame($article->user, $managedArticle->user);
-        $this->assertHasDeprecationMessages();
+        self::assertSame($article->user, $managedArticle->user);
     }
 }
