@@ -4,8 +4,16 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\ORM\Functional\Ticket;
 
+use Doctrine\ORM\Exception\ORMException;
+use Doctrine\ORM\Mapping\Column;
+use Doctrine\ORM\Mapping\DiscriminatorColumn;
+use Doctrine\ORM\Mapping\DiscriminatorMap;
+use Doctrine\ORM\Mapping\Entity;
+use Doctrine\ORM\Mapping\GeneratedValue;
+use Doctrine\ORM\Mapping\Id;
+use Doctrine\ORM\Mapping\InheritanceType;
+use Doctrine\ORM\Mapping\Table;
 use Doctrine\ORM\OptimisticLockException;
-use Doctrine\ORM\ORMException;
 use Doctrine\ORM\Tools\ToolsException;
 use Doctrine\Persistence\Mapping\MappingException;
 use Doctrine\Tests\OrmFunctionalTestCase;
@@ -106,7 +114,10 @@ abstract class DDC6303BaseClass
     public $id;
 }
 
-/** @Entity @Table */
+/**
+ * @Entity
+ * @Table
+ */
 class DDC6303ChildA extends DDC6303BaseClass
 {
     /**
@@ -125,7 +136,10 @@ class DDC6303ChildA extends DDC6303BaseClass
     }
 }
 
-/** @Entity @Table */
+/**
+ * @Entity
+ * @Table
+ */
 class DDC6303ChildB extends DDC6303BaseClass
 {
     /**
