@@ -4,7 +4,6 @@ declare(strict_types=1);
 
 namespace tests\Doctrine\Tests\ORM\Functional\Ticket;
 
-use Doctrine\ORM\Cache\Region\DefaultMultiGetRegion;
 use Doctrine\Tests\Models\Cache\Attraction;
 use Doctrine\Tests\Models\Cache\Bar;
 use Doctrine\Tests\ORM\Functional\SecondLevelCacheAbstractTest;
@@ -21,31 +20,27 @@ class DDC7969Test extends SecondLevelCacheAbstractTest
         $this->loadFixturesAttractions();
 
         // Entities are already cached due to fixtures - hence flush before testing
-        $region = $this->cache->getEntityCacheRegion(Attraction::class);
-
-        if ($region instanceof DefaultMultiGetRegion) {
-            $region->getCache()->flushAll();
-        }
+        $this->cache->getEntityCacheRegion(Attraction::class)->evictAll();
 
         $bar = $this->attractions[0];
         assert($bar instanceof Bar);
 
         $repository = $this->_em->getRepository(Bar::class);
 
-        $this->assertFalse($this->cache->containsEntity(Bar::class, $bar->getId()));
-        $this->assertFalse($this->cache->containsEntity(Attraction::class, $bar->getId()));
+        self::assertFalse($this->cache->containsEntity(Bar::class, $bar->getId()));
+        self::assertFalse($this->cache->containsEntity(Attraction::class, $bar->getId()));
 
         $repository->findOneBy([
             'name' => $bar->getName(),
         ]);
 
-        $this->assertTrue($this->cache->containsEntity(Bar::class, $bar->getId()));
+        self::assertTrue($this->cache->containsEntity(Bar::class, $bar->getId()));
 
         $repository->findOneBy([
             'name' => $bar->getName(),
         ]);
 
         // One hit for entity cache, one hit for query cache
-        $this->assertEquals(2, $this->secondLevelCacheLogger->getHitCount());
+        self::assertEquals(2, $this->secondLevelCacheLogger->getHitCount());
     }
 }
