@@ -5,8 +5,9 @@ declare(strict_types=1);
 namespace Doctrine\Tests\ORM\Functional\Ticket;
 
 use Doctrine\DBAL\LockMode;
+use Doctrine\DBAL\Platforms\SqlitePlatform;
+use Doctrine\ORM\Exception\ORMException;
 use Doctrine\ORM\OptimisticLockException;
-use Doctrine\ORM\ORMException;
 use Doctrine\ORM\TransactionRequiredException;
 use Doctrine\Persistence\Mapping\MappingException;
 use Doctrine\Tests\Models\Company\CompanyManager;
@@ -29,7 +30,7 @@ class DDC933Test extends OrmFunctionalTestCase
      */
     public function testLockCTIClass(): void
     {
-        if ($this->_em->getConnection()->getDatabasePlatform()->getName() === 'sqlite') {
+        if ($this->_em->getConnection()->getDatabasePlatform() instanceof SqlitePlatform) {
             self::markTestSkipped('It should not run on in-memory databases');
         }
 
