@@ -5,6 +5,11 @@ declare(strict_types=1);
 namespace Doctrine\Tests\ORM\Functional\Ticket;
 
 use Doctrine\ORM\AbstractQuery;
+use Doctrine\ORM\Mapping\Column;
+use Doctrine\ORM\Mapping\Entity;
+use Doctrine\ORM\Mapping\Id;
+use Doctrine\ORM\Mapping\JoinColumn;
+use Doctrine\ORM\Mapping\ManyToOne;
 use Doctrine\Tests\IterableTester;
 use Doctrine\Tests\OrmFunctionalTestCase;
 
@@ -42,19 +47,19 @@ final class GH7496WithToIterableTest extends OrmFunctionalTestCase
             $q->toIterable([], AbstractQuery::HYDRATE_OBJECT)
         );
 
-        $this->assertCount(2, $bs);
-        $this->assertInstanceOf(GH7496EntityB::class, $bs[0]);
-        $this->assertInstanceOf(GH7496EntityB::class, $bs[1]);
-        $this->assertEquals(1, $bs[0]->id);
-        $this->assertEquals(1, $bs[1]->id);
+        self::assertCount(2, $bs);
+        self::assertInstanceOf(GH7496EntityB::class, $bs[0]);
+        self::assertInstanceOf(GH7496EntityB::class, $bs[1]);
+        self::assertEquals(1, $bs[0]->id);
+        self::assertEquals(1, $bs[1]->id);
 
         $bs = IterableTester::iterableToArray(
             $q->toIterable([], AbstractQuery::HYDRATE_ARRAY)
         );
 
-        $this->assertCount(2, $bs);
-        $this->assertEquals(1, $bs[0]['id']);
-        $this->assertEquals(1, $bs[1]['id']);
+        self::assertCount(2, $bs);
+        self::assertEquals(1, $bs[0]['id']);
+        self::assertEquals(1, $bs[1]['id']);
     }
 }
 
