@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\ORM\Functional;
 
 use Doctrine\ORM\ORMInvalidArgumentException;
@@ -8,18 +10,18 @@ use Doctrine\Tests\OrmFunctionalTestCase;
 
 class UnitOfWorkLifecycleTest extends OrmFunctionalTestCase
 {
-    protected function setUp() : void
+    protected function setUp(): void
     {
         $this->useModelSet('cms');
         parent::setUp();
     }
 
-    public function testScheduleInsertManaged()
+    public function testScheduleInsertManaged(): void
     {
-        $user = new CmsUser();
-        $user->username = "beberlei";
-        $user->name = "Benjamin";
-        $user->status = "active";
+        $user           = new CmsUser();
+        $user->username = 'beberlei';
+        $user->name     = 'Benjamin';
+        $user->status   = 'active';
         $this->_em->persist($user);
         $this->_em->flush();
 
@@ -29,12 +31,12 @@ class UnitOfWorkLifecycleTest extends OrmFunctionalTestCase
         $this->_em->getUnitOfWork()->scheduleForInsert($user);
     }
 
-    public function testScheduleInsertDeleted()
+    public function testScheduleInsertDeleted(): void
     {
-        $user = new CmsUser();
-        $user->username = "beberlei";
-        $user->name = "Benjamin";
-        $user->status = "active";
+        $user           = new CmsUser();
+        $user->username = 'beberlei';
+        $user->name     = 'Benjamin';
+        $user->status   = 'active';
         $this->_em->persist($user);
         $this->_em->flush();
 
@@ -46,12 +48,12 @@ class UnitOfWorkLifecycleTest extends OrmFunctionalTestCase
         $this->_em->getUnitOfWork()->scheduleForInsert($user);
     }
 
-    public function testScheduleInsertTwice()
+    public function testScheduleInsertTwice(): void
     {
-        $user = new CmsUser();
-        $user->username = "beberlei";
-        $user->name = "Benjamin";
-        $user->status = "active";
+        $user           = new CmsUser();
+        $user->username = 'beberlei';
+        $user->name     = 'Benjamin';
+        $user->status   = 'active';
 
         $this->_em->getUnitOfWork()->scheduleForInsert($user);
 
@@ -61,7 +63,7 @@ class UnitOfWorkLifecycleTest extends OrmFunctionalTestCase
         $this->_em->getUnitOfWork()->scheduleForInsert($user);
     }
 
-    public function testAddToIdentityMapWithoutIdentity()
+    public function testAddToIdentityMapWithoutIdentity(): void
     {
         $user = new CmsUser();
 
@@ -71,7 +73,7 @@ class UnitOfWorkLifecycleTest extends OrmFunctionalTestCase
         $this->_em->getUnitOfWork()->registerManaged($user, [], []);
     }
 
-    public function testMarkReadOnlyNonManaged()
+    public function testMarkReadOnlyNonManaged(): void
     {
         $user = new CmsUser();
 
