@@ -6,14 +6,14 @@ namespace Doctrine\Tests\ORM\Functional\Ticket;
 
 use Doctrine\Common\EventManager;
 use Doctrine\DBAL\Connection;
-use Doctrine\DBAL\Driver\Statement;
+use Doctrine\DBAL\Result;
 use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\ORM\Events;
 use Doctrine\ORM\Internal\Hydration\AbstractHydrator;
 use Doctrine\ORM\ORMException;
 use Doctrine\ORM\Query\ResultSetMapping;
 use Doctrine\Tests\OrmFunctionalTestCase;
-use PHPUnit_Framework_MockObject_MockObject;
+use PHPUnit\Framework\MockObject\MockObject;
 
 use function iterator_to_array;
 
@@ -22,16 +22,16 @@ use function iterator_to_array;
  */
 class AbstractHydratorTest extends OrmFunctionalTestCase
 {
-    /** @var EventManager|PHPUnit_Framework_MockObject_MockObject */
+    /** @var EventManager&MockObject */
     private $mockEventManager;
 
-    /** @var Statement|PHPUnit_Framework_MockObject_MockObject */
-    private $mockStatement;
+    /** @var Result&MockObject */
+    private $mockResult;
 
-    /** @var ResultSetMapping|PHPUnit_Framework_MockObject_MockObject */
+    /** @var ResultSetMapping&MockObject */
     private $mockResultMapping;
 
-    /** @var AbstractHydrator */
+    /** @var AbstractHydrator&MockObject */
     private $hydrator;
 
     protected function setUp(): void
@@ -41,8 +41,8 @@ class AbstractHydratorTest extends OrmFunctionalTestCase
         $mockConnection             = $this->createMock(Connection::class);
         $mockEntityManagerInterface = $this->createMock(EntityManagerInterface::class);
         $this->mockEventManager     = $this->createMock(EventManager::class);
-        $this->mockStatement        = $this->createMock(Statement::class);
-        $this->mockResultMapping    = $this->getMockBuilder(ResultSetMapping::class);
+        $this->mockResult           = $this->createMock(Result::class);
+        $this->mockResultMapping    = $this->createMock(ResultSetMapping::class);
 
         $mockEntityManagerInterface
             ->expects(self::any())
@@ -52,9 +52,9 @@ class AbstractHydratorTest extends OrmFunctionalTestCase
             ->expects(self::any())
             ->method('getConnection')
             ->willReturn($mockConnection);
-        $this->mockStatement
+        $this->mockResult
             ->expects(self::any())
-            ->method('fetch')
+            ->method('fetchAssociative')
             ->willReturn(false);
 
         $this->hydrator = $this
@@ -94,7 +94,7 @@ class AbstractHydratorTest extends OrmFunctionalTestCase
                 $this->assertTrue($eventListenerHasBeenRegistered);
             });
 
-        iterator_to_array($this->hydrator->iterate($this->mockStatement, $this->mockResultMapping));
+        iterator_to_array($this->hydrator->iterate($this->mockResult, $this->mockResultMapping));
     }
 
     /**
@@ -123,7 +123,7 @@ class AbstractHydratorTest extends OrmFunctionalTestCase
                 $this->assertTrue($eventListenerHasBeenRegistered);
             });
 
-        $this->hydrator->hydrateAll($this->mockStatement, $this->mockResultMapping);
+        $this->hydrator->hydrateAll($this->mockResult, $this->mockResultMapping);
     }
 
     /**
@@ -159,6 +159,6 @@ class AbstractHydratorTest extends OrmFunctionalTestCase
             ->willThrowException(new ORMException());
 
         $this->expectException(ORMException::class);
-        $this->hydrator->hydrateAll($this->mockStatement, $this->mockResultMapping);
+        $this->hydrator->hydrateAll($this->mockResult, $this->mockResultMapping);
     }
 }
