@@ -6,7 +6,7 @@ namespace Doctrine\Tests\ORM\Hydration;
 
 use Doctrine\ORM\Internal\Hydration\ArrayHydrator;
 use Doctrine\ORM\Query\ResultSetMapping;
-use Doctrine\Tests\Mocks\HydratorMockStatement;
+use Doctrine\Tests\Mocks\ArrayResultFactory;
 use Doctrine\Tests\Models\CMS\CmsArticle;
 use Doctrine\Tests\Models\CMS\CmsComment;
 use Doctrine\Tests\Models\CMS\CmsPhonenumber;
@@ -14,9 +14,6 @@ use Doctrine\Tests\Models\CMS\CmsUser;
 use Doctrine\Tests\Models\Forum\ForumBoard;
 use Doctrine\Tests\Models\Forum\ForumCategory;
 
-use function count;
-use function is_array;
-
 class ArrayHydratorTest extends HydrationTestCase
 {
     /**
@@ -56,18 +53,18 @@ class ArrayHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = new HydratorMockStatement($resultSet);
+        $stmt     = ArrayResultFactory::createFromArray($resultSet);
         $hydrator = new ArrayHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
-        $this->assertEquals(2, count($result));
-        $this->assertTrue(is_array($result));
+        self::assertCount(2, $result);
+        self::assertIsArray($result);
 
-        $this->assertEquals(1, $result[0]['id']);
-        $this->assertEquals('romanb', $result[0]['name']);
+        self::assertEquals(1, $result[0]['id']);
+        self::assertEquals('romanb', $result[0]['name']);
 
-        $this->assertEquals(2, $result[1]['id']);
-        $this->assertEquals('jwage', $result[1]['name']);
+        self::assertEquals(2, $result[1]['id']);
+        self::assertEquals('jwage', $result[1]['name']);
     }
 
     /**
@@ -100,28 +97,28 @@ class ArrayHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = new HydratorMockStatement($resultSet);
+        $stmt     = ArrayResultFactory::createFromArray($resultSet);
         $hydrator = new ArrayHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
-        $this->assertEquals(2, count($result));
-        $this->assertTrue(is_array($result));
+        self::assertCount(2, $result);
+        self::assertIsArray($result);
 
-        $this->assertArrayHasKey('nameUpper', $result[0]);
-        $this->assertArrayNotHasKey('id', $result[0]);
-        $this->assertArrayNotHasKey('name', $result[0]);
+        self::assertArrayHasKey('nameUpper', $result[0]);
+        self::assertArrayNotHasKey('id', $result[0]);
+        self::assertArrayNotHasKey('name', $result[0]);
 
-        $this->assertArrayHasKey(0, $result[0]);
-        $this->assertArrayHasKey('id', $result[0][0]);
-        $this->assertArrayHasKey('name', $result[0][0]);
+        self::assertArrayHasKey(0, $result[0]);
+        self::assertArrayHasKey('id', $result[0][0]);
+        self::assertArrayHasKey('name', $result[0][0]);
 
-        $this->assertArrayHasKey('nameUpper', $result[1]);
-        $this->assertArrayNotHasKey('id', $result[1]);
-        $this->assertArrayNotHasKey('name', $result[1]);
+        self::assertArrayHasKey('nameUpper', $result[1]);
+        self::assertArrayNotHasKey('id', $result[1]);
+        self::assertArrayNotHasKey('name', $result[1]);
 
-        $this->assertArrayHasKey(0, $result[1]);
-        $this->assertArrayHasKey('id', $result[1][0]);
-        $this->assertArrayHasKey('name', $result[1][0]);
+        self::assertArrayHasKey(0, $result[1]);
+        self::assertArrayHasKey('id', $result[1][0]);
+        self::assertArrayHasKey('name', $result[1][0]);
     }
 
     /**
@@ -148,20 +145,20 @@ class ArrayHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = new HydratorMockStatement($resultSet);
+        $stmt     = ArrayResultFactory::createFromArray($resultSet);
         $hydrator = new ArrayHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
-        $this->assertEquals(2, count($result));
-        $this->assertTrue(is_array($result));
+        self::assertCount(2, $result);
+        self::assertIsArray($result);
 
-        $this->assertArrayHasKey('user', $result[0]);
-        $this->assertEquals(1, $result[0]['user']['id']);
-        $this->assertEquals('romanb', $result[0]['user']['name']);
+        self::assertArrayHasKey('user', $result[0]);
+        self::assertEquals(1, $result[0]['user']['id']);
+        self::assertEquals('romanb', $result[0]['user']['name']);
 
-        $this->assertArrayHasKey('user', $result[1]);
-        $this->assertEquals(2, $result[1]['user']['id']);
-        $this->assertEquals('jwage', $result[1]['user']['name']);
+        self::assertArrayHasKey('user', $result[1]);
+        self::assertEquals(2, $result[1]['user']['id']);
+        self::assertEquals('jwage', $result[1]['user']['name']);
     }
 
     /**
@@ -195,23 +192,23 @@ class ArrayHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = new HydratorMockStatement($resultSet);
+        $stmt     = ArrayResultFactory::createFromArray($resultSet);
         $hydrator = new ArrayHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
-        $this->assertEquals(4, count($result));
+        self::assertCount(4, $result);
 
-        $this->assertEquals(1, $result[0]['id']);
-        $this->assertEquals('romanb', $result[0]['name']);
+        self::assertEquals(1, $result[0]['id']);
+        self::assertEquals('romanb', $result[0]['name']);
 
-        $this->assertEquals(1, $result[1]['id']);
-        $this->assertEquals('Cool things.', $result[1]['topic']);
+        self::assertEquals(1, $result[1]['id']);
+        self::assertEquals('Cool things.', $result[1]['topic']);
 
-        $this->assertEquals(2, $result[2]['id']);
-        $this->assertEquals('jwage', $result[2]['name']);
+        self::assertEquals(2, $result[2]['id']);
+        self::assertEquals('jwage', $result[2]['name']);
 
-        $this->assertEquals(2, $result[3]['id']);
-        $this->assertEquals('Cool things II.', $result[3]['topic']);
+        self::assertEquals(2, $result[3]['id']);
+        self::assertEquals('Cool things II.', $result[3]['topic']);
     }
 
     /**
@@ -245,27 +242,27 @@ class ArrayHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = new HydratorMockStatement($resultSet);
+        $stmt     = ArrayResultFactory::createFromArray($resultSet);
         $hydrator = new ArrayHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
-        $this->assertEquals(4, count($result));
+        self::assertCount(4, $result);
 
-        $this->assertArrayHasKey('user', $result[0]);
-        $this->assertEquals(1, $result[0]['user']['id']);
-        $this->assertEquals('romanb', $result[0]['user']['name']);
+        self::assertArrayHasKey('user', $result[0]);
+        self::assertEquals(1, $result[0]['user']['id']);
+        self::assertEquals('romanb', $result[0]['user']['name']);
 
-        $this->assertArrayHasKey(0, $result[1]);
-        $this->assertEquals(1, $result[1][0]['id']);
-        $this->assertEquals('Cool things.', $result[1][0]['topic']);
+        self::assertArrayHasKey(0, $result[1]);
+        self::assertEquals(1, $result[1][0]['id']);
+        self::assertEquals('Cool things.', $result[1][0]['topic']);
 
-        $this->assertArrayHasKey('user', $result[2]);
-        $this->assertEquals(2, $result[2]['user']['id']);
-        $this->assertEquals('jwage', $result[2]['user']['name']);
+        self::assertArrayHasKey('user', $result[2]);
+        self::assertEquals(2, $result[2]['user']['id']);
+        self::assertEquals('jwage', $result[2]['user']['name']);
 
-        $this->assertArrayHasKey(0, $result[3]);
-        $this->assertEquals(2, $result[3][0]['id']);
-        $this->assertEquals('Cool things II.', $result[3][0]['topic']);
+        self::assertArrayHasKey(0, $result[3]);
+        self::assertEquals(2, $result[3][0]['id']);
+        self::assertEquals('Cool things II.', $result[3][0]['topic']);
     }
 
     /**
@@ -299,27 +296,27 @@ class ArrayHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = new HydratorMockStatement($resultSet);
+        $stmt     = ArrayResultFactory::createFromArray($resultSet);
         $hydrator = new ArrayHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
-        $this->assertEquals(4, count($result));
+        self::assertCount(4, $result);
 
-        $this->assertArrayHasKey(0, $result[0]);
-        $this->assertEquals(1, $result[0][0]['id']);
-        $this->assertEquals('romanb', $result[0][0]['name']);
+        self::assertArrayHasKey(0, $result[0]);
+        self::assertEquals(1, $result[0][0]['id']);
+        self::assertEquals('romanb', $result[0][0]['name']);
 
-        $this->assertArrayHasKey('article', $result[1]);
-        $this->assertEquals(1, $result[1]['article']['id']);
-        $this->assertEquals('Cool things.', $result[1]['article']['topic']);
+        self::assertArrayHasKey('article', $result[1]);
+        self::assertEquals(1, $result[1]['article']['id']);
+        self::assertEquals('Cool things.', $result[1]['article']['topic']);
 
-        $this->assertArrayHasKey(0, $result[2]);
-        $this->assertEquals(2, $result[2][0]['id']);
-        $this->assertEquals('jwage', $result[2][0]['name']);
+        self::assertArrayHasKey(0, $result[2]);
+        self::assertEquals(2, $result[2][0]['id']);
+        self::assertEquals('jwage', $result[2][0]['name']);
 
-        $this->assertArrayHasKey('article', $result[3]);
-        $this->assertEquals(2, $result[3]['article']['id']);
-        $this->assertEquals('Cool things II.', $result[3]['article']['topic']);
+        self::assertArrayHasKey('article', $result[3]);
+        self::assertEquals(2, $result[3]['article']['id']);
+        self::assertEquals('Cool things II.', $result[3]['article']['topic']);
     }
 
     /**
@@ -353,27 +350,27 @@ class ArrayHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = new HydratorMockStatement($resultSet);
+        $stmt     = ArrayResultFactory::createFromArray($resultSet);
         $hydrator = new ArrayHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
-        $this->assertEquals(4, count($result));
+        self::assertCount(4, $result);
 
-        $this->assertArrayHasKey('user', $result[0]);
-        $this->assertEquals(1, $result[0]['user']['id']);
-        $this->assertEquals('romanb', $result[0]['user']['name']);
+        self::assertArrayHasKey('user', $result[0]);
+        self::assertEquals(1, $result[0]['user']['id']);
+        self::assertEquals('romanb', $result[0]['user']['name']);
 
-        $this->assertArrayHasKey('article', $result[1]);
-        $this->assertEquals(1, $result[1]['article']['id']);
-        $this->assertEquals('Cool things.', $result[1]['article']['topic']);
+        self::assertArrayHasKey('article', $result[1]);
+        self::assertEquals(1, $result[1]['article']['id']);
+        self::assertEquals('Cool things.', $result[1]['article']['topic']);
 
-        $this->assertArrayHasKey('user', $result[2]);
-        $this->assertEquals(2, $result[2]['user']['id']);
-        $this->assertEquals('jwage', $result[2]['user']['name']);
+        self::assertArrayHasKey('user', $result[2]);
+        self::assertEquals(2, $result[2]['user']['id']);
+        self::assertEquals('jwage', $result[2]['user']['name']);
 
-        $this->assertArrayHasKey('article', $result[3]);
-        $this->assertEquals(2, $result[3]['article']['id']);
-        $this->assertEquals('Cool things II.', $result[3]['article']['topic']);
+        self::assertArrayHasKey('article', $result[3]);
+        self::assertEquals(2, $result[3]['article']['id']);
+        self::assertEquals('Cool things II.', $result[3]['article']['topic']);
     }
 
     /**
@@ -408,22 +405,22 @@ class ArrayHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = new HydratorMockStatement($resultSet);
+        $stmt     = ArrayResultFactory::createFromArray($resultSet);
         $hydrator = new ArrayHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
-        $this->assertEquals(2, count($result));
-        $this->assertTrue(is_array($result));
-        $this->assertTrue(is_array($result[0]));
-        $this->assertTrue(is_array($result[1]));
+        self::assertCount(2, $result);
+        self::assertIsArray($result);
+        self::assertIsArray($result[0]);
+        self::assertIsArray($result[1]);
 
         // first user => 2 phonenumbers
-        $this->assertArrayHasKey($userEntityKey, $result[0]);
-        $this->assertEquals(2, $result[0]['numPhones']);
+        self::assertArrayHasKey($userEntityKey, $result[0]);
+        self::assertEquals(2, $result[0]['numPhones']);
 
         // second user => 1 phonenumber
-        $this->assertArrayHasKey($userEntityKey, $result[1]);
-        $this->assertEquals(1, $result[1]['numPhones']);
+        self::assertArrayHasKey($userEntityKey, $result[1]);
+        self::assertEquals(1, $result[1]['numPhones']);
     }
 
     /**
@@ -472,27 +469,27 @@ class ArrayHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = new HydratorMockStatement($resultSet);
+        $stmt     = ArrayResultFactory::createFromArray($resultSet);
         $hydrator = new ArrayHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
-        $this->assertEquals(2, count($result));
+        self::assertCount(2, $result);
 
-        $this->assertTrue(is_array($result));
-        $this->assertTrue(is_array($result[0]));
-        $this->assertTrue(is_array($result[1]));
+        self::assertIsArray($result);
+        self::assertIsArray($result[0]);
+        self::assertIsArray($result[1]);
 
         // first user => 2 phonenumbers
-        $this->assertEquals(2, count($result[0][$userEntityKey]['phonenumbers']));
-        $this->assertEquals('ROMANB', $result[0]['nameUpper']);
+        self::assertCount(2, $result[0][$userEntityKey]['phonenumbers']);
+        self::assertEquals('ROMANB', $result[0]['nameUpper']);
 
         // second user => 1 phonenumber
-        $this->assertEquals(1, count($result[1][$userEntityKey]['phonenumbers']));
-        $this->assertEquals('JWAGE', $result[1]['nameUpper']);
+        self::assertCount(1, $result[1][$userEntityKey]['phonenumbers']);
+        self::assertEquals('JWAGE', $result[1]['nameUpper']);
 
-        $this->assertEquals(42, $result[0][$userEntityKey]['phonenumbers'][0]['phonenumber']);
-        $this->assertEquals(43, $result[0][$userEntityKey]['phonenumbers'][1]['phonenumber']);
-        $this->assertEquals(91, $result[1][$userEntityKey]['phonenumbers'][0]['phonenumber']);
+        self::assertEquals(42, $result[0][$userEntityKey]['phonenumbers'][0]['phonenumber']);
+        self::assertEquals(43, $result[0][$userEntityKey]['phonenumbers'][1]['phonenumber']);
+        self::assertEquals(91, $result[1][$userEntityKey]['phonenumbers'][0]['phonenumber']);
     }
 
     /**
@@ -545,30 +542,30 @@ class ArrayHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = new HydratorMockStatement($resultSet);
+        $stmt     = ArrayResultFactory::createFromArray($resultSet);
         $hydrator = new ArrayHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
-        $this->assertEquals(2, count($result));
+        self::assertCount(2, $result);
 
-        $this->assertTrue(is_array($result));
-        $this->assertTrue(is_array($result[1]));
-        $this->assertTrue(is_array($result[2]));
+        self::assertIsArray($result);
+        self::assertIsArray($result[1]);
+        self::assertIsArray($result[2]);
 
         // test the scalar values
-        $this->assertEquals('ROMANB', $result[1]['nameUpper']);
-        $this->assertEquals('JWAGE', $result[2]['nameUpper']);
+        self::assertEquals('ROMANB', $result[1]['nameUpper']);
+        self::assertEquals('JWAGE', $result[2]['nameUpper']);
 
         // first user => 2 phonenumbers. notice the custom indexing by user id
-        $this->assertEquals(2, count($result[1][$userEntityKey]['phonenumbers']));
+        self::assertCount(2, $result[1][$userEntityKey]['phonenumbers']);
 
         // second user => 1 phonenumber. notice the custom indexing by user id
-        $this->assertEquals(1, count($result[2][$userEntityKey]['phonenumbers']));
+        self::assertCount(1, $result[2][$userEntityKey]['phonenumbers']);
 
         // test the custom indexing of the phonenumbers
-        $this->assertTrue(isset($result[1][$userEntityKey]['phonenumbers']['42']));
-        $this->assertTrue(isset($result[1][$userEntityKey]['phonenumbers']['43']));
-        $this->assertTrue(isset($result[2][$userEntityKey]['phonenumbers']['91']));
+        self::assertTrue(isset($result[1][$userEntityKey]['phonenumbers']['42']));
+        self::assertTrue(isset($result[1][$userEntityKey]['phonenumbers']['43']));
+        self::assertTrue(isset($result[2][$userEntityKey]['phonenumbers']['91']));
     }
 
     /**
@@ -659,31 +656,31 @@ class ArrayHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = new HydratorMockStatement($resultSet);
+        $stmt     = ArrayResultFactory::createFromArray($resultSet);
         $hydrator = new ArrayHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
-        $this->assertEquals(2, count($result));
-        $this->assertTrue(is_array($result));
-        $this->assertTrue(is_array($result[0]));
-        $this->assertTrue(is_array($result[1]));
+        self::assertCount(2, $result);
+        self::assertIsArray($result);
+        self::assertIsArray($result[0]);
+        self::assertIsArray($result[1]);
         // first user => 2 phonenumbers, 2 articles
-        $this->assertEquals(2, count($result[0][0]['phonenumbers']));
-        $this->assertEquals(2, count($result[0][0]['articles']));
-        $this->assertEquals('ROMANB', $result[0]['nameUpper']);
+        self::assertCount(2, $result[0][0]['phonenumbers']);
+        self::assertCount(2, $result[0][0]['articles']);
+        self::assertEquals('ROMANB', $result[0]['nameUpper']);
         // second user => 1 phonenumber, 2 articles
-        $this->assertEquals(1, count($result[1][0]['phonenumbers']));
-        $this->assertEquals(2, count($result[1][0]['articles']));
-        $this->assertEquals('JWAGE', $result[1]['nameUpper']);
+        self::assertCount(1, $result[1][0]['phonenumbers']);
+        self::assertCount(2, $result[1][0]['articles']);
+        self::assertEquals('JWAGE', $result[1]['nameUpper']);
 
-        $this->assertEquals(42, $result[0][0]['phonenumbers'][0]['phonenumber']);
-        $this->assertEquals(43, $result[0][0]['phonenumbers'][1]['phonenumber']);
-        $this->assertEquals(91, $result[1][0]['phonenumbers'][0]['phonenumber']);
+        self::assertEquals(42, $result[0][0]['phonenumbers'][0]['phonenumber']);
+        self::assertEquals(43, $result[0][0]['phonenumbers'][1]['phonenumber']);
+        self::assertEquals(91, $result[1][0]['phonenumbers'][0]['phonenumber']);
 
-        $this->assertEquals('Getting things done!', $result[0][0]['articles'][0]['topic']);
-        $this->assertEquals('ZendCon', $result[0][0]['articles'][1]['topic']);
-        $this->assertEquals('LINQ', $result[1][0]['articles'][0]['topic']);
-        $this->assertEquals('PHP7', $result[1][0]['articles'][1]['topic']);
+        self::assertEquals('Getting things done!', $result[0][0]['articles'][0]['topic']);
+        self::assertEquals('ZendCon', $result[0][0]['articles'][1]['topic']);
+        self::assertEquals('LINQ', $result[1][0]['articles'][0]['topic']);
+        self::assertEquals('PHP7', $result[1][0]['articles'][1]['topic']);
     }
 
     /**
@@ -798,45 +795,45 @@ class ArrayHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = new HydratorMockStatement($resultSet);
+        $stmt     = ArrayResultFactory::createFromArray($resultSet);
         $hydrator = new ArrayHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
-        $this->assertEquals(2, count($result));
-        $this->assertTrue(is_array($result));
-        $this->assertTrue(is_array($result[0]));
-        $this->assertTrue(is_array($result[1]));
+        self::assertCount(2, $result);
+        self::assertIsArray($result);
+        self::assertIsArray($result[0]);
+        self::assertIsArray($result[1]);
 
         // first user => 2 phonenumbers, 2 articles, 1 comment on first article
-        $this->assertEquals(2, count($result[0][0]['phonenumbers']));
-        $this->assertEquals(2, count($result[0][0]['articles']));
-        $this->assertEquals(1, count($result[0][0]['articles'][0]['comments']));
-        $this->assertEquals('ROMANB', $result[0]['nameUpper']);
+        self::assertCount(2, $result[0][0]['phonenumbers']);
+        self::assertCount(2, $result[0][0]['articles']);
+        self::assertCount(1, $result[0][0]['articles'][0]['comments']);
+        self::assertEquals('ROMANB', $result[0]['nameUpper']);
         // second user => 1 phonenumber, 2 articles, no comments
-        $this->assertEquals(1, count($result[1][0]['phonenumbers']));
-        $this->assertEquals(2, count($result[1][0]['articles']));
-        $this->assertEquals('JWAGE', $result[1]['nameUpper']);
+        self::assertCount(1, $result[1][0]['phonenumbers']);
+        self::assertCount(2, $result[1][0]['articles']);
+        self::assertEquals('JWAGE', $result[1]['nameUpper']);
 
-        $this->assertEquals(42, $result[0][0]['phonenumbers'][0]['phonenumber']);
-        $this->assertEquals(43, $result[0][0]['phonenumbers'][1]['phonenumber']);
-        $this->assertEquals(91, $result[1][0]['phonenumbers'][0]['phonenumber']);
+        self::assertEquals(42, $result[0][0]['phonenumbers'][0]['phonenumber']);
+        self::assertEquals(43, $result[0][0]['phonenumbers'][1]['phonenumber']);
+        self::assertEquals(91, $result[1][0]['phonenumbers'][0]['phonenumber']);
 
-        $this->assertEquals('Getting things done!', $result[0][0]['articles'][0]['topic']);
-        $this->assertEquals('ZendCon', $result[0][0]['articles'][1]['topic']);
-        $this->assertEquals('LINQ', $result[1][0]['articles'][0]['topic']);
-        $this->assertEquals('PHP7', $result[1][0]['articles'][1]['topic']);
+        self::assertEquals('Getting things done!', $result[0][0]['articles'][0]['topic']);
+        self::assertEquals('ZendCon', $result[0][0]['articles'][1]['topic']);
+        self::assertEquals('LINQ', $result[1][0]['articles'][0]['topic']);
+        self::assertEquals('PHP7', $result[1][0]['articles'][1]['topic']);
 
-        $this->assertEquals('First!', $result[0][0]['articles'][0]['comments'][0]['topic']);
+        self::assertEquals('First!', $result[0][0]['articles'][0]['comments'][0]['topic']);
 
-        $this->assertTrue(isset($result[0][0]['articles'][0]['comments']));
+        self::assertTrue(isset($result[0][0]['articles'][0]['comments']));
 
         // empty comment collections
-        $this->assertTrue(is_array($result[0][0]['articles'][1]['comments']));
-        $this->assertEquals(0, count($result[0][0]['articles'][1]['comments']));
-        $this->assertTrue(is_array($result[1][0]['articles'][0]['comments']));
-        $this->assertEquals(0, count($result[1][0]['articles'][0]['comments']));
-        $this->assertTrue(is_array($result[1][0]['articles'][1]['comments']));
-        $this->assertEquals(0, count($result[1][0]['articles'][1]['comments']));
+        self::assertIsArray($result[0][0]['articles'][1]['comments']);
+        self::assertCount(0, $result[0][0]['articles'][1]['comments']);
+        self::assertIsArray($result[1][0]['articles'][0]['comments']);
+        self::assertCount(0, $result[1][0]['articles'][0]['comments']);
+        self::assertIsArray($result[1][0]['articles'][1]['comments']);
+        self::assertCount(0, $result[1][0]['articles'][1]['comments']);
     }
 
     /**
@@ -912,18 +909,18 @@ class ArrayHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = new HydratorMockStatement($resultSet);
+        $stmt     = ArrayResultFactory::createFromArray($resultSet);
         $hydrator = new ArrayHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
-        $this->assertEquals(2, count($result));
-        $this->assertTrue(is_array($result));
-        $this->assertTrue(is_array($result[0]));
-        $this->assertTrue(is_array($result[1]));
-        $this->assertTrue(isset($result[0]['boards']));
-        $this->assertEquals(3, count($result[0]['boards']));
-        $this->assertTrue(isset($result[1]['boards']));
-        $this->assertEquals(1, count($result[1]['boards']));
+        self::assertCount(2, $result);
+        self::assertIsArray($result);
+        self::assertIsArray($result[0]);
+        self::assertIsArray($result[1]);
+        self::assertTrue(isset($result[0]['boards']));
+        self::assertCount(3, $result[0]['boards']);
+        self::assertTrue(isset($result[1]['boards']));
+        self::assertCount(1, $result[1]['boards']);
     }
 
     /**
@@ -975,29 +972,29 @@ class ArrayHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = new HydratorMockStatement($resultSet);
+        $stmt     = ArrayResultFactory::createFromArray($resultSet);
         $hydrator = new ArrayHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
-        $this->assertEquals(3, count($result));
+        self::assertCount(3, $result);
 
-        $this->assertEquals(2, count($result[0][$entityKey])); // User array
-        $this->assertEquals(1, $result[0]['id']);
-        $this->assertEquals('The First', $result[0]['topic']);
-        $this->assertEquals(1, $result[0]['cid']);
-        $this->assertEquals('First Comment', $result[0]['ctopic']);
+        self::assertCount(2, $result[0][$entityKey]); // User array
+        self::assertEquals(1, $result[0]['id']);
+        self::assertEquals('The First', $result[0]['topic']);
+        self::assertEquals(1, $result[0]['cid']);
+        self::assertEquals('First Comment', $result[0]['ctopic']);
 
-        $this->assertEquals(2, count($result[1][$entityKey])); // User array, duplicated
-        $this->assertEquals(1, $result[1]['id']); // duplicated
-        $this->assertEquals('The First', $result[1]['topic']); // duplicated
-        $this->assertEquals(2, $result[1]['cid']);
-        $this->assertEquals('Second Comment', $result[1]['ctopic']);
+        self::assertCount(2, $result[1][$entityKey]); // User array, duplicated
+        self::assertEquals(1, $result[1]['id']); // duplicated
+        self::assertEquals('The First', $result[1]['topic']); // duplicated
+        self::assertEquals(2, $result[1]['cid']);
+        self::assertEquals('Second Comment', $result[1]['ctopic']);
 
-        $this->assertEquals(2, count($result[2][$entityKey])); // User array, duplicated
-        $this->assertEquals(42, $result[2]['id']);
-        $this->assertEquals('The Answer', $result[2]['topic']);
-        $this->assertNull($result[2]['cid']);
-        $this->assertNull($result[2]['ctopic']);
+        self::assertCount(2, $result[2][$entityKey]); // User array, duplicated
+        self::assertEquals(42, $result[2]['id']);
+        self::assertEquals('The Answer', $result[2]['topic']);
+        self::assertNull($result[2]['cid']);
+        self::assertNull($result[2]['ctopic']);
     }
 
     /**
@@ -1024,21 +1021,21 @@ class ArrayHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = new HydratorMockStatement($resultSet);
+        $stmt     = ArrayResultFactory::createFromArray($resultSet);
         $hydrator = new ArrayHydrator($this->entityManager);
         $iterator = $hydrator->iterate($stmt, $rsm);
         $rowNum   = 0;
 
         while (($row = $iterator->next()) !== false) {
-            $this->assertEquals(1, count($row));
-            $this->assertTrue(is_array($row[0]));
+            self::assertCount(1, $row);
+            self::assertIsArray($row[0]);
 
             if ($rowNum === 0) {
-                $this->assertEquals(1, $row[0]['id']);
-                $this->assertEquals('romanb', $row[0]['name']);
+                self::assertEquals(1, $row[0]['id']);
+                self::assertEquals('romanb', $row[0]['name']);
             } elseif ($rowNum === 1) {
-                $this->assertEquals(2, $row[0]['id']);
-                $this->assertEquals('jwage', $row[0]['name']);
+                self::assertEquals(2, $row[0]['id']);
+                self::assertEquals('jwage', $row[0]['name']);
             }
 
             ++$rowNum;
@@ -1069,22 +1066,22 @@ class ArrayHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = new HydratorMockStatement($resultSet);
+        $stmt     = ArrayResultFactory::createFromArray($resultSet);
         $hydrator = new ArrayHydrator($this->entityManager);
         $iterator = $hydrator->iterate($stmt, $rsm);
         $rowNum   = 0;
 
         while (($row = $iterator->next()) !== false) {
-            $this->assertEquals(1, count($row));
-            $this->assertArrayHasKey(0, $row);
-            $this->assertArrayHasKey('user', $row[0]);
+            self::assertCount(1, $row);
+            self::assertArrayHasKey(0, $row);
+            self::assertArrayHasKey('user', $row[0]);
 
             if ($rowNum === 0) {
-                $this->assertEquals(1, $row[0]['user']['id']);
-                $this->assertEquals('romanb', $row[0]['user']['name']);
+                self::assertEquals(1, $row[0]['user']['id']);
+                self::assertEquals('romanb', $row[0]['user']['name']);
             } elseif ($rowNum === 1) {
-                $this->assertEquals(2, $row[0]['user']['id']);
-                $this->assertEquals('jwage', $row[0]['user']['name']);
+                self::assertEquals(2, $row[0]['user']['id']);
+                self::assertEquals('jwage', $row[0]['user']['name']);
             }
 
             ++$rowNum;
@@ -1114,14 +1111,14 @@ class ArrayHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = new HydratorMockStatement($resultSet);
+        $stmt     = ArrayResultFactory::createFromArray($resultSet);
         $hydrator = new ArrayHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
-        $this->assertEquals(1, count($result));
-        $this->assertArrayHasKey('id', $result[0]);
-        $this->assertArrayHasKey('name', $result[0]);
-        $this->assertArrayNotHasKey('foo', $result[0]);
+        self::assertCount(1, $result);
+        self::assertArrayHasKey('id', $result[0]);
+        self::assertArrayHasKey('name', $result[0]);
+        self::assertArrayNotHasKey('foo', $result[0]);
     }
 
     /**
@@ -1165,21 +1162,21 @@ class ArrayHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = new HydratorMockStatement($resultSet);
+        $stmt     = ArrayResultFactory::createFromArray($resultSet);
         $hydrator = new ArrayHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
-        $this->assertEquals(4, count($result), 'Should hydrate four results.');
+        self::assertCount(4, $result, 'Should hydrate four results.');
 
-        $this->assertEquals('ROMANB', $result[0]['nameUpper']);
-        $this->assertEquals('ROMANB', $result[1]['nameUpper']);
-        $this->assertEquals('JWAGE', $result[2]['nameUpper']);
-        $this->assertEquals('JWAGE', $result[3]['nameUpper']);
+        self::assertEquals('ROMANB', $result[0]['nameUpper']);
+        self::assertEquals('ROMANB', $result[1]['nameUpper']);
+        self::assertEquals('JWAGE', $result[2]['nameUpper']);
+        self::assertEquals('JWAGE', $result[3]['nameUpper']);
 
-        $this->assertEquals(['id' => 1, 'status' => 'developer'], $result[0][$userEntityKey]);
-        $this->assertNull($result[1][$userEntityKey]);
-        $this->assertEquals(['id' => 2, 'status' => 'developer'], $result[2][$userEntityKey]);
-        $this->assertNull($result[3][$userEntityKey]);
+        self::assertEquals(['id' => 1, 'status' => 'developer'], $result[0][$userEntityKey]);
+        self::assertNull($result[1][$userEntityKey]);
+        self::assertEquals(['id' => 2, 'status' => 'developer'], $result[2][$userEntityKey]);
+        self::assertNull($result[3][$userEntityKey]);
     }
 
     /**
@@ -1215,16 +1212,16 @@ class ArrayHydratorTest extends HydrationTestCase
             ],
         ];
 
-        $stmt     = new HydratorMockStatement($resultSet);
+        $stmt     = ArrayResultFactory::createFromArray($resultSet);
         $hydrator = new ArrayHydrator($this->entityManager);
         $result   = $hydrator->hydrateAll($stmt, $rsm);
 
-        $this->assertEquals(2, count($result));
+        self::assertCount(2, $result);
 
-        $this->assertTrue(isset($result[1]));
-        $this->assertEquals(1, $result[1][$userEntityKey]['id']);
+        self::assertArrayHasKey(1, $result);
+        self::assertEquals(1, $result[1][$userEntityKey]['id']);
 
-        $this->assertTrue(isset($result[2]));
-        $this->assertEquals(2, $result[2][$userEntityKey]['id']);
+        self::assertArrayHasKey(2, $result);
+        self::assertEquals(2, $result[2][$userEntityKey]['id']);
     }
 }
