@@ -5,15 +5,15 @@ declare(strict_types=1);
 namespace Doctrine\Tests\ORM\Id;
 
 use BadMethodCallException;
-use Doctrine\ORM\EntityManager;
+use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\ORM\Id\SequenceGenerator;
+use Doctrine\Tests\Mocks\ArrayResultFactory;
 use Doctrine\Tests\Mocks\ConnectionMock;
-use Doctrine\Tests\Mocks\StatementArrayMock;
 use Doctrine\Tests\OrmTestCase;
 
 class SequenceGeneratorTest extends OrmTestCase
 {
-    /** @var EntityManager */
+    /** @var EntityManagerInterface */
     private $entityManager;
 
     /** @var SequenceGenerator */
@@ -42,10 +42,10 @@ class SequenceGeneratorTest extends OrmTestCase
 
         for ($i = 0; $i < 42; ++$i) {
             if ($i % 10 === 0) {
-                $this->connection->setQueryResult(new StatementArrayMock([[(int) ($i / 10) * 10]]));
+                $this->connection->setQueryResult(ArrayResultFactory::createFromArray([[(int) ($i / 10) * 10]]));
             }
 
-            $id = $this->sequenceGenerator->generate($this->entityManager, null);
+            $id = $this->sequenceGenerator->generateId($this->entityManager, null);
 
             self::assertSame($i, $id);
             self::assertSame((int) ($i / 10) * 10 + 10, $this->sequenceGenerator->getCurrentMaxValue());
