@@ -4,13 +4,28 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\ORM\Mapping;
 
-use Doctrine\Common\Annotations\AnnotationException;
 use Doctrine\Common\Annotations\AnnotationReader;
+use Doctrine\ORM\Cache\Exception\CacheException;
 use Doctrine\ORM\Mapping;
+use Doctrine\ORM\Mapping\Cache;
 use Doctrine\ORM\Mapping\ClassMetadata;
 use Doctrine\ORM\Mapping\ClassMetadataFactory;
+use Doctrine\ORM\Mapping\Column;
+use Doctrine\ORM\Mapping\DiscriminatorColumn;
+use Doctrine\ORM\Mapping\DiscriminatorMap;
 use Doctrine\ORM\Mapping\Driver\AnnotationDriver;
+use Doctrine\ORM\Mapping\Entity;
+use Doctrine\ORM\Mapping\GeneratedValue;
+use Doctrine\ORM\Mapping\HasLifecycleCallbacks;
+use Doctrine\ORM\Mapping\Id;
+use Doctrine\ORM\Mapping\InheritanceType;
+use Doctrine\ORM\Mapping\ManyToMany;
+use Doctrine\ORM\Mapping\ManyToOne;
+use Doctrine\ORM\Mapping\MappedSuperclass;
 use Doctrine\ORM\Mapping\MappingException;
+use Doctrine\ORM\Mapping\OneToMany;
+use Doctrine\ORM\Mapping\PostLoad;
+use Doctrine\ORM\Mapping\PreUpdate;
 use Doctrine\Persistence\Mapping\Driver\MappingDriver;
 use Doctrine\Persistence\Mapping\RuntimeReflectionService;
 use Doctrine\Tests\Models\CMS\CmsUser;
@@ -19,6 +34,7 @@ use Doctrine\Tests\Models\DDC1872\DDC1872ExampleEntityWithOverride;
 use Doctrine\Tests\Models\DirectoryTree\Directory;
 use Doctrine\Tests\Models\DirectoryTree\File;
 use Doctrine\Tests\Models\ECommerce\ECommerceCart;
+use Generator;
 
 class AnnotationDriverTest extends AbstractMappingDriverTest
 {
@@ -38,7 +54,7 @@ class AnnotationDriverTest extends AbstractMappingDriverTest
 
     public function testFailingSecondLevelCacheAssociation(): void
     {
-        $this->expectException('Doctrine\ORM\Cache\CacheException');
+        $this->expectException(CacheException::class);
         $this->expectExceptionMessage('Entity association field "Doctrine\Tests\ORM\Mapping\AnnotationSLC#foo" not configured as part of the second-level cache.');
         $mappingDriver = $this->loadDriver();
 
@@ -56,7 +72,7 @@ class AnnotationDriverTest extends AbstractMappingDriverTest
         $annotationDriver = $this->loadDriver();
 
         $annotationDriver->loadMetadataForClass(Mapping\InvalidColumn::class, $cm);
-        $this->assertEquals('string', $cm->fieldMappings['id']['type']);
+        self::assertEquals('string', $cm->fieldMappings['id']['type']);
     }
 
     /**
@@ -70,7 +86,7 @@ class AnnotationDriverTest extends AbstractMappingDriverTest
         $annotationDriver = $this->loadDriverForCMSModels();
         $afterTestReset   = $annotationDriver->getAllClassNames();
 
-        $this->assertEquals($original, $afterTestReset);
+        self::assertEquals($original, $afterTestReset);
     }
 
     /**
@@ -84,7 +100,7 @@ class AnnotationDriverTest extends AbstractMappingDriverTest
         $annotationDriver = $this->loadDriverForCMSModels();
         $afterTestReset   = $annotationDriver->getAllClassNames();
 
-        $this->assertEquals($original, $afterTestReset);
+        self::assertEquals($original, $afterTestReset);
     }
 
     /**
@@ -97,7 +113,7 @@ class AnnotationDriverTest extends AbstractMappingDriverTest
         $annotationDriver = $this->loadDriverForCMSModels();
         $classes          = $annotationDriver->getAllClassNames();
 
-        $this->assertContains(CmsUser::class, $classes);
+        self::assertContains(CmsUser::class, $classes);
     }
 
     /**
@@ -110,7 +126,7 @@ class AnnotationDriverTest extends AbstractMappingDriverTest
         $annotationDriver = $this->loadDriverForCMSModels();
         $classes          = $annotationDriver->getAllClassNames();
 
-        $this->assertNotContains(ECommerceCart::class, $classes);
+        self::assertNotContains(ECommerceCart::class, $classes);
     }
 
     protected function loadDriverForCMSModels(): AnnotationDriver
@@ -150,10 +166,10 @@ class AnnotationDriverTest extends AbstractMappingDriverTest
         $factory->setEntityManager($em);
 
         $classPage = $factory->getMetadataFor(File::class);
-        $this->assertEquals(File::class, $classPage->associationMappings['parentDirectory']['sourceEntity']);
+        self::assertEquals(File::class, $classPage->associationMappings['parentDirectory']['sourceEntity']);
 
         $classDirectory = $factory->getMetadataFor(Directory::class);
-        $this->assertEquals(Directory::class, $classDirectory->associationMappings['parentDirectory']['sourceEntity']);
+        self::assertEquals(Directory::class, $classDirectory->associationMappings['parentDirectory']['sourceEntity']);
     }
 
     /**
@@ -174,7 +190,7 @@ class AnnotationDriverTest extends AbstractMappingDriverTest
             "mapped superclass 'Doctrine\Tests\ORM\Mapping\InvalidMappedSuperClass#users'"
         );
 
-        $usingInvalidMsc = $factory->getMetadataFor(UsingInvalidMappedSuperClass::class);
+        $factory->getMetadataFor(UsingInvalidMappedSuperClass::class);
     }
 
     /**
@@ -211,10 +227,10 @@ class AnnotationDriverTest extends AbstractMappingDriverTest
         $factory->setEntityManager($em);
 
         $cm = $factory->getMetadataFor(AnnotationChild::class);
-        $this->assertEquals(['postLoad' => ['postLoad'], 'preUpdate' => ['preUpdate']], $cm->lifecycleCallbacks);
+        self::assertEquals(['postLoad' => ['postLoad'], 'preUpdate' => ['preUpdate']], $cm->lifecycleCallbacks);
 
         $cm = $factory->getMetadataFor(AnnotationParent::class);
-        $this->assertEquals(['postLoad' => ['postLoad'], 'preUpdate' => ['preUpdate']], $cm->lifecycleCallbacks);
+        self::assertEquals(['postLoad' => ['postLoad'], 'preUpdate' => ['preUpdate']], $cm->lifecycleCallbacks);
     }
 
     /**
@@ -242,8 +258,8 @@ class AnnotationDriverTest extends AbstractMappingDriverTest
         $factory = new ClassMetadataFactory();
         $factory->setEntityManager($em);
 
-        $this->expectException(AnnotationException::class);
-        $this->expectExceptionMessage('[Enum Error] Attribute "fetch" of @Doctrine\ORM\Mapping\OneToMany declared on property Doctrine\Tests\ORM\Mapping\InvalidFetchOption::$collection accept');
+        $this->expectException(MappingException::class);
+        $this->expectExceptionMessage("Entity 'Doctrine\Tests\ORM\Mapping\InvalidFetchOption' has a mapping with invalid fetch mode 'eager'");
 
         $factory->getMetadataFor(InvalidFetchOption::class);
     }
@@ -255,10 +271,34 @@ class AnnotationDriverTest extends AbstractMappingDriverTest
         $metadataWithoutOverride = $factory->getMetadataFor(DDC1872ExampleEntityWithoutOverride::class);
         $metadataWithOverride    = $factory->getMetadataFor(DDC1872ExampleEntityWithOverride::class);
 
-        $this->assertEquals('trait_foo', $metadataWithoutOverride->fieldMappings['foo']['columnName']);
-        $this->assertEquals('foo_overridden', $metadataWithOverride->fieldMappings['foo']['columnName']);
-        $this->assertArrayHasKey('example_trait_bar_id', $metadataWithoutOverride->associationMappings['bar']['joinColumnFieldNames']);
-        $this->assertArrayHasKey('example_entity_overridden_bar_id', $metadataWithOverride->associationMappings['bar']['joinColumnFieldNames']);
+        self::assertEquals('trait_foo', $metadataWithoutOverride->fieldMappings['foo']['columnName']);
+        self::assertEquals('foo_overridden', $metadataWithOverride->fieldMappings['foo']['columnName']);
+        self::assertArrayHasKey('example_trait_bar_id', $metadataWithoutOverride->associationMappings['bar']['joinColumnFieldNames']);
+        self::assertArrayHasKey('example_entity_overridden_bar_id', $metadataWithOverride->associationMappings['bar']['joinColumnFieldNames']);
+    }
+
+    /**
+     * @psalm-param class-string $class
+     *
+     * @dataProvider provideDiscriminatorColumnTestcases
+     */
+    public function testLengthForDiscriminatorColumn(string $class, int $expectedLength): void
+    {
+        $factory = $this->createClassMetadataFactory();
+
+        $metadata = $factory->getMetadataFor($class);
+
+        self::assertNotNull($metadata->discriminatorColumn);
+        self::assertArrayHasKey('length', $metadata->discriminatorColumn);
+        self::assertSame($expectedLength, $metadata->discriminatorColumn['length']);
+    }
+
+    public function provideDiscriminatorColumnTestcases(): Generator
+    {
+        yield [DiscriminatorColumnWithNullLength::class, 255];
+        yield [DiscriminatorColumnWithNoLength::class, 255];
+        yield [DiscriminatorColumnWithZeroLength::class, 0];
+        yield [DiscriminatorColumnWithNonZeroLength::class, 60];
     }
 }
 
@@ -424,3 +464,83 @@ class AnnotationSLCFoo
      */
     public $id;
 }
+
+/**
+ * @Entity
+ * @InheritanceType("SINGLE_TABLE")
+ * @DiscriminatorColumn(
+ *     name="type",
+ *     type="string",
+ *     length=0,
+ *     columnDefinition="enum('region','airport','station','poi') NOT NULL",
+ * ),
+ * @DiscriminatorMap({"s"="SuperEntity", "c"="ChildEntity"})
+ */
+class DiscriminatorColumnWithZeroLength
+{
+    /**
+     * @var int
+     * @Id
+     * @Column
+     */
+    public $id;
+}
+
+/**
+ * @Entity
+ * @InheritanceType("SINGLE_TABLE")
+ * @DiscriminatorColumn(
+ *     name="type",
+ *     type="string",
+ * ),
+ * @DiscriminatorMap({"s"="SuperEntity", "c"="ChildEntity"})
+ */
+class DiscriminatorColumnWithNoLength
+{
+    /**
+     * @var int
+     * @Id
+     * @Column
+     */
+    public $id;
+}
+
+/**
+ * @Entity
+ * @InheritanceType("SINGLE_TABLE")
+ * @DiscriminatorColumn(
+ *     name="type",
+ *     type="string",
+ *     length=60,
+ * ),
+ * @DiscriminatorMap({"s"="SuperEntity", "c"="ChildEntity"})
+ */
+class DiscriminatorColumnWithNonZeroLength
+{
+    /**
+     * @var int
+     * @Id
+     * @Column
+     */
+    public $id;
+}
+
+/**
+ * @Entity
+ * @InheritanceType("SINGLE_TABLE")
+ * @DiscriminatorColumn(
+ *     name="type",
+ *     type="string",
+ *     length=null,
+ * ),
+ * @DiscriminatorMap({"s"="SuperEntity", "c"="ChildEntity"})
+ */
+class DiscriminatorColumnWithNullLength
+{
+    /**
+     * @var int
+     * @Id
+     * @Column
+     */
+    public $id;
+}
