@@ -35,22 +35,22 @@ class ClassMetadataBuilderTest extends OrmTestCase
     public function testSetMappedSuperClass(): void
     {
         $this->assertIsFluent($this->builder->setMappedSuperClass());
-        $this->assertTrue($this->cm->isMappedSuperclass);
-        $this->assertFalse($this->cm->isEmbeddedClass);
+        self::assertTrue($this->cm->isMappedSuperclass);
+        self::assertFalse($this->cm->isEmbeddedClass);
     }
 
     public function testSetEmbedable(): void
     {
         $this->assertIsFluent($this->builder->setEmbeddable());
-        $this->assertTrue($this->cm->isEmbeddedClass);
-        $this->assertFalse($this->cm->isMappedSuperclass);
+        self::assertTrue($this->cm->isEmbeddedClass);
+        self::assertFalse($this->cm->isMappedSuperclass);
     }
 
     public function testAddEmbeddedWithOnlyRequiredParams(): void
     {
         $this->assertIsFluent($this->builder->addEmbedded('name', Name::class));
 
-        $this->assertEquals(
+        self::assertEquals(
             [
                 'name' => [
                     'class' => Name::class,
@@ -73,7 +73,7 @@ class ClassMetadataBuilderTest extends OrmTestCase
             )
         );
 
-        $this->assertEquals(
+        self::assertEquals(
             [
                 'name' => [
                     'class' => Name::class,
@@ -89,12 +89,12 @@ class ClassMetadataBuilderTest extends OrmTestCase
     public function testCreateEmbeddedWithoutExtraParams(): void
     {
         $embeddedBuilder = $this->builder->createEmbedded('name', Name::class);
-        $this->assertInstanceOf(EmbeddedBuilder::class, $embeddedBuilder);
+        self::assertInstanceOf(EmbeddedBuilder::class, $embeddedBuilder);
 
-        $this->assertFalse(isset($this->cm->embeddedClasses['name']));
+        self::assertFalse(isset($this->cm->embeddedClasses['name']));
 
         $this->assertIsFluent($embeddedBuilder->build());
-        $this->assertEquals(
+        self::assertEquals(
             [
                 'class' => Name::class,
                 'columnPrefix' => null,
@@ -109,11 +109,11 @@ class ClassMetadataBuilderTest extends OrmTestCase
     {
         $embeddedBuilder = $this->builder->createEmbedded('name', Name::class);
 
-        $this->assertEquals($embeddedBuilder, $embeddedBuilder->setColumnPrefix('nm_'));
+        self::assertEquals($embeddedBuilder, $embeddedBuilder->setColumnPrefix('nm_'));
 
         $this->assertIsFluent($embeddedBuilder->build());
 
-        $this->assertEquals(
+        self::assertEquals(
             [
                 'class' => Name::class,
                 'columnPrefix' => 'nm_',
@@ -127,31 +127,31 @@ class ClassMetadataBuilderTest extends OrmTestCase
     public function testSetCustomRepositoryClass(): void
     {
         $this->assertIsFluent($this->builder->setCustomRepositoryClass(CmsGroup::class));
-        $this->assertEquals(CmsGroup::class, $this->cm->customRepositoryClassName);
+        self::assertEquals(CmsGroup::class, $this->cm->customRepositoryClassName);
     }
 
     public function testSetReadOnly(): void
     {
         $this->assertIsFluent($this->builder->setReadOnly());
-        $this->assertTrue($this->cm->isReadOnly);
+        self::assertTrue($this->cm->isReadOnly);
     }
 
     public function testSetTable(): void
     {
         $this->assertIsFluent($this->builder->setTable('users'));
-        $this->assertEquals('users', $this->cm->table['name']);
+        self::assertEquals('users', $this->cm->table['name']);
     }
 
     public function testAddIndex(): void
     {
         $this->assertIsFluent($this->builder->addIndex(['username', 'name'], 'users_idx'));
-        $this->assertEquals(['users_idx' => ['columns' => ['username', 'name']]], $this->cm->table['indexes']);
+        self::assertEquals(['users_idx' => ['columns' => ['username', 'name']]], $this->cm->table['indexes']);
     }
 
     public function testAddUniqueConstraint(): void
     {
         $this->assertIsFluent($this->builder->addUniqueConstraint(['username', 'name'], 'users_idx'));
-        $this->assertEquals(['users_idx' => ['columns' => ['username', 'name']]], $this->cm->table['uniqueConstraints']);
+        self::assertEquals(['users_idx' => ['columns' => ['username', 'name']]], $this->cm->table['uniqueConstraints']);
     }
 
     public function testSetPrimaryTableRelated(): void
@@ -160,7 +160,7 @@ class ClassMetadataBuilderTest extends OrmTestCase
         $this->builder->addIndex(['username', 'name'], 'users_idx');
         $this->builder->setTable('users');
 
-        $this->assertEquals(
+        self::assertEquals(
             [
                 'name' => 'users',
                 'indexes' => ['users_idx' => ['columns' => ['username', 'name']]],
@@ -173,19 +173,19 @@ class ClassMetadataBuilderTest extends OrmTestCase
     public function testSetInheritanceJoined(): void
     {
         $this->assertIsFluent($this->builder->setJoinedTableInheritance());
-        $this->assertEquals(ClassMetadata::INHERITANCE_TYPE_JOINED, $this->cm->inheritanceType);
+        self::assertEquals(ClassMetadata::INHERITANCE_TYPE_JOINED, $this->cm->inheritanceType);
     }
 
     public function testSetInheritanceSingleTable(): void
     {
         $this->assertIsFluent($this->builder->setSingleTableInheritance());
-        $this->assertEquals(ClassMetadata::INHERITANCE_TYPE_SINGLE_TABLE, $this->cm->inheritanceType);
+        self::assertEquals(ClassMetadata::INHERITANCE_TYPE_SINGLE_TABLE, $this->cm->inheritanceType);
     }
 
     public function testSetDiscriminatorColumn(): void
     {
         $this->assertIsFluent($this->builder->setDiscriminatorColumn('discr', 'string', '124'));
-        $this->assertEquals(['fieldName' => 'discr', 'name' => 'discr', 'type' => 'string', 'length' => '124'], $this->cm->discriminatorColumn);
+        self::assertEquals(['fieldName' => 'discr', 'name' => 'discr', 'type' => 'string', 'length' => '124'], $this->cm->discriminatorColumn);
     }
 
     public function testAddDiscriminatorMapClass(): void
@@ -193,45 +193,45 @@ class ClassMetadataBuilderTest extends OrmTestCase
         $this->assertIsFluent($this->builder->addDiscriminatorMapClass('test', CmsUser::class));
         $this->assertIsFluent($this->builder->addDiscriminatorMapClass('test2', CmsGroup::class));
 
-        $this->assertEquals(
+        self::assertEquals(
             ['test' => CmsUser::class, 'test2' => CmsGroup::class],
             $this->cm->discriminatorMap
         );
-        $this->assertEquals('test', $this->cm->discriminatorValue);
+        self::assertEquals('test', $this->cm->discriminatorValue);
     }
 
     public function testChangeTrackingPolicyExplicit(): void
     {
         $this->assertIsFluent($this->builder->setChangeTrackingPolicyDeferredExplicit());
-        $this->assertEquals(ClassMetadata::CHANGETRACKING_DEFERRED_EXPLICIT, $this->cm->changeTrackingPolicy);
+        self::assertEquals(ClassMetadata::CHANGETRACKING_DEFERRED_EXPLICIT, $this->cm->changeTrackingPolicy);
     }
 
     public function testChangeTrackingPolicyNotify(): void
     {
         $this->assertIsFluent($this->builder->setChangeTrackingPolicyNotify());
-        $this->assertEquals(ClassMetadata::CHANGETRACKING_NOTIFY, $this->cm->changeTrackingPolicy);
+        self::assertEquals(ClassMetadata::CHANGETRACKING_NOTIFY, $this->cm->changeTrackingPolicy);
     }
 
     public function testAddField(): void
     {
         $this->assertIsFluent($this->builder->addField('name', 'string'));
-        $this->assertEquals(['columnName' => 'name', 'fieldName' => 'name', 'type' => 'string'], $this->cm->fieldMappings['name']);
+        self::assertEquals(['columnName' => 'name', 'fieldName' => 'name', 'type' => 'string'], $this->cm->fieldMappings['name']);
     }
 
     public function testCreateField(): void
     {
         $fieldBuilder = $this->builder->createField('name', 'string');
-        $this->assertInstanceOf(FieldBuilder::class, $fieldBuilder);
+        self::assertInstanceOf(FieldBuilder::class, $fieldBuilder);
 
-        $this->assertFalse(isset($this->cm->fieldMappings['name']));
+        self::assertFalse(isset($this->cm->fieldMappings['name']));
         $this->assertIsFluent($fieldBuilder->build());
-        $this->assertEquals(['columnName' => 'name', 'fieldName' => 'name', 'type' => 'string'], $this->cm->fieldMappings['name']);
+        self::assertEquals(['columnName' => 'name', 'fieldName' => 'name', 'type' => 'string'], $this->cm->fieldMappings['name']);
     }
 
     public function testCreateVersionedField(): void
     {
         $this->builder->createField('name', 'integer')->columnName('username')->length(124)->nullable()->columnDefinition('foobar')->unique()->isVersionField()->build();
-        $this->assertEquals(
+        self::assertEquals(
             [
                 'columnDefinition' => 'foobar',
                 'columnName' => 'username',
@@ -250,15 +250,15 @@ class ClassMetadataBuilderTest extends OrmTestCase
     {
         $this->builder->createField('id', 'integer')->makePrimaryKey()->generatedValue()->build();
 
-        $this->assertEquals(['id'], $this->cm->identifier);
-        $this->assertEquals(['columnName' => 'id', 'fieldName' => 'id', 'id' => true, 'type' => 'integer'], $this->cm->fieldMappings['id']);
+        self::assertEquals(['id'], $this->cm->identifier);
+        self::assertEquals(['columnName' => 'id', 'fieldName' => 'id', 'id' => true, 'type' => 'integer'], $this->cm->fieldMappings['id']);
     }
 
     public function testCreateUnsignedOptionField(): void
     {
         $this->builder->createField('state', 'integer')->option('unsigned', true)->build();
 
-        $this->assertEquals(
+        self::assertEquals(
             ['fieldName' => 'state', 'type' => 'integer', 'options' => ['unsigned' => true], 'columnName' => 'state'],
             $this->cm->fieldMappings['state']
         );
@@ -268,7 +268,7 @@ class ClassMetadataBuilderTest extends OrmTestCase
     {
         $this->builder->addLifecycleEvent('getStatus', 'postLoad');
 
-        $this->assertEquals(['postLoad' => ['getStatus']], $this->cm->lifecycleCallbacks);
+        self::assertEquals(['postLoad' => ['getStatus']], $this->cm->lifecycleCallbacks);
     }
 
     public function testCreateManyToOne(): void
@@ -281,7 +281,7 @@ class ClassMetadataBuilderTest extends OrmTestCase
                               ->build()
         );
 
-        $this->assertEquals(
+        self::assertEquals(
             [
                 'groups' => [
                     'fieldName' => 'groups',
@@ -341,7 +341,7 @@ class ClassMetadataBuilderTest extends OrmTestCase
                 ->build()
         );
 
-        $this->assertEquals(
+        self::assertEquals(
             [
                 'groups' => [
                     'fieldName' => 'groups',
@@ -399,7 +399,7 @@ class ClassMetadataBuilderTest extends OrmTestCase
                               ->build()
         );
 
-        $this->assertEquals(
+        self::assertEquals(
             [
                 'groups' => [
                     'fieldName' => 'groups',
@@ -459,7 +459,7 @@ class ClassMetadataBuilderTest extends OrmTestCase
                 ->build()
         );
 
-        $this->assertEquals(
+        self::assertEquals(
             [
                 'groups' => [
                     'fieldName' => 'groups',
@@ -532,7 +532,7 @@ class ClassMetadataBuilderTest extends OrmTestCase
                               ->build()
         );
 
-        $this->assertEquals(
+        self::assertEquals(
             [
                 'groups' =>
                 [
@@ -626,7 +626,7 @@ class ClassMetadataBuilderTest extends OrmTestCase
                         ->build()
         );
 
-        $this->assertEquals(
+        self::assertEquals(
             [
                 'groups' =>
                 [
@@ -677,7 +677,7 @@ class ClassMetadataBuilderTest extends OrmTestCase
                 ->build()
         );
 
-        $this->assertEquals(
+        self::assertEquals(
             [
                 'groups' => [
                     'fieldName' => 'groups',
@@ -728,7 +728,7 @@ class ClassMetadataBuilderTest extends OrmTestCase
                 ->build()
         );
 
-        $this->assertEquals(
+        self::assertEquals(
             [
                 'groups' =>
                 [
@@ -772,7 +772,7 @@ class ClassMetadataBuilderTest extends OrmTestCase
             ->orphanRemoval()
             ->build();
 
-        $this->assertEquals(
+        self::assertEquals(
             [
                 'groups' => [
                     'fieldName' => 'groups',
@@ -825,6 +825,6 @@ class ClassMetadataBuilderTest extends OrmTestCase
 
     public function assertIsFluent($ret): void
     {
-        $this->assertSame($this->builder, $ret, 'Return Value has to be same instance as used builder');
+        self::assertSame($this->builder, $ret, 'Return Value has to be same instance as used builder');
     }
 }
