@@ -7,18 +7,26 @@ namespace Doctrine\Tests\ORM\Mapping;
 use Doctrine\Common\EventManager;
 use Doctrine\DBAL\Connection;
 use Doctrine\ORM\Configuration;
-use Doctrine\ORM\EntityManager;
 use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\ORM\Event\OnClassMetadataNotFoundEventArgs;
 use Doctrine\ORM\Events;
+use Doctrine\ORM\Exception\ORMException;
 use Doctrine\ORM\Id\AbstractIdGenerator;
 use Doctrine\ORM\Mapping\ClassMetadata;
 use Doctrine\ORM\Mapping\ClassMetadataFactory;
+use Doctrine\ORM\Mapping\Column;
+use Doctrine\ORM\Mapping\DiscriminatorColumn;
+use Doctrine\ORM\Mapping\DiscriminatorMap;
+use Doctrine\ORM\Mapping\Entity;
+use Doctrine\ORM\Mapping\Exception\CannotGenerateIds;
+use Doctrine\ORM\Mapping\GeneratedValue;
+use Doctrine\ORM\Mapping\Id;
+use Doctrine\ORM\Mapping\InheritanceType;
 use Doctrine\ORM\Mapping\MappingException;
-use Doctrine\ORM\ORMException;
 use Doctrine\Persistence\Mapping\Driver\MappingDriver;
 use Doctrine\Persistence\Mapping\RuntimeReflectionService;
 use Doctrine\Tests\Mocks\ConnectionMock;
+use Doctrine\Tests\Mocks\DatabasePlatformMock;
 use Doctrine\Tests\Mocks\DriverMock;
 use Doctrine\Tests\Mocks\EntityManagerMock;
 use Doctrine\Tests\Mocks\MetadataDriverMock;
@@ -50,8 +58,8 @@ class ClassMetadataFactoryTest extends OrmTestCase
 
         $conn         = $entityManager->getConnection();
         $mockPlatform = $conn->getDatabasePlatform();
-        $mockPlatform->setPrefersSequences(true);
-        $mockPlatform->setPrefersIdentityColumns(false);
+        $mockPlatform->setSupportsSequences(true);
+        $mockPlatform->setSupportsIdentityColumns(false);
 
         $cm1 = $this->createValidClassMetadata();
 
@@ -61,21 +69,39 @@ class ClassMetadataFactoryTest extends OrmTestCase
         $cmf->setMetadataFor($cm1->name, $cm1);
 
         // Prechecks
-        $this->assertEquals([], $cm1->parentClasses);
-        $this->assertEquals(ClassMetadata::INHERITANCE_TYPE_NONE, $cm1->inheritanceType);
-        $this->assertTrue($cm1->hasField('name'));
-        $this->assertEquals(2, count($cm1->associationMappings));
-        $this->assertEquals(ClassMetadata::GENERATOR_TYPE_AUTO, $cm1->generatorType);
-        $this->assertEquals('group', $cm1->table['name']);
+        self::assertEquals([], $cm1->parentClasses);
+        self::assertEquals(ClassMetadata::INHERITANCE_TYPE_NONE, $cm1->inheritanceType);
+        self::assertTrue($cm1->hasField('name'));
+        self::assertEquals(2, count($cm1->associationMappings));
+        self::assertEquals(ClassMetadata::GENERATOR_TYPE_AUTO, $cm1->generatorType);
+        self::assertEquals('group', $cm1->table['name']);
 
         // Go
         $cmMap1 = $cmf->getMetadataFor($cm1->name);
 
-        $this->assertSame($cm1, $cmMap1);
-        $this->assertEquals('group', $cmMap1->table['name']);
-        $this->assertTrue($cmMap1->table['quoted']);
-        $this->assertEquals([], $cmMap1->parentClasses);
-        $this->assertTrue($cmMap1->hasField('name'));
+        self::assertSame($cm1, $cmMap1);
+        self::assertEquals('group', $cmMap1->table['name']);
+        self::assertTrue($cmMap1->table['quoted']);
+        self::assertEquals([], $cmMap1->parentClasses);
+        self::assertTrue($cmMap1->hasField('name'));
+    }
+
+    public function testItThrowsWhenUsingAutoWithIncompatiblePlatform(): void
+    {
+        $cm1 = $this->createValidClassMetadata();
+        $cm1->setIdGeneratorType(ClassMetadata::GENERATOR_TYPE_AUTO);
+        $entityManager = $this->createEntityManager(new MetadataDriverMock());
+        $connection    = $entityManager->getConnection();
+        assert($connection instanceof ConnectionMock);
+        $platform = $connection->getDatabasePlatform();
+        assert($platform instanceof DatabasePlatformMock);
+        $platform->setSupportsIdentityColumns(false);
+        $cmf = new ClassMetadataFactoryTestSubject();
+        $cmf->setEntityManager($entityManager);
+        $cmf->setMetadataForClass($cm1->name, $cm1);
+        $this->expectException(CannotGenerateIds::class);
+
+        $actual = $cmf->getMetadataFor($cm1->name);
     }
 
     public function testGetMetadataForReturnsLoadedCustomIdGenerator(): void
@@ -88,8 +114,8 @@ class ClassMetadataFactoryTest extends OrmTestCase
 
         $actual = $cmf->getMetadataFor($cm1->name);
 
-        $this->assertEquals(ClassMetadata::GENERATOR_TYPE_CUSTOM, $actual->generatorType);
-        $this->assertInstanceOf(CustomIdGenerator::class, $actual->idGenerator);
+        self::assertEquals(ClassMetadata::GENERATOR_TYPE_CUSTOM, $actual->generatorType);
+        self::assertInstanceOf(CustomIdGenerator::class, $actual->idGenerator);
     }
 
     public function testGetMetadataForThrowsExceptionOnUnknownCustomGeneratorClass(): void
@@ -129,9 +155,9 @@ class ClassMetadataFactoryTest extends OrmTestCase
         $h2 = $mf->hasMetadataFor('\\' . DoctrineGlobalArticle::class);
         $m2 = $mf->getMetadataFor('\\' . DoctrineGlobalArticle::class);
 
-        $this->assertNotSame($m1, $m2);
-        $this->assertFalse($h2);
-        $this->assertTrue($h1);
+        self::assertNotSame($m1, $m2);
+        self::assertFalse($h2);
+        self::assertTrue($h1);
     }
 
     /**
@@ -141,19 +167,23 @@ class ClassMetadataFactoryTest extends OrmTestCase
     {
         $cmf    = new ClassMetadataFactory();
         $driver = $this->createMock(MappingDriver::class);
-        $driver->expects($this->at(0))
-               ->method('isTransient')
-               ->with($this->equalTo(CmsUser::class))
-               ->will($this->returnValue(true));
-        $driver->expects($this->at(1))
-               ->method('isTransient')
-               ->with($this->equalTo(CmsArticle::class))
-               ->will($this->returnValue(false));
+        $driver->expects(self::exactly(2))
+            ->method('isTransient')
+            ->withConsecutive(
+                [CmsUser::class],
+                [CmsArticle::class]
+            )
+            ->willReturnMap(
+                [
+                    [CmsUser::class, true],
+                    [CmsArticle::class, false],
+                ]
+            );
 
         $em = $this->createEntityManager($driver);
 
-        $this->assertTrue($em->getMetadataFactory()->isTransient(CmsUser::class));
-        $this->assertFalse($em->getMetadataFactory()->isTransient(CmsArticle::class));
+        self::assertTrue($em->getMetadataFactory()->isTransient(CmsUser::class));
+        self::assertFalse($em->getMetadataFactory()->isTransient(CmsArticle::class));
     }
 
     /**
@@ -163,20 +193,24 @@ class ClassMetadataFactoryTest extends OrmTestCase
     {
         $cmf    = new ClassMetadataFactory();
         $driver = $this->createMock(MappingDriver::class);
-        $driver->expects($this->at(0))
-               ->method('isTransient')
-               ->with($this->equalTo(CmsUser::class))
-               ->will($this->returnValue(true));
-        $driver->expects($this->at(1))
-               ->method('isTransient')
-               ->with($this->equalTo(CmsArticle::class))
-               ->will($this->returnValue(false));
+        $driver->expects(self::exactly(2))
+            ->method('isTransient')
+            ->withConsecutive(
+                [CmsUser::class],
+                [CmsArticle::class]
+            )
+            ->willReturnMap(
+                [
+                    [CmsUser::class, true],
+                    [CmsArticle::class, false],
+                ]
+            );
 
         $em = $this->createEntityManager($driver);
         $em->getConfiguration()->addEntityNamespace('CMS', 'Doctrine\Tests\Models\CMS');
 
-        $this->assertTrue($em->getMetadataFactory()->isTransient('CMS:CmsUser'));
-        $this->assertFalse($em->getMetadataFactory()->isTransient('CMS:CmsArticle'));
+        self::assertTrue($em->getMetadataFactory()->isTransient('CMS:CmsUser'));
+        self::assertFalse($em->getMetadataFactory()->isTransient('CMS:CmsArticle'));
     }
 
     public function testAddDefaultDiscriminatorMap(): void
@@ -199,22 +233,22 @@ class ClassMetadataFactoryTest extends OrmTestCase
         $childClass        = ChildClass::class;
         $anotherChildClass = AnotherChildClass::class;
 
-        $rootClassKey         = array_search($rootClass, $rootDiscriminatorMap);
-        $childClassKey        = array_search($childClass, $rootDiscriminatorMap);
-        $anotherChildClassKey = array_search($anotherChildClass, $rootDiscriminatorMap);
+        $rootClassKey         = array_search($rootClass, $rootDiscriminatorMap, true);
+        $childClassKey        = array_search($childClass, $rootDiscriminatorMap, true);
+        $anotherChildClassKey = array_search($anotherChildClass, $rootDiscriminatorMap, true);
 
-        $this->assertEquals('rootclass', $rootClassKey);
-        $this->assertEquals('childclass', $childClassKey);
-        $this->assertEquals('anotherchildclass', $anotherChildClassKey);
+        self::assertEquals('rootclass', $rootClassKey);
+        self::assertEquals('childclass', $childClassKey);
+        self::assertEquals('anotherchildclass', $anotherChildClassKey);
 
-        $this->assertEquals($childDiscriminatorMap, $rootDiscriminatorMap);
-        $this->assertEquals($anotherChildDiscriminatorMap, $rootDiscriminatorMap);
+        self::assertEquals($childDiscriminatorMap, $rootDiscriminatorMap);
+        self::assertEquals($anotherChildDiscriminatorMap, $rootDiscriminatorMap);
 
         // ClassMetadataFactory::addDefaultDiscriminatorMap shouldn't be called again, because the
         // discriminator map is already cached
         $cmf = $this->getMockBuilder(ClassMetadataFactory::class)->setMethods(['addDefaultDiscriminatorMap'])->getMock();
         $cmf->setEntityManager($em);
-        $cmf->expects($this->never())
+        $cmf->expects(self::never())
             ->method('addDefaultDiscriminatorMap');
 
         $rootMetadata = $cmf->getMetadataFor(RootClass::class);
@@ -227,9 +261,9 @@ class ClassMetadataFactoryTest extends OrmTestCase
         $mockDriver = new MetadataDriverMock();
         $em         = $this->createEntityManager($mockDriver, $conn);
 
-        $conn->expects($this->any())
+        $conn->expects(self::any())
             ->method('getDatabasePlatform')
-            ->will($this->throwException(new Exception('Exception thrown in test when calling getDatabasePlatform')));
+            ->will(self::throwException(new Exception('Exception thrown in test when calling getDatabasePlatform')));
 
         $cmf = new ClassMetadataFactory();
         $cmf->setEntityManager($em);
@@ -237,7 +271,7 @@ class ClassMetadataFactoryTest extends OrmTestCase
         // getting all the metadata should work, even if get DatabasePlatform blows up
         $metadata = $cmf->getAllMetadata();
         // this will just be an empty array - there was no error
-        $this->assertEquals([], $metadata);
+        self::assertEquals([], $metadata);
     }
 
     protected function createEntityManager(MappingDriver $metadataDriver, $conn = null): EntityManagerMock
@@ -307,60 +341,60 @@ class ClassMetadataFactoryTest extends OrmTestCase
         $addressMetadata = $cmf->getMetadataFor(Quote\Address::class);
 
         // Phone Class Metadata
-        $this->assertTrue($phoneMetadata->fieldMappings['number']['quoted']);
-        $this->assertEquals('phone-number', $phoneMetadata->fieldMappings['number']['columnName']);
+        self::assertTrue($phoneMetadata->fieldMappings['number']['quoted']);
+        self::assertEquals('phone-number', $phoneMetadata->fieldMappings['number']['columnName']);
 
         $user = $phoneMetadata->associationMappings['user'];
-        $this->assertTrue($user['joinColumns'][0]['quoted']);
-        $this->assertEquals('user-id', $user['joinColumns'][0]['name']);
-        $this->assertEquals('user-id', $user['joinColumns'][0]['referencedColumnName']);
+        self::assertTrue($user['joinColumns'][0]['quoted']);
+        self::assertEquals('user-id', $user['joinColumns'][0]['name']);
+        self::assertEquals('user-id', $user['joinColumns'][0]['referencedColumnName']);
 
         // User Group Metadata
-        $this->assertTrue($groupMetadata->fieldMappings['id']['quoted']);
-        $this->assertTrue($groupMetadata->fieldMappings['name']['quoted']);
+        self::assertTrue($groupMetadata->fieldMappings['id']['quoted']);
+        self::assertTrue($groupMetadata->fieldMappings['name']['quoted']);
 
-        $this->assertEquals('user-id', $userMetadata->fieldMappings['id']['columnName']);
-        $this->assertEquals('user-name', $userMetadata->fieldMappings['name']['columnName']);
+        self::assertEquals('user-id', $userMetadata->fieldMappings['id']['columnName']);
+        self::assertEquals('user-name', $userMetadata->fieldMappings['name']['columnName']);
 
         $user = $groupMetadata->associationMappings['parent'];
-        $this->assertTrue($user['joinColumns'][0]['quoted']);
-        $this->assertEquals('parent-id', $user['joinColumns'][0]['name']);
-        $this->assertEquals('group-id', $user['joinColumns'][0]['referencedColumnName']);
+        self::assertTrue($user['joinColumns'][0]['quoted']);
+        self::assertEquals('parent-id', $user['joinColumns'][0]['name']);
+        self::assertEquals('group-id', $user['joinColumns'][0]['referencedColumnName']);
 
         // Address Class Metadata
-        $this->assertTrue($addressMetadata->fieldMappings['id']['quoted']);
-        $this->assertTrue($addressMetadata->fieldMappings['zip']['quoted']);
+        self::assertTrue($addressMetadata->fieldMappings['id']['quoted']);
+        self::assertTrue($addressMetadata->fieldMappings['zip']['quoted']);
 
-        $this->assertEquals('address-id', $addressMetadata->fieldMappings['id']['columnName']);
-        $this->assertEquals('address-zip', $addressMetadata->fieldMappings['zip']['columnName']);
+        self::assertEquals('address-id', $addressMetadata->fieldMappings['id']['columnName']);
+        self::assertEquals('address-zip', $addressMetadata->fieldMappings['zip']['columnName']);
 
         $user = $addressMetadata->associationMappings['user'];
-        $this->assertTrue($user['joinColumns'][0]['quoted']);
-        $this->assertEquals('user-id', $user['joinColumns'][0]['name']);
-        $this->assertEquals('user-id', $user['joinColumns'][0]['referencedColumnName']);
+        self::assertTrue($user['joinColumns'][0]['quoted']);
+        self::assertEquals('user-id', $user['joinColumns'][0]['name']);
+        self::assertEquals('user-id', $user['joinColumns'][0]['referencedColumnName']);
 
         // User Class Metadata
-        $this->assertTrue($userMetadata->fieldMappings['id']['quoted']);
-        $this->assertTrue($userMetadata->fieldMappings['name']['quoted']);
+        self::assertTrue($userMetadata->fieldMappings['id']['quoted']);
+        self::assertTrue($userMetadata->fieldMappings['name']['quoted']);
 
-        $this->assertEquals('user-id', $userMetadata->fieldMappings['id']['columnName']);
-        $this->assertEquals('user-name', $userMetadata->fieldMappings['name']['columnName']);
+        self::assertEquals('user-id', $userMetadata->fieldMappings['id']['columnName']);
+        self::assertEquals('user-name', $userMetadata->fieldMappings['name']['columnName']);
 
         $address = $userMetadata->associationMappings['address'];
-        $this->assertTrue($address['joinColumns'][0]['quoted']);
-        $this->assertEquals('address-id', $address['joinColumns'][0]['name']);
-        $this->assertEquals('address-id', $address['joinColumns'][0]['referencedColumnName']);
+        self::assertTrue($address['joinColumns'][0]['quoted']);
+        self::assertEquals('address-id', $address['joinColumns'][0]['name']);
+        self::assertEquals('address-id', $address['joinColumns'][0]['referencedColumnName']);
 
         $groups = $userMetadata->associationMappings['groups'];
-        $this->assertTrue($groups['joinTable']['quoted']);
-        $this->assertTrue($groups['joinTable']['joinColumns'][0]['quoted']);
-        $this->assertEquals('quote-users-groups', $groups['joinTable']['name']);
-        $this->assertEquals('user-id', $groups['joinTable']['joinColumns'][0]['name']);
-        $this->assertEquals('user-id', $groups['joinTable']['joinColumns'][0]['referencedColumnName']);
+        self::assertTrue($groups['joinTable']['quoted']);
+        self::assertTrue($groups['joinTable']['joinColumns'][0]['quoted']);
+        self::assertEquals('quote-users-groups', $groups['joinTable']['name']);
+        self::assertEquals('user-id', $groups['joinTable']['joinColumns'][0]['name']);
+        self::assertEquals('user-id', $groups['joinTable']['joinColumns'][0]['referencedColumnName']);
 
-        $this->assertTrue($groups['joinTable']['inverseJoinColumns'][0]['quoted']);
-        $this->assertEquals('group-id', $groups['joinTable']['inverseJoinColumns'][0]['name']);
-        $this->assertEquals('group-id', $groups['joinTable']['inverseJoinColumns'][0]['referencedColumnName']);
+        self::assertTrue($groups['joinTable']['inverseJoinColumns'][0]['quoted']);
+        self::assertEquals('group-id', $groups['joinTable']['inverseJoinColumns'][0]['name']);
+        self::assertEquals('group-id', $groups['joinTable']['inverseJoinColumns'][0]['referencedColumnName']);
     }
 
     /**
@@ -382,19 +416,19 @@ class ClassMetadataFactoryTest extends OrmTestCase
         $cmf->setEntityManager($em);
 
         $listener
-            ->expects($this->any())
+            ->expects(self::any())
             ->method('onClassMetadataNotFound')
-            ->will($this->returnCallback(static function (OnClassMetadataNotFoundEventArgs $args) use ($metadata, $em, $test): void {
-                $test->assertNull($args->getFoundMetadata());
-                $test->assertSame('Foo', $args->getClassName());
-                $test->assertSame($em, $args->getObjectManager());
+            ->will(self::returnCallback(static function (OnClassMetadataNotFoundEventArgs $args) use ($metadata, $em): void {
+                self::assertNull($args->getFoundMetadata());
+                self::assertSame('Foo', $args->getClassName());
+                self::assertSame($em, $args->getObjectManager());
 
                 $args->setFoundMetadata($metadata);
             }));
 
         $eventManager->addEventListener([Events::onClassMetadataNotFound], $listener);
 
-        $this->assertSame($metadata, $cmf->getMetadataFor('Foo'));
+        self::assertSame($metadata, $cmf->getMetadataFor('Foo'));
     }
 
     /**
@@ -411,7 +445,7 @@ class ClassMetadataFactoryTest extends OrmTestCase
         $class    = new ReflectionClass(ClassMetadataFactory::class);
         $property = $class->getProperty('em');
         $property->setAccessible(true);
-        $this->assertSame($entityManager, $property->getValue($classMetadataFactory));
+        self::assertSame($entityManager, $property->getValue($classMetadataFactory));
     }
 
     /**
@@ -451,7 +485,7 @@ class ClassMetadataFactoryTest extends OrmTestCase
 
         $userMetadata = $cmf->getMetadataFor(DDC4006User::class);
 
-        $this->assertTrue($userMetadata->isIdGeneratorIdentity());
+        self::assertTrue($userMetadata->isIdGeneratorIdentity());
     }
 
     public function testInvalidSubClassCase(): void
@@ -501,6 +535,7 @@ class ClassMetadataFactoryTestSubject extends ClassMetadataFactory
 
     /**
      * @psalm-param class-string<object> $className
+     *
      * @override
      */
     protected function newClassMetadataInstance($className): ClassMetadata
@@ -553,7 +588,11 @@ class TestEntity1
 
 class CustomIdGenerator extends AbstractIdGenerator
 {
-    public function generate(EntityManager $em, $entity): void
+    /**
+     * {@inheritdoc}
+     */
+    public function generateId(EntityManagerInterface $em, $entity): string
     {
+        return 'foo';
     }
 }
