@@ -47,13 +47,13 @@ class QuoteStrategyTest extends OrmTestCase
         $em     = $this->getTestEntityManager();
         $config = $em->getConfiguration();
 
-        $this->assertInstanceOf(QuoteStrategy::class, $config->getQuoteStrategy());
-        $this->assertInstanceOf(DefaultQuoteStrategy::class, $config->getQuoteStrategy());
+        self::assertInstanceOf(QuoteStrategy::class, $config->getQuoteStrategy());
+        self::assertInstanceOf(DefaultQuoteStrategy::class, $config->getQuoteStrategy());
 
         $config->setQuoteStrategy(new MyQuoteStrategy());
 
-        $this->assertInstanceOf(QuoteStrategy::class, $config->getQuoteStrategy());
-        $this->assertInstanceOf(MyQuoteStrategy::class, $config->getQuoteStrategy());
+        self::assertInstanceOf(QuoteStrategy::class, $config->getQuoteStrategy());
+        self::assertInstanceOf(MyQuoteStrategy::class, $config->getQuoteStrategy());
     }
 
     public function testGetColumnName(): void
@@ -62,20 +62,20 @@ class QuoteStrategyTest extends OrmTestCase
         $cm->mapField(['fieldName' => 'name', 'columnName' => '`name`']);
         $cm->mapField(['fieldName' => 'id', 'columnName' => 'id']);
 
-        $this->assertEquals('id', $this->strategy->getColumnName('id', $cm, $this->platform));
-        $this->assertEquals('"name"', $this->strategy->getColumnName('name', $cm, $this->platform));
+        self::assertEquals('id', $this->strategy->getColumnName('id', $cm, $this->platform));
+        self::assertEquals('"name"', $this->strategy->getColumnName('name', $cm, $this->platform));
     }
 
     public function testGetTableName(): void
     {
         $cm = $this->createClassMetadata(CmsUser::class);
         $cm->setPrimaryTable(['name' => '`cms_user`']);
-        $this->assertEquals('"cms_user"', $this->strategy->getTableName($cm, $this->platform));
+        self::assertEquals('"cms_user"', $this->strategy->getTableName($cm, $this->platform));
 
         $cm = new ClassMetadata(CmsUser::class);
         $cm->initializeReflection(new RuntimeReflectionService());
         $cm->setPrimaryTable(['name' => 'cms_user']);
-        $this->assertEquals('cms_user', $this->strategy->getTableName($cm, $this->platform));
+        self::assertEquals('cms_user', $this->strategy->getTableName($cm, $this->platform));
     }
 
     public function testJoinTableName(): void
@@ -101,8 +101,8 @@ class QuoteStrategyTest extends OrmTestCase
             ]
         );
 
-        $this->assertEquals('"cmsaddress_cmsuser"', $this->strategy->getJoinTableName($cm1->associationMappings['user'], $cm1, $this->platform));
-        $this->assertEquals('cmsaddress_cmsuser', $this->strategy->getJoinTableName($cm2->associationMappings['user'], $cm2, $this->platform));
+        self::assertEquals('"cmsaddress_cmsuser"', $this->strategy->getJoinTableName($cm1->associationMappings['user'], $cm1, $this->platform));
+        self::assertEquals('cmsaddress_cmsuser', $this->strategy->getJoinTableName($cm2->associationMappings['user'], $cm2, $this->platform));
     }
 
     public function testIdentifierColumnNames(): void
@@ -126,17 +126,17 @@ class QuoteStrategyTest extends OrmTestCase
             ]
         );
 
-        $this->assertEquals(['"id"'], $this->strategy->getIdentifierColumnNames($cm1, $this->platform));
-        $this->assertEquals(['id'], $this->strategy->getIdentifierColumnNames($cm2, $this->platform));
+        self::assertEquals(['"id"'], $this->strategy->getIdentifierColumnNames($cm1, $this->platform));
+        self::assertEquals(['id'], $this->strategy->getIdentifierColumnNames($cm2, $this->platform));
     }
 
     public function testColumnAlias(): void
     {
         $i = 0;
-        $this->assertEquals('columnName_0', $this->strategy->getColumnAlias('columnName', $i++, $this->platform));
-        $this->assertEquals('column_name_1', $this->strategy->getColumnAlias('column_name', $i++, $this->platform));
-        $this->assertEquals('COLUMN_NAME_2', $this->strategy->getColumnAlias('COLUMN_NAME', $i++, $this->platform));
-        $this->assertEquals('COLUMNNAME_3', $this->strategy->getColumnAlias('COLUMN-NAME-', $i++, $this->platform));
+        self::assertEquals('columnName_0', $this->strategy->getColumnAlias('columnName', $i++, $this->platform));
+        self::assertEquals('column_name_1', $this->strategy->getColumnAlias('column_name', $i++, $this->platform));
+        self::assertEquals('COLUMN_NAME_2', $this->strategy->getColumnAlias('COLUMN_NAME', $i++, $this->platform));
+        self::assertEquals('COLUMNNAME_3', $this->strategy->getColumnAlias('COLUMN-NAME-', $i++, $this->platform));
     }
 
     public function testQuoteIdentifierJoinColumns(): void
@@ -154,7 +154,7 @@ class QuoteStrategyTest extends OrmTestCase
             ]
         );
 
-        $this->assertEquals(['"article"'], $this->strategy->getIdentifierColumnNames($cm, $this->platform));
+        self::assertEquals(['"article"'], $this->strategy->getIdentifierColumnNames($cm, $this->platform));
     }
 
     public function testJoinColumnName(): void
@@ -173,7 +173,7 @@ class QuoteStrategyTest extends OrmTestCase
         );
 
         $joinColumn = $cm->associationMappings['article']['joinColumns'][0];
-        $this->assertEquals('"article"', $this->strategy->getJoinColumnName($joinColumn, $cm, $this->platform));
+        self::assertEquals('"article"', $this->strategy->getJoinColumnName($joinColumn, $cm, $this->platform));
     }
 
     public function testReferencedJoinColumnName(): void
@@ -192,7 +192,7 @@ class QuoteStrategyTest extends OrmTestCase
         );
 
         $joinColumn = $cm->associationMappings['article']['joinColumns'][0];
-        $this->assertEquals('"id"', $this->strategy->getReferencedJoinColumnName($joinColumn, $cm, $this->platform));
+        self::assertEquals('"id"', $this->strategy->getReferencedJoinColumnName($joinColumn, $cm, $this->platform));
     }
 }
 
