@@ -34,7 +34,7 @@ class StaticPHPMappingDriverTest extends AbstractMappingDriverTest
      */
     public function testSchemaDefinitionViaExplicitTableSchemaAnnotationProperty(): void
     {
-        $this->markTestIncomplete();
+        self::markTestIncomplete();
     }
 
     /**
@@ -43,6 +43,16 @@ class StaticPHPMappingDriverTest extends AbstractMappingDriverTest
      */
     public function testSchemaDefinitionViaSchemaDefinedInTableNameInTableAnnotationProperty(): void
     {
-        $this->markTestIncomplete();
+        self::markTestIncomplete();
+    }
+
+    public function testEntityIncorrectIndexes(): void
+    {
+        self::markTestSkipped('Static PHP driver does not ensure index correctness');
+    }
+
+    public function testEntityIncorrectUniqueContraint(): void
+    {
+        self::markTestSkipped('Static PHP driver does not ensure index correctness');
     }
 }
