@@ -6,7 +6,6 @@ namespace Doctrine\Tests\ORM\Mapping\Symfony;
 
 use Doctrine\ORM\Mapping\Driver\SimplifiedYamlDriver;
 use Doctrine\Persistence\Mapping\Driver\FileDriver;
-use Doctrine\Tests\VerifyDeprecations;
 
 use function array_flip;
 
@@ -15,8 +14,6 @@ use function array_flip;
  */
 class YamlDriverTest extends AbstractDriverTest
 {
-    use VerifyDeprecations;
-
     protected function getFileExtension(): string
     {
         return '.orm.yml';
@@ -24,9 +21,6 @@ class YamlDriverTest extends AbstractDriverTest
 
     protected function getDriver(array $paths = []): FileDriver
     {
-        $driver = new SimplifiedYamlDriver(array_flip($paths));
-        $this->expectDeprecationMessageSame('YAML mapping driver is deprecated and will be removed in Doctrine ORM 3.0, please migrate to annotation or XML driver.');
-
-        return $driver;
+        return new SimplifiedYamlDriver(array_flip($paths));
     }
 }
