@@ -8,10 +8,10 @@ use Doctrine\ORM\Mapping\ClassMetadata;
 use Doctrine\ORM\Mapping\ClassMetadataFactory;
 use Doctrine\ORM\Mapping\Driver\YamlDriver;
 use Doctrine\Persistence\Mapping\Driver\MappingDriver;
+use Doctrine\Tests\Models\DDC3711\DDC3711EntityA;
 use Doctrine\Tests\Models\DirectoryTree\Directory;
 use Doctrine\Tests\Models\DirectoryTree\File;
 use Doctrine\Tests\Models\Generic\SerializationModel;
-use Doctrine\Tests\VerifyDeprecations;
 use Symfony\Component\Yaml\Yaml;
 
 use function class_exists;
@@ -20,12 +20,10 @@ use const DIRECTORY_SEPARATOR;
 
 class YamlMappingDriverTest extends AbstractMappingDriverTest
 {
-    use VerifyDeprecations;
-
     protected function loadDriver(): MappingDriver
     {
         if (! class_exists(Yaml::class, true)) {
-            $this->markTestSkipped('Please install Symfony YAML Component into the include path of your PHP installation.');
+            self::markTestSkipped('Please install Symfony YAML Component into the include path of your PHP installation.');
         }
 
         return new YamlDriver(__DIR__ . DIRECTORY_SEPARATOR . 'yaml');
@@ -48,12 +46,11 @@ class YamlMappingDriverTest extends AbstractMappingDriverTest
 
         $classPage = new ClassMetadata(File::class);
         $classPage = $factory->getMetadataFor(File::class);
-        $this->assertEquals(File::class, $classPage->associationMappings['parentDirectory']['sourceEntity']);
+        self::assertEquals(File::class, $classPage->associationMappings['parentDirectory']['sourceEntity']);
 
         $classDirectory = new ClassMetadata(Directory::class);
         $classDirectory = $factory->getMetadataFor(Directory::class);
-        $this->assertEquals(Directory::class, $classDirectory->associationMappings['parentDirectory']['sourceEntity']);
-        $this->assertHasDeprecationMessages();
+        self::assertEquals(Directory::class, $classDirectory->associationMappings['parentDirectory']['sourceEntity']);
     }
 
     /**
@@ -78,21 +75,30 @@ class YamlMappingDriverTest extends AbstractMappingDriverTest
         $nameField  = $metadata->fieldMappings['name'];
         $valueField = $metadata->fieldMappings['value'];
 
-        $this->assertEquals('name', $unique[0]);
-        $this->assertEquals('value', $unique[1]);
+        self::assertEquals('name', $unique[0]);
+        self::assertEquals('value', $unique[1]);
 
-        $this->assertEquals('value', $indexes[0]);
-        $this->assertEquals('name', $indexes[1]);
+        self::assertEquals('value', $indexes[0]);
+        self::assertEquals('name', $indexes[1]);
 
-        $this->assertEquals(255, $nameField['length']);
-        $this->assertEquals(255, $valueField['length']);
-        $this->assertHasDeprecationMessages();
+        self::assertEquals(255, $nameField['length']);
+        self::assertEquals(255, $valueField['length']);
     }
 
-    public function testDeprecation(): void
+    public function testCompositeKeyForJoinTableInManyToManyCreation(): void
     {
-        $this->createClassMetadata(DDC2069Entity::class);
-        $this->expectDeprecationMessageSame('YAML mapping driver is deprecated and will be removed in Doctrine ORM 3.0, please migrate to annotation or XML driver.');
+        $yamlDriver = $this->loadDriver();
+
+        $em = $this->getTestEntityManager();
+        $em->getConfiguration()->setMetadataDriverImpl($yamlDriver);
+        $factory = new ClassMetadataFactory();
+        $factory->setEntityManager($em);
+
+        $entityA = new ClassMetadata(DDC3711EntityA::class);
+        $entityA = $factory->getMetadataFor(DDC3711EntityA::class);
+
+        self::assertEquals(['link_a_id1' => 'id1', 'link_a_id2' => 'id2'], $entityA->associationMappings['entityB']['relationToSourceKeyColumns']);
+        self::assertEquals(['link_b_id1' => 'id1', 'link_b_id2' => 'id2'], $entityA->associationMappings['entityB']['relationToTargetKeyColumns']);
     }
 }
 
