@@ -1,18 +1,20 @@
 <?php
 
+declare(strict_types=1);
+
 use Doctrine\ORM\Mapping\ClassMetadataInfo;
 
 $metadata->mapField(
     [
-   'id'                 => true,
-   'fieldName'          => 'id',
+        'id'                 => true,
+        'fieldName'          => 'id',
     ]
 );
 
 $metadata->setDiscriminatorColumn(
     [
-    'name'              => "dtype",
-    'columnDefinition'  => "ENUM('ONE','TWO')"
+        'name'              => 'dtype',
+        'columnDefinition'  => "ENUM('ONE','TWO')",
     ]
 );
 
