@@ -8,7 +8,7 @@ use Doctrine\ORM\ORMInvalidArgumentException;
 use PHPUnit\Framework\TestCase;
 use stdClass;
 
-use function spl_object_hash;
+use function spl_object_id;
 use function uniqid;
 
 /**
@@ -30,16 +30,16 @@ class ORMInvalidArgumentExceptionTest extends TestCase
     }
 
     /**
-     * @return string[][]
+     * @psalm-return list<array{mixed, string}>
      */
     public function invalidEntityNames(): array
     {
         return [
-            [null, 'Entity name must be a string, NULL given'],
-            [true, 'Entity name must be a string, boolean given'],
-            [123, 'Entity name must be a string, integer given'],
-            [123.45, 'Entity name must be a string, double given'],
-            [new stdClass(), 'Entity name must be a string, object given'],
+            [null, 'Entity name must be a string, null given'],
+            [true, 'Entity name must be a string, bool given'],
+            [123, 'Entity name must be a string, int given'],
+            [123.45, 'Entity name must be a string, float given'],
+            [new stdClass(), 'Entity name must be a string, stdClass given'],
         ];
     }
 
@@ -87,7 +87,7 @@ class ORMInvalidArgumentExceptionTest extends TestCase
                     ],
                 ],
                 'A new entity was found through the relationship \'foo1#bar1\' that was not configured to cascade '
-                . 'persist operations for entity: stdClass@' . spl_object_hash($entity1)
+                . 'persist operations for entity: stdClass@' . spl_object_id($entity1)
                 . '. To solve this issue: Either explicitly call EntityManager#persist() on this unknown entity '
                 . 'or configure cascade persist this association in the mapping for example '
                 . '@ManyToOne(..,cascade={"persist"}). If you cannot find out which entity causes the problem '
@@ -106,13 +106,13 @@ class ORMInvalidArgumentExceptionTest extends TestCase
                 ],
                 'Multiple non-persisted new entities were found through the given association graph:' . "\n\n"
                 . ' * A new entity was found through the relationship \'foo1#bar1\' that was not configured to '
-                . 'cascade persist operations for entity: stdClass@' . spl_object_hash($entity1) . '. '
+                . 'cascade persist operations for entity: stdClass@' . spl_object_id($entity1) . '. '
                 . 'To solve this issue: Either explicitly call EntityManager#persist() on this unknown entity '
                 . 'or configure cascade persist this association in the mapping for example '
                 . '@ManyToOne(..,cascade={"persist"}). If you cannot find out which entity causes the problem '
                 . 'implement \'baz1#__toString()\' to get a clue.' . "\n"
                 . ' * A new entity was found through the relationship \'foo2#bar2\' that was not configured to '
-                . 'cascade persist operations for entity: stdClass@' . spl_object_hash($entity2) . '. To solve '
+                . 'cascade persist operations for entity: stdClass@' . spl_object_id($entity2) . '. To solve '
                 . 'this issue: Either explicitly call EntityManager#persist() on this unknown entity or '
                 . 'configure cascade persist this association in the mapping for example '
                 . '@ManyToOne(..,cascade={"persist"}). If you cannot find out which entity causes the problem '
