@@ -5,7 +5,7 @@ declare(strict_types=1);
 namespace Doctrine\Tests\ORM\Persisters;
 
 use Doctrine\Common\Collections\Criteria;
-use Doctrine\ORM\EntityManager;
+use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\ORM\Persisters\Entity\BasicEntityPersister;
 use Doctrine\Tests\Models\GeoNames\Admin1;
 use Doctrine\Tests\Models\GeoNames\Admin1AlternateName;
@@ -17,7 +17,7 @@ class BasicEntityPersisterCompositeTypeParametersTest extends OrmTestCase
     /** @var BasicEntityPersister */
     protected $persister;
 
-    /** @var EntityManager */
+    /** @var EntityManagerInterface */
     protected $entityManager;
 
     protected function setUp(): void
@@ -40,8 +40,8 @@ class BasicEntityPersisterCompositeTypeParametersTest extends OrmTestCase
 
         [$values, $types] = $this->persister->expandParameters(['admin1' => $admin1]);
 
-        $this->assertEquals(['integer', 'string'], $types);
-        $this->assertEquals([10, 'IT'], $values);
+        self::assertEquals(['integer', 'string'], $types);
+        self::assertEquals([10, 'IT'], $values);
     }
 
     public function testExpandCriteriaParametersWillExpandCompositeEntityKeys(): void
@@ -54,7 +54,7 @@ class BasicEntityPersisterCompositeTypeParametersTest extends OrmTestCase
 
         [$values, $types] = $this->persister->expandCriteriaParameters($criteria);
 
-        $this->assertEquals(['integer', 'string'], $types);
-        $this->assertEquals([10, 'IT'], $values);
+        self::assertEquals(['integer', 'string'], $types);
+        self::assertEquals([10, 'IT'], $values);
     }
 }
