@@ -4,16 +4,15 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\ORM\Repository;
 
+use Closure;
 use Doctrine\ORM\Configuration;
 use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\ORM\Mapping\ClassMetadata;
 use Doctrine\ORM\Repository\DefaultRepositoryFactory;
 use Doctrine\Tests\Models\DDC753\DDC753DefaultRepository;
 use Doctrine\Tests\Models\DDC869\DDC869PaymentRepository;
+use PHPUnit\Framework\MockObject\MockObject;
 use PHPUnit\Framework\TestCase;
-use PHPUnit_Framework_MockObject_MockObject;
-
-use function assert;
 
 /**
  * Tests for {@see \Doctrine\ORM\Repository\DefaultRepositoryFactory}
@@ -22,10 +21,10 @@ use function assert;
  */
 class DefaultRepositoryFactoryTest extends TestCase
 {
-    /** @var EntityManagerInterface|PHPUnit_Framework_MockObject_MockObject */
+    /** @var EntityManagerInterface&MockObject */
     private $entityManager;
 
-    /** @var Configuration|PHPUnit_Framework_MockObject_MockObject */
+    /** @var Configuration&MockObject */
     private $configuration;
 
     /** @var DefaultRepositoryFactory */
@@ -38,19 +37,19 @@ class DefaultRepositoryFactoryTest extends TestCase
         $this->repositoryFactory = new DefaultRepositoryFactory();
 
         $this->configuration
-            ->expects($this->any())
+            ->expects(self::any())
             ->method('getDefaultRepositoryClassName')
-            ->will($this->returnValue(DDC869PaymentRepository::class));
+            ->will(self::returnValue(DDC869PaymentRepository::class));
     }
 
     public function testCreatesRepositoryFromDefaultRepositoryClass(): void
     {
         $this->entityManager
-            ->expects($this->any())
+            ->expects(self::any())
             ->method('getClassMetadata')
-            ->will($this->returnCallback([$this, 'buildClassMetadata']));
+            ->will(self::returnCallback(Closure::fromCallable([$this, 'buildClassMetadata'])));
 
-        $this->assertInstanceOf(
+        self::assertInstanceOf(
             DDC869PaymentRepository::class,
             $this->repositoryFactory->getRepository($this->entityManager, self::class)
         );
@@ -59,11 +58,11 @@ class DefaultRepositoryFactoryTest extends TestCase
     public function testCreatedRepositoriesAreCached(): void
     {
         $this->entityManager
-            ->expects($this->any())
+            ->expects(self::any())
             ->method('getClassMetadata')
-            ->will($this->returnCallback([$this, 'buildClassMetadata']));
+            ->will(self::returnCallback(Closure::fromCallable([$this, 'buildClassMetadata'])));
 
-        $this->assertSame(
+        self::assertSame(
             $this->repositoryFactory->getRepository($this->entityManager, self::class),
             $this->repositoryFactory->getRepository($this->entityManager, self::class)
         );
@@ -75,11 +74,11 @@ class DefaultRepositoryFactoryTest extends TestCase
         $customMetadata->customRepositoryClassName = DDC753DefaultRepository::class;
 
         $this->entityManager
-            ->expects($this->any())
+            ->expects(self::any())
             ->method('getClassMetadata')
-            ->will($this->returnValue($customMetadata));
+            ->will(self::returnValue($customMetadata));
 
-        $this->assertInstanceOf(
+        self::assertInstanceOf(
             DDC753DefaultRepository::class,
             $this->repositoryFactory->getRepository($this->entityManager, self::class)
         );
@@ -90,34 +89,30 @@ class DefaultRepositoryFactoryTest extends TestCase
         $em1 = $this->createEntityManager();
         $em2 = $this->createEntityManager();
 
-        $em1->expects($this->any())
+        $em1->expects(self::any())
             ->method('getClassMetadata')
-            ->will($this->returnCallback([$this, 'buildClassMetadata']));
+            ->will(self::returnCallback(Closure::fromCallable([$this, 'buildClassMetadata'])));
 
-        $em2->expects($this->any())
+        $em2->expects(self::any())
             ->method('getClassMetadata')
-            ->will($this->returnCallback([$this, 'buildClassMetadata']));
+            ->will(self::returnCallback(Closure::fromCallable([$this, 'buildClassMetadata'])));
 
         $repo1 = $this->repositoryFactory->getRepository($em1, self::class);
         $repo2 = $this->repositoryFactory->getRepository($em2, self::class);
 
-        $this->assertSame($repo1, $this->repositoryFactory->getRepository($em1, self::class));
-        $this->assertSame($repo2, $this->repositoryFactory->getRepository($em2, self::class));
+        self::assertSame($repo1, $this->repositoryFactory->getRepository($em1, self::class));
+        self::assertSame($repo2, $this->repositoryFactory->getRepository($em2, self::class));
 
-        $this->assertNotSame($repo1, $repo2);
+        self::assertNotSame($repo1, $repo2);
     }
 
     /**
-     * @return PHPUnit_Framework_MockObject_MockObject|ClassMetadata
-     *
-     * @private
+     * @return ClassMetadata&MockObject
      */
-    public function buildClassMetadata(string $className)
+    private function buildClassMetadata(string $className): ClassMetadata
     {
         $metadata = $this->createMock(ClassMetadata::class);
-        assert($metadata instanceof ClassMetadata || $metadata instanceof PHPUnit_Framework_MockObject_MockObject);
-
-        $metadata->expects($this->any())->method('getName')->will($this->returnValue($className));
+        $metadata->expects(self::any())->method('getName')->will(self::returnValue($className));
 
         $metadata->customRepositoryClassName = null;
 
@@ -125,15 +120,15 @@ class DefaultRepositoryFactoryTest extends TestCase
     }
 
     /**
-     * @return EntityManagerInterface|PHPUnit_Framework_MockObject_MockObject
+     * @return EntityManagerInterface&MockObject
      */
     private function createEntityManager(): EntityManagerInterface
     {
         $entityManager = $this->createMock(EntityManagerInterface::class);
 
-        $entityManager->expects($this->any())
+        $entityManager->expects(self::any())
             ->method('getConfiguration')
-            ->will($this->returnValue($this->configuration));
+            ->will(self::returnValue($this->configuration));
 
         return $entityManager;
     }
