@@ -7,21 +7,12 @@ namespace Doctrine\Tests\ORM\Tools\Console\Command;
 use Doctrine\ORM\Tools\Console\Command\ConvertDoctrine1SchemaCommand;
 use Doctrine\ORM\Tools\EntityGenerator;
 use Doctrine\Tests\OrmTestCase;
-use Doctrine\Tests\VerifyDeprecations;
 use Symfony\Component\Console\Output\OutputInterface;
 
 use function sys_get_temp_dir;
 
 class ConvertDoctrine1SchemaCommandTest extends OrmTestCase
 {
-    use VerifyDeprecations;
-
-    /** @after */
-    public function ensureTestGeneratedDeprecationMessages(): void
-    {
-        $this->assertHasDeprecationMessages();
-    }
-
     public function testExecution(): void
     {
         $entityGenerator = $this->createMock(EntityGenerator::class);
@@ -29,9 +20,9 @@ class ConvertDoctrine1SchemaCommandTest extends OrmTestCase
         $command->setEntityGenerator($entityGenerator);
 
         $output = $this->createMock(OutputInterface::class);
-        $output->expects($this->once())
+        $output->expects(self::once())
                ->method('writeln')
-               ->with($this->equalTo('No Metadata Classes to process.'));
+               ->with(self::equalTo('No Metadata Classes to process.'));
 
         $command->convertDoctrine1Schema([], sys_get_temp_dir(), 'annotation', 4, null, $output);
     }
