@@ -22,7 +22,7 @@ class CountWalkerTest extends PaginationTestCase
         $query->setHint(CountWalker::HINT_DISTINCT, true);
         $query->setFirstResult(null)->setMaxResults(null);
 
-        $this->assertEquals(
+        self::assertEquals(
             'SELECT count(DISTINCT b0_.id) AS sclr_0 FROM BlogPost b0_ INNER JOIN Category c1_ ON b0_.category_id = c1_.id INNER JOIN Author a2_ ON b0_.author_id = a2_.id',
             $query->getSQL()
         );
@@ -37,7 +37,7 @@ class CountWalkerTest extends PaginationTestCase
         $query->setHint(CountWalker::HINT_DISTINCT, true);
         $query->setFirstResult(null)->setMaxResults(null);
 
-        $this->assertEquals(
+        self::assertEquals(
             'SELECT count(DISTINCT a0_.id) AS sclr_0 FROM Author a0_',
             $query->getSQL()
         );
@@ -52,7 +52,7 @@ class CountWalkerTest extends PaginationTestCase
         $query->setHint(CountWalker::HINT_DISTINCT, true);
         $query->setFirstResult(null)->setMaxResults(null);
 
-        $this->assertEquals(
+        self::assertEquals(
             'SELECT count(DISTINCT b0_.id) AS sclr_0 FROM BlogPost b0_ GROUP BY b0_.id',
             $query->getSQL()
         );
@@ -67,7 +67,7 @@ class CountWalkerTest extends PaginationTestCase
         $query->setHint(CountWalker::HINT_DISTINCT, true);
         $query->setFirstResult(null)->setMaxResults(null);
 
-        $this->assertEquals(
+        self::assertEquals(
             'SELECT count(DISTINCT b0_.id) AS sclr_0 FROM BlogPost b0_ INNER JOIN Category c1_ ON b0_.category_id = c1_.id INNER JOIN Author a2_ ON b0_.author_id = a2_.id',
             $query->getSQL()
         );
@@ -82,7 +82,7 @@ class CountWalkerTest extends PaginationTestCase
         $query->setHint(CountWalker::HINT_DISTINCT, true);
         $query->setFirstResult(null)->setMaxResults(null);
 
-        $this->assertEquals(
+        self::assertEquals(
             'SELECT count(DISTINCT b0_.id) AS sclr_0 FROM BlogPost b0_ INNER JOIN Category c1_ ON b0_.category_id = c1_.id INNER JOIN Author a2_ ON b0_.author_id = a2_.id',
             $query->getSQL()
         );
@@ -114,7 +114,7 @@ class CountWalkerTest extends PaginationTestCase
         $query->setHint(CountWalker::HINT_DISTINCT, true);
         $query->setFirstResult(null)->setMaxResults(null);
 
-        $this->assertEquals(
+        self::assertEquals(
             'SELECT count(DISTINCT b0_.id) AS sclr_0 FROM BlogPost b0_ LEFT JOIN Category c1_ ON (b0_.category_id = c1_.id)',
             $query->getSQL()
         );
