@@ -20,7 +20,7 @@ class LimitSubqueryWalkerTest extends PaginationTestCase
 
         $limitQuery->setHint(Query::HINT_CUSTOM_TREE_WALKERS, [LimitSubqueryWalker::class]);
 
-        $this->assertEquals(
+        self::assertEquals(
             'SELECT DISTINCT m0_.id AS id_0 FROM MyBlogPost m0_ INNER JOIN Category c1_ ON m0_.category_id = c1_.id INNER JOIN Author a2_ ON m0_.author_id = a2_.id',
             $limitQuery->getSQL()
         );
@@ -34,7 +34,7 @@ class LimitSubqueryWalkerTest extends PaginationTestCase
 
         $limitQuery->setHint(Query::HINT_CUSTOM_TREE_WALKERS, [LimitSubqueryWalker::class]);
 
-        $this->assertEquals(
+        self::assertEquals(
             'SELECT DISTINCT m0_.id AS id_0, m0_.title AS title_1 FROM MyBlogPost m0_ INNER JOIN Category c1_ ON m0_.category_id = c1_.id INNER JOIN Author a2_ ON m0_.author_id = a2_.id ORDER BY m0_.title ASC',
             $limitQuery->getSQL()
         );
@@ -62,7 +62,7 @@ class LimitSubqueryWalkerTest extends PaginationTestCase
 
         $limitQuery->setHint(Query::HINT_CUSTOM_TREE_WALKERS, [LimitSubqueryWalker::class]);
 
-        $this->assertEquals(
+        self::assertEquals(
             'SELECT DISTINCT a0_.id AS id_0 FROM Author a0_',
             $limitQuery->getSQL()
         );
@@ -107,7 +107,7 @@ class LimitSubqueryWalkerTest extends PaginationTestCase
 
         $limitQuery->setHint(Query::HINT_CUSTOM_TREE_WALKERS, [LimitSubqueryWalker::class]);
 
-        $this->assertEquals(
+        self::assertEquals(
             'SELECT DISTINCT m0_.id AS id_0, m0_.author_id AS sclr_1 FROM MyBlogPost m0_ ORDER BY m0_.author_id ASC',
             $limitQuery->getSQL()
         );
@@ -124,7 +124,7 @@ class LimitSubqueryWalkerTest extends PaginationTestCase
 
         $limitQuery->setHint(Query::HINT_CUSTOM_TREE_WALKERS, [LimitSubqueryWalker::class]);
 
-        $this->assertEquals(
+        self::assertEquals(
             'SELECT DISTINCT m0_.id AS id_0 FROM MyBlogPost m0_ INNER JOIN Category c1_ ON (m0_.category_id = c1_.id)',
             $limitQuery->getSQL()
         );
@@ -138,7 +138,7 @@ class LimitSubqueryWalkerTest extends PaginationTestCase
 
         $limitQuery->setHint(Query::HINT_CUSTOM_TREE_WALKERS, [LimitSubqueryWalker::class]);
 
-        $this->assertEquals(
+        self::assertEquals(
             'SELECT DISTINCT m0_.id AS id_0, m0_.title AS title_1 FROM MyBlogPost m0_ INNER JOIN Category c1_ ON (m0_.category_id = c1_.id) ORDER BY m0_.title ASC',
             $limitQuery->getSQL()
         );
