@@ -13,14 +13,15 @@ use Doctrine\ORM\Tools\Pagination\Paginator;
 use Doctrine\Tests\Mocks\ConnectionMock;
 use Doctrine\Tests\Mocks\DriverMock;
 use Doctrine\Tests\OrmTestCase;
+use PHPUnit\Framework\MockObject\MockObject;
 
 class PaginatorTest extends OrmTestCase
 {
-    /** @var Connection */
+    /** @var Connection&MockObject */
     private $connection;
-    /** @var EntityManagerInterface */
+    /** @var EntityManagerInterface&MockObject */
     private $em;
-    /** @var AbstractHydrator */
+    /** @var AbstractHydrator&MockObject */
     private $hydrator;
 
     protected function setUp(): void
@@ -62,19 +63,14 @@ class PaginatorTest extends OrmTestCase
         $query->setMaxResults(1);
         $paginator = (new Paginator($query, true))->setUseOutputWalkers(false);
 
-        $this->connection->expects($this->exactly(3))->method('executeQuery');
-
-        $this->connection->expects($this->at(0))
+        $this->connection
+            ->expects(self::exactly(3))
             ->method('executeQuery')
-            ->with($this->anything(), [$paramInWhere]);
-
-        $this->connection->expects($this->at(1))
-            ->method('executeQuery')
-            ->with($this->anything(), [$paramInWhere]);
-
-        $this->connection->expects($this->at(2))
-            ->method('executeQuery')
-            ->with($this->anything(), [$paramInSubSelect, $paramInWhere, $returnedIds]);
+            ->withConsecutive(
+                [self::anything(), [$paramInWhere]],
+                [self::anything(), [$paramInWhere]],
+                [self::anything(), [$paramInSubSelect, $paramInWhere, $returnedIds]]
+            );
 
         $paginator->count();
         $paginator->getIterator();
@@ -82,7 +78,7 @@ class PaginatorTest extends OrmTestCase
 
     public function testPaginatorNotCaringAboutExtraParametersWithoutOutputWalkers(): void
     {
-        $this->connection->expects($this->exactly(3))->method('executeQuery');
+        $this->connection->expects(self::exactly(3))->method('executeQuery');
 
         $this->createPaginatorWithExtraParametersWithoutOutputWalkers([])->count();
         $this->createPaginatorWithExtraParametersWithoutOutputWalkers([[10]])->count();
@@ -91,7 +87,7 @@ class PaginatorTest extends OrmTestCase
 
     public function testgetIteratorDoesCareAboutExtraParametersWithoutOutputWalkersWhenResultIsNotEmpty(): void
     {
-        $this->connection->expects($this->exactly(1))->method('executeQuery');
+        $this->connection->expects(self::exactly(1))->method('executeQuery');
         $this->expectException(Query\QueryException::class);
         $this->expectExceptionMessage('Too many parameters: the query defines 1 parameters and you bound 2');
 
@@ -104,7 +100,7 @@ class PaginatorTest extends OrmTestCase
     private function createPaginatorWithExtraParametersWithoutOutputWalkers(array $willReturnRows): Paginator
     {
         $this->hydrator->method('hydrateAll')->willReturn($willReturnRows);
-        $this->connection->method('executeQuery')->with($this->anything(), []);
+        $this->connection->method('executeQuery')->with(self::anything(), []);
 
         $query = new Query($this->em);
         $query->setDQL('SELECT u FROM Doctrine\\Tests\\Models\\CMS\\CmsUser u');
