@@ -6,10 +6,25 @@ namespace Doctrine\Tests\ORM\Tools;
 
 use Doctrine\Common\Collections\Collection;
 use Doctrine\ORM\Mapping\ClassMetadata;
+use Doctrine\ORM\Mapping\ClassMetadataInfo;
+use Doctrine\ORM\Mapping\Column;
+use Doctrine\ORM\Mapping\Entity;
+use Doctrine\ORM\Mapping\Id;
+use Doctrine\ORM\Mapping\Index;
+use Doctrine\ORM\Mapping\JoinColumn;
+use Doctrine\ORM\Mapping\ManyToOne;
+use Doctrine\ORM\Mapping\MappingException;
+use Doctrine\ORM\Mapping\OneToMany;
+use Doctrine\ORM\Mapping\OneToOne;
+use Doctrine\ORM\Mapping\Table;
+use Doctrine\ORM\Mapping\UnderscoreNamingStrategy;
+use Doctrine\ORM\Mapping\UniqueConstraint;
 use Doctrine\ORM\Tools\Event\GenerateSchemaEventArgs;
 use Doctrine\ORM\Tools\Event\GenerateSchemaTableEventArgs;
 use Doctrine\ORM\Tools\SchemaTool;
 use Doctrine\ORM\Tools\ToolEvents;
+use Doctrine\Persistence\Mapping\Driver\StaticPHPDriver;
+use Doctrine\Persistence\Mapping\RuntimeReflectionService;
 use Doctrine\Tests\Models\CMS\CmsAddress;
 use Doctrine\Tests\Models\CMS\CmsArticle;
 use Doctrine\Tests\Models\CMS\CmsComment;
@@ -20,6 +35,8 @@ use Doctrine\Tests\Models\CMS\CmsUser;
 use Doctrine\Tests\Models\CompositeKeyInheritance\JoinedDerivedChildClass;
 use Doctrine\Tests\Models\CompositeKeyInheritance\JoinedDerivedIdentityClass;
 use Doctrine\Tests\Models\CompositeKeyInheritance\JoinedDerivedRootClass;
+use Doctrine\Tests\Models\Enums\Card;
+use Doctrine\Tests\Models\Enums\Suit;
 use Doctrine\Tests\Models\Forum\ForumAvatar;
 use Doctrine\Tests\Models\Forum\ForumUser;
 use Doctrine\Tests\Models\NullDefault\NullDefaultColumn;
@@ -47,8 +64,8 @@ class SchemaToolTest extends OrmTestCase
 
         $schema = $schemaTool->getSchemaFromMetadata($classes);
 
-        $this->assertTrue($schema->hasTable('cms_users'), 'Table cms_users should exist.');
-        $this->assertTrue($schema->getTable('cms_users')->columnsAreIndexed(['username']), 'username column should be indexed.');
+        self::assertTrue($schema->hasTable('cms_users'), 'Table cms_users should exist.');
+        self::assertTrue($schema->getTable('cms_users')->columnsAreIndexed(['username']), 'username column should be indexed.');
     }
 
     public function testAnnotationOptionsAttribute(): void
@@ -87,10 +104,10 @@ class SchemaToolTest extends OrmTestCase
 
         $schema = $schemaTool->getSchemaFromMetadata($classes);
 
-        $this->assertTrue($schema->hasTable('forum_users'));
+        self::assertTrue($schema->hasTable('forum_users'));
         $table = $schema->getTable('forum_users');
-        $this->assertTrue($table->hasColumn('avatar_id'));
-        $this->assertEquals($customColumnDef, $table->getColumn('avatar_id')->getColumnDefinition());
+        self::assertTrue($table->hasColumn('avatar_id'));
+        self::assertEquals($customColumnDef, $table->getColumn('avatar_id')->getColumnDefinition());
     }
 
     /**
@@ -157,8 +174,8 @@ class SchemaToolTest extends OrmTestCase
 
         $schema = $schemaTool->getSchemaFromMetadata($classes);
 
-        $this->assertEquals(count($classes), $listener->tableCalls);
-        $this->assertTrue($listener->schemaCalled);
+        self::assertEquals(count($classes), $listener->tableCalls);
+        self::assertTrue($listener->schemaCalled);
     }
 
     public function testNullDefaultNotAddedToCustomSchemaOptions(): void
@@ -171,7 +188,24 @@ class SchemaToolTest extends OrmTestCase
             ->getColumn('nullDefault')
             ->getCustomSchemaOptions();
 
-        $this->assertSame([], $customSchemaOptions);
+        self::assertSame([], $customSchemaOptions);
+    }
+
+    /**
+     * @requires PHP 8.1
+     */
+    public function testEnumTypeAddedToCustomSchemaOptions(): void
+    {
+        $em         = $this->getTestEntityManager();
+        $schemaTool = new SchemaTool($em);
+
+        $customSchemaOptions = $schemaTool->getSchemaFromMetadata([$em->getClassMetadata(Card::class)])
+            ->getTable('Card')
+            ->getColumn('suit')
+            ->getCustomSchemaOptions();
+
+        self::assertArrayHasKey('enumType', $customSchemaOptions);
+        self::assertSame(Suit::class, $customSchemaOptions['enumType']);
     }
 
     /**
@@ -187,12 +221,12 @@ class SchemaToolTest extends OrmTestCase
 
         $schema = $schemaTool->getSchemaFromMetadata($classes);
 
-        $this->assertTrue($schema->hasTable('unique_constraint_annotation_table'));
+        self::assertTrue($schema->hasTable('unique_constraint_annotation_table'));
         $table = $schema->getTable('unique_constraint_annotation_table');
 
-        $this->assertEquals(2, count($table->getIndexes()));
-        $this->assertTrue($table->hasIndex('primary'));
-        $this->assertTrue($table->hasIndex('uniq_hash'));
+        self::assertCount(2, $table->getIndexes());
+        self::assertTrue($table->hasIndex('primary'));
+        self::assertTrue($table->hasIndex('uniq_hash'));
     }
 
     public function testRemoveUniqueIndexOverruledByPrimaryKey(): void
@@ -206,12 +240,12 @@ class SchemaToolTest extends OrmTestCase
 
         $schema = $schemaTool->getSchemaFromMetadata($classes);
 
-        $this->assertTrue($schema->hasTable('first_entity'), 'Table first_entity should exist.');
+        self::assertTrue($schema->hasTable('first_entity'), 'Table first_entity should exist.');
 
         $indexes = $schema->getTable('first_entity')->getIndexes();
 
-        $this->assertCount(1, $indexes, 'there should be only one index');
-        $this->assertTrue(current($indexes)->isPrimary(), 'index should be primary');
+        self::assertCount(1, $indexes, 'there should be only one index');
+        self::assertTrue(current($indexes)->isPrimary(), 'index should be primary');
     }
 
     public function testSetDiscriminatorColumnWithoutLength(): void
@@ -225,13 +259,13 @@ class SchemaToolTest extends OrmTestCase
 
         $schema = $schemaTool->getSchemaFromMetadata([$metadata]);
 
-        $this->assertTrue($schema->hasTable('first_entity'));
+        self::assertTrue($schema->hasTable('first_entity'));
         $table = $schema->getTable('first_entity');
 
-        $this->assertTrue($table->hasColumn('discriminator'));
+        self::assertTrue($table->hasColumn('discriminator'));
         $column = $table->getColumn('discriminator');
 
-        $this->assertEquals(255, $column->getLength());
+        self::assertEquals(255, $column->getLength());
     }
 
     public function testDerivedCompositeKey(): void
@@ -277,6 +311,80 @@ class SchemaToolTest extends OrmTestCase
             self::assertSame($foreignColumns, $foreignKey->getForeignColumns());
         }
     }
+
+    public function testIndexesBasedOnFields(): void
+    {
+        $em = $this->getTestEntityManager();
+        $em->getConfiguration()->setNamingStrategy(new UnderscoreNamingStrategy());
+
+        $schemaTool = new SchemaTool($em);
+        $metadata   = $em->getClassMetadata(IndexByFieldEntity::class);
+        $schema     = $schemaTool->getSchemaFromMetadata([$metadata]);
+        $table      = $schema->getTable('field_index');
+
+        self::assertEquals(['index', 'field_name'], $table->getIndex('index')->getColumns());
+        self::assertEquals(['index', 'table'], $table->getIndex('uniq')->getColumns());
+    }
+
+    public function testIncorrectIndexesBasedOnFields(): void
+    {
+        $em = $this->getTestEntityManager();
+        $em->getConfiguration()->setNamingStrategy(new UnderscoreNamingStrategy());
+
+        $schemaTool    = new SchemaTool($em);
+        $mappingDriver = new StaticPHPDriver([]);
+        $class         = new ClassMetadata(IncorrectIndexByFieldEntity::class);
+
+        $class->initializeReflection(new RuntimeReflectionService());
+        $mappingDriver->loadMetadataForClass(IncorrectIndexByFieldEntity::class, $class);
+
+        $this->expectException(MappingException::class);
+        $schemaTool->getSchemaFromMetadata([$class]);
+    }
+
+    public function testIncorrectUniqueConstraintsBasedOnFields(): void
+    {
+        $em = $this->getTestEntityManager();
+        $em->getConfiguration()->setNamingStrategy(new UnderscoreNamingStrategy());
+
+        $schemaTool    = new SchemaTool($em);
+        $mappingDriver = new StaticPHPDriver([]);
+        $class         = new ClassMetadata(IncorrectUniqueConstraintByFieldEntity::class);
+
+        $class->initializeReflection(new RuntimeReflectionService());
+        $mappingDriver->loadMetadataForClass(IncorrectUniqueConstraintByFieldEntity::class, $class);
+
+        $this->expectException(MappingException::class);
+        $schemaTool->getSchemaFromMetadata([$class]);
+    }
+
+    /**
+     * @group schema-configuration
+     */
+    public function testConfigurationSchemaIgnoredEntity(): void
+    {
+        $em         = $this->getTestEntityManager();
+        $schemaTool = new SchemaTool($em);
+
+        $classes = [
+            $em->getClassMetadata(FirstEntity::class),
+            $em->getClassMetadata(SecondEntity::class),
+        ];
+
+        $schema = $schemaTool->getSchemaFromMetadata($classes);
+
+        self::assertTrue($schema->hasTable('first_entity'), 'Table first_entity should exist.');
+        self::assertTrue($schema->hasTable('second_entity'), 'Table second_entity should exist.');
+
+        $em->getConfiguration()->setSchemaIgnoreClasses([
+            SecondEntity::class,
+        ]);
+
+        $schema = $schemaTool->getSchemaFromMetadata($classes);
+
+        self::assertTrue($schema->hasTable('first_entity'), 'Table first_entity should exist.');
+        self::assertFalse($schema->hasTable('second_entity'), 'Table second_entity should not exist.');
+    }
 }
 
 /**
@@ -425,3 +533,121 @@ class GH6830Category
      */
     public $boards;
 }
+
+/**
+ * @Entity
+ * @Table(
+ *     name="field_index",
+ *     indexes={
+ *         @Index(name="index", fields={"index", "fieldName"}),
+ *     },
+ *     uniqueConstraints={
+ *         @UniqueConstraint(name="uniq", fields={"index", "table"})
+ *     }
+ * )
+ */
+class IndexByFieldEntity
+{
+    /**
+     * @var int
+     * @Id
+     * @Column(type="integer")
+     */
+    public $id;
+
+    /**
+     * @var string
+     * @Column
+     */
+    public $index;
+
+    /**
+     * @var string
+     * @Column
+     */
+    public $table;
+
+    /**
+     * @var string
+     * @Column
+     */
+    public $fieldName;
+}
+
+class IncorrectIndexByFieldEntity
+{
+    /** @var int */
+    public $id;
+
+    /** @var string */
+    public $index;
+
+    /** @var string */
+    public $table;
+
+    /** @var string */
+    public $fieldName;
+
+    public static function loadMetadata(ClassMetadataInfo $metadata): void
+    {
+        $metadata->mapField(
+            [
+                'id'                 => true,
+                'fieldName'          => 'id',
+            ]
+        );
+
+        $metadata->mapField(['fieldName' => 'index']);
+
+        $metadata->mapField(['fieldName' => 'table']);
+
+        $metadata->mapField(['fieldName' => 'fieldName']);
+
+        $metadata->setPrimaryTable(
+            [
+                'indexes' => [
+                    ['columns' => ['index'], 'fields' => ['fieldName']],
+                ],
+            ]
+        );
+    }
+}
+
+class IncorrectUniqueConstraintByFieldEntity
+{
+    /** @var int */
+    public $id;
+
+    /** @var string */
+    public $index;
+
+    /** @var string */
+    public $table;
+
+    /** @var string */
+    public $fieldName;
+
+    public static function loadMetadata(ClassMetadataInfo $metadata): void
+    {
+        $metadata->mapField(
+            [
+                'id'                 => true,
+                'fieldName'          => 'id',
+            ]
+        );
+
+        $metadata->mapField(['fieldName' => 'index']);
+
+        $metadata->mapField(['fieldName' => 'table']);
+
+        $metadata->mapField(['fieldName' => 'fieldName']);
+
+        $metadata->setPrimaryTable(
+            [
+                'uniqueConstraints' => [
+                    ['columns' => ['index'], 'fields' => ['fieldName']],
+                ],
+            ]
+        );
+    }
+}
