@@ -5,15 +5,31 @@ declare(strict_types=1);
 namespace Doctrine\Tests\ORM\Tools;
 
 use Doctrine\Common\Collections\ArrayCollection;
-use Doctrine\ORM\EntityManager;
+use Doctrine\Common\Collections\Collection;
+use Doctrine\ORM\EntityManagerInterface;
+use Doctrine\ORM\Mapping\Column;
+use Doctrine\ORM\Mapping\DiscriminatorMap;
+use Doctrine\ORM\Mapping\Embeddable;
+use Doctrine\ORM\Mapping\Entity;
+use Doctrine\ORM\Mapping\GeneratedValue;
+use Doctrine\ORM\Mapping\Id;
+use Doctrine\ORM\Mapping\InheritanceType;
+use Doctrine\ORM\Mapping\JoinColumn;
+use Doctrine\ORM\Mapping\JoinTable;
+use Doctrine\ORM\Mapping\ManyToMany;
+use Doctrine\ORM\Mapping\ManyToOne;
+use Doctrine\ORM\Mapping\MappedSuperclass;
+use Doctrine\ORM\Mapping\OneToMany;
 use Doctrine\ORM\Mapping\OneToOne;
+use Doctrine\ORM\Mapping\OrderBy;
+use Doctrine\ORM\Mapping\Table;
 use Doctrine\ORM\Tools\SchemaValidator;
 use Doctrine\Tests\Models\ECommerce\ECommerceCart;
 use Doctrine\Tests\OrmTestCase;
 
 class SchemaValidatorTest extends OrmTestCase
 {
-    /** @var EntityManager */
+    /** @var EntityManagerInterface */
     private $em = null;
 
     /** @var SchemaValidator */
@@ -59,7 +75,7 @@ class SchemaValidatorTest extends OrmTestCase
 
         $ce = $this->validator->validateClass($class1);
 
-        $this->assertEquals(
+        self::assertEquals(
             [
                 "The inverse join columns of the many-to-many table 'Entity1Entity2' have to contain to ALL identifier columns of the target entity 'Doctrine\Tests\ORM\Tools\InvalidEntity2', however 'key4' are missing.",
                 "The join columns of the many-to-many table 'Entity1Entity2' have to contain to ALL identifier columns of the source entity 'Doctrine\Tests\ORM\Tools\InvalidEntity1', however 'key2' are missing.",
@@ -78,7 +94,7 @@ class SchemaValidatorTest extends OrmTestCase
 
         $ce = $this->validator->validateClass($class2);
 
-        $this->assertEquals(
+        self::assertEquals(
             [
                 "The referenced column name 'id' has to be a primary key column on the target entity class 'Doctrine\Tests\ORM\Tools\InvalidEntity1'.",
                 "The join columns of the association 'assoc' have to match to ALL identifier columns of the target entity 'Doctrine\Tests\ORM\Tools\InvalidEntity1', however 'key1, key2' are missing.",
@@ -97,7 +113,7 @@ class SchemaValidatorTest extends OrmTestCase
 
         $ce = $this->validator->validateClass($class1);
 
-        $this->assertEquals([], $ce);
+        self::assertEquals([], $ce);
     }
 
     /**
@@ -108,7 +124,7 @@ class SchemaValidatorTest extends OrmTestCase
         $classThree = $this->em->getClassMetadata(DDC1649Three::class);
         $ce         = $this->validator->validateClass($classThree);
 
-        $this->assertEquals(
+        self::assertEquals(
             [
                 "Cannot map association 'Doctrine\Tests\ORM\Tools\DDC1649Three#two as identifier, because the target entity 'Doctrine\Tests\ORM\Tools\DDC1649Two' also maps an association as identifier.",
                 "The referenced column name 'id' has to be a primary key column on the target entity class 'Doctrine\Tests\ORM\Tools\DDC1649Two'.",
@@ -125,7 +141,7 @@ class SchemaValidatorTest extends OrmTestCase
         $class = $this->em->getClassMetadata(DDC3274One::class);
         $ce    = $this->validator->validateClass($class);
 
-        $this->assertEquals(
+        self::assertEquals(
             [
                 'The field Doctrine\Tests\ORM\Tools\DDC3274One#two is on the inverse side of a bi-directional ' .
                 'relationship, but the specified mappedBy association on the target-entity ' .
@@ -143,7 +159,7 @@ class SchemaValidatorTest extends OrmTestCase
         $class = $this->em->getClassMetadata(DDC3322One::class);
         $ce    = $this->validator->validateClass($class);
 
-        $this->assertEquals(
+        self::assertEquals(
             [
                 'The association Doctrine\Tests\ORM\Tools\DDC3322One#invalidAssoc is ordered by a foreign field ' .
                 'invalidField that is not a field on the target entity Doctrine\Tests\ORM\Tools\DDC3322ValidEntity1.',
@@ -160,7 +176,7 @@ class SchemaValidatorTest extends OrmTestCase
         $class = $this->em->getClassMetadata(DDC3322Two::class);
         $ce    = $this->validator->validateClass($class);
 
-        $this->assertEquals(
+        self::assertEquals(
             [
                 'The association Doctrine\Tests\ORM\Tools\DDC3322Two#invalidAssoc is ordered by a field oneToMany ' .
                 'on Doctrine\Tests\ORM\Tools\DDC3322ValidEntity1 that is a collection-valued association.',
@@ -177,7 +193,7 @@ class SchemaValidatorTest extends OrmTestCase
         $class = $this->em->getClassMetadata(DDC3322Three::class);
         $ce    = $this->validator->validateClass($class);
 
-        $this->assertEquals(
+        self::assertEquals(
             [
                 'The association Doctrine\Tests\ORM\Tools\DDC3322Three#invalidAssoc is ordered by a field oneToOneInverse ' .
                 'on Doctrine\Tests\ORM\Tools\DDC3322ValidEntity1 that is the inverse side of an association.',
@@ -194,11 +210,51 @@ class SchemaValidatorTest extends OrmTestCase
         $class = $this->em->getClassMetadata(EmbeddableWithAssociation::class);
         $ce    = $this->validator->validateClass($class);
 
-        $this->assertEquals(
+        self::assertEquals(
             ["Embeddable 'Doctrine\Tests\ORM\Tools\EmbeddableWithAssociation' does not support associations"],
             $ce
         );
     }
+
+    /**
+     * @group 8771
+     */
+    public function testMappedSuperclassNotPresentInDiscriminator(): void
+    {
+        $class1 = $this->em->getClassMetadata(MappedSuperclassEntity::class);
+        $ce     = $this->validator->validateClass($class1);
+
+        $this->assertEquals([], $ce);
+    }
+}
+
+/**
+ * @MappedSuperclass
+ */
+abstract class MappedSuperclassEntity extends ParentEntity
+{
+}
+
+/**
+ * @Entity
+ * @InheritanceType("SINGLE_TABLE")
+ * @DiscriminatorMap({"child" = ChildEntity::class})
+ */
+abstract class ParentEntity
+{
+    /**
+     * @var mixed
+     * @Id
+     * @Column
+     */
+    protected $key;
+}
+
+/**
+ * @Entity
+ */
+class ChildEntity extends MappedSuperclassEntity
+{
 }
 
 /**
@@ -265,7 +321,8 @@ class DDC1587ValidEntity1
 {
     /**
      * @var int
-     * @Id @GeneratedValue
+     * @Id
+     * @GeneratedValue
      * @Column(name="pk", type="integer")
      */
     private $pk;
