@@ -4,15 +4,15 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\ORM\Tools;
 
-use Doctrine\Common\Cache\ArrayCache;
-use Doctrine\Common\Cache\Cache;
+use Doctrine\Common\Cache\Psr6\DoctrineProvider;
 use Doctrine\ORM\Configuration;
 use Doctrine\ORM\Mapping\Driver\AnnotationDriver;
+use Doctrine\ORM\Mapping\Driver\AttributeDriver;
 use Doctrine\ORM\Mapping\Driver\XmlDriver;
 use Doctrine\ORM\Mapping\Driver\YamlDriver;
 use Doctrine\ORM\Tools\Setup;
 use Doctrine\Tests\OrmTestCase;
-use Doctrine\Tests\VerifyDeprecations;
+use Symfony\Component\Cache\Adapter\ArrayAdapter;
 
 use function count;
 use function get_include_path;
@@ -23,8 +23,6 @@ use function sys_get_temp_dir;
 
 class SetupTest extends OrmTestCase
 {
-    use VerifyDeprecations;
-
     /** @var int */
     private $originalAutoloaderCount;
 
@@ -57,45 +55,46 @@ class SetupTest extends OrmTestCase
     {
         Setup::registerAutoloadDirectory(__DIR__ . '/../../../../../vendor/doctrine/common/lib');
 
-        $this->assertEquals($this->originalAutoloaderCount + 2, count(spl_autoload_functions()));
+        self::assertCount($this->originalAutoloaderCount + 2, spl_autoload_functions());
     }
 
     public function testAnnotationConfiguration(): void
     {
         $config = Setup::createAnnotationMetadataConfiguration([], true);
 
-        $this->assertInstanceOf(Configuration::class, $config);
-        $this->assertEquals(sys_get_temp_dir(), $config->getProxyDir());
-        $this->assertEquals('DoctrineProxies', $config->getProxyNamespace());
-        $this->assertInstanceOf(AnnotationDriver::class, $config->getMetadataDriverImpl());
+        self::assertInstanceOf(Configuration::class, $config);
+        self::assertEquals(sys_get_temp_dir(), $config->getProxyDir());
+        self::assertEquals('DoctrineProxies', $config->getProxyNamespace());
+        self::assertInstanceOf(AnnotationDriver::class, $config->getMetadataDriverImpl());
+    }
+
+    /**
+     * @requires PHP >= 8.0
+     */
+    public function testAttributeConfiguration(): void
+    {
+        $config = Setup::createAttributeMetadataConfiguration([], true);
+
+        self::assertInstanceOf(Configuration::class, $config);
+        self::assertEquals(sys_get_temp_dir(), $config->getProxyDir());
+        self::assertEquals('DoctrineProxies', $config->getProxyNamespace());
+        self::assertInstanceOf(AttributeDriver::class, $config->getMetadataDriverImpl());
     }
 
     public function testXMLConfiguration(): void
     {
         $config = Setup::createXMLMetadataConfiguration([], true);
 
-        $this->assertInstanceOf(Configuration::class, $config);
-        $this->assertInstanceOf(XmlDriver::class, $config->getMetadataDriverImpl());
+        self::assertInstanceOf(Configuration::class, $config);
+        self::assertInstanceOf(XmlDriver::class, $config->getMetadataDriverImpl());
     }
 
     public function testYAMLConfiguration(): void
     {
         $config = Setup::createYAMLMetadataConfiguration([], true);
 
-        $this->assertInstanceOf(Configuration::class, $config);
-        $this->assertInstanceOf(YamlDriver::class, $config->getMetadataDriverImpl());
-        $this->assertHasDeprecationMessages();
-    }
-
-    /**
-     * @group 5904
-     */
-    public function testCacheNamespaceShouldBeGeneratedWhenCacheIsNotGiven(): void
-    {
-        $config = Setup::createConfiguration(false, '/foo');
-        $cache  = $config->getMetadataCacheImpl();
-
-        self::assertSame('dc2_1effb2475fcfba4f9e8b8a1dbc8f3caf_', $cache->getNamespace());
+        self::assertInstanceOf(Configuration::class, $config);
+        self::assertInstanceOf(YamlDriver::class, $config->getMetadataDriverImpl());
     }
 
     /**
@@ -103,7 +102,7 @@ class SetupTest extends OrmTestCase
      */
     public function testCacheNamespaceShouldBeGeneratedWhenCacheIsGivenButHasNoNamespace(): void
     {
-        $config = Setup::createConfiguration(false, '/foo', new ArrayCache());
+        $config = Setup::createConfiguration(false, '/foo', DoctrineProvider::wrap(new ArrayAdapter()));
         $cache  = $config->getMetadataCacheImpl();
 
         self::assertSame('dc2_1effb2475fcfba4f9e8b8a1dbc8f3caf_', $cache->getNamespace());
@@ -114,12 +113,11 @@ class SetupTest extends OrmTestCase
      */
     public function testConfiguredCacheNamespaceShouldBeUsedAsPrefixOfGeneratedNamespace(): void
     {
-        $originalCache = new ArrayCache();
+        $originalCache = DoctrineProvider::wrap(new ArrayAdapter());
         $originalCache->setNamespace('foo');
 
         $config = Setup::createConfiguration(false, '/foo', $originalCache);
         $cache  = $config->getMetadataCacheImpl();
-
         self::assertSame($originalCache, $cache);
         self::assertSame('foo:dc2_1effb2475fcfba4f9e8b8a1dbc8f3caf_', $cache->getNamespace());
     }
@@ -130,7 +128,7 @@ class SetupTest extends OrmTestCase
     public function testConfigureProxyDir(): void
     {
         $config = Setup::createAnnotationMetadataConfiguration([], true, '/foo');
-        $this->assertEquals('/foo', $config->getProxyDir());
+        self::assertEquals('/foo', $config->getProxyDir());
     }
 
     /**
@@ -138,12 +136,16 @@ class SetupTest extends OrmTestCase
      */
     public function testConfigureCache(): void
     {
-        $cache  = new ArrayCache();
-        $config = Setup::createAnnotationMetadataConfiguration([], true, null, $cache);
+        $adapter = new ArrayAdapter();
+        $cache   = DoctrineProvider::wrap($adapter);
+        $config  = Setup::createAnnotationMetadataConfiguration([], true, null, $cache);
 
-        $this->assertSame($cache, $config->getResultCacheImpl());
-        $this->assertSame($cache, $config->getMetadataCacheImpl());
-        $this->assertSame($cache, $config->getQueryCacheImpl());
+        self::assertSame($adapter, $config->getResultCache()->getCache()->getPool());
+        self::assertSame($cache, $config->getResultCacheImpl());
+        self::assertSame($adapter, $config->getQueryCache()->getCache()->getPool());
+        self::assertSame($cache, $config->getQueryCacheImpl());
+
+        self::assertSame($adapter, $config->getMetadataCache()->getCache()->getPool());
     }
 
     /**
@@ -151,11 +153,15 @@ class SetupTest extends OrmTestCase
      */
     public function testConfigureCacheCustomInstance(): void
     {
-        $cache  = $this->createMock(Cache::class);
-        $config = Setup::createConfiguration(true, null, $cache);
+        $adapter = new ArrayAdapter();
+        $cache   = DoctrineProvider::wrap($adapter);
+        $config  = Setup::createConfiguration(true, null, $cache);
 
-        $this->assertSame($cache, $config->getResultCacheImpl());
-        $this->assertSame($cache, $config->getMetadataCacheImpl());
-        $this->assertSame($cache, $config->getQueryCacheImpl());
+        self::assertSame($adapter, $config->getResultCache()->getCache()->getPool());
+        self::assertSame($cache, $config->getResultCacheImpl());
+        self::assertSame($adapter, $config->getQueryCache()->getCache()->getPool());
+        self::assertSame($cache, $config->getQueryCacheImpl());
+
+        self::assertSame($adapter, $config->getMetadataCache()->getCache()->getPool());
     }
 }
