@@ -7,8 +7,17 @@ namespace Doctrine\Tests\ORM;
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\Common\Collections\Collection;
 use Doctrine\Common\EventManager;
+use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
+use Doctrine\ORM\EntityNotFoundException;
 use Doctrine\ORM\Events;
 use Doctrine\ORM\Mapping\ClassMetadata;
+use Doctrine\ORM\Mapping\Column;
+use Doctrine\ORM\Mapping\Entity;
+use Doctrine\ORM\Mapping\GeneratedValue;
+use Doctrine\ORM\Mapping\Id;
+use Doctrine\ORM\Mapping\ManyToOne;
+use Doctrine\ORM\Mapping\OneToMany;
+use Doctrine\ORM\Mapping\Version;
 use Doctrine\ORM\OptimisticLockException;
 use Doctrine\ORM\ORMInvalidArgumentException;
 use Doctrine\ORM\UnitOfWork;
@@ -27,14 +36,13 @@ use Doctrine\Tests\Models\Forum\ForumUser;
 use Doctrine\Tests\Models\GeoNames\City;
 use Doctrine\Tests\Models\GeoNames\Country;
 use Doctrine\Tests\OrmTestCase;
-use PHPUnit_Framework_MockObject_MockObject;
+use PHPUnit\Framework\MockObject\MockObject;
 use stdClass;
 
 use function assert;
 use function count;
 use function gc_collect_cycles;
 use function get_class;
-use function is_numeric;
 use function random_int;
 use function uniqid;
 
@@ -43,6 +51,8 @@ use function uniqid;
  */
 class UnitOfWorkTest extends OrmTestCase
 {
+    use VerifyDeprecations;
+
     /**
      * SUT
      *
@@ -53,7 +63,7 @@ class UnitOfWorkTest extends OrmTestCase
     /**
      * Provides a sequence mock to the UnitOfWork
      *
-     * @var ConnectionMock
+     * @var ConnectionMock&MockObject
      */
     private $_connectionMock;
 
@@ -64,7 +74,7 @@ class UnitOfWorkTest extends OrmTestCase
      */
     private $_emMock;
 
-    /** @var EventManager|PHPUnit_Framework_MockObject_MockObject */
+    /** @var EventManager&MockObject */
     private $eventManager;
 
     protected function setUp(): void
@@ -82,9 +92,9 @@ class UnitOfWorkTest extends OrmTestCase
     {
         $user           = new ForumUser();
         $user->username = 'romanb';
-        $this->assertFalse($this->_unitOfWork->isScheduledForDelete($user));
+        self::assertFalse($this->_unitOfWork->isScheduledForDelete($user));
         $this->_unitOfWork->scheduleForDelete($user);
-        $this->assertFalse($this->_unitOfWork->isScheduledForDelete($user));
+        self::assertFalse($this->_unitOfWork->isScheduledForDelete($user));
     }
 
     /* Operational tests */
@@ -102,12 +112,12 @@ class UnitOfWorkTest extends OrmTestCase
         $this->_unitOfWork->persist($user);
 
         // Check
-        $this->assertEquals(0, count($userPersister->getInserts()));
-        $this->assertEquals(0, count($userPersister->getUpdates()));
-        $this->assertEquals(0, count($userPersister->getDeletes()));
-        $this->assertFalse($this->_unitOfWork->isInIdentityMap($user));
+        self::assertCount(0, $userPersister->getInserts());
+        self::assertCount(0, $userPersister->getUpdates());
+        self::assertCount(0, $userPersister->getDeletes());
+        self::assertFalse($this->_unitOfWork->isInIdentityMap($user));
         // should no longer be scheduled for insert
-        $this->assertTrue($this->_unitOfWork->isScheduledForInsert($user));
+        self::assertTrue($this->_unitOfWork->isScheduledForInsert($user));
 
         // Now lets check whether a subsequent commit() does anything
         $userPersister->reset();
@@ -116,12 +126,12 @@ class UnitOfWorkTest extends OrmTestCase
         $this->_unitOfWork->commit();
 
         // Check.
-        $this->assertEquals(1, count($userPersister->getInserts()));
-        $this->assertEquals(0, count($userPersister->getUpdates()));
-        $this->assertEquals(0, count($userPersister->getDeletes()));
+        self::assertCount(1, $userPersister->getInserts());
+        self::assertCount(0, $userPersister->getUpdates());
+        self::assertCount(0, $userPersister->getDeletes());
 
         // should have an id
-        $this->assertTrue(is_numeric($user->id));
+        self::assertIsNumeric($user->id);
     }
 
     /**
@@ -149,16 +159,16 @@ class UnitOfWorkTest extends OrmTestCase
 
         $this->_unitOfWork->commit();
 
-        $this->assertTrue(is_numeric($user->id));
-        $this->assertTrue(is_numeric($avatar->id));
+        self::assertIsNumeric($user->id);
+        self::assertIsNumeric($avatar->id);
 
-        $this->assertEquals(1, count($userPersister->getInserts()));
-        $this->assertEquals(0, count($userPersister->getUpdates()));
-        $this->assertEquals(0, count($userPersister->getDeletes()));
+        self::assertCount(1, $userPersister->getInserts());
+        self::assertCount(0, $userPersister->getUpdates());
+        self::assertCount(0, $userPersister->getDeletes());
 
-        $this->assertEquals(1, count($avatarPersister->getInserts()));
-        $this->assertEquals(0, count($avatarPersister->getUpdates()));
-        $this->assertEquals(0, count($avatarPersister->getDeletes()));
+        self::assertCount(1, $avatarPersister->getInserts());
+        self::assertCount(0, $avatarPersister->getUpdates());
+        self::assertCount(0, $avatarPersister->getDeletes());
     }
 
     public function testChangeTrackingNotify(): void
@@ -173,18 +183,17 @@ class UnitOfWorkTest extends OrmTestCase
         $this->_unitOfWork->persist($entity);
 
         $this->_unitOfWork->commit();
-        $this->assertCount(1, $persister->getInserts());
-
+        self::assertCount(1, $persister->getInserts());
         $persister->reset();
 
-        $this->assertTrue($this->_unitOfWork->isInIdentityMap($entity));
+        self::assertTrue($this->_unitOfWork->isInIdentityMap($entity));
 
         $entity->setData('newdata');
         $entity->setTransient('newtransientvalue');
 
-        $this->assertTrue($this->_unitOfWork->isScheduledForDirtyCheck($entity));
+        self::assertTrue($this->_unitOfWork->isScheduledForDirtyCheck($entity));
 
-        $this->assertEquals(['data' => ['thedata', 'newdata']], $this->_unitOfWork->getEntityChangeSet($entity));
+        self::assertEquals(['data' => ['thedata', 'newdata']], $this->_unitOfWork->getEntityChangeSet($entity));
 
         $item = new NotifyChangedRelatedItem();
         $entity->getItems()->add($item);
@@ -192,17 +201,17 @@ class UnitOfWorkTest extends OrmTestCase
         $this->_unitOfWork->persist($item);
 
         $this->_unitOfWork->commit();
-        $this->assertEquals(1, count($itemPersister->getInserts()));
+        self::assertCount(1, $itemPersister->getInserts());
         $persister->reset();
         $itemPersister->reset();
 
         $entity->getItems()->removeElement($item);
         $item->setOwner(null);
-        $this->assertTrue($entity->getItems()->isDirty());
+        self::assertTrue($entity->getItems()->isDirty());
         $this->_unitOfWork->commit();
         $updates = $itemPersister->getUpdates();
-        $this->assertEquals(1, count($updates));
-        $this->assertTrue($updates[0] === $item);
+        self::assertCount(1, $updates);
+        self::assertSame($updates[0], $item);
     }
 
     public function testChangeTrackingNotifyIndividualCommit(): void
@@ -220,24 +229,27 @@ class UnitOfWorkTest extends OrmTestCase
 
         $this->_unitOfWork->persist($entity);
         $this->_unitOfWork->persist($entity2);
+
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/orm/issues/8459');
+
         $this->_unitOfWork->commit($entity);
         $this->_unitOfWork->commit();
 
-        $this->assertEquals(2, count($persister->getInserts()));
+        self::assertEquals(2, count($persister->getInserts()));
 
         $persister->reset();
 
-        $this->assertTrue($this->_unitOfWork->isInIdentityMap($entity2));
+        self::assertTrue($this->_unitOfWork->isInIdentityMap($entity2));
 
         $entity->setData('newdata');
         $entity2->setData('newdata');
 
         $this->_unitOfWork->commit($entity);
 
-        $this->assertTrue($this->_unitOfWork->isScheduledForDirtyCheck($entity2));
-        $this->assertEquals(['data' => ['thedata', 'newdata']], $this->_unitOfWork->getEntityChangeSet($entity2));
-        $this->assertFalse($this->_unitOfWork->isScheduledForDirtyCheck($entity));
-        $this->assertEquals([], $this->_unitOfWork->getEntityChangeSet($entity));
+        self::assertTrue($this->_unitOfWork->isScheduledForDirtyCheck($entity2));
+        self::assertEquals(['data' => ['thedata', 'newdata']], $this->_unitOfWork->getEntityChangeSet($entity2));
+        self::assertFalse($this->_unitOfWork->isScheduledForDirtyCheck($entity));
+        self::assertEquals([], $this->_unitOfWork->getEntityChangeSet($entity));
     }
 
     public function testGetEntityStateOnVersionedEntityWithAssignedIdentifier(): void
@@ -247,8 +259,8 @@ class UnitOfWorkTest extends OrmTestCase
 
         $e     = new VersionedAssignedIdentifierEntity();
         $e->id = 42;
-        $this->assertEquals(UnitOfWork::STATE_NEW, $this->_unitOfWork->getEntityState($e));
-        $this->assertFalse($persister->isExistsCalled());
+        self::assertEquals(UnitOfWork::STATE_NEW, $this->_unitOfWork->getEntityState($e));
+        self::assertFalse($persister->isExistsCalled());
     }
 
     public function testGetEntityStateWithAssignedIdentity(): void
@@ -259,19 +271,19 @@ class UnitOfWorkTest extends OrmTestCase
         $ph              = new CmsPhonenumber();
         $ph->phonenumber = '12345';
 
-        $this->assertEquals(UnitOfWork::STATE_NEW, $this->_unitOfWork->getEntityState($ph));
-        $this->assertTrue($persister->isExistsCalled());
+        self::assertEquals(UnitOfWork::STATE_NEW, $this->_unitOfWork->getEntityState($ph));
+        self::assertTrue($persister->isExistsCalled());
 
         $persister->reset();
 
         // if the entity is already managed the exists() check should be skipped
         $this->_unitOfWork->registerManaged($ph, ['phonenumber' => '12345'], []);
-        $this->assertEquals(UnitOfWork::STATE_MANAGED, $this->_unitOfWork->getEntityState($ph));
-        $this->assertFalse($persister->isExistsCalled());
+        self::assertEquals(UnitOfWork::STATE_MANAGED, $this->_unitOfWork->getEntityState($ph));
+        self::assertFalse($persister->isExistsCalled());
         $ph2              = new CmsPhonenumber();
         $ph2->phonenumber = '12345';
-        $this->assertEquals(UnitOfWork::STATE_DETACHED, $this->_unitOfWork->getEntityState($ph2));
-        $this->assertFalse($persister->isExistsCalled());
+        self::assertEquals(UnitOfWork::STATE_DETACHED, $this->_unitOfWork->getEntityState($ph2));
+        self::assertFalse($persister->isExistsCalled());
     }
 
     /**
@@ -363,13 +375,13 @@ class UnitOfWorkTest extends OrmTestCase
         $entity->id = 123;
 
         $this->_unitOfWork->registerManaged($entity, ['id' => 123], []);
-        $this->assertTrue($this->_unitOfWork->isInIdentityMap($entity));
+        self::assertTrue($this->_unitOfWork->isInIdentityMap($entity));
 
         $this->_unitOfWork->remove($entity);
-        $this->assertFalse($this->_unitOfWork->isInIdentityMap($entity));
+        self::assertFalse($this->_unitOfWork->isInIdentityMap($entity));
 
         $this->_unitOfWork->persist($entity);
-        $this->assertTrue($this->_unitOfWork->isInIdentityMap($entity));
+        self::assertTrue($this->_unitOfWork->isInIdentityMap($entity));
     }
 
     /**
@@ -382,16 +394,18 @@ class UnitOfWorkTest extends OrmTestCase
         $entity2 = new Country(456, 'United Kingdom');
 
         $this->_unitOfWork->persist($entity1);
-        $this->assertTrue($this->_unitOfWork->isInIdentityMap($entity1));
+        self::assertTrue($this->_unitOfWork->isInIdentityMap($entity1));
 
         $this->_unitOfWork->persist($entity2);
-        $this->assertTrue($this->_unitOfWork->isInIdentityMap($entity2));
+        self::assertTrue($this->_unitOfWork->isInIdentityMap($entity2));
+
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/orm/issues/8460');
 
         $this->_unitOfWork->clear(Country::class);
-        $this->assertTrue($this->_unitOfWork->isInIdentityMap($entity1));
-        $this->assertFalse($this->_unitOfWork->isInIdentityMap($entity2));
-        $this->assertTrue($this->_unitOfWork->isScheduledForInsert($entity1));
-        $this->assertFalse($this->_unitOfWork->isScheduledForInsert($entity2));
+        self::assertTrue($this->_unitOfWork->isInIdentityMap($entity1));
+        self::assertFalse($this->_unitOfWork->isInIdentityMap($entity2));
+        self::assertTrue($this->_unitOfWork->isScheduledForInsert($entity1));
+        self::assertFalse($this->_unitOfWork->isScheduledForInsert($entity2));
     }
 
     /**
@@ -408,6 +422,8 @@ class UnitOfWorkTest extends OrmTestCase
         $this->_unitOfWork->persist($entity1);
         $this->_unitOfWork->persist($entity2);
 
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/orm/issues/8459');
+
         $this->_unitOfWork->commit($entity1);
         self::assertEmpty($this->_unitOfWork->getEntityChangeSet($entity1));
         self::assertCount(1, $this->_unitOfWork->getEntityChangeSet($entity2));
@@ -430,6 +446,8 @@ class UnitOfWorkTest extends OrmTestCase
         $this->_unitOfWork->persist($entity2);
         $this->_unitOfWork->persist($entity3);
 
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/orm/issues/8459');
+
         $this->_unitOfWork->commit([$entity1, $entity3]);
 
         self::assertEmpty($this->_unitOfWork->getEntityChangeSet($entity1));
@@ -455,9 +473,11 @@ class UnitOfWorkTest extends OrmTestCase
     }
 
     /**
+     * @param object $entity
+     *
      * @dataProvider entitiesWithValidIdentifiersProvider
      */
-    public function testAddToIdentityMapValidIdentifiers(object $entity, string $idHash): void
+    public function testAddToIdentityMapValidIdentifiers($entity, string $idHash): void
     {
         $this->_unitOfWork->persist($entity);
         $this->_unitOfWork->addToIdentityMap($entity);
@@ -514,11 +534,12 @@ class UnitOfWorkTest extends OrmTestCase
     }
 
     /**
+     * @param object               $entity
      * @param array<string, mixed> $identifier
      *
      * @dataProvider entitiesWithInvalidIdentifiersProvider
      */
-    public function testAddToIdentityMapInvalidIdentifiers(object $entity, array $identifier): void
+    public function testAddToIdentityMapInvalidIdentifiers($entity, array $identifier): void
     {
         $this->expectException(ORMInvalidArgumentException::class);
 
@@ -687,9 +708,9 @@ class UnitOfWorkTest extends OrmTestCase
 
         $this->_unitOfWork->commit();
 
-        $this->assertCount(1, $persister1->getInserts());
-        $this->assertCount(1, $persister2->getInserts());
-        $this->assertCount(1, $persister3->getInserts());
+        self::assertCount(1, $persister1->getInserts());
+        self::assertCount(1, $persister2->getInserts());
+        self::assertCount(1, $persister3->getInserts());
     }
 
     /**
@@ -812,6 +833,12 @@ class UnitOfWorkTest extends OrmTestCase
         $this->expectException(OptimisticLockException::class);
         $this->_unitOfWork->commit();
     }
+
+    public function testItThrowsWhenLookingUpIdentifierForUnknownEntity(): void
+    {
+        $this->expectException(EntityNotFoundException::class);
+        $this->_unitOfWork->getEntityIdentifier(new stdClass());
+    }
 }
 
 /**
@@ -962,7 +989,8 @@ class VersionedAssignedIdentifierEntity
 class EntityWithStringIdentifier
 {
     /**
-     * @Id @Column(type="string")
+     * @Id
+     * @Column(type="string")
      * @var string|null
      */
     public $id;
@@ -972,7 +1000,8 @@ class EntityWithStringIdentifier
 class EntityWithBooleanIdentifier
 {
     /**
-     * @Id @Column(type="boolean")
+     * @Id
+     * @Column(type="boolean")
      * @var bool|null
      */
     public $id;
@@ -982,13 +1011,15 @@ class EntityWithBooleanIdentifier
 class EntityWithCompositeStringIdentifier
 {
     /**
-     * @Id @Column(type="string")
+     * @Id
+     * @Column(type="string")
      * @var string|null
      */
     public $id1;
 
     /**
-     * @Id @Column(type="string")
+     * @Id
+     * @Column(type="string")
      * @var string|null
      */
     public $id2;
