@@ -7,11 +7,13 @@ namespace Doctrine\Tests;
 use Doctrine\Common\EventSubscriber;
 use Doctrine\DBAL\Connection;
 use Doctrine\DBAL\DriverManager;
+use Doctrine\DBAL\Schema\AbstractSchemaManager;
 use UnexpectedValueException;
 
 use function explode;
 use function fwrite;
-use function get_class;
+use function get_debug_type;
+use function method_exists;
 use function sprintf;
 use function strlen;
 use function strpos;
@@ -76,7 +78,7 @@ class TestUtil
 
         // Note, writes direct to STDERR to prevent phpunit detecting output - otherwise this would cause either an
         // "unexpected output" warning or a failure on the first test case to call this method.
-        fwrite(STDERR, sprintf("\nUsing DB driver %s\n", get_class($testConn->getDriver())));
+        fwrite(STDERR, sprintf("\nUsing DB driver %s\n", get_debug_type($testConn->getDriver())));
 
         // Connect as a privileged user to create and drop the test database.
         $privConn = DriverManager::getConnection($privConnParams);
@@ -84,24 +86,29 @@ class TestUtil
         $platform = $privConn->getDatabasePlatform();
 
         if ($platform->supportsCreateDropDatabase()) {
-            $dbname = $testConn->getDatabase();
+            $dbname = $testConnParams['dbname'] ?? $testConn->getDatabase();
             $testConn->close();
 
-            $privConn->getSchemaManager()->dropAndCreateDatabase($dbname);
+            self::createSchemaManager($privConn)->dropAndCreateDatabase($dbname);
 
             $privConn->close();
         } else {
-            $sm = $testConn->getSchemaManager();
-
-            $schema = $sm->createSchema();
+            $schema = self::createSchemaManager($testConn)->createSchema();
             $stmts  = $schema->toDropSql($testConn->getDatabasePlatform());
 
             foreach ($stmts as $stmt) {
-                $testConn->exec($stmt);
+                $testConn->executeStatement($stmt);
             }
         }
     }
 
+    private static function createSchemaManager(Connection $connection): AbstractSchemaManager
+    {
+        return method_exists(Connection::class, 'createSchemaManager')
+            ? $connection->createSchemaManager()
+            : $connection->getSchemaManager();
+    }
+
     private static function addDbEventSubscribers(Connection $conn): void
     {
         if (! isset($GLOBALS['db_event_subscribers'])) {
